@@ -3,7 +3,7 @@
 #
 # Psi4: an open-source quantum chemistry software package
 #
-# Copyright (c) 2007-2017 The Psi4 Developers.
+# Copyright (c) 2007-2018 The Psi4 Developers.
 #
 # The copyrights for code used from other parties are included in
 # the corresponding files.
@@ -27,8 +27,37 @@
 #
 
 """Import plugins eligible to be accessible in input files if detected."""
+import sys
 
 try:
     import v2rdm_casscf
 except ImportError:
     pass
+
+try:
+    import gpu_dfcc
+except ImportError:
+    pass
+
+try:
+    import forte
+except ImportError:
+    pass
+
+try:
+    import snsmp2
+except ImportError as e:
+    if sys.version_info >= (3, 0):
+        errmsg = e.msg
+    else:
+        errmsg = e.message
+
+    if 'scipy' in errmsg:
+        raise ImportError("""Psi4 plugin 'snsmp2' available, but scipy missing. Try `conda install scipy` or `pip install scipy`.""")
+    else:
+        pass
+
+try:
+    import resp
+except ImportError:
+    pass
