@@ -3,7 +3,7 @@
 #
 # Psi4: an open-source quantum chemistry software package
 #
-# Copyright (c) 2007-2017 The Psi4 Developers.
+# Copyright (c) 2007-2018 The Psi4 Developers.
 #
 # The copyrights for code used from other parties are included in
 # the corresponding files.
@@ -25,7 +25,6 @@
 #
 # @END LICENSE
 #
-
 """Module with functions to parse the input file and convert
 Psithon into standard Python. Particularly, forms psi4
 module calls that access the C++ side of Psi4.
@@ -36,15 +35,15 @@ module calls that access the C++ side of Psi4.
 #if sys.hexversion < 0x03000000:
 from __future__ import print_function
 from __future__ import absolute_import
-
 import re
 import os
 import sys
 import uuid
-from psi4.driver import pubchem
-from psi4.driver.p4util.exceptions import *
-from psi4.driver.p4util.util import set_memory
+
 from psi4 import core
+from psi4.driver.qcdb.molparse import pubchem
+from psi4.driver.p4util.util import set_memory
+from psi4.driver.p4util.exceptions import *
 
 # globally available regex strings
 pubchemre = re.compile(r'^(\s*pubchem\s*:\s*(.*)\n)$', re.MULTILINE | re.IGNORECASE)
@@ -100,6 +99,7 @@ def quotify(string, isbasis=False):
     string = wordre.sub(process_word_quotes, string)
     return string
 
+
 def dequotify(string):
     if string[0] == '"' and string[-1] == '"':
         return string[1:-1]
@@ -180,13 +180,13 @@ def process_set_commands(matchobj):
 def process_from_file_command(matchobj):
     """Function that process a match of ``from_file`` in molecule block."""
     string = matchobj.group(2)
-    mol=core.mol_from_file(string,1)
-    tempmol=[line for line in mol.split('\n') if line.strip() != '']
-    mol2=set(tempmol)
-    mol=""
+    mol = core.mol_from_file(string, 1)
+    tempmol = [line for line in mol.split('\n') if line.strip() != '']
+    mol2 = set(tempmol)
+    mol = ""
     for i in mol2:
-           mol+=i
-           mol+="\n"
+        mol += i
+        mol += "\n"
     return mol
 
 
@@ -236,7 +236,7 @@ def process_molecule_command(matchobj):
     geometry = matchobj.group(3)
     geometry = pubchemre.sub(process_pubchem_command, geometry)
     from_filere = re.compile(r'^(\s*from_file\s*:\s*(.*)\n)$', re.MULTILINE | re.IGNORECASE)
-    geometry = from_filere.sub(process_from_file_command,geometry)
+    geometry = from_filere.sub(process_from_file_command, geometry)
     molecule = spaces
 
     if name != "":
@@ -329,7 +329,9 @@ def process_basis_block(matchobj):
     command_lines = re.split('\n', matchobj.group(4))
 
     symbol_re = re.compile(r'^\s*assign\s+(?P<symbol>[A-Z]{1,3})\s+(?P<basis>[-+*\(\)\w]+)\s*$', re.IGNORECASE)
-    label_re = re.compile(r'^\s*assign\s+(?P<label>(?P<symbol>[A-Z]{1,3})(?:(_\w+)|(\d+))?)\s+(?P<basis>[-+*\(\)\w]+)\s*$', re.IGNORECASE)
+    label_re = re.compile(
+        r'^\s*assign\s+(?P<label>(?P<symbol>[A-Z]{1,3})(?:(_\w+)|(\d+))?)\s+(?P<basis>[-+*\(\)\w]+)\s*$',
+        re.IGNORECASE)
     all_re = re.compile(r'^\s*assign\s+(?P<basis>[-+*\(\)\w]+)\s*$', re.IGNORECASE)
     basislabel = re.compile(r'\s*\[\s*([-*\(\)\w]+)\s*\]\s*')
 
@@ -386,23 +388,23 @@ def process_basis_block(matchobj):
 
 def process_pcm_command(matchobj):
     """Function to process match of ``pcm name? { ... }``."""
-    spacing = str(matchobj.group(1)) # Ignore..
-    name = str(matchobj.group(2)) # Ignore..
-    block = str(matchobj.group(3)) # Get input to PCMSolver
-    # Setup unique scratch directory and move in, as done for other add-ons
-    psioh = core.IOManager.shared_object()
-    psio = core.IO.shared_object()
-    os.chdir(psioh.get_default_path())
-    pcm_tmpdir = 'psi.' + str(os.getpid()) + '.' + psio.get_default_namespace() + \
-        'pcmsolver.' + str(uuid.uuid4())[:8]
-    if os.path.exists(pcm_tmpdir) is False:
-        os.mkdir(pcm_tmpdir)
-    os.chdir(pcm_tmpdir)
-    with open('pcmsolver.inp', 'w') as handle:
+    spacing = str(matchobj.group(1))  # Ignore..
+    name = str(matchobj.group(2))  # Ignore..
+    block = str(matchobj.group(3))  # Get input to PCMSolver
+    suffix = str(os.getpid()) + '.' + str(uuid.uuid4())[:8]
+    pcmsolver_fname = 'pcmsolver.' + suffix + '.inp'
+    with open(pcmsolver_fname, 'w') as handle:
         handle.write(block)
     import pcmsolver
-    pcmsolver.parse_pcm_input('pcmsolver.inp')
-    return "" # The file has been written to disk; nothing needed in Psi4 input
+    parsed_pcm = pcmsolver.parse_pcm_input(pcmsolver_fname).splitlines()
+    os.remove(pcmsolver_fname)
+    pcmsolver_parsed_fname = '@pcmsolver.' + suffix
+    write_input_for_pcm = "parsedFile = os.path.join(os.getcwd(), '{}')\n".format(pcmsolver_parsed_fname)
+    write_input_for_pcm += "with open(parsedFile, 'w') as tmp:\n"
+    write_input_for_pcm += "    tmp.write('\\n'.join({}))\n\n".format(parsed_pcm)
+    write_input_for_pcm += "core.set_global_option(\'PCMSOLVER_PARSED_FNAME\', \'{}\')\n\n".format(
+        pcmsolver_parsed_fname)
+    return write_input_for_pcm
 
 
 def process_external_command(matchobj):
@@ -472,9 +474,11 @@ def process_external_command(matchobj):
         mobj = charge_re.match(line)
         if mobj:
             if units == 'ang':
-                extern += '%sqmmm.addChargeAngstrom(%s,%s,%s,%s)\n' % (spaces, mobj.group(1), mobj.group(2), mobj.group(3), mobj.group(4))
+                extern += '%sqmmm.addChargeAngstrom(%s,%s,%s,%s)\n' % (spaces, mobj.group(1), mobj.group(2),
+                                                                       mobj.group(3), mobj.group(4))
             if units == 'bohr':
-                extern += '%sqmmm.addChargeBohr(%s,%s,%s,%s)\n' % (spaces, mobj.group(1), mobj.group(2), mobj.group(3), mobj.group(4))
+                extern += '%sqmmm.addChargeBohr(%s,%s,%s,%s)\n' % (spaces, mobj.group(1), mobj.group(2), mobj.group(3),
+                                                                   mobj.group(4))
         else:
             lines2.append(line)
     lines = lines2
@@ -676,8 +680,7 @@ def process_input(raw_input, print_level=1):
     #   Must be stored then subbed in the end to escape the normal processing
 
     # Process "cfour name? { ... }"
-    cfour = re.compile(r'^(\s*?)cfour[=\s]*(\w*?)\s*\{(.*?)\}',
-                          re.MULTILINE | re.DOTALL | re.IGNORECASE)
+    cfour = re.compile(r'^(\s*?)cfour[=\s]*(\w*?)\s*\{(.*?)\}', re.MULTILINE | re.DOTALL | re.IGNORECASE)
     temp = re.sub(cfour, process_cfour_command, raw_input)
 
     # Return from handling literal blocks to normal processing
@@ -706,31 +709,28 @@ def process_input(raw_input, print_level=1):
     temp = process_multiline_arrays(temp)
 
     # Process all "set name? { ... }"
-    set_commands = re.compile(r'^(\s*?)set\s*([-,\w]*?)[\s=]*\{(.*?)\}',
-                              re.MULTILINE | re.DOTALL | re.IGNORECASE)
+    set_commands = re.compile(r'^(\s*?)set\s*([-,\w]*?)[\s=]*\{(.*?)\}', re.MULTILINE | re.DOTALL | re.IGNORECASE)
     temp = re.sub(set_commands, process_set_commands, temp)
 
     # Process all individual "set (module_list) key  {[value_list] or $value or value}"
     # N.B. We have to be careful here, because \s matches \n, leading to potential problems
     # with undesired multiline matches.  Better the double-negative [^\S\n] instead, which
     # will match any space, tab, etc., except a newline
-    set_command = re.compile(r'^(\s*?)set\s+(?:([-,\w]+)[^\S\n]+)?(\w+)(?:[^\S\n]|=)+((\[.*\])|(\$?[-+,*()\.\w]+))\s*$',
-                             re.MULTILINE | re.IGNORECASE)
+    set_command = re.compile(
+        r'^(\s*?)set\s+(?:([-,\w]+)[^\S\n]+)?(\w+)(?:[^\S\n]|=)+((\[.*\])|(\$?[-+,*()\.\w]+))\s*$',
+        re.MULTILINE | re.IGNORECASE)
     temp = re.sub(set_command, process_set_command, temp)
 
     # Process "molecule name? { ... }"
-    molecule = re.compile(r'^(\s*?)molecule[=\s]*(\S*?)\s*\{(.*?)\}',
-                          re.MULTILINE | re.DOTALL | re.IGNORECASE)
+    molecule = re.compile(r'^(\s*?)molecule[=\s]*(\S*?)\s*\{(.*?)\}', re.MULTILINE | re.DOTALL | re.IGNORECASE)
     temp = re.sub(molecule, process_molecule_command, temp)
 
     # Process "external name? { ... }"
-    external = re.compile(r'^(\s*?)external[=\s]*(\w*?)\s*\{(.*?)\}',
-                          re.MULTILINE | re.DOTALL | re.IGNORECASE)
+    external = re.compile(r'^(\s*?)external[=\s]*(\w*?)\s*\{(.*?)\}', re.MULTILINE | re.DOTALL | re.IGNORECASE)
     temp = re.sub(external, process_external_command, temp)
 
     # Process "pcm name? { ... }"
-    pcm = re.compile(r'^(\s*?)pcm[=\s]*(\w*?)\s*\{(.*?)^\}',
-                          re.MULTILINE | re.DOTALL | re.IGNORECASE)
+    pcm = re.compile(r'^(\s*?)pcm[=\s]*(\w*?)\s*\{(.*?)^\}', re.MULTILINE | re.DOTALL | re.IGNORECASE)
     temp = re.sub(pcm, process_pcm_command, temp)
 
     # Then remove repeated newlines
@@ -738,8 +738,7 @@ def process_input(raw_input, print_level=1):
     temp = re.sub(multiplenewlines, '\n', temp)
 
     # Process " extract"
-    extract = re.compile(r'(\s*?)(\w+)\s*=\s*\w+\.extract_subsets.*',
-                         re.IGNORECASE)
+    extract = re.compile(r'(\s*?)(\w+)\s*=\s*\w+\.extract_subsets.*', re.IGNORECASE)
     temp = re.sub(extract, process_extract_command, temp)
 
     # Process "print" and transform it to "core.print_out()"
@@ -747,20 +746,21 @@ def process_input(raw_input, print_level=1):
     #temp = re.sub(print_string, process_print_command, temp)
 
     # Process "memory ... "
-    memory_string = re.compile(r'(\s*?)memory\s+(\d*\.?\d+)\s*([KMGTPBE]i?B)',
-                               re.IGNORECASE)
+    memory_string = re.compile(r'(\s*?)memory\s+(\d*\.?\d+)\s*([KMGTPBE]i?B)', re.IGNORECASE)
     temp = re.sub(memory_string, process_memory_command, temp)
 
     # Process "basis name? { ... }"
-    basis_block = re.compile(r'^(\s*?)(basis|df_basis_scf|df_basis_mp2|df_basis_cc|df_basis_sapt)[=\s]*(\w*?)\s*\{(.*?)\}',
-                             re.MULTILINE | re.DOTALL | re.IGNORECASE)
+    basis_block = re.compile(
+        r'^(\s*?)(basis|df_basis_scf|df_basis_mp2|df_basis_cc|df_basis_sapt)[=\s]*(\w*?)\s*\{(.*?)\}',
+        re.MULTILINE | re.DOTALL | re.IGNORECASE)
     temp = re.sub(basis_block, process_basis_block, temp)
 
     # Process literal blocks by substituting back in
-    lit_block = re.compile(r'literals_psi4_yo-(\d*\d)')
+    lit_block = re.compile(r'literals_psi4_yo-(\w{8})')
     temp = re.sub(lit_block, process_literal_blocks, temp)
 
     future_imports = []
+
     def future_replace(m):
         future_imports.append(m.group(0))
         return ''
@@ -775,6 +775,7 @@ def process_input(raw_input, print_level=1):
     imports += 'from psi4.core import *\n'
     imports += 'from psi4.driver.diatomic import anharmonicity\n'
     imports += 'from psi4.driver.gaussian_n import *\n'
+    imports += 'from psi4.driver.frac import ip_fitting, frac_traverse\n'
     imports += 'from psi4.driver.aliases import *\n'
     imports += 'from psi4.driver.driver_cbs import *\n'
     imports += 'from psi4.driver.wrapper_database import database, db, DB_RGT, DB_RXN\n'
@@ -792,17 +793,11 @@ def process_input(raw_input, print_level=1):
     else:
         psirc = ''
 
-    # Override scratch directory if user specified via env_var
-    scratch = ''
-    scratch_env = core.get_environment('PSI_SCRATCH')
-    if len(scratch_env):
-        scratch += 'psi4_io.set_default_path("%s")\n' % (scratch_env)
-
     blank_mol = 'geometry("""\n'
     blank_mol += '0 1\nH\nH 1 0.74\n'
     blank_mol += '""","blank_molecule_psi4_yo")\n'
 
-    temp = imports + psirc + scratch + blank_mol + temp
+    temp = imports + psirc + blank_mol + temp
 
     # Move up the psi4.core namespace
     for func in dir(core):
