@@ -3,7 +3,7 @@
 #
 # Psi4: an open-source quantum chemistry software package
 #
-# Copyright (c) 2007-2017 The Psi4 Developers.
+# Copyright (c) 2007-2018 The Psi4 Developers.
 #
 # The copyrights for code used from other parties are included in
 # the corresponding files.
@@ -28,9 +28,8 @@
 
 from __future__ import absolute_import
 
-import sys, os
+import os
 import math
-from math import *
 from datetime import date
 
 class InPsight:
@@ -343,7 +342,7 @@ class InPsight:
                 b2 = self.atoms[l][7];
                 t2 = self.atoms[l][8];
 
-                R = sqrt((x1-x2)*(x1-x2) + \
+                R = math.sqrt((x1-x2)*(x1-x2) + \
                          (y1-y2)*(y1-y2) + \
                          (z1-z2)*(z1-z2))
 
@@ -374,7 +373,7 @@ class InPsight:
         natom = self.molecule.natom()
         for k in range(0,natom):
             x = [self.molecule.x(k), self.molecule.y(k), self.molecule.z(k)]
-            R = sqrt((x[0] - xc[0])*(x[0] - xc[0]) + \
+            R = math.sqrt((x[0] - xc[0])*(x[0] - xc[0]) + \
                      (x[1] - xc[1])*(x[1] - xc[1]) + \
                      (x[2] - xc[2])*(x[2] - xc[2]))
             if R > Rmax:
