@@ -3,7 +3,7 @@
 #
 # Psi4: an open-source quantum chemistry software package
 #
-# Copyright (c) 2007-2017 The Psi4 Developers.
+# Copyright (c) 2007-2018 The Psi4 Developers.
 #
 # The copyrights for code used from other parties are included in
 # the corresponding files.
@@ -25,14 +25,15 @@
 #
 # @END LICENSE
 #
-
 """Module with utility functions for use in input files."""
 from __future__ import division
+import os
 import re
 import sys
-import os
 import math
+
 import numpy as np
+
 from .exceptions import *
 
 
@@ -91,10 +92,9 @@ def cubeprop(wfn, **kwargs):
     """
     # By default compute the orbitals
     if not core.has_global_option_changed('CUBEPROP_TASKS'):
-        core.set_global_option('CUBEPROP_TASKS',['ORBITALS'])
+        core.set_global_option('CUBEPROP_TASKS', ['ORBITALS'])
 
-    if ((core.get_global_option('INTEGRAL_PACKAGE') == 'ERD') and
-        ('ESP' in core.get_global_option('CUBEPROP_TASKS'))):
+    if ((core.get_global_option('INTEGRAL_PACKAGE') == 'ERD') and ('ESP' in core.get_global_option('CUBEPROP_TASKS'))):
         raise ValidationError('INTEGRAL_PACKAGE ERD does not play nicely with electrostatic potential, so stopping.')
 
     cp = core.CubeProperties(wfn)
@@ -124,26 +124,24 @@ def set_memory(inputval, execute=True):
     >>> psi4.get_memory()
     Out[2]: 30000000000L
 
-    :good examples:
+    >>> # Good examples
+    >>> psi4.set_memory(800000000)        # 800000000
+    >>> psi4.set_memory(2004088624.9)     # 2004088624
+    >>> psi4.set_memory(1.0e9)            # 1000000000
+    >>> psi4.set_memory('600 mb')         # 600000000
+    >>> psi4.set_memory('600.0 MiB')      # 629145600
+    >>> psi4.set_memory('.6 Gb')          # 600000000
+    >>> psi4.set_memory(' 100000000kB ')  # 100000000000
+    >>> psi4.set_memory('2 eb')           # 2000000000000000000
 
-    800000000         # 800000000
-    2004088624.9      # 2004088624
-    1.0e9             # 1000000000
-    '600 mb'          # 600000000
-    '600.0 MiB'       # 629145600
-    '.6 Gb'           # 600000000
-    ' 100000000kB '   # 100000000000
-    '2 eb'            # 2000000000000000000
-
-    :bad examples:
-
-    {}         # odd type
-    ''         # no info
-    "8 dimms"  # unacceptable units
-    "1e5 gb"   # string w/ exponent
-    "5e5"      # string w/o units
-    2000       # mem too small
-    -5e5       # negative (and too small)
+    >>> # Bad examples
+    >>> psi4.set_memory({})         # odd type
+    >>> psi4.set_memory('')         # no info
+    >>> psi4.set_memory("8 dimms")  # unacceptable units
+    >>> psi4.set_memory("1e5 gb")   # string w/ exponent
+    >>> psi4.set_memory("5e5")      # string w/o units
+    >>> psi4.set_memory(2000)       # mem too small
+    >>> psi4.set_memory(-5e5)       # negative (and too small)
 
     """
     # Handle memory given in bytes directly (int or float)
@@ -182,13 +180,15 @@ def set_memory(inputval, execute=True):
     # Check minimum memory requirement
     min_mem_allowed = 262144000
     if memory_amount < min_mem_allowed:
-        raise ValidationError("""set_memory(): Requested {:.3} MiB ({:.3} MB); minimum 250 MiB (263 MB). Please, sir, I want some more.""".format(
-                memory_amount / 1024 ** 2, memory_amount / 1000 ** 2))
+        raise ValidationError(
+            """set_memory(): Requested {:.3} MiB ({:.3} MB); minimum 250 MiB (263 MB). Please, sir, I want some more.""".format(
+                memory_amount / 1024**2, memory_amount / 1000**2))
 
     if execute:
         core.set_memory_bytes(memory_amount)
     return memory_amount
 
+
 def get_memory():
     """Function to return the total memory allocation."""
     return core.get_memory()
@@ -216,7 +216,8 @@ def compare_values(expected, computed, digits, label, exitonfail=True):
     """
     if digits > 1:
         thresh = 10 ** -digits
-        message = ("\t%s: computed value (%.*f) does not match (%.*f) to %d digits." % (label, digits+1, computed, digits+1, expected, digits))
+        message = """\t{}: computed value ({:.{digits1}f}) does not match ({:.{digits1}f}) to {digits} digits.""".format(
+                  label, computed, expected, digits1=int(digits)+1, digits=digits)
     else:
         thresh = digits
         message = ("\t%s: computed value (%f) does not match (%f) to %f digits." % (label, computed, expected, digits))
@@ -252,7 +253,7 @@ def compare_strings(expected, computed, label):
     Performs a system exit on failure. Used in input files in the test suite.
 
     """
-    if(expected != computed):
+    if (expected != computed):
         message = ("\t%s: computed value (%s) does not match (%s)." % (label, computed, expected))
         raise TestComparisonError(message)
     success(label)
@@ -267,31 +268,36 @@ def compare_matrices(expected, computed, digits, label):
 
     """
     if (expected.nirrep() != computed.nirrep()):
-        message = ("\t%s has %d irreps, but %s has %d\n." % (expected.name(), expected.nirrep(), computed.name(), computed.nirrep()))
+        message = ("\t%s has %d irreps, but %s has %d\n." %
+                   (expected.name(), expected.nirrep(), computed.name(), computed.nirrep()))
         raise TestComparisonError(message)
     if (expected.symmetry() != computed.symmetry()):
-        message = ("\t%s has %d symmetry, but %s has %d\n." % (expected.name(), expected.symmetry(), computed.name(), computed.symmetry()))
+        message = ("\t%s has %d symmetry, but %s has %d\n." %
+                   (expected.name(), expected.symmetry(), computed.name(), computed.symmetry()))
         raise TestComparisonError(message)
     nirreps = expected.nirrep()
     symmetry = expected.symmetry()
     for irrep in range(nirreps):
-        if(expected.rows(irrep) != computed.rows(irrep)):
-            message = ("\t%s has %d rows in irrep %d, but %s has %d\n." % (expected.name(), expected.rows(irrep), irrep, computed.name(), computed.rows(irrep)))
+        if (expected.rows(irrep) != computed.rows(irrep)):
+            message = ("\t%s has %d rows in irrep %d, but %s has %d\n." %
+                       (expected.name(), expected.rows(irrep), irrep, computed.name(), computed.rows(irrep)))
             raise TestComparisonError(message)
-        if(expected.cols(irrep ^ symmetry) != computed.cols(irrep ^ symmetry)):
-            message = ("\t%s has %d columns in irrep, but %s has %d\n." % (expected.name(), expected.cols(irrep), irrep, computed.name(), computed.cols(irrep)))
+        if (expected.cols(irrep ^ symmetry) != computed.cols(irrep ^ symmetry)):
+            message = ("\t%s has %d columns in irrep, but %s has %d\n." %
+                       (expected.name(), expected.cols(irrep), irrep, computed.name(), computed.cols(irrep)))
             raise TestComparisonError(message)
         rows = expected.rows(irrep)
         cols = expected.cols(irrep ^ symmetry)
         failed = 0
         for row in range(rows):
             for col in range(cols):
-                if(abs(expected.get(irrep, row, col) - computed.get(irrep, row, col)) > 10 ** (-digits)):
-                    print("\t%s: computed value (%s) does not match (%s)." % (label, expected.get(irrep, row, col), computed.get(irrep, row, col)))
+                if (abs(expected.get(irrep, row, col) - computed.get(irrep, row, col)) > 10**(-digits)):
+                    print("\t%s: computed value (%s) does not match (%s)." %
+                          (label, expected.get(irrep, row, col), computed.get(irrep, row, col)))
                     failed = 1
                     break
 
-        if(failed):
+        if (failed):
             print("Check your output file for reporting of the matrices.")
             core.print_out("The Failed Test Matrices\n")
             core.print_out("Computed Matrix (2nd matrix passed in)\n")
@@ -311,26 +317,29 @@ def compare_vectors(expected, computed, digits, label):
 
     """
     if (expected.nirrep() != computed.nirrep()):
-        message = ("\t%s has %d irreps, but %s has %d\n." % (expected.name(), expected.nirrep(), computed.name(), computed.nirrep()))
+        message = ("\t%s has %d irreps, but %s has %d\n." %
+                   (expected.name(), expected.nirrep(), computed.name(), computed.nirrep()))
         raise TestComparisonError(message)
     nirreps = expected.nirrep()
     for irrep in range(nirreps):
-        if(expected.dim(irrep) != computed.dim(irrep)):
-            message = ("\tThe reference has %d entries in irrep %d, but the computed vector has %d\n." % (expected.dim(irrep), irrep, computed.dim(irrep)))
+        if (expected.dim(irrep) != computed.dim(irrep)):
+            message = ("\tThe reference has %d entries in irrep %d, but the computed vector has %d\n." %
+                       (expected.dim(irrep), irrep, computed.dim(irrep)))
             raise TestComparisonError(message)
         dim = expected.dim(irrep)
         failed = 0
         for entry in range(dim):
-            if(abs(expected.get(irrep, entry) - computed.get(irrep, entry)) > 10 ** (-digits)):
+            if (abs(expected.get(irrep, entry) - computed.get(irrep, entry)) > 10**(-digits)):
                 failed = 1
                 break
 
-        if(failed):
+        if (failed):
             core.print_out("The computed vector\n")
             computed.print_out()
             core.print_out("The reference vector\n")
             expected.print_out()
-            message = ("\t%s: computed value (%s) does not match (%s)." % (label, computed.get(irrep, entry), expected.get(irrep, entry)))
+            message = ("\t%s: computed value (%s) does not match (%s)." %
+                       (label, computed.get(irrep, entry), expected.get(irrep, entry)))
             raise TestComparisonError(message)
     success(label)
     return True
@@ -345,6 +354,8 @@ def compare_arrays(expected, computed, digits, label):
     """
 
     try:
+        expected = np.asarray(expected)
+        computed = np.asarray(computed)
         shape1 = expected.shape
         shape2 = computed.shape
     except:
@@ -353,7 +364,7 @@ def compare_arrays(expected, computed, digits, label):
     if shape1 != shape2:
         TestComparisonError("Input shapes do not match.")
 
-    tol = 10 ** (-digits)
+    tol = 10**(-digits)
     if not np.allclose(expected, computed, atol=tol):
         message = "\tArray difference norm is %12.6f." % np.linalg.norm(expected - computed)
         raise TestComparisonError(message)
@@ -367,21 +378,19 @@ def compare_cubes(expected, computed, label):
     Performs a system exit on failure. Used in input files in the test suite.
 
     """
-    # Skip the first six elemets which are just labels
-    evec = [float(k) for k in expected.split()[6:]]
-    cvec = [float(k) for k in computed.split()[6:]]
-    if len(evec) == len(cvec):
-        for n in range(len(evec)):
-            if (math.fabs(evec[n]-cvec[n]) > 1.0e-4):
-                message = ("\t%s: computed cube file does not match expected cube file." % label)
-                raise TestComparisonError(message)
+    # Grab grid points. Skip the first nine lines and the last one
+    evec = np.genfromtxt(expected, skip_header=9, skip_footer=1)
+    cvec = np.genfromtxt(computed, skip_header=9, skip_footer=1)
+    if evec.size == cvec.size:
+        if not np.allclose(cvec, evec, rtol=5e-05, atol=1e-10):
+            message = ("\t%s: computed cube file does not match expected cube file." % label)
+            raise TestComparisonError(message)
     else:
-        message = ("\t%s: computed cube file does not match expected cube file." % (label, computed, expected))
+        message = ("\t%s: computed cube file does not match size of expected cube file." % label)
         raise TestComparisonError(message)
     success(label)
     return True
 
-
 # Uncomment and use if compare_arrays above is inadequate
 #def compare_lists(expected, computed, digits, label):
 #    """Function to compare two Python lists. Prints :py:func:`util.success`
@@ -411,8 +420,7 @@ def compare_cubes(expected, computed, label):
 #    success(label)
 
 
-def copy_file_to_scratch(filename, prefix, namespace, unit, move = False):
-
+def copy_file_to_scratch(filename, prefix, namespace, unit, move=False):
     """Function to move file into scratch with correct naming
     convention.
 
@@ -442,9 +450,9 @@ def copy_file_to_scratch(filename, prefix, namespace, unit, move = False):
     pid = str(os.getpid())
     scratch = core.IOManager.shared_object().get_file_path(int(unit))
 
-    cp = '/bin/cp';
+    cp = '/bin/cp'
     if move:
-        cp = '/bin/mv';
+        cp = '/bin/mv'
 
     unit = str(unit)
 
@@ -463,8 +471,8 @@ def copy_file_to_scratch(filename, prefix, namespace, unit, move = False):
     os.system(command)
     #print command
 
-def copy_file_from_scratch(filename, prefix, namespace, unit, move = False):
 
+def copy_file_from_scratch(filename, prefix, namespace, unit, move=False):
     """Function to move file out of scratch with correct naming
     convention.
 
@@ -494,9 +502,9 @@ def copy_file_from_scratch(filename, prefix, namespace, unit, move = False):
     pid = str(os.getpid())
     scratch = core.IOManager.shared_object().get_file_path(int(unit))
 
-    cp = '/bin/cp';
+    cp = '/bin/cp'
     if move:
-        cp = '/bin/mv';
+        cp = '/bin/mv'
 
     unit = str(unit)
 
@@ -541,7 +549,8 @@ def csx2endict():
     dictionary.
 
     """
-    blockprefix = ['chemicalSemantics', 'molecularCalculation', 'quantumMechanics', 'singleReferenceState', 'singleDeterminant']
+    blockprefix = ['chemicalSemantics', 'molecularCalculation', 'quantumMechanics', 'singleReferenceState',
+                   'singleDeterminant']
     blockmidfix = ['energies', 'energy']
     prefix = 'cs:'
 
