@@ -3,7 +3,7 @@
 #
 # Psi4: an open-source quantum chemistry software package
 #
-# Copyright (c) 2007-2017 The Psi4 Developers.
+# Copyright (c) 2007-2018 The Psi4 Developers.
 #
 # The copyrights for code used from other parties are included in
 # the corresponding files.
@@ -29,4 +29,5 @@
 from .proc_table import procedures, hooks, energy_only_methods
 from .proc import scf_helper, scf_wavefunction_factory
 from .empirical_dispersion import EmpericalDispersion
-from . import dft_functional
+from . import dft_funcs
+from . import response
