@@ -3,7 +3,7 @@
 #
 # Psi4: an open-source quantum chemistry software package
 #
-# Copyright (c) 2007-2017 The Psi4 Developers.
+# Copyright (c) 2007-2018 The Psi4 Developers.
 #
 # The copyrights for code used from other parties are included in
 # the corresponding files.
@@ -31,14 +31,14 @@ functions: :py:mod:`driver.energy`, :py:mod:`driver.optimize`,
 :py:mod:`driver.response`, and :py:mod:`driver.frequency`.
 
 """
+from __future__ import print_function
 from __future__ import absolute_import
-import re
 import os
+import re
 import math
-import warnings
 import pickle
-import copy
 import collections
+
 from psi4.driver import constants
 from psi4.driver.driver import *
 # never import aliases into this file
@@ -220,6 +220,7 @@ def database(name, db_name, **kwargs):
     if kwargs.get('bsse_type', None) is not None:
         raise ValidationError("""Database: Cannot specify bsse_type for database. Use the cp keyword withing database instead.""")
 
+    allowoptexceeded = kwargs.get('allowoptexceeded', False)
     optstash = p4util.OptionsState(
         ['WRITER_FILE_LABEL'],
         ['SCF', 'REFERENCE'])
@@ -228,7 +229,7 @@ def database(name, db_name, **kwargs):
     kwargs.pop('molecule', None)
 
     # Paths to search for database files: here + PSIPATH + library + PYTHONPATH
-    psidatadir = os.environ.get('PSIDATADIR', None)
+    psidatadir = core.get_datadir()
     #nolongerpredictable psidatadir = __file__ + '/../..' if psidatadir is None else psidatadir
     libraryPath = ':' + os.path.abspath(psidatadir) + '/databases'
     driver_loc = os.path.dirname(os.path.abspath(__file__))
@@ -532,14 +533,21 @@ def database(name, db_name, **kwargs):
         if db_mode == 'continuous':
             exec(banners)
 
-            molecule = core.Molecule.create_molecule_from_string(GEOS[rgt].create_psi4_string_from_molecule())
+            molecule = core.Molecule.from_dict(GEOS[rgt].to_dict())
             molecule.set_name(rgt)
             molecule.update_geometry()
 
             exec(commands)
             #print 'MOLECULE LIVES %23s %8s %4d %4d %4s' % (rgt, core.get_global_option('REFERENCE'),
             #    molecule.molecular_charge(), molecule.multiplicity(), molecule.schoenflies_symbol())
-            ERGT[rgt] = func(molecule=molecule, **kwargs)
+            if allowoptexceeded:
+                try:
+                    ERGT[rgt] = func(molecule=molecule, **kwargs)
+                except ConvergenceError:
+                    core.print_out("Optimization exceeded cycles for %s" % (rgt))
+                    ERGT[rgt] = 0.0
+            else:
+                ERGT[rgt] = func(molecule=molecule, **kwargs)
             core.print_variables()
             exec(actives)
             for envv in db_tabulate:
@@ -632,7 +640,8 @@ def database(name, db_name, **kwargs):
         db_rxn = dbse + '-' + str(rxn)
         for i in range(len(ACTV[db_rxn])):
             if abs(ERGT[ACTV[db_rxn][i]]) < 1.0e-12:
-                FAIL[rxn] = 1
+                if not allowoptexceeded:
+                    FAIL[rxn] = 1
 
     #   tabulate requested process::environment variables
     tables += """   For each VARIABLE requested by tabulate, a 'Reaction Value' will be formed from\n"""
