@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -287,7 +287,9 @@
 #define PSIF_DFOCC_AMPS        277  /*- DFOCC Amplitudes -*/
 #define PSIF_DFOCC_DENS        278  /*- DFOCC PDMs -*/
 #define PSIF_DFOCC_IABC        279  /*- DFOCC (IA|BC) -*/ 
-#define PSIF_DFOCC_TEMP        280  /*- DFOCC temporary storage -*/
+#define PSIF_DFOCC_ABIC        280  /*- DFOCC <AB|IC> -*/ 
+#define PSIF_DFOCC_MIABC       281  /*- DFOCC M_iabc -*/ 
+#define PSIF_DFOCC_TEMP        282  /*- DFOCC temporary storage -*/
 
 #define PSIF_SAD               300  /*- A SAD file (File for SAD related quantities -*/
 
