@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -32,8 +32,7 @@
 
 using namespace psi;
 
-void export_misc(py::module &m)
-{
-    m.def("tstart", tstart, "docstring"); 
-    m.def("tstop", tstop, "docstring"); 
+void export_misc(py::module &m) {
+    m.def("tstart", tstart, "docstring");
+    m.def("tstop", tstop, "docstring");
 }
