@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -34,24 +34,29 @@
 **  CCENERGY: Program to calculate coupled cluster energies.
 */
 
-#include <cstdio>
-#include <cstdlib>
-#include <cstring>
-#include <cmath>
-#include <sys/types.h>
-#include <unistd.h>
+#include "Params.h"
+#include "MOInfo.h"
+#include "Local.h"
+#include "ccwave.h"
+
 #include "psi4/libciomr/libciomr.h"
 #include "psi4/libdpd/dpd.h"
 #include "psi4/libqt/qt.h"
 #include "psi4/libmints/wavefunction.h"
 #include "psi4/libpsio/psio.h"
 #include "psi4/libpsio/psio.hpp"
-#include <sys/types.h>
+#include "psi4/libpsi4util/PsiOutStream.h"
 #include "psi4/psifiles.h"
-#include "Params.h"
-#include "MOInfo.h"
-#include "Local.h"
-#include "ccwave.h"
+#include "psi4/libpsi4util/process.h"
+#include "psi4/liboptions/liboptions.h"
+
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+#include <cmath>
+#include <sys/types.h>
+#include <unistd.h>
+#include <sys/types.h>
 
 namespace psi { namespace ccenergy {
 
@@ -126,7 +131,7 @@ double CCEnergyWavefunction::compute_energy()
         spaces.push_back(moinfo_.bvir_sym);
         delete[] dpd_list[0];
         dpd_list[0] = new DPD(0, moinfo_.nirreps, params_.memory, 0, cachefiles,
-                              cachelist, NULL, 4, spaces);
+                              cachelist, nullptr, 4, spaces);
         dpd_set_default(0);
 
         if( params_.df ){
@@ -141,7 +146,7 @@ double CCEnergyWavefunction::compute_energy()
             aospaces.push_back(moinfo_.bocc_sym);
             aospaces.push_back(moinfo_.sopi);
             aospaces.push_back(moinfo_.sosym);
-            dpd_init(1, moinfo_.nirreps, params_.memory, 0, cachefiles, cachelist, NULL, 4, aospaces);
+            dpd_init(1, moinfo_.nirreps, params_.memory, 0, cachefiles, cachelist, nullptr, 4, aospaces);
             dpd_set_default(0);
         }
 
@@ -166,7 +171,7 @@ double CCEnergyWavefunction::compute_energy()
             aospaces.push_back(moinfo_.occ_sym);
             aospaces.push_back(moinfo_.sopi);
             aospaces.push_back(moinfo_.sosym);
-            dpd_init(1, moinfo_.nirreps, params_.memory, 0, cachefiles, cachelist, NULL, 2, aospaces);
+            dpd_init(1, moinfo_.nirreps, params_.memory, 0, cachefiles, cachelist, nullptr, 2, aospaces);
             dpd_set_default(0);
         }
 
@@ -341,6 +346,13 @@ double CCEnergyWavefunction::compute_energy()
         update();
         checkpoint();
     }  // end loop over iterations
+
+    // DGAS Edit
+    Process::environment.globals["CC T1 DIAGNOSTIC"] = moinfo_.t1diag;
+    Process::environment.globals["CC D1 DIAGNOSTIC"] = moinfo_.d1diag;
+    Process::environment.globals["CC NEW D1 DIAGNOSTIC"] = moinfo_.new_d1diag;
+    Process::environment.globals["CC D2 DIAGNOSTIC"] = moinfo_.d2diag;
+
     outfile->Printf( "\n");
     if(!done) {
         outfile->Printf( "     ** Wave function not converged to %2.1e ** \n",
@@ -502,6 +514,7 @@ double CCEnergyWavefunction::compute_energy()
 #endif
 
     energy_ = moinfo_.ecc + moinfo_.eref;
+    name_  = "CCSD";
     Process::environment.globals["CURRENT ENERGY"] = moinfo_.ecc+moinfo_.eref;
     Process::environment.globals["CURRENT CORRELATION ENERGY"] = moinfo_.ecc;
     //Process::environment.globals["CC TOTAL ENERGY"] = moinfo.ecc+moinfo.eref;
