@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -30,17 +30,21 @@
     \ingroup CCENERGY
     \brief Enter brief description of file here
 */
-#include <cstdio>
-#include "psi4/psi4-dec.h"
+
 #include "MOInfo.h"
 #include "ccwave.h"
 
+#include "psi4/psi4-dec.h"
+#include "psi4/libpsi4util/PsiOutStream.h"
+
+#include <cstdio>
+
 namespace psi { namespace ccenergy {
 
-void CCEnergyWavefunction::update(void)
-{
-  outfile->Printf("  %4d      %20.15f    %4.3e    %7.6f    %7.6f    %7.6f    %7.6f\n",
-          moinfo_.iter,moinfo_.ecc,moinfo_.conv,moinfo_.t1diag,moinfo_.d1diag,moinfo_.new_d1diag,moinfo_.d2diag);
-
+void CCEnergyWavefunction::update(void) {
+    outfile->Printf("  %4d      %20.15f    %4.3e    %7.6f    %7.6f    %7.6f    %7.6f\n",
+                    moinfo_.iter, moinfo_.ecc, moinfo_.conv, moinfo_.t1diag, moinfo_.d1diag,
+                    moinfo_.new_d1diag, moinfo_.d2diag);
 }
-}} // namespace psi::ccenergy
+}
+}  // namespace psi::ccenergy
