@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -121,7 +121,7 @@ int **cacheprep_uhf(int level, int *cachefiles)
 
 int **cacheprep_rhf(int level, int *cachefiles)
 {
-  int **cachelist = NULL;
+  int **cachelist = nullptr;
 
   /* The listing of CC files whose entries may be cached */
   cachefiles[PSIF_CC_AINTS] = 1;
