@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -34,21 +34,26 @@
 **  CCLAMBDA: Program to calculate the coupled-cluster lambda vector.
 */
 
-#include <cstdio>
-#include <cstdlib>
-#include <cstring>
-#include <cmath>
+#include "MOInfo.h"
+#include "Params.h"
+#include "Local.h"
+#include "globals.h"
+#include "cclambda.h"
+
+#include "psi4/libpsi4util/process.h"
+#include "psi4/libpsi4util/PsiOutStream.h"
+#include "psi4/liboptions/liboptions.h"
 #include "psi4/libciomr/libciomr.h"
 #include "psi4/libpsio/psio.h"
 #include "psi4/libpsio/psio.hpp"
 #include "psi4/libqt/qt.h"
 #include "psi4/psi4-dec.h"
 #include "psi4/libmints/wavefunction.h"
-#include "MOInfo.h"
-#include "Params.h"
-#include "Local.h"
-#include "globals.h"
-#include "cclambda.h"
+
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+#include <cmath>
 
 namespace psi { namespace cclambda {
 
@@ -167,7 +172,7 @@ double CCLambdaWavefunction::compute_energy()
       spaces.push_back(moinfo.occ_sym);
       spaces.push_back(moinfo.virtpi);
       spaces.push_back(moinfo.vir_sym);
-      dpd_init(0, moinfo.nirreps, params.memory, 0, cachefiles, cachelist, NULL, 2, spaces);
+      dpd_init(0, moinfo.nirreps, params.memory, 0, cachefiles, cachelist, nullptr, 2, spaces);
 
       if(params.aobasis) { /* Set up new DPD for AO-basis algorithm */
           std::vector<int*> aospaces;
@@ -175,7 +180,7 @@ double CCLambdaWavefunction::compute_energy()
           aospaces.push_back(moinfo.occ_sym);
           aospaces.push_back(moinfo.sopi);
           aospaces.push_back(moinfo.sosym);
-          dpd_init(1, moinfo.nirreps, params.memory, 0, cachefiles, cachelist, NULL, 2, aospaces);
+          dpd_init(1, moinfo.nirreps, params.memory, 0, cachefiles, cachelist, nullptr, 2, aospaces);
           dpd_set_default(0);
       }
 
@@ -193,7 +198,7 @@ double CCLambdaWavefunction::compute_energy()
       spaces.push_back(moinfo.bvirtpi);
       spaces.push_back(moinfo.bvir_sym);
 
-      dpd_init(0, moinfo.nirreps, params.memory, 0, cachefiles, cachelist, NULL, 4, spaces);
+      dpd_init(0, moinfo.nirreps, params.memory, 0, cachefiles, cachelist, nullptr, 4, spaces);
 
       if(params.aobasis) { /* Set up new DPD's for AO-basis algorithm */
           std::vector<int*> aospaces;
@@ -205,7 +210,7 @@ double CCLambdaWavefunction::compute_energy()
           aospaces.push_back(moinfo.bocc_sym);
           aospaces.push_back(moinfo.sopi);
           aospaces.push_back(moinfo.sosym);
-          dpd_init(1, moinfo.nirreps, params.memory, 0, cachefiles, cachelist, NULL, 4, aospaces);
+          dpd_init(1, moinfo.nirreps, params.memory, 0, cachefiles, cachelist, nullptr, 4, aospaces);
           dpd_set_default(0);
       }
     }
@@ -238,9 +243,9 @@ double CCLambdaWavefunction::compute_energy()
       }
 
       outfile->Printf("\tSymmetry of left-hand state: %s\n",
-              moinfo.labels[ moinfo.sym^(pL_params[i].irrep) ]);
+              moinfo.labels[ moinfo.sym^(pL_params[i].irrep) ].c_str());
       outfile->Printf("\tSymmetry of left-hand eigenvector: %s\n",
-              moinfo.labels[(pL_params[i].irrep)]);
+              moinfo.labels[(pL_params[i].irrep)].c_str());
 
       denom(pL_params[i]); /* uses L_params.cceom_energy for excited states */
       init_amps(pL_params[i]); /* uses denominators for initial zeta guess */
