@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -549,7 +549,7 @@ double ET_AAB(void)
 			}
 
 			/*
-			if(fabs(value_c) > 1e-7) {
+			if(std::fabs(value_c) > 1e-7) {
 			  cnt++;
 			  outfile->Printf( "%d %d %d %d %d %d %20.14f\n", I, J, K, A, B, C, value_c);
 			}
