@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -39,7 +39,7 @@
 #include "Params.h"
 #define EXTERN
 #include "globals.h"
-#include "psi4/libparallel/ParallelPrinter.h"
+#include "psi4/libpsi4util/PsiOutStream.h"
 namespace psi { namespace cctriples {
 
 double ET_UHF_ABB(void)
@@ -168,7 +168,7 @@ double ET_UHF_ABB(void)
 	    }
 	  }
 	}
-  std::shared_ptr<OutFile> printer(new OutFile("ijk.dat",TRUNCATE));
+  auto printer = std::make_shared<PsiOutStream>("ijk.dat",std::ostream::trunc);
   //ffile(&ijkfile,"ijk.dat",0);
   printer->Printf("Spin Case: ABB\n");
   printer->Printf("Number of IJK combintions: %d\n", nijk);
