@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -39,7 +39,7 @@
 #include "Params.h"
 #define EXTERN
 #include "globals.h"
-#include "psi4/libparallel/ParallelPrinter.h"
+#include "psi4/libpsi4util/PsiOutStream.h"
 namespace psi { namespace cctriples {
 
 double ET_UHF_BBB(void)
@@ -122,7 +122,7 @@ double ET_UHF_BBB(void)
 	    }
 	  }
 	}
-  std::shared_ptr<OutFile> printer(new OutFile("ijk.dat",TRUNCATE));
+  auto printer = std::make_shared<PsiOutStream>("ijk.dat",std::ostream::trunc);
   //ffile(&ijkfile,"ijk.dat",0);
   printer->Printf("Spin Case: BBB\n");
   printer->Printf("Number of IJK combintions: %d\n", nijk);
@@ -751,7 +751,7 @@ double ET_UHF_BBB(void)
 		      }
 
 		      /*
-		      if(fabs(VABC[Gab][ab][c]) > 1e-7)
+		      if(std::fabs(VABC[Gab][ab][c]) > 1e-7)
 			outfile->Printf( "%d %d %d %d %d %d %20.15f\n", I,J,K,A,B,C,VABC[Gab][ab][c]);
 		      */
 
