@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -52,10 +52,6 @@
 namespace psi{
 
 class Options;
-class PSIO;
-class Chkpt;
-class Matrix;
-class Vector;
 class IntegralTransform;
 
 namespace dcft{
@@ -107,7 +103,7 @@ protected:
                         bool backwards, double alpha, double beta);
     void file2_transform(dpdfile2 *A, dpdfile2 *B, SharedMatrix C, bool backwards);
     void AO_contribute(dpdbuf4 *tau1_AO, dpdbuf4 *tau2_AO, int p, int q,
-                       int r, int s, double value, dpdfile2* = NULL, dpdfile2* = NULL, dpdfile2* = NULL);
+                       int r, int s, double value, dpdfile2* = nullptr, dpdfile2* = nullptr, dpdfile2* = nullptr);
     //void AO_contribute(dpdfile2 *tau1_AO, dpdfile2 *tau2_AO, int p, int q,
     //        int r, int s, double value);
     bool correct_mo_phases(bool dieOnError = true);
