@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -26,20 +26,25 @@
  * @END LICENSE
  */
 
+#include "dcft.h"
+#include "defines.h"
+
 #include "psi4/libtrans/integraltransform.h"
 #include "psi4/libpsio/psio.hpp"
 #include "psi4/libqt/qt.h"
 #include "psi4/libiwl/iwl.h"
 #include "psi4/libdiis/diismanager.h"
-#include "dcft.h"
-#include "defines.h"
 
+#include "psi4/libpsi4util/PsiOutStream.h"
+#include "psi4/liboptions/liboptions.h"
 #include "psi4/psifiles.h"
 #include "psi4/libciomr/libciomr.h"
 #include "psi4/libpsio/psio.h"
 
 #include "psi4/psi4-dec.h"
 
+#include <cmath>
+
 namespace psi{ namespace dcft{
 
 void
@@ -97,7 +102,7 @@ DCFTSolver::run_simult_dcft_oo_RHF()
         if(options_.get_str("DCFT_TYPE") == "DF" && options_.get_str("AO_BASIS") == "NONE"){
             build_DF_tensors_RHF();
 
-            SharedMatrix mo_h = SharedMatrix(new Matrix("MO-based H", nirrep_, nmopi_, nmopi_));
+            auto mo_h = std::make_shared<Matrix>("MO-based H", nirrep_, nmopi_, nmopi_);
             mo_h->copy(so_h_);
             mo_h->transform(Ca_);
 
@@ -130,7 +135,7 @@ DCFTSolver::run_simult_dcft_oo_RHF()
         build_cumulant_intermediates_RHF();
         // Compute the residuals for density cumulant equations
         cumulant_convergence_ = compute_cumulant_residual_RHF();
-        if (fabs(cumulant_convergence_) > 100.0) throw PSIEXCEPTION("DCFT density cumulant equations diverged");
+        if (std::fabs(cumulant_convergence_) > 100.0) throw PSIEXCEPTION("DCFT density cumulant equations diverged");
         // Check convergence for density cumulant iterations
         cumulantDone_ = cumulant_convergence_ < cumulant_threshold_;
         // Update density cumulant tensor
@@ -145,7 +150,7 @@ DCFTSolver::run_simult_dcft_oo_RHF()
         orbitals_convergence_ = compute_orbital_residual_RHF();
         orbitalsDone_ = orbitals_convergence_ < orbitals_threshold_;
         // Check convergence of the total DCFT energy
-        energyConverged_ = fabs(old_total_energy_ - new_total_energy_) < energy_threshold_;
+        energyConverged_ = std::fabs(old_total_energy_ - new_total_energy_) < energy_threshold_;
         // Compute the orbital rotation step using Jacobi method
         compute_orbital_rotation_jacobi_RHF();
         if(orbitals_convergence_ < diis_start_thresh_ && cumulant_convergence_ < diis_start_thresh_){
@@ -242,7 +247,7 @@ DCFTSolver::compute_orbital_residual_RHF() {
         for(int i = 0; i < naoccpi_[h]; ++i){
             for(int a = 0; a < navirpi_[h]; ++a){
                 double value = 2.0 * (Xia.matrix[h][i][a] - Xai.matrix[h][a][i]);
-                maxGradient = (fabs(value) > maxGradient) ? fabs(value) : maxGradient;
+                maxGradient = (std::fabs(value) > maxGradient) ? std::fabs(value) : maxGradient;
                 orbital_gradient_a_->set(h, i, a + naoccpi_[h], value);
                 orbital_gradient_a_->set(h, a + naoccpi_[h], i, (-1.0) * value);
             }
@@ -620,7 +625,7 @@ DCFTSolver::rotate_orbitals_RHF() {
     dcft_timer_on("DCFTSolver::rotate_orbitals_RHF()");
 
     // Initialize the orbital rotation matrix
-    SharedMatrix U_a(new Matrix("Orbital rotation matrix (Alpha)", nirrep_, nmopi_, nmopi_));
+    auto U_a = std::make_shared<Matrix>("Orbital rotation matrix (Alpha)", nirrep_, nmopi_, nmopi_);
 
     // Compute the orbital rotation matrix and rotate the orbitals
 
