@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -58,9 +58,9 @@ namespace psi { namespace detci {
 ** initialize everything but buf_num and buf_member, which depend on the
 ** CIvector structure
 */
-void CIWavefunction::H0block_init(unsigned int size) {
+void CIWavefunction::H0block_init(size_t size) {
 
-   unsigned int size2;
+   size_t size2;
 
    if (size > Parameters_->h0blocksize) H0block_->size = Parameters_->h0blocksize;
    else H0block_->size = size;
@@ -106,59 +106,60 @@ void CIWavefunction::H0block_init(unsigned int size) {
      }
 }
 
-
-void CIWavefunction::H0block_free(void)
-{
-   int i;
-
-   if (H0block_->osize) {
-      free_matrix(H0block_->H0b, H0block_->osize);
-      if (Parameters_->precon == PRECON_GEN_DAVIDSON)
-         free(H0block_->H0b_diag_transpose);
-      free_matrix(H0block_->H0b_diag, H0block_->osize);
-      free_matrix(H0block_->tmp1, H0block_->osize);
-      free(H0block_->H00);
-      free(H0block_->c0b);
-      free(H0block_->c0bp);
-      free(H0block_->s0b);
-      free(H0block_->s0bp);
-      free(H0block_->alplist);
-      free(H0block_->betlist);
-      free(H0block_->alpidx);
-      free(H0block_->betidx);
-      free(H0block_->blknum);
-      free(H0block_->pair);
-      if (Parameters_->precon == PRECON_H0BLOCK_INVERT)
-         free_matrix(H0block_->H0b_inv, H0block_->osize);
-      if (Parameters_->h0block_coupling) {
-         free(H0block_->tmp_array1);
-         free(H0block_->tmp_array2);
-         }
-      if (H0block_->nbuf) {
-         free(H0block_->buf_num);
-         for (i=0; i<H0block_->nbuf; i++) free(H0block_->buf_member[i]);
-         free(H0block_->buf_member);
-         }
-      }
+void CIWavefunction::H0block_free(void) {
+    if (H0block_->osize) {
+        free_matrix(H0block_->H0b, H0block_->osize);
+        if (Parameters_->precon == PRECON_GEN_DAVIDSON) {
+            free(H0block_->H0b_diag_transpose);
+        }
+        free_matrix(H0block_->H0b_diag, H0block_->osize);
+        free_matrix(H0block_->tmp1, H0block_->osize);
+        free(H0block_->H00);
+        free(H0block_->c0b);
+        free(H0block_->c0bp);
+        free(H0block_->s0b);
+        free(H0block_->s0bp);
+        free(H0block_->alplist);
+        free(H0block_->betlist);
+        free(H0block_->alpidx);
+        free(H0block_->betidx);
+        free(H0block_->blknum);
+        free(H0block_->pair);
+        if (Parameters_->precon == PRECON_H0BLOCK_INVERT) {
+            free_matrix(H0block_->H0b_inv, H0block_->osize);
+        }
+        if (Parameters_->h0block_coupling) {
+            free(H0block_->tmp_array1);
+            free(H0block_->tmp_array2);
+        }
+        if (H0block_->nbuf) {
+            for (int i = 0; i < H0block_->nbuf; i++) {
+                if (H0block_->buf_num[i]) {
+                    free(H0block_->buf_member[i]);
+                }
+            }
+            free(H0block_->buf_num);
+            free(H0block_->buf_member);
+            H0block_->nbuf = 0;
+        }
+    }
 }
 
-void CIWavefunction::H0block_print(void)
-{
-   int i;
+void CIWavefunction::H0block_print(void) {
+    int i;
 
-   outfile->Printf( "\nMembers of H0 block:\n\n");
-   for (i=0; i<H0block_->size; i++) {
-     std::string configstring(print_config(CalcInfo_->num_ci_orbs, CalcInfo_->num_alp_expl,
-         CalcInfo_->num_bet_expl, alplist_[H0block_->alplist[i]] +
-         H0block_->alpidx[i], betlist_[H0block_->betlist[i]] +
-         H0block_->betidx[i], CalcInfo_->num_drc_orbs));
-      outfile->Printf( "  %3d [%3d] %10.6lf  Block %2d (%4d,%4d)  %s\n",
-         i+1, H0block_->pair[i] + 1, H0block_->H00[i], H0block_->blknum[i],
-         H0block_->alpidx[i], H0block_->betidx[i], configstring.c_str());
-      }
+    outfile->Printf("\nMembers of H0 block:\n\n");
+    for (i = 0; i < H0block_->size; i++) {
+        std::string configstring(print_config(
+            CalcInfo_->num_ci_orbs, CalcInfo_->num_alp_expl, CalcInfo_->num_bet_expl,
+            alplist_[H0block_->alplist[i]] + H0block_->alpidx[i],
+            betlist_[H0block_->betlist[i]] + H0block_->betidx[i], CalcInfo_->num_drc_orbs));
+        outfile->Printf("  %3d [%3d] %10.6lf  Block %2d (%4d,%4d)  %s\n", i + 1,
+                        H0block_->pair[i] + 1, H0block_->H00[i], H0block_->blknum[i],
+                        H0block_->alpidx[i], H0block_->betidx[i], configstring.c_str());
+    }
 }
 
-
 int CIWavefunction::H0block_calc(double E)
 {
    int i, j, size;
@@ -181,8 +182,11 @@ int CIWavefunction::H0block_calc(double E)
      for (i=0; i<size; i++) {
         for (j=0; j<size; j++)
            H0block_->H0b_diag_transpose[j] = H0block_->H0b_diag[j][i];
-        dot_arr(H0block_->H0b_diag_transpose, H0block_->c0b, size, &H0xc0[i]);
-        dot_arr(H0block_->H0b_diag_transpose, H0block_->s0b, size, &H0xs0[i]);
+        //dot_arr(H0block_->H0b_diag_transpose, H0block_->c0b, size, &H0xc0[i]);
+        //dot_arr(H0block_->H0b_diag_transpose, H0block_->s0b, size, &H0xs0[i]);
+        
+           H0xc0[i] = C_DDOT(size, H0block_->H0b_diag_transpose, 1, H0block_->c0b, 1);
+           H0xs0[i] = C_DDOT(size, H0block_->H0b_diag_transpose, 1, H0block_->s0b, 1);
         }
      for (i=0; i<size; i++) {
         c_tmp = s_tmp = 0.0;
@@ -190,7 +194,7 @@ int CIWavefunction::H0block_calc(double E)
            tval1 = H0xc0[j] * H0block_->H0b_diag[i][j];
            tval2 = H0xs0[j] * H0block_->H0b_diag[i][j];
            tval3 = H0block_->H0b_eigvals[j] - E;
-           if (fabs(tval3) < HD_MIN) tval3 = 0.0;
+           if (std::fabs(tval3) < HD_MIN) tval3 = 0.0;
            else tval3 = 1.0/tval3;
            tval1 *= tval3;
            tval2 *= tval3;
@@ -257,12 +261,14 @@ int CIWavefunction::H0block_calc(double E)
          }
 
        /* get c0bp = (H0b - E)^{-1} * c0b */
-       mmult(H0block_->H0b_inv, 0, &(H0block_->c0b), 1, &(H0block_->c0bp), 1,
-             size, size, 1, 0);
+       C_DGEMM('N', 'T', size, size, size, 1.0, H0block_->H0b_inv[0], size, &(H0block_->c0b)[0], size, 0.0, &(H0block_->c0bp)[0], size);
+       //mmult(H0block_->H0b_inv, 0, &(H0block_->c0b), 1, &(H0block_->c0bp), 1,
+       //      size, size, 1, 0);
 
        /* get s0bp = (H0b - E)^{-1} * s0b */
-       mmult(H0block_->H0b_inv, 0, &(H0block_->s0b), 1, &(H0block_->s0bp), 1,
-             size, size, 1, 0);
+       C_DGEMM('N', 'T', size, size, size, 1.0, H0block_->H0b_inv[0], size, &(H0block_->s0b)[0], size, 0.0, &(H0block_->s0bp)[0], size);
+       //mmult(H0block_->H0b_inv, 0, &(H0block_->s0b), 1, &(H0block_->s0bp), 1,
+       //      size, size, 1, 0);
        }
 
      if (print_ > 4) {
@@ -336,7 +342,7 @@ void CIWavefunction::H0block_xy(double *x, double *y, double E)
    for (i=0; i<H0block_->size; i++) {
       tval = H0block_->H00[i] - E;
       c = H0block_->c0b[i];
-      if (fabs(tval) < HD_MIN) tval = HD_MIN; /* prevent /0 */
+      if (std::fabs(tval) < HD_MIN) tval = HD_MIN; /* prevent /0 */
       tval = 1.0 / tval;
       tx += c * c * tval;
       ty += c * H0block_->s0b[i] * tval;
@@ -357,11 +363,13 @@ void CIWavefunction::H0block_xy(double *x, double *y, double E)
       outfile->Printf("H0block_->s0bp[%d] = %lf\n",i,H0block_->s0bp[i]);
   */
 
-   dot_arr(H0block_->c0b, H0block_->c0bp, H0block_->size, &tx);
+   //dot_arr(H0block_->c0b, H0block_->c0bp, H0block_->size, &tx);
+   tx = C_DDOT(H0block_->size,  H0block_->c0bp, 1, H0block_->c0b, 1);
    *x += tx;
-   dot_arr(H0block_->s0b, H0block_->c0bp, H0block_->size, &ty);
+   //dot_arr(H0block_->s0b, H0block_->c0bp, H0block_->size, &ty);
+   ty = C_DDOT(H0block_->size,  H0block_->c0bp, 1, H0block_->s0b, 1);
  /*
-   dot_arr(H0block_->c0b, H0block_->s0bp, H0block_->size, &ty);
+   //dot_arr(H0block_->c0b, H0block_->s0bp, H0block_->size, &ty);
  */
    *y += ty;
    /* outfile->Printf("+tx = %lf +ty = %lf\n",tx,ty); */
@@ -499,11 +507,11 @@ void CIWavefunction::H0block_spin_cpl_chk(void)
       spin_cpl_vals2 = H0block_->spin_cp_vals;
 
     i = H0block_->size-1;
-    diff = fabs(H0block_->H00[i] - spin_cpl_vals2);
+    diff = std::fabs(H0block_->H00[i] - spin_cpl_vals2);
    /* outfile->Printf("diff[%d] = %20.15f\n", i, diff); */
     while (i > 0 && diff < zero) {
       i--;
-      diff = fabs(H0block_->H00[i] - spin_cpl_vals2);
+      diff = std::fabs(H0block_->H00[i] - spin_cpl_vals2);
     /*  outfile->Printf("diff[%d] = %20.15f\n", i, diff); */
     }
 
@@ -536,11 +544,11 @@ void CIWavefunction::H0block_spin_cpl_chk(void)
     }
 
     i = newsize - 1;
-    diff = fabs(H0block_->H00[i] - spin_cpl_vals2);
+    diff = std::fabs(H0block_->H00[i] - spin_cpl_vals2);
    /* outfile->Printf("diff[%d] = %20.15f\n", i, diff); */
-    while (i > 0 && fabs(diff) < zero) {
+    while (i > 0 && std::fabs(diff) < zero) {
       i--;
-      diff = fabs(H0block_->H00[i] - spin_cpl_vals2);
+      diff = std::fabs(H0block_->H00[i] - spin_cpl_vals2);
      /* outfile->Printf("diff[%d] = %20.15f\n", i, diff); */
     }
 
@@ -563,11 +571,11 @@ void CIWavefunction::H0block_spin_cpl_chk(void)
     newsize = H0block_->size + H0block_->coupling_size;
 
     i = newsize - 1;
-    diff = fabs(H0block_->H00[i] - spin_cpl_vals2);
+    diff = std::fabs(H0block_->H00[i] - spin_cpl_vals2);
    /* outfile->Printf("diff[%d] = %20.15f\n", i, diff); */
-    while (i > 0 && fabs(diff) < zero) {
+    while (i > 0 && std::fabs(diff) < zero) {
       i--;
-      diff = fabs(H0block_->H00[i] - spin_cpl_vals2);
+      diff = std::fabs(H0block_->H00[i] - spin_cpl_vals2);
      /* outfile->Printf("diff[%d] = %20.15f\n", i, diff); */
     }
 
@@ -763,7 +771,7 @@ void CIWavefunction::H0block_coupling_calc(double E)
      /* form delta_2 array  (D-E)^-1 r_2 */
      for (i=size; i<size2; i++) {
         tval1 = H0block_->H00[i] - E;
-        if (fabs(tval1) > HD_MIN)
+        if (std::fabs(tval1) > HD_MIN)
           H0block_->c0bp[i] = H0block_->c0b[i]/tval1;
         else H0block_->c0bp[i] = 0.0;
         delta_2[i-size] = H0block_->c0bp[i];
@@ -792,7 +800,8 @@ void CIWavefunction::H0block_coupling_calc(double E)
            H_12[j-size] = matrix_element(&I, &J);
            } /* end loop over j */
 
-        dot_arr(H_12, delta_2, H0block_->coupling_size, &tval2);
+        // dot_arr(H_12, delta_2, H0block_->coupling_size, &tval2);
+        tval2 = C_DDOT(H0block_->coupling_size, H_12, 1, delta_2, 1);
         gamma_1[i] = tval2;
         for (j=0; j<H0block_->coupling_size; j++)
            gamma_2[j] += H_12[j] * delta_1[i];
@@ -804,7 +813,7 @@ void CIWavefunction::H0block_coupling_calc(double E)
      /* First delta_2 */
      for (i=size; i<size2; i++) {
         tval1 = H0block_->H00[i] - E;
-        if (fabs(tval1) > HD_MIN)
+        if (std::fabs(tval1) > HD_MIN)
           delta_2[i-size] = gamma_2[i-size]/tval1;
         else delta_2[i-size] = 0.0;
         }
@@ -837,7 +846,7 @@ void CIWavefunction::H0block_coupling_calc(double E)
 
      /*
        detH0 = invert_matrix(H0block_->tmp1, H0block_->H0b_inv, size, outfile);
-       mmult(H0block_->H0b_inv,0,&(gamma_1),1,&(delta_1),1,size,size,1,0);
+       // mmult(H0block_->H0b_inv,0,&(gamma_1),1,&(delta_1),1,size,size,1,0);
      */
 
     /*
