@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -39,20 +39,22 @@
 ** Last modified by MLL on 25 November 1997
 */
 
+#include "psi4/detci/structs.h"
+#include "psi4/detci/ci_tol.h"
+#include "psi4/detci/civect.h"
+#include "psi4/detci/ciwave.h"
 
-#include <cstdio>
-#include <cstdlib>
-#include <cmath>
 #include "psi4/psifiles.h"
 #include "psi4/libciomr/libciomr.h"
 #include "psi4/libqt/qt.h"
 #include "psi4/libqt/slaterdset.h"
 #include "psi4/libmints/vector.h"
-#include "psi4/detci/structs.h"
-#include "psi4/detci/ci_tol.h"
-#include "psi4/detci/civect.h"
-#include "psi4/detci/ciwave.h"
 #include "psi4/physconst.h"
+#include "psi4/libpsi4util/process.h"
+
+#include <cstdio>
+#include <cstdlib>
+#include <cmath>
 
 namespace psi { namespace detci {
 
@@ -65,7 +67,7 @@ void CIWavefunction::sem_iter(CIvect &Hd, struct stringwr **alplist, struct stri
       int nroots, int maxiter, int maxnvect)
 {
    int i, j, k, l, ij, I, L, L2=0, L3=0, tmpi, detH0;
-   unsigned long det1, N;
+   size_t det1, N;
    int num_alp_str, num_bet_str, Llast;
    int *mi_iac, *mi_ibc, *mi_iaidx, *mi_ibidx, *root_converged;
    int *Lvec, *did_root, num_root_converged;
@@ -435,7 +437,7 @@ void CIWavefunction::sem_iter(CIvect &Hd, struct stringwr **alplist, struct stri
                }
             tval = H0block_->H0b_diag[l][i];
             if ((int) Parameters_->S % 2) tval = -tval;
-            if (fabs(H0block_->H0b_diag[j][i] - tval) > 1.0E-8) {
+            if (std::fabs(H0block_->H0b_diag[j][i] - tval) > 1.0E-8) {
               tmpi = 1;
               outfile->Printf("(sem_iter): H0block_->H0b_diag[%d][%d]"
                       " - H0block_->H0b_diag[%d][%d] = %lf - %lf = %lf"
@@ -450,7 +452,7 @@ void CIWavefunction::sem_iter(CIvect &Hd, struct stringwr **alplist, struct stri
        l = Parameters_->filter_guess_H0_det2;
            tval = H0block_->H0b_diag[l][i];
        if (Parameters_->filter_guess_sign == -1) tval = -tval;
-       if (fabs(H0block_->H0b_diag[j][i] - tval) > 1.0E-8) {
+       if (std::fabs(H0block_->H0b_diag[j][i] - tval) > 1.0E-8) {
          tmpi = 1;
          outfile->Printf( "(sem_iter): Guess vector failed user-specified"
                           " criterion.\n");
@@ -472,7 +474,7 @@ void CIWavefunction::sem_iter(CIvect &Hd, struct stringwr **alplist, struct stri
             Cvec.buf_unlock();
             tval = Cvec.calc_ssq(buffer1, buffer2, alplist, betlist, k);
             Cvec.buf_lock(buffer1);
-            if (fabs(tval - (Parameters_->S*(Parameters_->S+1.0))) > 1.0E-3) {
+            if (std::fabs(tval - (Parameters_->S*(Parameters_->S+1.0))) > 1.0E-3) {
               outfile->Printf(
                  "Computed <S^2> not as desired, discarding guess\n");
               }
@@ -731,7 +733,7 @@ void CIWavefunction::sem_iter(CIvect &Hd, struct stringwr **alplist, struct stri
          for (i=0; i<nroots; i++) {
             if (form_M && ((collapse_num-last_lse_collapse_num)
                >= Parameters_->lse_collapse) &&
-               (fabs(lambda[iter2][i]-lastroot[i]) < lse_tolerance)
+               (std::fabs(lambda[iter2][i]-lastroot[i]) < lse_tolerance)
                 && (m_lambda[iter2][i][0] > MALPHA_TOLERANCE)) {
                lse_do_arr[i] = 1; lse_do++;
               }
@@ -1013,7 +1015,7 @@ void CIWavefunction::sem_iter(CIvect &Hd, struct stringwr **alplist, struct stri
       /* check for convergence */
       converged = 1;
       for (i=0; i<nroots; i++) {
-         if (dvecnorm[i] <= conv_rms && fabs(lambda[iter2][i] - lastroot[i])
+         if (dvecnorm[i] <= conv_rms && std::fabs(lambda[iter2][i] - lastroot[i])
             <= conv_e) root_converged[i] = 1;
          else {
             root_converged[i] = 0;
