@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -31,13 +31,11 @@
 #include "dfocc.h"
 
 using namespace psi;
-using namespace std;
 
+namespace psi {
+namespace dfoccwave {
 
-namespace psi{ namespace dfoccwave{
-
-void DFOCC::ccsd_WmnijT2_low()
-{
+void DFOCC::ccsd_WmnijT2_low() {
     // defs
     SharedTensor2d K, T, Tnew, U, Tau, W, X;
     SharedTensor2d M, L, I, Y, S, A;
@@ -90,19 +88,19 @@ void DFOCC::ccsd_WmnijT2_low()
     A->gemm(false, true, Va, Ta, 1.0, 0.0);
     Vs.reset();
     Va.reset();
-    // add to W(mn,ij)
-    #pragma omp parallel for
-    for(int m = 0 ; m < naoccA; ++m){
-        for(int n = 0 ; n < naoccA; ++n){
-            int mn = index2(m,n);
-            int mn2 = ij_idxAA->get(m,n);
-            for(int i = 0 ; i < naoccA; ++i){
-                for(int j = 0 ; j < naoccA; ++j){
-                    int ij = index2(i,j);
-                    int ij2 = ij_idxAA->get(i,j);
-                    int perm1 = ( i > j ) ? 1 : -1;
-                    int perm2 = ( m > n ) ? 1 : -1;
-                    double value = S->get(mn,ij) + (perm1 * perm2 * A->get(mn,ij));
+// add to W(mn,ij)
+#pragma omp parallel for
+    for (int m = 0; m < naoccA; ++m) {
+        for (int n = 0; n < naoccA; ++n) {
+            int mn = index2(m, n);
+            int mn2 = ij_idxAA->get(m, n);
+            for (int i = 0; i < naoccA; ++i) {
+                for (int j = 0; j < naoccA; ++j) {
+                    int ij = index2(i, j);
+                    int ij2 = ij_idxAA->get(i, j);
+                    int perm1 = (i > j) ? 1 : -1;
+                    int perm2 = (m > n) ? 1 : -1;
+                    double value = S->get(mn, ij) + (perm1 * perm2 * A->get(mn, ij));
                     W->add(mn2, ij2, value);
                 }
             }
@@ -138,18 +136,18 @@ void DFOCC::ccsd_WmnijT2_low()
     // T(ia,jb) <-- S(a>=b,i>=j) + A(a>=b,i>=j)
     Tnew = SharedTensor2d(new Tensor2d("New T2 (IA|JB)", naoccA, navirA, naoccA, navirA));
     Tnew->read_symm(psio_, PSIF_DFOCC_AMPS);
-    #pragma omp parallel for
-    for(int a = 0 ; a < navirA; ++a){
-        for(int b = 0 ; b < navirA; ++b){
-            int ab = index2(a,b);
-            for(int i = 0 ; i < naoccA; ++i){
-                int ia = ia_idxAA->get(i,a);
-                for(int j = 0 ; j < naoccA; ++j){
-                    int jb = ia_idxAA->get(j,b);
-                    int ij = index2(i,j);
-                    int perm1 = ( i > j ) ? 1 : -1;
-                    int perm2 = ( a > b ) ? 1 : -1;
-                    double value = S->get(ij,ab) + (perm1 * perm2 * A->get(ij,ab));
+#pragma omp parallel for
+    for (int a = 0; a < navirA; ++a) {
+        for (int b = 0; b < navirA; ++b) {
+            int ab = index2(a, b);
+            for (int i = 0; i < naoccA; ++i) {
+                int ia = ia_idxAA->get(i, a);
+                for (int j = 0; j < naoccA; ++j) {
+                    int jb = ia_idxAA->get(j, b);
+                    int ij = index2(i, j);
+                    int perm1 = (i > j) ? 1 : -1;
+                    int perm2 = (a > b) ? 1 : -1;
+                    double value = S->get(ij, ab) + (perm1 * perm2 * A->get(ij, ab));
                     Tnew->add(ia, jb, value);
                 }
             }
@@ -162,7 +160,7 @@ void DFOCC::ccsd_WmnijT2_low()
 
     timer_off("WmnijT2");
 
-}// end ccsd_WmnijT2_low
+}  // end ccsd_WmnijT2_low
 
 //======================================================================
 //    WmnijT2
@@ -224,8 +222,7 @@ void DFOCC::ccsd_WmnijT2_low()
 //======================================================================
 //    WmbejT2
 //======================================================================
-void DFOCC::ccsd_WmbejT2_low()
-{
+void DFOCC::ccsd_WmbejT2_low() {
     // defs
     SharedTensor2d K, T, T1, Tnew, U, Tau, W, W2, X, Y;
 
@@ -346,13 +343,12 @@ void DFOCC::ccsd_WmbejT2_low()
 
     timer_off("WmbejT2");
 
-}// end ccsd_WmbejT2_low
+}  // end ccsd_WmbejT2_low
 
 //======================================================================
 //    WijamT2
 //======================================================================
-void DFOCC::ccsd_WijamT2_low()
-{
+void DFOCC::ccsd_WijamT2_low() {
     // defs
     SharedTensor2d K, M, L, I, T, Tnew, U, Tau, W, X, Y, S, A;
     SharedTensor2d V, Vs, Ts, Va, Ta;
@@ -369,22 +365,22 @@ void DFOCC::ccsd_WijamT2_low()
     // (-)Tau(ij, ab) = 1/2 (Tau_ij^ab - Tau_ji^ab) * (2 - \delta_{ab})
     U = SharedTensor2d(new Tensor2d("(+)Tau [I>=J|A>=B]", ntri_ijAA, ntri_abAA));
     T = SharedTensor2d(new Tensor2d("(-)Tau [I>=J|A>=B]", ntri_ijAA, ntri_abAA));
-    #pragma omp parallel for
-    for(int i = 0 ; i < naoccA; ++i){
-        for(int j = 0 ; j <= i; ++j){
-            int ij = index2(i,j);
-            for(int a = 0 ; a < navirA; ++a){
-                int ia = ia_idxAA->get(i,a);
-                int ja = ia_idxAA->get(j,a);
-                for(int b = 0 ; b <= a; ++b){
+#pragma omp parallel for
+    for (int i = 0; i < naoccA; ++i) {
+        for (int j = 0; j <= i; ++j) {
+            int ij = index2(i, j);
+            for (int a = 0; a < navirA; ++a) {
+                int ia = ia_idxAA->get(i, a);
+                int ja = ia_idxAA->get(j, a);
+                for (int b = 0; b <= a; ++b) {
                     double perm = (a == b ? 1.0 : 2.0);
-                    int ab = index2(a,b);
-                    int jb = ia_idxAA->get(j,b);
-                    int ib = ia_idxAA->get(i,b);
-                    double value1 = 0.5 * perm * ( Tau->get(ia,jb) + Tau->get(ja,ib) );
-                    double value2 = 0.5 * perm * ( Tau->get(ia,jb) - Tau->get(ja,ib) );
-                    U->set(ij,ab,value1);
-                    T->set(ij,ab,value2);
+                    int ab = index2(a, b);
+                    int jb = ia_idxAA->get(j, b);
+                    int ib = ia_idxAA->get(i, b);
+                    double value1 = 0.5 * perm * (Tau->get(ia, jb) + Tau->get(ja, ib));
+                    double value2 = 0.5 * perm * (Tau->get(ia, jb) - Tau->get(ja, ib));
+                    U->set(ij, ab, value1);
+                    T->set(ij, ab, value2);
                 }
             }
         }
@@ -407,46 +403,44 @@ void DFOCC::ccsd_WijamT2_low()
     S = SharedTensor2d(new Tensor2d("S (AM, I>=J)", navirA, ntri_ijAA));
     A = SharedTensor2d(new Tensor2d("A (AM, I>=J)", navirA, ntri_ijAA));
     // Main loop
-    for(int m = 0 ; m < naoccA; ++m){
+    for (int m = 0; m < naoccA; ++m) {
+        // Form V[m](ae,f) = \sum_{Q} b(Q,ae) B(mfQ)
+        I->contract(true, true, navirA * navirA, navirA, nQ, K, L, 0, m * navirA * nQ, 1.0, 0.0);
 
-            // Form V[m](ae,f) = \sum_{Q} b(Q,ae) B(mfQ)
-            I->contract(true, true, navirA * navirA, navirA, nQ, K, L, 0, m*navirA*nQ, 1.0, 0.0);
-
-            // Form (+)V[m](a, e>=f)
-            #pragma omp parallel for
-            for(int a = 0 ; a < navirA; ++a){
-                for(int e = 0 ; e < navirA; ++e){
-                    int ae = ab_idxAA->get(a,e);
-                    for(int f = 0 ; f <= e; ++f){
-                        int af = ab_idxAA->get(a,f);
-                        int ef = index2(e,f);
-                        double value1 = 0.5 * ( I->get(ae, f) + I->get(af, e) );
-                        double value2 = 0.5 * ( I->get(ae, f) - I->get(af, e) );
-                        Vs->set(a, ef, value1);
-                        Va->set(a, ef, value2);
-                    }
+// Form (+)V[m](a, e>=f)
+#pragma omp parallel for
+        for (int a = 0; a < navirA; ++a) {
+            for (int e = 0; e < navirA; ++e) {
+                int ae = ab_idxAA->get(a, e);
+                for (int f = 0; f <= e; ++f) {
+                    int af = ab_idxAA->get(a, f);
+                    int ef = index2(e, f);
+                    double value1 = 0.5 * (I->get(ae, f) + I->get(af, e));
+                    double value2 = 0.5 * (I->get(ae, f) - I->get(af, e));
+                    Vs->set(a, ef, value1);
+                    Va->set(a, ef, value2);
                 }
             }
+        }
 
-            // Form S[m](a, i>=j) = \sum_{e>=f} Tau(i>=j,e>=f) V[m](a, e>=f)
-            S->gemm(false, true, Vs, U, 1.0, 0.0);
-            A->gemm(false, true, Va, T, 1.0, 0.0);
+        // Form S[m](a, i>=j) = \sum_{e>=f} Tau(i>=j,e>=f) V[m](a, e>=f)
+        S->gemm(false, true, Vs, U, 1.0, 0.0);
+        A->gemm(false, true, Va, T, 1.0, 0.0);
 
-            // Form S(am,ij) & A(ab,ij)-->W(ijam)
-            #pragma omp parallel for
-            for(int a = 0 ; a < navirA; ++a){
-                int am = ai_idxAA->get(a,m);
-                for(int i = 0 ; i < naoccA; ++i){
-                    for(int j = 0 ; j < naoccA; ++j){
-                        int ij = ij_idxAA->get(i,j);
-                        int ij2 = index2(i,j);
-                        int perm = ( i > j ) ? 1 : -1;
-                        double value = S->get(a,ij2) + (perm * A->get(a,ij2));
-                        W->set(ij, am, value);
-                    }
+// Form S(am,ij) & A(ab,ij)-->W(ijam)
+#pragma omp parallel for
+        for (int a = 0; a < navirA; ++a) {
+            int am = ai_idxAA->get(a, m);
+            for (int i = 0; i < naoccA; ++i) {
+                for (int j = 0; j < naoccA; ++j) {
+                    int ij = ij_idxAA->get(i, j);
+                    int ij2 = index2(i, j);
+                    int perm = (i > j) ? 1 : -1;
+                    double value = S->get(a, ij2) + (perm * A->get(a, ij2));
+                    W->set(ij, am, value);
                 }
             }
-
+        }
     }
     K.reset();
     I.reset();
@@ -477,13 +471,12 @@ void DFOCC::ccsd_WijamT2_low()
 
     timer_off("WijamT2");
 
-}// end ccsd_WijamT2_low
+}  // end ccsd_WijamT2_low
 
 //======================================================================
 //    WabefT2
 //======================================================================
-void DFOCC::ccsd_WabefT2_low()
-{
+void DFOCC::ccsd_WabefT2_low() {
     // defs
     SharedTensor2d K, M, L, I, T, Tnew, U, Tau, W, X, Y, S, A;
     SharedTensor2d V, Vs, Ts, Va, Ta;
@@ -497,22 +490,22 @@ void DFOCC::ccsd_WabefT2_low()
     // (-)Tau(ij, ab) = 1/2 (Tau_ij^ab - Tau_ji^ab) * (2 - \delta_{ab})
     U = SharedTensor2d(new Tensor2d("(+)Tau [I>=J|A>=B]", ntri_ijAA, ntri_abAA));
     T = SharedTensor2d(new Tensor2d("(-)Tau [I>=J|A>=B]", ntri_ijAA, ntri_abAA));
-    #pragma omp parallel for
-    for(int i = 0 ; i < naoccA; ++i){
-        for(int j = 0 ; j <= i; ++j){
-            int ij = index2(i,j);
-            for(int a = 0 ; a < navirA; ++a){
-                int ia = ia_idxAA->get(i,a);
-                int ja = ia_idxAA->get(j,a);
-                for(int b = 0 ; b <= a; ++b){
+#pragma omp parallel for
+    for (int i = 0; i < naoccA; ++i) {
+        for (int j = 0; j <= i; ++j) {
+            int ij = index2(i, j);
+            for (int a = 0; a < navirA; ++a) {
+                int ia = ia_idxAA->get(i, a);
+                int ja = ia_idxAA->get(j, a);
+                for (int b = 0; b <= a; ++b) {
                     double perm = (a == b ? 1.0 : 2.0);
-                    int ab = index2(a,b);
-                    int jb = ia_idxAA->get(j,b);
-                    int ib = ia_idxAA->get(i,b);
-                    double value1 = 0.5 * perm * ( Tau->get(ia,jb) + Tau->get(ja,ib) );
-                    double value2 = 0.5 * perm * ( Tau->get(ia,jb) - Tau->get(ja,ib) );
-                    U->set(ij,ab,value1);
-                    T->set(ij,ab,value2);
+                    int ab = index2(a, b);
+                    int jb = ia_idxAA->get(j, b);
+                    int ib = ia_idxAA->get(i, b);
+                    double value1 = 0.5 * perm * (Tau->get(ia, jb) + Tau->get(ja, ib));
+                    double value2 = 0.5 * perm * (Tau->get(ia, jb) - Tau->get(ja, ib));
+                    U->set(ij, ab, value1);
+                    T->set(ij, ab, value2);
                 }
             }
         }
@@ -537,45 +530,44 @@ void DFOCC::ccsd_WabefT2_low()
     S = SharedTensor2d(new Tensor2d("S (A>=B, I>=J)", ntri_abAA, ntri_ijAA));
     A = SharedTensor2d(new Tensor2d("A (A>=B, I>=J)", ntri_abAA, ntri_ijAA));
     // Main loop
-    for(int a = 0 ; a < navirA; ++a){
-            int nb = a+1;
+    for (int a = 0; a < navirA; ++a) {
+        int nb = a + 1;
 
-            // Form V[a](bf,e) = \sum_{Q} B(bfQ)*B(aeQ) cost = V^4N/2
-            I->contract(false, true, navirA*nb, navirA, nQ, K, K, 0, a*navirA*nQ, 1.0, 0.0);
+        // Form V[a](bf,e) = \sum_{Q} B(bfQ)*B(aeQ) cost = V^4N/2
+        I->contract(false, true, navirA * nb, navirA, nQ, K, K, 0, a * navirA * nQ, 1.0, 0.0);
 
-            // Form (+)V[a](b, e>=f)
-            #pragma omp parallel for
-            for(int b = 0 ; b <= a; ++b){
-                for(int e = 0 ; e < navirA; ++e){
-                    int be = e + (b * navirA);
-                    for(int f = 0 ; f <= e; ++f){
-                        int ef = index2(e,f);
-                        int bf = f + (b * navirA);
-                        double value1 = 0.5 * ( I->get(bf, e) + I->get(be, f) );
-                        double value2 = 0.5 * ( I->get(bf, e) - I->get(be, f) );
-                        Vs->set(b, ef, value1);
-                        Va->set(b, ef, value2);
-                    }
+// Form (+)V[a](b, e>=f)
+#pragma omp parallel for
+        for (int b = 0; b <= a; ++b) {
+            for (int e = 0; e < navirA; ++e) {
+                int be = e + (b * navirA);
+                for (int f = 0; f <= e; ++f) {
+                    int ef = index2(e, f);
+                    int bf = f + (b * navirA);
+                    double value1 = 0.5 * (I->get(bf, e) + I->get(be, f));
+                    double value2 = 0.5 * (I->get(bf, e) - I->get(be, f));
+                    Vs->set(b, ef, value1);
+                    Va->set(b, ef, value2);
                 }
             }
+        }
 
-            // Form T[a](b, i>=j) = \sum_{e>=f} Tau(i>=j,e>=f) V[a](b, e>=f)
-            Ts->contract(false, true, nb, ntri_ijAA, ntri_abAA, Vs, U, 1.0, 0.0);
-            Ta->contract(false, true, nb, ntri_ijAA, ntri_abAA, Va, T, 1.0, 0.0);
+        // Form T[a](b, i>=j) = \sum_{e>=f} Tau(i>=j,e>=f) V[a](b, e>=f)
+        Ts->contract(false, true, nb, ntri_ijAA, ntri_abAA, Vs, U, 1.0, 0.0);
+        Ta->contract(false, true, nb, ntri_ijAA, ntri_abAA, Va, T, 1.0, 0.0);
 
-            // Form S(ij,ab) & A(ij,ab)
-            #pragma omp parallel for
-            for(int b = 0 ; b <=a; ++b){
-                int ab = index2(a,b);
-                for(int i = 0 ; i < naoccA; ++i){
-                    for(int j = 0 ; j <= i; ++j){
-                        int ij = index2(i,j);
-                        S->add(ab, ij, Ts->get(b,ij));
-                        A->add(ab, ij, Ta->get(b,ij));
-                    }
+// Form S(ij,ab) & A(ij,ab)
+#pragma omp parallel for
+        for (int b = 0; b <= a; ++b) {
+            int ab = index2(a, b);
+            for (int i = 0; i < naoccA; ++i) {
+                for (int j = 0; j <= i; ++j) {
+                    int ij = index2(i, j);
+                    S->add(ab, ij, Ts->get(b, ij));
+                    A->add(ab, ij, Ta->get(b, ij));
                 }
             }
-
+        }
     }
     K.reset();
     I.reset();
@@ -589,18 +581,18 @@ void DFOCC::ccsd_WabefT2_low()
     // T(ia,jb) <-- S(a>=b,i>=j) + A(a>=b,i>=j)
     Tnew = SharedTensor2d(new Tensor2d("New T2 (IA|JB)", naoccA, navirA, naoccA, navirA));
     Tnew->read_symm(psio_, PSIF_DFOCC_AMPS);
-    #pragma omp parallel for
-    for(int a = 0 ; a < navirA; ++a){
-        for(int b = 0 ; b < navirA; ++b){
-            int ab = index2(a,b);
-            for(int i = 0 ; i < naoccA; ++i){
-                int ia = ia_idxAA->get(i,a);
-                for(int j = 0 ; j < naoccA; ++j){
-                    int jb = ia_idxAA->get(j,b);
-                    int ij = index2(i,j);
-                    int perm1 = ( i > j ) ? 1 : -1;
-                    int perm2 = ( a > b ) ? 1 : -1;
-                    double value = S->get(ab,ij) + (perm1 * perm2 * A->get(ab,ij));
+#pragma omp parallel for
+    for (int a = 0; a < navirA; ++a) {
+        for (int b = 0; b < navirA; ++b) {
+            int ab = index2(a, b);
+            for (int i = 0; i < naoccA; ++i) {
+                int ia = ia_idxAA->get(i, a);
+                for (int j = 0; j < naoccA; ++j) {
+                    int jb = ia_idxAA->get(j, b);
+                    int ij = index2(i, j);
+                    int perm1 = (i > j) ? 1 : -1;
+                    int perm2 = (a > b) ? 1 : -1;
+                    double value = S->get(ab, ij) + (perm1 * perm2 * A->get(ab, ij));
                     Tnew->add(ia, jb, value);
                 }
             }
@@ -613,13 +605,12 @@ void DFOCC::ccsd_WabefT2_low()
 
     timer_off("WabefT2");
 
-}// end ccsd_WabefT2_low
+}  // end ccsd_WabefT2_low
 
 //======================================================================
 //    Wabef2T2: 2nd version
 //======================================================================
-void DFOCC::ccsd_Wabef2T2_low()
-{
+void DFOCC::ccsd_Wabef2T2_low() {
     // defs
     SharedTensor2d K, M, L, I, T, Tnew, U, Tau, W, X, Y, S, A;
     SharedTensor2d V, Vs, Ts, Va, Ta, J, T1;
@@ -633,22 +624,22 @@ void DFOCC::ccsd_Wabef2T2_low()
     // (-)Tau(ij, ab) = 1/2 (Tau_ij^ab - Tau_ji^ab) * (2 - \delta_{ab})
     U = SharedTensor2d(new Tensor2d("(+)Tau [I>=J|A>=B]", ntri_ijAA, ntri_abAA));
     T = SharedTensor2d(new Tensor2d("(-)Tau [I>=J|A>=B]", ntri_ijAA, ntri_abAA));
-    #pragma omp parallel for
-    for(int i = 0 ; i < naoccA; ++i){
-        for(int j = 0 ; j <= i; ++j){
-            int ij = index2(i,j);
-            for(int a = 0 ; a < navirA; ++a){
-                int ia = ia_idxAA->get(i,a);
-                int ja = ia_idxAA->get(j,a);
-                for(int b = 0 ; b <= a; ++b){
+#pragma omp parallel for
+    for (int i = 0; i < naoccA; ++i) {
+        for (int j = 0; j <= i; ++j) {
+            int ij = index2(i, j);
+            for (int a = 0; a < navirA; ++a) {
+                int ia = ia_idxAA->get(i, a);
+                int ja = ia_idxAA->get(j, a);
+                for (int b = 0; b <= a; ++b) {
                     double perm = (a == b ? 1.0 : 2.0);
-                    int ab = index2(a,b);
-                    int jb = ia_idxAA->get(j,b);
-                    int ib = ia_idxAA->get(i,b);
-                    double value1 = 0.5 * perm * ( Tau->get(ia,jb) + Tau->get(ja,ib) );
-                    double value2 = 0.5 * perm * ( Tau->get(ia,jb) - Tau->get(ja,ib) );
-                    U->set(ij,ab,value1);
-                    T->set(ij,ab,value2);
+                    int ab = index2(a, b);
+                    int jb = ia_idxAA->get(j, b);
+                    int ib = ia_idxAA->get(i, b);
+                    double value1 = 0.5 * perm * (Tau->get(ia, jb) + Tau->get(ja, ib));
+                    double value2 = 0.5 * perm * (Tau->get(ia, jb) - Tau->get(ja, ib));
+                    U->set(ij, ab, value1);
+                    T->set(ij, ab, value2);
                 }
             }
         }
@@ -693,28 +684,28 @@ void DFOCC::ccsd_Wabef2T2_low()
     S = SharedTensor2d(new Tensor2d("S (A>=B, I>=J)", ntri_abAA, ntri_ijAA));
     A = SharedTensor2d(new Tensor2d("A (A>=B, I>=J)", ntri_abAA, ntri_ijAA));
     // Main loop
-    for(int a = 0 ; a < navirA; ++a){
-        int nb = a+1;
+    for (int a = 0; a < navirA; ++a) {
+        int nb = a + 1;
 
         // Form J[a](bf,e) = \sum_{Q} B(bfQ)*[B(aeQ)-T(aeQ)] cost = V^4N/2
-        I->contract(false, true, navirA*nb, navirA, nQ, K, X, 0, a*navirA*nQ, 1.0, 0.0);
+        I->contract(false, true, navirA * nb, navirA, nQ, K, X, 0, a * navirA * nQ, 1.0, 0.0);
 
         // Form J[a](mf,e) = \sum_{Q} B(mfQ)*B(aeQ) cost = OV^3N
-        J->contract(false, true, navirA*naoccA, navirA, nQ, L, K, 0, a*navirA*nQ, 1.0, 0.0);
+        J->contract(false, true, navirA * naoccA, navirA, nQ, L, K, 0, a * navirA * nQ, 1.0, 0.0);
 
         // J[a](b,fe) -= \sum_{m} t(m,b) * J[a](mf,e)
-        I->contract(false, false, nb, navirA*navirA, naoccA, T1, J, -1.0, 1.0);
+        I->contract(false, false, nb, navirA * navirA, naoccA, T1, J, -1.0, 1.0);
 
-        // Form (+)V[a](b, e>=f)
-        #pragma omp parallel for
-        for(int b = 0 ; b <= a; ++b){
-            for(int e = 0 ; e < navirA; ++e){
+// Form (+)V[a](b, e>=f)
+#pragma omp parallel for
+        for (int b = 0; b <= a; ++b) {
+            for (int e = 0; e < navirA; ++e) {
                 int be = e + (b * navirA);
-                for(int f = 0 ; f <= e; ++f){
-                    int ef = index2(e,f);
+                for (int f = 0; f <= e; ++f) {
+                    int ef = index2(e, f);
                     int bf = f + (b * navirA);
-                    double value1 = 0.5 * ( I->get(bf, e) + I->get(be, f) );
-                    double value2 = 0.5 * ( I->get(bf, e) - I->get(be, f) );
+                    double value1 = 0.5 * (I->get(bf, e) + I->get(be, f));
+                    double value2 = 0.5 * (I->get(bf, e) - I->get(be, f));
                     Vs->set(b, ef, value1);
                     Va->set(b, ef, value2);
                 }
@@ -725,19 +716,18 @@ void DFOCC::ccsd_Wabef2T2_low()
         Ts->contract(false, true, nb, ntri_ijAA, ntri_abAA, Vs, U, 1.0, 0.0);
         Ta->contract(false, true, nb, ntri_ijAA, ntri_abAA, Va, T, 1.0, 0.0);
 
-        // Form S(ij,ab) & A(ij,ab)
-        #pragma omp parallel for
-        for(int b = 0 ; b <=a; ++b){
-            int ab = index2(a,b);
-            for(int i = 0 ; i < naoccA; ++i){
-                for(int j = 0 ; j <= i; ++j){
-                    int ij = index2(i,j);
-                     S->add(ab, ij, Ts->get(b,ij));
-                     A->add(ab, ij, Ta->get(b,ij));
+// Form S(ij,ab) & A(ij,ab)
+#pragma omp parallel for
+        for (int b = 0; b <= a; ++b) {
+            int ab = index2(a, b);
+            for (int i = 0; i < naoccA; ++i) {
+                for (int j = 0; j <= i; ++j) {
+                    int ij = index2(i, j);
+                    S->add(ab, ij, Ts->get(b, ij));
+                    A->add(ab, ij, Ta->get(b, ij));
                 }
             }
         }
-
     }
     K.reset();
     I.reset();
@@ -755,18 +745,18 @@ void DFOCC::ccsd_Wabef2T2_low()
     // T(ia,jb) <-- S(a>=b,i>=j) + A(a>=b,i>=j)
     Tnew = SharedTensor2d(new Tensor2d("New T2 (IA|JB)", naoccA, navirA, naoccA, navirA));
     Tnew->read_symm(psio_, PSIF_DFOCC_AMPS);
-    #pragma omp parallel for
-    for(int a = 0 ; a < navirA; ++a){
-        for(int b = 0 ; b < navirA; ++b){
-            int ab = index2(a,b);
-            for(int i = 0 ; i < naoccA; ++i){
-                int ia = ia_idxAA->get(i,a);
-                for(int j = 0 ; j < naoccA; ++j){
-                    int jb = ia_idxAA->get(j,b);
-                    int ij = index2(i,j);
-                    int perm1 = ( i > j ) ? 1 : -1;
-                    int perm2 = ( a > b ) ? 1 : -1;
-                    double value = S->get(ab,ij) + (perm1 * perm2 * A->get(ab,ij));
+#pragma omp parallel for
+    for (int a = 0; a < navirA; ++a) {
+        for (int b = 0; b < navirA; ++b) {
+            int ab = index2(a, b);
+            for (int i = 0; i < naoccA; ++i) {
+                int ia = ia_idxAA->get(i, a);
+                for (int j = 0; j < naoccA; ++j) {
+                    int jb = ia_idxAA->get(j, b);
+                    int ij = index2(i, j);
+                    int perm1 = (i > j) ? 1 : -1;
+                    int perm2 = (a > b) ? 1 : -1;
+                    double value = S->get(ab, ij) + (perm1 * perm2 * A->get(ab, ij));
                     Tnew->add(ia, jb, value);
                 }
             }
@@ -779,7 +769,7 @@ void DFOCC::ccsd_Wabef2T2_low()
 
     timer_off("WabefT2");
 
-}// end ccsd_Wabef2T2_low
-
-}} // End Namespaces
+}  // end ccsd_Wabef2T2_low
 
+}  // namespace dfoccwave
+}  // namespace psi
