@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -33,13 +33,14 @@
 
 #include "findif.h"
 #include "psi4/libmints/writer_file_prefix.h"
-#include "psi4/libparallel/ParallelPrinter.h"
+#include "psi4/libpsi4util/PsiOutStream.h"
 #include "psi4/liboptions/liboptions_python.h"
 #include "psi4/libmints/molecule.h"
 #include "psi4/libmints/matrix.h"
 #include "psi4/libmints/cdsalclist.h"
 #include "psi4/libmints/pointgrp.h"
 #include "psi4/libmints/petitelist.h"
+#include "psi4/libmints/wavefunction.h"
 #include "psi4/physconst.h"
 
 #include "psi4/pybind11.h"
@@ -47,19 +48,17 @@
 namespace psi {
 namespace findif {
 
-SharedMatrix fd_freq_1(std::shared_ptr <Molecule> mol, Options &options,
-                       const py::list &grad_list, int freq_irrep_only)
-{
+SharedMatrix fd_freq_1(std::shared_ptr <Molecule>mol, Options &options,
+                       const py::list &grad_list, int freq_irrep_only ) {
     int pts = options.get_int("POINTS");
     double disp_size = options.get_double("DISP_SIZE");
     int print_lvl = options.get_int("PRINT");
 
     int Natom = mol->natom();
-    std::shared_ptr <MatrixFactory> fact;
-    py::object pyExtern = dynamic_cast<PythonDataType *>(options["EXTERN"].get())->to_python();
-    bool project = !pyExtern && !options.get_bool("PERTURB_H");
+    bool t_project = !options.get_bool("EXTERN") && !options.get_bool("PERTURB_H");
+    bool r_project = t_project && options.get_bool("FD_PROJECT");
 
-    CdSalcList salc_list(mol, fact, 0xFF, project, project);
+    CdSalcList salc_list(mol, 0xFF, t_project, r_project);
     int Nirrep = salc_list.nirrep();
 
     // *** Build vectors that list indices of salcs for each irrep
@@ -104,12 +103,14 @@ SharedMatrix fd_freq_1(std::shared_ptr <Molecule> mol, Options &options,
     for (int h = 0; h < Nirrep; ++h)
         Ndisp_all += Ndisp_pi[h];
 
-    outfile->Printf("\n-------------------------------------------------------------\n\n");
+    if (print_lvl) {
+        outfile->Printf("\n-------------------------------------------------------------\n\n");
 
-    outfile->Printf("  Computing second-derivative from gradients using projected, \n");
-    outfile->Printf("  symmetry-adapted, cartesian coordinates (fd_freq_1).\n\n");
+        outfile->Printf("  Computing second-derivative from gradients using projected, \n");
+        outfile->Printf("  symmetry-adapted, cartesian coordinates (fd_freq_1).\n\n");
 
-    outfile->Printf("  %d gradients passed in, including the reference geometry.\n", (int) len(grad_list));
+        outfile->Printf("  %d gradients passed in, including the reference geometry.\n", (int)len(grad_list));
+    }
 
     // We are passing in the reference geometry at the moment, though we are not using
     // its gradient.  Could be removed later.
@@ -121,9 +122,11 @@ SharedMatrix fd_freq_1(std::shared_ptr <Molecule> mol, Options &options,
     }
 
     // *** Generate complete list of gradients from unique ones.
-    outfile->Printf("  Generating complete list of displacements from unique ones.\n\n");
+    if (print_lvl){
+        outfile->Printf("  Generating complete list of displacements from unique ones.\n\n");
+    }
 
-    std::shared_ptr <PointGroup> pg = mol->point_group();
+    std::shared_ptr<PointGroup> pg = mol->point_group();
     CharacterTable ct = mol->point_group()->char_table();
     int order = ct.order();
 
@@ -174,8 +177,10 @@ SharedMatrix fd_freq_1(std::shared_ptr <Molecule> mol, Options &options,
         for (op_disp = 0; op_disp < order; ++op_disp)
             if (gamma.character(op_disp) == -1)
                 break;
-        outfile->Printf("\tOperation %d takes plus displacements of irrep %s to minus ones.\n",
-                        op_disp + 1, gamma.symbol());
+        if (print_lvl) {
+            outfile->Printf("\tOperation %d takes plus displacements of irrep %s to minus ones.\n", op_disp + 1,
+                            gamma.symbol());
+        }
 
         // Get 3x3 matrix representation of operation.
         SymmetryOperation so = ct.symm_operation(op_disp);
@@ -186,7 +191,7 @@ SharedMatrix fd_freq_1(std::shared_ptr <Molecule> mol, Options &options,
             // Read the - displacement and generate the +
             gradients.push_back(grad_list[disp_cnt].cast<SharedMatrix>());
 
-            SharedMatrix new_grad(new Matrix(Natom, 3));
+            auto new_grad = std::make_shared<Matrix>(Natom, 3);
 
             for (int atom = 0; atom < Natom; ++atom) {
                 int atom2 = atom_map[atom][op_disp]; // how this atom transforms under this op.
@@ -204,7 +209,7 @@ SharedMatrix fd_freq_1(std::shared_ptr <Molecule> mol, Options &options,
             if (pts == 5) {
                 gradients.push_back(grad_list[disp_cnt].cast<SharedMatrix>());
 
-                SharedMatrix new_grad2(new Matrix(Natom, 3));
+                auto new_grad2 = std::make_shared<Matrix>(Natom, 3);
 
                 for (int atom = 0; atom < Natom; ++atom) {
                     int atom2 = atom_map[atom][op_disp]; // how this atom transforms under this op.
@@ -257,11 +262,9 @@ SharedMatrix fd_freq_1(std::shared_ptr <Molecule> mol, Options &options,
             gradients[i]->print();
     }
 
-    char **irrep_lbls = mol->irrep_labels();
+    std::vector<std::string> irrep_lbls = mol->irrep_labels();
     double **H_irr[8];
 
-    std::vector < VIBRATION * > modes;
-
     for (int h = 0; h < Nirrep; ++h) {
 
         if (salcs_pi[h].size() == 0) continue;
@@ -328,7 +331,7 @@ SharedMatrix fd_freq_1(std::shared_ptr <Molecule> mol, Options &options,
         }
 
         if (print_lvl >= 3) {
-            outfile->Printf("\n\tForce Constants for irrep %s in mass-weighted, ", irrep_lbls[h]);
+            outfile->Printf("\n\tForce Constants for irrep %s in mass-weighted, ", irrep_lbls[h].c_str());
             outfile->Printf("symmetry-adapted cartesian coordinates.\n");
             mat_print(H_irr[h], salcs_pi[h].size(), salcs_pi[h].size(), "outfile");
         }
@@ -351,34 +354,15 @@ SharedMatrix fd_freq_1(std::shared_ptr <Molecule> mol, Options &options,
                 dim, 0, normal_irr[0], dim);
 
         if (print_lvl >= 2) {
-            outfile->Printf("\n\tNormal coordinates (non-mass-weighted) for irrep %s:\n", irrep_lbls[h]);
+            outfile->Printf("\n\tNormal coordinates (non-mass-weighted) for irrep %s:\n", irrep_lbls[h].c_str());
             eivout(normal_irr, evals, 3 * Natom, dim, "outfile");
         }
 
-        for (int i = 0; i < salcs_pi[h].size(); ++i) {
-            double *v = init_array(3 * Natom);
-            for (int x = 0; x < 3 * Natom; ++x)
-                v[x] = normal_irr[x][i];
-            VIBRATION *vib = new VIBRATION(h, evals[i], v);
-            modes.push_back(vib);
-        }
-
         free(evals);
         free_block(evects);
         free_block(normal_irr);
     }
 
-    // This print function also saves frequencies in wavefunction.
-    print_vibrations(mol, modes);
-
-    // Optionally, save normal modes to file.
-    if (options.get_bool("NORMAL_MODES_WRITE")) {
-        save_normal_modes(mol, modes);
-    }
-
-    for (int i = 0; i < modes.size(); ++i)
-        delete modes[i];
-    modes.clear();
 
     // Build complete hessian for transformation to cartesians
     double **H = block_matrix(Nsalc_all, Nsalc_all);
@@ -395,24 +379,29 @@ SharedMatrix fd_freq_1(std::shared_ptr <Molecule> mol, Options &options,
 
     // Transform Hessian into cartesian coordinates
     if (print_lvl >= 3) {
-        outfile->Printf("\n\tFull force constant matrix in mass-weighted SALCS.\n");
+        outfile->Printf("\n\tForce constant matrix for all computed irreps in mass-weighted SALCS.\n");
         mat_print(H, Nsalc_all, Nsalc_all, "outfile");
     }
 
     // Build Bu^-1/2 matrix for the whole Hessian
-    SharedMatrix B_shared = salc_list.matrix();
-    double **B = B_shared->pointer();
+    //SharedMatrix B_shared = salc_list.matrix();
+    //double **B = B_shared->pointer();
 
     // double **Hx = block_matrix(3*Natom, 3*Natom);
-    SharedMatrix mat_Hx = SharedMatrix(new Matrix("Hessian", 3 * Natom, 3 * Natom));
+    auto mat_Hx = std::make_shared<Matrix>("Hessian", 3 * Natom, 3 * Natom);
     double **Hx = mat_Hx->pointer();
 
     // Hx = Bt H B
-    for (int i = 0; i < Nsalc_all; ++i)
-        for (int j = 0; j < Nsalc_all; ++j)
-            for (int x1 = 0; x1 < 3 * Natom; ++x1)
-                for (int x2 = 0; x2 <= x1; ++x2)
-                    Hx[x1][x2] += B[i][x1] * H[i][j] * B[j][x2];
+    for (int h = 0; h < Nirrep; ++h) {
+        SharedMatrix B_irr_shared = salc_list.matrix_irrep(h);
+        double **B_irr = B_irr_shared->pointer();
+        int start = salc_irr_start[h];
+        for (int i = 0; i < salcs_pi[h].size(); ++i)
+            for (int j = 0; j < salcs_pi[h].size(); ++j)
+                for (int x1 = 0; x1 < 3 * Natom; ++x1)
+                    for (int x2 = 0; x2 <= x1; ++x2)
+                        Hx[x1][x2] += B_irr[i][x1] * H[start + i][start + j] * B_irr[j][x2];
+    }
 
     for (int x1 = 0; x1 < 3 * Natom; ++x1)
         for (int x2 = 0; x2 < x1; ++x2)
@@ -435,28 +424,30 @@ SharedMatrix fd_freq_1(std::shared_ptr <Molecule> mol, Options &options,
         mat_print(Hx, 3 * Natom, 3 * Natom, "outfile");
     }
 
-    // Print a hessian file
-    if (options.get_bool("HESSIAN_WRITE")) {
-        std::string hess_fname = get_writer_file_prefix(mol->name()) + ".hess";
-        std::shared_ptr <OutFile> printer(new OutFile(hess_fname, TRUNCATE));
-        //FILE *of_Hx = fopen(hess_fname.c_str(),"w");
-        printer->Printf("%5d", Natom);
-        printer->Printf("%5d\n", 6 * Natom);
-
-        int cnt = -1;
-        for (int i = 0; i < 3 * Natom; ++i) {
-            for (int j = 0; j < 3 * Natom; ++j) {
-                printer->Printf("%20.10lf", Hx[i][j]);
-                if (++cnt == 2) {
-                    printer->Printf("\n");
-                    cnt = -1;
-                }
-            }
-        }
-    }
+//    // Print a hessian file
+//    if (options.get_bool("HESSIAN_WRITE")) {
+//        std::string hess_fname = get_writer_file_prefix(mol->name()) + ".hess";
+//        auto printer = std::make_shared<PsiOutStream>(hess_fname, std::ostream::trunc);
+//        //FILE *of_Hx = fopen(hess_fname.c_str(),"w");
+//        printer->Printf("%5d", Natom);
+//        printer->Printf("%5d\n", 6 * Natom);
+//
+//        int cnt = -1;
+//        for (int i = 0; i < 3 * Natom; ++i) {
+//            for (int j = 0; j < 3 * Natom; ++j) {
+//                printer->Printf("%20.10lf", Hx[i][j]);
+//                if (++cnt == 2) {
+//                    printer->Printf("\n");
+//                    cnt = -1;
+//                }
+//            }
+//        }
+//    }
 //  free_block(Hx);
 
-    outfile->Printf("\n-------------------------------------------------------------\n");
+    if (print_lvl) {
+        outfile->Printf("\n-------------------------------------------------------------\n");
+    }
 
     return mat_Hx;
 }
