@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -32,6 +32,7 @@
 #include "psi4/libmints/wavefunction.h"
 #include"psi4/libqt/qt.h"
 #include<sys/times.h>
+#include <unistd.h>
 #include "psi4/libciomr/libciomr.h"
 #include "psi4/libmints/mintshelper.h"
 #ifdef _OPENMP
@@ -43,7 +44,6 @@
 #include"blas.h"
 #include"ccsd.h"
 #include "psi4/libmints/basisset.h"
-#include "psi4/libmints/basisset_parser.h"
 #include "psi4/lib3index/3index.h"
 
 using namespace psi;
@@ -102,6 +102,9 @@ double DFCoupledCluster::compute_energy() {
   Process::environment.globals["CCSD SAME-SPIN CORRELATION ENERGY"] = eccsd_ss;
   Process::environment.globals["CCSD TOTAL ENERGY"] = eccsd + escf;
   Process::environment.globals["CURRENT ENERGY"] = eccsd + escf;
+  /* updates the wavefunction for checkpointing */
+  energy_ = Process::environment.globals["CCSD TOTAL ENERGY"];
+  name_ = "DF-CCSD";
 
   if (options_.get_bool("COMPUTE_TRIPLES")){
       long int o = ndoccact;
@@ -113,7 +116,7 @@ double DFCoupledCluster::compute_energy() {
           // the buffer integrals was at least 2v^3, so these should definitely fit.
           double *Z     = (double*)malloc(v*v*v*sizeof(double));
           double *Z2    = (double*)malloc(v*v*v*sizeof(double));
-          std::shared_ptr<PSIO> psio(new PSIO());
+          auto psio = std::make_shared<PSIO>();
           psio->open(PSIF_DCC_ABCI,PSIO_OPEN_NEW);
           psio_address addr2 = PSIO_ZERO;
           for (long int i=0; i<o; i++){
@@ -142,7 +145,7 @@ double DFCoupledCluster::compute_energy() {
           psio_address addr = PSIO_ZERO;
           double * temp1 = (double*)malloc(( nQ*v > o*v*v ? nQ*v : o*v*v)*sizeof(double));
           double * temp2 = (double*)malloc(o*v*v*sizeof(double));
-          std::shared_ptr<PSIO> psio(new PSIO());
+          auto psio = std::make_shared<PSIO>();
           psio->open(PSIF_DCC_ABCI4,PSIO_OPEN_NEW);
           for (long int a = 0; a < v; a++) {
               #pragma omp parallel for schedule (static)
@@ -182,7 +185,7 @@ double DFCoupledCluster::compute_energy() {
               }
           }
       }
-      std::shared_ptr<PSIO> psio(new PSIO());
+      auto psio = std::make_shared<PSIO>();
       psio->open(PSIF_DCC_IJAK,PSIO_OPEN_NEW);
       psio->write_entry(PSIF_DCC_IJAK,"E2ijak",(char*)&temp2[0],o*o*o*v*sizeof(double));
       psio->close(PSIF_DCC_IJAK,1);
@@ -280,7 +283,7 @@ PsiReturnType DFCoupledCluster::CCSDIterations() {
   double Eold           = 1.0e9;
   if (brueckner_iter == 0 ) eccsd = 0.0;
 
-  std::shared_ptr<PSIO> psio(new PSIO());
+  auto psio = std::make_shared<PSIO>();
   psio_address addr;
 
   // zero residual
@@ -294,7 +297,7 @@ PsiReturnType DFCoupledCluster::CCSDIterations() {
   struct tms total_tmstime;
   times(&total_tmstime);
 
-  time_t time_start = time(NULL);
+  time_t time_start = time(nullptr);
   double user_start = ((double) total_tmstime.tms_utime)/clk_tck;
   double sys_start  = ((double) total_tmstime.tms_stime)/clk_tck;
 
@@ -315,7 +318,7 @@ PsiReturnType DFCoupledCluster::CCSDIterations() {
 
   memset((void*)diisvec,'\0',(maxdiis+1)*sizeof(double));
   while(iter < maxiter) {
-      time_t iter_start = time(NULL);
+      time_t iter_start = time(nullptr);
 
       // evaluate cc diagrams
       memset((void*)w1,'\0',o*v*sizeof(double));
@@ -358,8 +361,8 @@ PsiReturnType DFCoupledCluster::CCSDIterations() {
       //}else {
       //    double min = 1.0e9;
       //    for (int j = 1; j <= (diis_iter < maxdiis ? diis_iter : maxdiis); j++) {
-      //        if ( fabs( diisvec[j-1] ) < min ) {
-      //            min = fabs( diisvec[j-1] );
+      //        if ( std::fabs( diisvec[j-1] ) < min ) {
+      //            min = std::fabs( diisvec[j-1] );
       //            replace_diis_iter = j;
       //        }
       //    }
@@ -369,7 +372,7 @@ PsiReturnType DFCoupledCluster::CCSDIterations() {
       else if (replace_diis_iter<maxdiis) replace_diis_iter++;
       else replace_diis_iter = 1;
 
-      time_t iter_stop = time(NULL);
+      time_t iter_stop = time(nullptr);
       outfile->Printf("  %5i   %i %i %15.10f %15.10f %15.10f %8d\n",
             iter,diis_iter-1,replace_diis_iter,eccsd,eccsd-Eold,nrm,(int)iter_stop-(int)iter_start);
 
@@ -380,11 +383,11 @@ PsiReturnType DFCoupledCluster::CCSDIterations() {
       }
 
       // energy and amplitude convergence check
-      if (fabs(eccsd - Eold) < e_conv && nrm < r_conv) break;
+      if (std::fabs(eccsd - Eold) < e_conv && nrm < r_conv) break;
   }
 
   times(&total_tmstime);
-  time_t time_stop = time(NULL);
+  time_t time_stop = time(nullptr);
   double user_stop = ((double) total_tmstime.tms_utime)/clk_tck;
   double sys_stop  = ((double) total_tmstime.tms_stime)/clk_tck;
 
@@ -401,9 +404,13 @@ PsiReturnType DFCoupledCluster::CCSDIterations() {
 
   double t1diag = C_DNRM2(o*v,t1,1) / sqrt(2.0 * o);
   outfile->Printf("        T1 diagnostic:                  %20.12lf\n",t1diag);
-  std::shared_ptr<Matrix>T (new Matrix(o,o));
-  std::shared_ptr<Matrix>eigvec (new Matrix(o,o));
-  std::shared_ptr<Vector>eigval (new Vector(o));
+
+  // add T1 diagnostic to globals
+  Process::environment.globals["CC T1 DIAGNOSTIC"] = t1diag;
+
+  auto T = std::make_shared<Matrix>(o,o);
+  auto eigvec = std::make_shared<Matrix>(o,o);
+  auto eigval = std::make_shared<Vector>(o);
   double ** Tp = T->pointer();
   for (long int i = 0; i < o; i++) {
       for (long int j = 0; j < o; j++) {
@@ -418,6 +425,9 @@ PsiReturnType DFCoupledCluster::CCSDIterations() {
   outfile->Printf("        D1 diagnostic:                  %20.12lf\n",sqrt(eigval->pointer()[0]));
   outfile->Printf("\n");
 
+  // add D1 diagnostic to globals
+  Process::environment.globals["CC D1 DIAGNOSTIC"] = sqrt(eigval->pointer()[0]);
+
   // delta mp2 correction for fno computations:
   if (options_.get_bool("NAT_ORBS")){
       double delta_emp2 = Process::environment.globals["MP2 CORRELATION ENERGY"] - emp2;
@@ -493,7 +503,7 @@ double DFCoupledCluster::CheckEnergy(){
     F_DGEMM('n','t',o*v,o*v,nQ,1.0,Qov,o*v,Qov,o*v,0.0,integrals,o*v);
 
     if (t2_on_disk){
-        std::shared_ptr<PSIO> psio (new PSIO());
+        auto psio = std::make_shared<PSIO>();
         psio->open(PSIF_DCC_T2,PSIO_OPEN_OLD);
         psio->read_entry(PSIF_DCC_T2,"t2",(char*)&tempv[0],o*o*v*v*sizeof(double));
         psio->close(PSIF_DCC_T2,1);
@@ -695,12 +705,12 @@ void DFCoupledCluster::AllocateMemory() {
   Ca = reference_wavefunction_->Ca()->pointer();
 
   // one-electron integrals
-  std::shared_ptr<MintsHelper> mints(new MintsHelper(basisset_, options_, 0));
+  auto mints = std::make_shared<MintsHelper>(basisset_, options_, 0);
   H = mints->so_kinetic();
   H->add(mints->so_potential());
 
   if (t2_on_disk) {
-     std::shared_ptr<PSIO> psio (new PSIO());
+     auto psio = std::make_shared<PSIO>();
      psio->open(PSIF_DCC_T2,PSIO_OPEN_NEW);
      psio->write_entry(PSIF_DCC_T2,"t2",(char*)&tempt[0],o*o*v*v*sizeof(double));
      psio->close(PSIF_DCC_T2,1);
@@ -736,7 +746,7 @@ void DFCoupledCluster::UpdateT2(){
   long int v = nvirt;
   long int o = ndoccact;
 
-  std::shared_ptr<PSIO> psio(new PSIO());
+  auto psio = std::make_shared<PSIO>();
 
   // df (ai|bj)
   psio->open(PSIF_DCC_QSO,PSIO_OPEN_OLD);
@@ -795,7 +805,7 @@ void DFCoupledCluster::Vabcd1(){
     long int otri = o*(o+1)/2;
     long int vtri = v*(v+1)/2;
 
-    std::shared_ptr<PSIO> psio(new PSIO());
+    auto psio = std::make_shared<PSIO>();
 
     if (t2_on_disk){
         psio->open(PSIF_DCC_T2,PSIO_OPEN_OLD);
