@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -29,12 +29,8 @@
 #ifndef three_index_H
 #define three_index_H
 
-#include "fitter.h"
 #include "dftensor.h"
-#include "pstensor.h"
 #include "denominator.h"
-#include "schwarz.h"
 #include "cholesky.h"
-#include "qr.h"
 
-#endif
\ No newline at end of file
+#endif
