@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -26,11 +26,11 @@
  * @END LICENSE
  */
 
- #include "psi4/pragma.h"
- PRAGMA_WARNING_PUSH
- PRAGMA_WARNING_IGNORE_DEPRECATED_DECLARATIONS
- #include <memory>
- PRAGMA_WARNING_POP
+#include "psi4/pragma.h"
+PRAGMA_WARNING_PUSH
+PRAGMA_WARNING_IGNORE_DEPRECATED_DECLARATIONS
+#include <memory>
+PRAGMA_WARNING_POP
 #include "psi4/libpsio/psio.hpp"
 #include "diismanager.h"
 #include <cstdarg>
@@ -39,11 +39,14 @@
 #include "psi4/libciomr/libciomr.h"
 #include "psi4/libqt/qt.h"
 #include "psi4/psifiles.h"
+#include "psi4/libpsi4util/PsiOutStream.h"
+#include "psi4/libpsi4util/process.h"
+
+#include <cmath>
 
 using namespace psi;
 
-
-namespace psi{
+namespace psi {
 /**
  *
  * @param maxSubspaceSize Maximum number of vectors allowed in the subspace
@@ -52,39 +55,29 @@ namespace psi{
  * @param storagePolicy: How to store the DIIS vectors
  * @param psio: the PSIO object to use for I/O.  Do not specify if DPD is being used.
  */
-DIISManager::DIISManager(int maxSubspaceSize,
-                         const std::string& label,
-                         RemovalPolicy removalPolicy,
-                         StoragePolicy storagePolicy):
-            _maxSubspaceSize(maxSubspaceSize),
-            _removalPolicy(removalPolicy),
-            _storagePolicy(storagePolicy),
-            _errorVectorSize(0),
-            _vectorSize(0),
-            _psio(_default_psio_lib_),
-            _entryCount(0),
-            _label(label)
-{
-}
+DIISManager::DIISManager(int maxSubspaceSize, const std::string &label, RemovalPolicy removalPolicy,
+                         StoragePolicy storagePolicy)
+    : _maxSubspaceSize(maxSubspaceSize),
+      _removalPolicy(removalPolicy),
+      _storagePolicy(storagePolicy),
+      _errorVectorSize(0),
+      _vectorSize(0),
+      _psio(_default_psio_lib_),
+      _entryCount(0),
+      _label(label) {}
 
-int DIISManager::subspace_size()
-{
-    return _subspace.size();
-}
+int DIISManager::subspace_size() { return _subspace.size(); }
 
 /**
  * Determines the size of the error vector from a list of input quantities.  This function should
  * not be called until set_error_vector_size() has been called.
  */
-void
-DIISManager::set_vector_size(int numQuantities, ...)
-{
-    if(_vectorSize)
-        throw SanityCheckError("DIISManager: The size of the DIIS vector has already been set",
-                               __FILE__, __LINE__);
-    if(_errorVectorSize == 0)
-        throw SanityCheckError("DIISManager: The error vector size must be set before the vector size",
-                               __FILE__, __LINE__);
+void DIISManager::set_vector_size(int numQuantities, ...) {
+    if (_vectorSize)
+        throw SanityCheckError("DIISManager: The size of the DIIS vector has already been set", __FILE__, __LINE__);
+    if (_errorVectorSize == 0)
+        throw SanityCheckError("DIISManager: The error vector size must be set before the vector size", __FILE__,
+                               __LINE__);
     _numVectorComponents = numQuantities;
     dpdfile2 *file2;
     dpdbuf4 *buf4;
@@ -92,35 +85,35 @@ DIISManager::set_vector_size(int numQuantities, ...)
     Matrix *matrix;
     va_list args;
     va_start(args, numQuantities);
-    for(int i=0; i < numQuantities; ++i) {
+    for (int i = 0; i < numQuantities; ++i) {
         DIISEntry::InputType type = static_cast<DIISEntry::InputType>(va_arg(args, int));
         _componentTypes.push_back(type);
         size_t size = 0;
-        switch(type){
+        switch (type) {
             case DIISEntry::Pointer:
                 size += va_arg(args, int);
                 break;
             case DIISEntry::DPDBuf4:
-                buf4 = va_arg(args, dpdbuf4*);
-                for(int h = 0; h < buf4->params->nirreps; ++h){
+                buf4 = va_arg(args, dpdbuf4 *);
+                for (int h = 0; h < buf4->params->nirreps; ++h) {
                     size += buf4->params->rowtot[h] * buf4->params->coltot[h];
                 }
                 break;
             case DIISEntry::DPDFile2:
-                file2 = va_arg(args, dpdfile2*);
-                for(int h = 0; h < file2->params->nirreps; ++h){
+                file2 = va_arg(args, dpdfile2 *);
+                for (int h = 0; h < file2->params->nirreps; ++h) {
                     size += file2->params->rowtot[h] * file2->params->coltot[h];
                 }
                 break;
             case DIISEntry::Matrix:
-                matrix = va_arg(args, Matrix*);
-                for(int h = 0; h < matrix->nirrep(); ++h){
+                matrix = va_arg(args, Matrix *);
+                for (int h = 0; h < matrix->nirrep(); ++h) {
                     size += matrix->rowspi()[h] * matrix->colspi()[h];
                 }
                 break;
             case DIISEntry::Vector:
-                vector = va_arg(args, Vector*);
-                for(int h = 0; h < vector->nirrep(); ++h){
+                vector = va_arg(args, Vector *);
+                for (int h = 0; h < vector->nirrep(); ++h) {
                     size += vector->dimpi()[h];
                 }
                 break;
@@ -133,16 +126,12 @@ DIISManager::set_vector_size(int numQuantities, ...)
     va_end(args);
 }
 
-
 /**
  * Determines the size of the error vector from a list of input quantities.
  */
-void
-DIISManager::set_error_vector_size(int numQuantities, ...)
-{
-    if(_errorVectorSize)
-        throw SanityCheckError("The size of the DIIS error vector has already been set",
-                               __FILE__, __LINE__);
+void DIISManager::set_error_vector_size(int numQuantities, ...) {
+    if (_errorVectorSize)
+        throw SanityCheckError("The size of the DIIS error vector has already been set", __FILE__, __LINE__);
     _numErrorVectorComponents = numQuantities;
     dpdfile2 *file2;
     dpdbuf4 *buf4;
@@ -150,35 +139,35 @@ DIISManager::set_error_vector_size(int numQuantities, ...)
     Matrix *matrix;
     va_list args;
     va_start(args, numQuantities);
-    for(int i=0; i < numQuantities; ++i) {
+    for (int i = 0; i < numQuantities; ++i) {
         DIISEntry::InputType type = static_cast<DIISEntry::InputType>(va_arg(args, int));
         _componentTypes.push_back(type);
         size_t size = 0;
-        switch(type){
+        switch (type) {
             case DIISEntry::Pointer:
                 size += va_arg(args, int);
                 break;
             case DIISEntry::DPDBuf4:
-                buf4 = va_arg(args, dpdbuf4*);
-                for(int h = 0; h < buf4->params->nirreps; ++h){
+                buf4 = va_arg(args, dpdbuf4 *);
+                for (int h = 0; h < buf4->params->nirreps; ++h) {
                     size += buf4->params->rowtot[h] * buf4->params->coltot[h];
                 }
                 break;
             case DIISEntry::DPDFile2:
-                file2 = va_arg(args, dpdfile2*);
-                for(int h = 0; h < file2->params->nirreps; ++h){
+                file2 = va_arg(args, dpdfile2 *);
+                for (int h = 0; h < file2->params->nirreps; ++h) {
                     size += file2->params->rowtot[h] * file2->params->coltot[h];
                 }
                 break;
             case DIISEntry::Matrix:
-                matrix = va_arg(args, Matrix*);
-                for(int h = 0; h < matrix->nirrep(); ++h){
+                matrix = va_arg(args, Matrix *);
+                for (int h = 0; h < matrix->nirrep(); ++h) {
                     size += matrix->rowspi()[h] * matrix->colspi()[h];
                 }
                 break;
             case DIISEntry::Vector:
-                vector = va_arg(args, Vector*);
-                for(int h = 0; h < vector->nirrep(); ++h){
+                vector = va_arg(args, Vector *);
+                for (int h = 0; h < vector->nirrep(); ++h) {
                     size += vector->dimpi()[h];
                 }
                 break;
@@ -191,7 +180,6 @@ DIISManager::set_error_vector_size(int numQuantities, ...)
     va_end(args);
 }
 
-
 /**
  * Adds a new vector and error vector to the DIIS subspace.
  * @param numQuantities - the number of components used to construct the
@@ -205,13 +193,13 @@ DIISManager::set_error_vector_size(int numQuantities, ...)
  * set_size functions, which takes only the size of that array.
  * @return Whether the subspace was updated
  */
-bool
-DIISManager::add_entry(int numQuantities, ...)
-{
-    if(!_maxSubspaceSize) return false;
-    if(_componentSizes.size() != numQuantities)
-        throw SanityCheckError("The number of parameters passed to the set_size routines"
-                               " and add_entry are inconsistent", __FILE__, __LINE__);
+bool DIISManager::add_entry(int numQuantities, ...) {
+    if (!_maxSubspaceSize) return false;
+    if (_componentSizes.size() != numQuantities)
+        throw SanityCheckError(
+            "The number of parameters passed to the set_size routines"
+            " and add_entry are inconsistent",
+            __FILE__, __LINE__);
 
     timer_on("DIISManager::add_entry");
     dpdfile2 *file2;
@@ -221,26 +209,25 @@ DIISManager::add_entry(int numQuantities, ...)
     double *array;
     va_list args;
     va_start(args, numQuantities);
-    double *errorVectorPtr = new double [_errorVectorSize];
-    double *vectorPtr      = new double [_vectorSize];
+    double *errorVectorPtr = new double[_errorVectorSize];
+    double *vectorPtr = new double[_vectorSize];
     double *arrayPtr = errorVectorPtr;
-    for(int i = 0; i < numQuantities; ++i) {
+    for (int i = 0; i < numQuantities; ++i) {
         DIISEntry::InputType type = _componentTypes[i];
         // If we've filled the error vector, start filling the vector
-        if(i == _numErrorVectorComponents) arrayPtr = vectorPtr;
-        switch(type){
+        if (i == _numErrorVectorComponents) arrayPtr = vectorPtr;
+        switch (type) {
             case DIISEntry::Pointer:
-                array = va_arg(args, double*);
-                for(int j = 0; j < _componentSizes[i]; ++j)
-                    *arrayPtr++ = array[j];
+                array = va_arg(args, double *);
+                for (int j = 0; j < _componentSizes[i]; ++j) *arrayPtr++ = array[j];
                 break;
             case DIISEntry::DPDBuf4:
-                buf4 = va_arg(args, dpdbuf4*);
-                for(int h = 0; h < buf4->params->nirreps; ++h){
+                buf4 = va_arg(args, dpdbuf4 *);
+                for (int h = 0; h < buf4->params->nirreps; ++h) {
                     global_dpd_->buf4_mat_irrep_init(buf4, h);
                     global_dpd_->buf4_mat_irrep_rd(buf4, h);
-                    for(int row = 0; row < buf4->params->rowtot[h]; ++row){
-                        for(int col = 0; col < buf4->params->coltot[h]; ++col){
+                    for (int row = 0; row < buf4->params->rowtot[h]; ++row) {
+                        for (int col = 0; col < buf4->params->coltot[h]; ++col) {
                             *arrayPtr++ = buf4->matrix[h][row][col];
                         }
                     }
@@ -248,12 +235,12 @@ DIISManager::add_entry(int numQuantities, ...)
                 }
                 break;
             case DIISEntry::DPDFile2:
-                file2 = va_arg(args, dpdfile2*);
+                file2 = va_arg(args, dpdfile2 *);
                 global_dpd_->file2_mat_init(file2);
                 global_dpd_->file2_mat_rd(file2);
-                for(int h = 0; h < file2->params->nirreps; ++h){
-                    for(int row = 0; row < file2->params->rowtot[h]; ++row){
-                        for(int col = 0; col < file2->params->coltot[h]; ++col){
+                for (int h = 0; h < file2->params->nirreps; ++h) {
+                    for (int row = 0; row < file2->params->rowtot[h]; ++row) {
+                        for (int col = 0; col < file2->params->coltot[h]; ++col) {
                             *arrayPtr++ = file2->matrix[h][row][col];
                         }
                     }
@@ -261,20 +248,20 @@ DIISManager::add_entry(int numQuantities, ...)
                 global_dpd_->file2_mat_close(file2);
                 break;
             case DIISEntry::Matrix:
-                matrix = va_arg(args, Matrix*);
-                for(int h = 0; h < matrix->nirrep(); ++h){
-                    for(int row = 0; row < matrix->rowspi()[h]; ++row){
-                        for(int col = 0; col < matrix->colspi()[h]; ++col){
+                matrix = va_arg(args, Matrix *);
+                for (int h = 0; h < matrix->nirrep(); ++h) {
+                    for (int row = 0; row < matrix->rowspi()[h]; ++row) {
+                        for (int col = 0; col < matrix->colspi()[h]; ++col) {
                             *arrayPtr++ = matrix->get(h, row, col);
                         }
                     }
                 }
                 break;
             case DIISEntry::Vector:
-                vector = va_arg(args, Vector*);
-                for(int h = 0; h < vector->nirrep(); ++h){
-                    for(int row = 0; row < vector->dimpi()[h]; ++row){
-                            *arrayPtr++ = vector->get(h, row);
+                vector = va_arg(args, Vector *);
+                for (int h = 0; h < vector->nirrep(); ++h) {
+                    for (int row = 0; row < vector->dimpi()[h]; ++row) {
+                        *arrayPtr++ = vector->get(h, row);
                     }
                 }
                 break;
@@ -285,25 +272,23 @@ DIISManager::add_entry(int numQuantities, ...)
     va_end(args);
 
     int entryID = get_next_entry_id();
-    if(_subspace.size() < _maxSubspaceSize){
-        _subspace.push_back(new DIISEntry(_label, entryID, _entryCount++,
-                            _errorVectorSize, errorVectorPtr,
-                            _vectorSize, vectorPtr, _psio));
-    }else{
+    if (_subspace.size() < _maxSubspaceSize) {
+        _subspace.push_back(new DIISEntry(_label, entryID, _entryCount++, _errorVectorSize, errorVectorPtr, _vectorSize,
+                                          vectorPtr, _psio));
+    } else {
         delete _subspace[entryID];
-        _subspace[entryID] = new DIISEntry(_label, entryID, _entryCount++,
-                                           _errorVectorSize, errorVectorPtr,
+        _subspace[entryID] = new DIISEntry(_label, entryID, _entryCount++, _errorVectorSize, errorVectorPtr,
                                            _vectorSize, vectorPtr, _psio);
     }
 
-    if(_storagePolicy == OnDisk) {
+    if (_storagePolicy == OnDisk) {
         _subspace[entryID]->dump_vector_to_disk();
         _subspace[entryID]->dump_error_vector_to_disk();
     }
 
     // Make we don't know any inner products involving this new entry
-    for(int i = 0; i < _subspace.size(); ++i)
-        if(i != entryID) _subspace[i]->invalidate_dot(entryID);
+    for (int i = 0; i < _subspace.size(); ++i)
+        if (i != entryID) _subspace[i]->invalidate_dot(entryID);
 
     timer_off("DIISManager::add_entry");
 
@@ -314,37 +299,34 @@ DIISManager::add_entry(int numQuantities, ...)
  * Figures out the ID of the next entry to be added by determining whether an entry
  * must be removed in order to add a new one.
  */
-int
-DIISManager::get_next_entry_id()
-{
+int DIISManager::get_next_entry_id() {
     int entry = 0;
-    if(_subspace.size() < _maxSubspaceSize){
+    if (_subspace.size() < _maxSubspaceSize) {
         entry = _subspace.size();
-    }else{
-        if(_removalPolicy == OldestAdded){
+    } else {
+        if (_removalPolicy == OldestAdded) {
             int oldest = _subspace[0]->orderAdded();
-            for(int i = 1; i < _subspace.size(); ++i){
-                if(_subspace[i]->orderAdded() < oldest){
+            for (int i = 1; i < _subspace.size(); ++i) {
+                if (_subspace[i]->orderAdded() < oldest) {
                     oldest = _subspace[i]->orderAdded();
                     entry = i;
                 }
             }
-        }else if (_removalPolicy == LargestError){
+        } else if (_removalPolicy == LargestError) {
             double largest = _subspace[0]->rmsError();
-            for(int i = 1; i < _subspace.size(); ++i){
-                if(_subspace[i]->rmsError() > largest){
+            for (int i = 1; i < _subspace.size(); ++i) {
+                if (_subspace[i]->rmsError() > largest) {
                     largest = _subspace[i]->rmsError();
                     entry = i;
                 }
             }
-        }else{
+        } else {
             throw SanityCheckError("Unknown RemovalPolicy", __FILE__, __LINE__);
         }
     }
     return entry;
 }
 
-
 /**
  * Performs the extapolation, based on the current subspace
  * @param numQuantitites - the number of quantities that the vector comprises.
@@ -352,37 +334,34 @@ DIISManager::get_next_entry_id()
  * function.  The types of each component should not be specified here, unlike the
  * set_vector_size() function call.
  */
-bool
-DIISManager::extrapolate(int numQuantities, ...)
-{
-    if(!_subspace.size()) return false;
+bool DIISManager::extrapolate(int numQuantities, ...) {
+    if (!_subspace.size()) return false;
 
     timer_on("DIISManager::extrapolate");
 
     int dimension = _subspace.size() + 1;
-    SharedMatrix B(new Matrix("B (DIIS Connectivity Matrix", dimension, dimension));
+    auto B = std::make_shared<Matrix>("B (DIIS Connectivity Matrix", dimension, dimension);
     double **bMatrix = B->pointer();
     double *coefficients = init_array(dimension);
     double *force = init_array(dimension);
 
-    timer_on("DIISManager::extrapolate: bMatrix setup");
+    timer_on("bMatrix setup");
 
-    for(int i = 0; i < _subspace.size(); ++i){
+    for (int i = 0; i < _subspace.size(); ++i) {
         coefficients[i] = 0.0;
         bMatrix[i][_subspace.size()] = bMatrix[_subspace.size()][i] = 1.0;
         DIISEntry *entryI = _subspace[i];
-        for(int j = 0; j < _subspace.size(); ++j){
+        for (int j = 0; j < _subspace.size(); ++j) {
             DIISEntry *entryJ = _subspace[j];
-            if(entryI->dot_is_known_with(j)){
+            if (entryI->dot_is_known_with(j)) {
                 bMatrix[i][j] = entryI->dot_with(j);
-            }else{
-                double dot = C_DDOT(_errorVectorSize,
-                                    const_cast<double*>(entryI->errorVector()), 1,
-                                    const_cast<double*>(entryJ->errorVector()), 1);
+            } else {
+                double dot = C_DDOT(_errorVectorSize, const_cast<double *>(entryI->errorVector()), 1,
+                                    const_cast<double *>(entryJ->errorVector()), 1);
                 bMatrix[i][j] = dot;
                 entryI->set_dot_with(j, dot);
                 entryJ->set_dot_with(i, dot);
-                if(_storagePolicy == OnDisk){
+                if (_storagePolicy == OnDisk) {
                     entryI->free_error_vector_memory();
                     entryJ->free_error_vector_memory();
                 }
@@ -392,15 +371,15 @@ DIISManager::extrapolate(int numQuantities, ...)
     force[_subspace.size()] = 1.0;
     bMatrix[_subspace.size()][_subspace.size()] = 0.0;
 
-    timer_off("DIISManager::extrapolate: bMatrix setup");
-    timer_on("DIISManager::extrapolate: bMatrix pseudoinverse");
+    timer_off("bMatrix setup");
+    timer_on("bMatrix pseudoinverse");
 
     // => Balance <= //
 
-    double** Bp = B->pointer();
+    double **Bp = B->pointer();
 
-    SharedVector S(new Vector("S", dimension));
-    double* Sp = S->pointer();
+    auto S = std::make_shared<Vector>("S", dimension);
+    double *Sp = S->pointer();
 
     // Trap an explicit zero
     bool is_zero = false;
@@ -416,9 +395,9 @@ DIISManager::extrapolate(int numQuantities, ...)
         }
     } else {
         for (int i = 0; i < dimension - 1; i++) {
-            Sp[i] = pow(Bp[i][i],-1.0/2.0);
+            Sp[i] = pow(Bp[i][i], -1.0 / 2.0);
         }
-        Sp[dimension-1] = 1.0;
+        Sp[dimension - 1] = 1.0;
     }
 
     for (int i = 0; i < dimension; i++) {
@@ -430,14 +409,14 @@ DIISManager::extrapolate(int numQuantities, ...)
     // => S [S^-1 B S^-1] S \ f <= //
 
     B->power(-1.0, 1.0E-12);
-    C_DGEMV('N',dimension,dimension,1.0,Bp[0],dimension,force,1,0.0,coefficients,1);
+    C_DGEMV('N', dimension, dimension, 1.0, Bp[0], dimension, force, 1, 0.0, coefficients, 1);
     for (int i = 0; i < dimension; i++) {
         coefficients[i] *= Sp[i];
     }
 
-    timer_off("DIISManager::extrapolate: bMatrix pseudoinverse");
+    timer_off("bMatrix pseudoinverse");
 
-    timer_on("DIISManager::extrapolate: form new data");
+    timer_on("New vector");
 
     dpdfile2 *file2;
     dpdbuf4 *buf4;
@@ -445,33 +424,32 @@ DIISManager::extrapolate(int numQuantities, ...)
     Matrix *matrix;
     double *array;
     va_list args;
-    int print  = Process::environment.options.get_int("PRINT");
-    if(print > 2) outfile->Printf( "DIIS coefficients: ");
-    for(int n = 0; n < _subspace.size(); ++n){
+    int print = Process::environment.options.get_int("PRINT");
+    if (print > 2) outfile->Printf("DIIS coefficients: ");
+    for (int n = 0; n < _subspace.size(); ++n) {
         double coefficient = coefficients[n];
-        if(print > 2) outfile->Printf( " %.3f ", coefficient);
+        if (print > 2) outfile->Printf(" %.3f ", coefficient);
         const double *arrayPtr = _subspace[n]->vector();
         va_start(args, numQuantities);
-        for(int i=0; i < numQuantities; ++i) {
+        for (int i = 0; i < numQuantities; ++i) {
             // The indexing arrays contain the error vector, then the vector, so they
             // need to be offset by the number of components in the error vector
             int componentIndex = i + _numErrorVectorComponents;
             DIISEntry::InputType type = _componentTypes[componentIndex];
-            switch(type){
+            switch (type) {
                 case DIISEntry::Pointer:
-                    array = va_arg(args, double*);
-                    if(!n) ::memset(array, 0, _componentSizes[componentIndex] * sizeof(double));
-                    for(int j = 0; j < _componentSizes[componentIndex]; ++j)
-                        array[j] += coefficient * *arrayPtr++;
+                    array = va_arg(args, double *);
+                    if (!n) ::memset(array, 0, _componentSizes[componentIndex] * sizeof(double));
+                    for (int j = 0; j < _componentSizes[componentIndex]; ++j) array[j] += coefficient * *arrayPtr++;
                     break;
                 case DIISEntry::DPDBuf4:
-                    buf4 = va_arg(args, dpdbuf4*);
-                    if(!n) global_dpd_->buf4_scm(buf4, 0.0);
-                    for(int h = 0; h < buf4->params->nirreps; ++h){
+                    buf4 = va_arg(args, dpdbuf4 *);
+                    if (!n) global_dpd_->buf4_scm(buf4, 0.0);
+                    for (int h = 0; h < buf4->params->nirreps; ++h) {
                         global_dpd_->buf4_mat_irrep_init(buf4, h);
                         global_dpd_->buf4_mat_irrep_rd(buf4, h);
-                        for(int row = 0; row < buf4->params->rowtot[h]; ++row){
-                            for(int col = 0; col < buf4->params->coltot[h]; ++col){
+                        for (int row = 0; row < buf4->params->rowtot[h]; ++row) {
+                            for (int col = 0; col < buf4->params->coltot[h]; ++col) {
                                 buf4->matrix[h][row][col] += coefficient * *arrayPtr++;
                             }
                         }
@@ -480,14 +458,14 @@ DIISManager::extrapolate(int numQuantities, ...)
                     }
                     break;
                 case DIISEntry::DPDFile2:
-                    file2 = va_arg(args, dpdfile2*);
-                    if(!n) global_dpd_->file2_scm(file2, 0.0);
+                    file2 = va_arg(args, dpdfile2 *);
+                    if (!n) global_dpd_->file2_scm(file2, 0.0);
                     global_dpd_->file2_mat_init(file2);
                     global_dpd_->file2_mat_rd(file2);
-                    for(int h = 0; h < file2->params->nirreps; ++h){
-                        for(int row = 0; row < file2->params->rowtot[h]; ++row){
-                            for(int col = 0; col < file2->params->coltot[h]; ++col){
-                                 file2->matrix[h][row][col] += coefficient * *arrayPtr++;
+                    for (int h = 0; h < file2->params->nirreps; ++h) {
+                        for (int row = 0; row < file2->params->rowtot[h]; ++row) {
+                            for (int col = 0; col < file2->params->coltot[h]; ++col) {
+                                file2->matrix[h][row][col] += coefficient * *arrayPtr++;
                             }
                         }
                     }
@@ -495,27 +473,27 @@ DIISManager::extrapolate(int numQuantities, ...)
                     global_dpd_->file2_mat_close(file2);
                     break;
                 case DIISEntry::Matrix:
-                    matrix = va_arg(args, Matrix*);
-                    if(!n) matrix->zero();
-                    for(int h = 0; h < matrix->nirrep(); ++h){
-                        for(int row = 0; row < matrix->rowspi()[h]; ++row){
-                            for(int col = 0; col < matrix->colspi()[h]; ++col){
+                    matrix = va_arg(args, Matrix *);
+                    if (!n) matrix->zero();
+                    for (int h = 0; h < matrix->nirrep(); ++h) {
+                        for (int row = 0; row < matrix->rowspi()[h]; ++row) {
+                            for (int col = 0; col < matrix->colspi()[h]; ++col) {
                                 matrix->add(h, row, col, coefficient * *arrayPtr++);
                             }
                         }
                     }
                     break;
                 case DIISEntry::Vector:
-                    vector = va_arg(args, Vector*);
-                    if(!n){
-                        for(int h = 0; h < vector->nirrep(); ++h){
-                            for(int row = 0; row < vector->dimpi()[h]; ++row){
+                    vector = va_arg(args, Vector *);
+                    if (!n) {
+                        for (int h = 0; h < vector->nirrep(); ++h) {
+                            for (int row = 0; row < vector->dimpi()[h]; ++row) {
                                 vector->set(h, row, 0.0);
                             }
                         }
                     }
-                    for(int h = 0; h < vector->nirrep(); ++h){
-                        for(int row = 0; row < vector->dimpi()[h]; ++row){
+                    for (int h = 0; h < vector->nirrep(); ++h) {
+                        for (int row = 0; row < vector->dimpi()[h]; ++row) {
                             double val = vector->get(h, row);
                             vector->set(h, row, coefficient * *arrayPtr++ + val);
                         }
@@ -525,13 +503,13 @@ DIISManager::extrapolate(int numQuantities, ...)
                     throw SanityCheckError("Unknown input type", __FILE__, __LINE__);
             }
         }
-        if(_storagePolicy == OnDisk) _subspace[n]->free_vector_memory();
+        if (_storagePolicy == OnDisk) _subspace[n]->free_vector_memory();
         va_end(args);
     }
 
-    timer_off("DIISManager::extrapolate: form new data");
+    timer_off("New vector");
 
-    if(print > 2) outfile->Printf( "\n");
+    if (print > 2) outfile->Printf("\n");
     free(coefficients);
     free(force);
 
@@ -540,38 +518,31 @@ DIISManager::extrapolate(int numQuantities, ...)
     return true;
 }
 
-
 /**
  * Removes any vectors existing in the DIIS subspace.
  */
-void
-DIISManager::reset_subspace()
-{
-    for(int i = 0; i < _subspace.size(); ++i) delete _subspace[i];
+void DIISManager::reset_subspace() {
+    for (int i = 0; i < _subspace.size(); ++i) delete _subspace[i];
     _subspace.clear();
 }
 
 /**
  * Deletes the DIIS scratch file
  */
-void
-DIISManager::delete_diis_file()
-{
+void DIISManager::delete_diis_file() {
     if (_psio->open_check(PSIF_LIBDIIS) == 0) {
         _psio->open(PSIF_LIBDIIS, PSIO_OPEN_OLD);
     }
     _psio->close(PSIF_LIBDIIS, 0);
 }
 
-DIISManager::~DIISManager()
-{
-    for (int i=0; i<_subspace.size(); ++i) {
-        DIISEntry* temp = _subspace[i];
+DIISManager::~DIISManager() {
+    for (int i = 0; i < _subspace.size(); ++i) {
+        DIISEntry *temp = _subspace[i];
         delete temp;
     }
     _subspace.clear();
-    if (_psio->open_check(PSIF_LIBDIIS))
-        _psio->close(PSIF_LIBDIIS, 1);
+    if (_psio->open_check(PSIF_LIBDIIS)) _psio->close(PSIF_LIBDIIS, 1);
 }
 
-} // Namespace
+}  // Namespace
