@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -41,7 +41,7 @@
 #include <pthread.h>
 #include "dpd.h"
 #include "psi4/psi4-dec.h"
-#include "psi4/libparallel/ParallelPrinter.h"
+#include "psi4/libpsi4util/PsiOutStream.h"
 //MKL Header
 #ifdef USING_LAPACK_MKL
 #include <mkl.h>
@@ -72,7 +72,7 @@ void DPD::cc3_sigma_RHF_ic(dpdbuf4 *CIjAb, dpdbuf4 *WAbEi, dpdbuf4 *WMbIj,
                            double omega, std::string out, int nthreads, int newtrips)
 {
    std::shared_ptr<psi::PsiOutStream> printer=(out=="outfile"?outfile:
-            std::shared_ptr<OutFile>(new OutFile(out)));
+            std::make_shared<PsiOutStream>(out));
     int h, nirreps, thread, nijk, *ijk_part, errcod=0;
     int Gi, Gj, Gk, Gl, Ga, Gb, Gc, Gd;
     int i, j, k, l, a, b, c, d, row, col;
@@ -239,7 +239,7 @@ void DPD::cc3_sigma_RHF_ic(dpdbuf4 *CIjAb, dpdbuf4 *WAbEi, dpdbuf4 *WMbIj,
                 /* execute threads */
                 for (thread=0;thread<nthreads;++thread) {
                     if (!ijk_part[thread]) continue;
-                    errcod = pthread_create(&(p_thread[thread]), NULL, cc3_sigma_RHF_ic_thread,
+                    errcod = pthread_create(&(p_thread[thread]), nullptr, cc3_sigma_RHF_ic_thread,
                                             (void *) &thread_data_array[thread]);
                     if (errcod) {
                         outfile->Printf("pthread_create in cc3_sigma_RHF_ic failed\n");
@@ -249,7 +249,7 @@ void DPD::cc3_sigma_RHF_ic(dpdbuf4 *CIjAb, dpdbuf4 *WAbEi, dpdbuf4 *WMbIj,
 
                 for (thread=0; thread<nthreads;++thread) {
                     if (!ijk_part[thread]) continue;
-                    errcod = pthread_join(p_thread[thread], NULL);
+                    errcod = pthread_join(p_thread[thread], nullptr);
                     if (errcod) {
                         outfile->Printf("pthread_join in cc3_sigma_RHF_ic failed\n");
                         exit(PSI_RETURN_FAILURE);
@@ -344,7 +344,7 @@ void* cc3_sigma_RHF_ic_thread(void* thread_data_in)
     double omega;
     dpdfile2 *FME, *fIJ, *fAB;
     dpdbuf4 *CIjAb, *WAbEi, *WMbIj, *Dints, *WmAEf, *WMnIe;
-    std::string OutFileRMR;
+    std::string out_fname;
     int newtrips;
     int Gcb, Gac, cb, ac;
 
@@ -923,7 +923,7 @@ void* cc3_sigma_RHF_ic_thread(void* thread_data_in)
     free(Wa);
     free(Va);
 
-    pthread_exit(NULL);
+    pthread_exit(nullptr);
 }
 
 }
