@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -26,7 +26,6 @@
  * @END LICENSE
  */
 
-#include "psi4/lib3index/3index.h"
 #include "psi4/libpsio/psio.hpp"
 #include "psi4/libpsio/psio.h"
 #include "psi4/libpsio/aiohandler.h"
@@ -36,24 +35,17 @@
 #include "psi4/libmints/sieve.h"
 #include "psi4/libiwl/iwl.hpp"
 #include "jk.h"
-#include "jk_independent.h"
-#include "link.h"
-#include "direct_screening.h"
-#include "cubature.h"
-#include "points.h"
 
-#include "psi4/lib3index/cholesky.h"
 #include "psi4/libmints/matrix.h"
 #include "psi4/libmints/basisset.h"
 #include "psi4/libmints/sobasis.h"
 #include "psi4/libmints/mintshelper.h"
 #include <sstream>
-#include "psi4/libparallel/ParallelPrinter.h"
+#include "psi4/libpsi4util/PsiOutStream.h"
 #ifdef _OPENMP
 #include <omp.h>
 #endif
 
-using namespace std;
 using namespace psi;
 
 namespace psi {
@@ -86,7 +78,7 @@ void DiskJK::print_header() const
 }
 void DiskJK::preiterations()
 {
-    std::shared_ptr<MintsHelper> mints(new MintsHelper(primary_, options_, 0));
+    auto mints = std::make_shared<MintsHelper>(primary_, options_, 0);
     mints->integrals();
     if(do_wK_)
         mints->integrals_erf(omega_);
@@ -110,7 +102,7 @@ void DiskJK::preiterations()
 }
 void DiskJK::compute_JK()
 {
-    std::shared_ptr<PSIO> psio(new PSIO());
+    auto psio = std::make_shared<PSIO>();
     IWL *iwl = new IWL(psio.get(), PSIF_SO_TEI, cutoff_, 1, 1);
     Label *lblptr = iwl->labels();
     Value *valptr = iwl->values();
@@ -122,7 +114,7 @@ void DiskJK::compute_JK()
             lastBuffer = iwl->last_buffer();
             for(int index = 0; index < iwl->buffer_count(); ++index){
                 labelIndex = 4*index;
-                pabs  = abs((int) lblptr[labelIndex++]);
+                pabs  = std::abs((int) lblptr[labelIndex++]);
                 qabs  = (int) lblptr[labelIndex++];
                 rabs  = (int) lblptr[labelIndex++];
                 sabs  = (int) lblptr[labelIndex++];
@@ -296,7 +288,7 @@ void DiskJK::compute_JK()
             lastBuffer = iwl->last_buffer();
             for(int index = 0; index < iwl->buffer_count(); ++index){
                 labelIndex = 4*index;
-                pabs  = abs((int) lblptr[labelIndex++]);
+                pabs  = std::abs((int) lblptr[labelIndex++]);
                 qabs  = (int) lblptr[labelIndex++];
                 rabs  = (int) lblptr[labelIndex++];
                 sabs  = (int) lblptr[labelIndex++];
@@ -484,7 +476,7 @@ void DiskJK::compute_JK()
             lastBuffer = iwl->last_buffer();
             for(int index = 0; index < iwl->buffer_count(); ++index){
                 labelIndex = 4*index;
-                pabs  = abs((int) lblptr[labelIndex++]);
+                pabs  = std::abs((int) lblptr[labelIndex++]);
                 qabs  = (int) lblptr[labelIndex++];
                 rabs  = (int) lblptr[labelIndex++];
                 sabs  = (int) lblptr[labelIndex++];
