@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -26,15 +26,16 @@
  * @END LICENSE
  */
 
-
-#include "psi4/libqt/qt.h"
-#include "psi4/psi4-dec.h"
 #include "points.h"
 #include "hamiltonian.h"
 #include "jk.h"
 #include "v.h"
+
+#include "psi4/libqt/qt.h"
+#include "psi4/psi4-dec.h"
 #include "psi4/libmints/vector.h"
 #include "psi4/libmints/matrix.h"
+#include "psi4/libpsi4util/PsiOutStream.h"
 
 #include <sstream>
 
@@ -80,7 +81,7 @@ SharedMatrix RHamiltonian::explicit_hamiltonian()
 {
     std::shared_ptr<Vector> diag = diagonal();
 
-    SharedMatrix H(new Matrix("Explicit Hamiltonian", diag->nirrep(), diag->dimpi(), diag->dimpi()));
+    auto H = std::make_shared<Matrix>("Explicit Hamiltonian", diag->nirrep(), diag->dimpi(), diag->dimpi());
 
     std::shared_ptr<Vector> b(diag->clone());
     std::shared_ptr<Vector> s(diag->clone());
@@ -128,7 +129,7 @@ void MatrixRHamiltonian::print_header() const
 }
 std::shared_ptr<Vector> MatrixRHamiltonian::diagonal()
 {
-    std::shared_ptr<Vector> diag(new Vector("Matrix Diagonal", M_->rowspi()));
+    auto diag = std::make_shared<Vector>("Matrix Diagonal", M_->rowspi());
     for (int h = 0; h < M_->nirrep(); ++h) {
         int n = M_->rowspi()[h];
         if (!n) continue;
@@ -170,8 +171,8 @@ void MatrixUHamiltonian::print_header() const
 }
 std::pair<std::shared_ptr<Vector>, std::shared_ptr<Vector> > MatrixUHamiltonian::diagonal()
 {
-    std::shared_ptr<Vector> diaga(new Vector("Alpha Matrix Diagonal", M_.first->rowspi()));
-    std::shared_ptr<Vector> diagb(new Vector("Beta Matrix Diagonal", M_.first->rowspi()));
+    auto diaga = std::make_shared<Vector>("Alpha Matrix Diagonal", M_.first->rowspi());
+    auto diagb = std::make_shared<Vector>("Beta Matrix Diagonal", M_.first->rowspi());
     for (int h = 0; h < M_.first->nirrep(); ++h) {
         int n = M_.first->rowspi()[h];
         if (!n) continue;
@@ -234,7 +235,7 @@ std::shared_ptr<Vector> CISRHamiltonian::diagonal()
         }
     }
 
-    std::shared_ptr<Vector> diag(new Vector("CIS Diagonal", nov));
+    auto diag = std::make_shared<Vector>("CIS Diagonal", nov);
 
     for (int symm = 0; symm < nirrep; ++symm) {
         long int offset = 0L;
@@ -327,7 +328,7 @@ void CISRHamiltonian::product(const std::vector<std::shared_ptr<Vector> >& x,
 
                 std::stringstream ss;
                 ss << "C_left, h = " << symm << ", N = " << N;
-                SharedMatrix Cl(new Matrix(ss.str(), Caocc_->nirrep(), Caocc_->rowspi(), rank));
+                auto Cl = std::make_shared<Matrix>(ss.str(), Caocc_->nirrep(), Caocc_->rowspi(), rank);
 
                 double** Clp = Cl->pointer(delta_h);
                 double** Cop = Caocc_->pointer(delta_h);
@@ -335,7 +336,7 @@ void CISRHamiltonian::product(const std::vector<std::shared_ptr<Vector> >& x,
 
                 std::stringstream ss2;
                 ss2 << "C_right, h = " << symm << ", N = " << N;
-                SharedMatrix Cr(new Matrix(ss2.str(), Caocc_->nirrep(), Caocc_->rowspi(), rank, symm));
+                auto Cr = std::make_shared<Matrix>(ss2.str(), Caocc_->nirrep(), Caocc_->rowspi(), rank, symm);
 
                 double** Crp = Cr->pointer(delta_h^symm);
                 double** Cvp = Cavir_->pointer(delta_h^symm);
@@ -347,7 +348,7 @@ void CISRHamiltonian::product(const std::vector<std::shared_ptr<Vector> >& x,
             } else {
                 std::stringstream ss;
                 ss << "C_right, h = " << symm << ", N = " << N;
-                SharedMatrix Cr(new Matrix(ss.str(), Caocc_->nirrep(), Caocc_->rowspi(), Caocc_->colspi(), symm));
+                auto Cr = std::make_shared<Matrix>(ss.str(), Caocc_->nirrep(), Caocc_->rowspi(), Caocc_->colspi(), symm);
 
                 offset = 0L;
                 for (int h = 0; h < Caocc_->nirrep(); ++h) {
@@ -439,7 +440,7 @@ std::vector<SharedMatrix > CISRHamiltonian::unpack(const std::shared_ptr<Vector>
     int nirrep = eig->nirrep();
     std::vector<SharedMatrix > t1;
     for (int symm = 0; symm < nirrep; ++symm) {
-        SharedMatrix t(new Matrix("T",Caocc_->nirrep(), Caocc_->colspi(), Cavir_->colspi(), symm));
+        auto t = std::make_shared<Matrix>("T",Caocc_->nirrep(), Caocc_->colspi(), Cavir_->colspi(), symm);
         long int offset = 0L;
         for (int h = 0; h < nirrep; ++h) {
             int nocc = Caocc_->colspi()[h];
@@ -485,7 +486,7 @@ std::shared_ptr<Vector> TDHFRHamiltonian::diagonal()
         }
     }
 
-    std::shared_ptr<Vector> diag(new Vector("TDHF Diagonal", nov));
+    auto diag = std::make_shared<Vector>("TDHF Diagonal", nov);
 
     for (int symm = 0; symm < nirrep; ++symm) {
         long int offset = 0L;
@@ -535,7 +536,7 @@ void TDHFRHamiltonian::product(const std::vector<std::shared_ptr<Vector> >& x,
 
             std::stringstream ss;
             ss << "C_right_X, h = " << symm << ", N = " << N;
-            SharedMatrix CXr(new Matrix(ss.str(), Caocc_->nirrep(), Caocc_->rowspi(), Caocc_->colspi(), symm));
+            auto CXr = std::make_shared<Matrix>(ss.str(), Caocc_->nirrep(), Caocc_->rowspi(), Caocc_->colspi(), symm);
 
             long int offset = 0L;
             for (int h = 0; h < Caocc_->nirrep(); ++h) {
@@ -558,7 +559,7 @@ void TDHFRHamiltonian::product(const std::vector<std::shared_ptr<Vector> >& x,
 
             std::stringstream ss2;
             ss2 << "C_right_Y, h = " << symm << ", N = " << N;
-            SharedMatrix CYr(new Matrix(ss.str(), Caocc_->nirrep(), Caocc_->rowspi(), Caocc_->colspi(), symm));
+            auto CYr = std::make_shared<Matrix>(ss.str(), Caocc_->nirrep(), Caocc_->rowspi(), Caocc_->colspi(), symm);
 
             offset = 0L;
             for (int h = 0; h < Caocc_->nirrep(); ++h) {
@@ -709,7 +710,7 @@ std::shared_ptr<Vector> CPHFRHamiltonian::diagonal()
         }
     }
 
-    std::shared_ptr<Vector> diag(new Vector("CPHF Diagonal", nov));
+    auto diag = std::make_shared<Vector>("CPHF Diagonal", nov);
 
     for (int symm = 0; symm < nirrep; ++symm) {
         long int offset = 0L;
@@ -748,7 +749,7 @@ std::map<std::string, SharedVector> CPHFRHamiltonian::pack(const std::map<std::s
     for (std::map<std::string, SharedMatrix>::const_iterator it = x.begin();
         it != x.end(); ++it) {
 
-        std::shared_ptr<Vector> v(new Vector("X", nov));
+        auto v = std::make_shared<Vector>("X", nov);
         SharedMatrix x2 = (*it).second;
         int symm = x2->symmetry();
         int offset = 0;
@@ -784,7 +785,7 @@ void CPHFRHamiltonian::product(const std::vector<std::shared_ptr<Vector> >& x,
 
             std::stringstream ss;
             ss << "C_right, h = " << symm << ", N = " << N;
-            SharedMatrix Cr(new Matrix(ss.str(), Caocc_->nirrep(), Caocc_->rowspi(), Caocc_->colspi(), symm));
+            auto Cr = std::make_shared<Matrix>(ss.str(), Caocc_->nirrep(), Caocc_->rowspi(), Caocc_->colspi(), symm);
 
             long int offset = 0L;
             for (int h = 0; h < Caocc_->nirrep(); ++h) {
@@ -876,7 +877,7 @@ std::vector<SharedMatrix > CPHFRHamiltonian::unpack(const std::vector<std::share
     int nirrep = x[0]->nirrep();
     for (size_t i = 0; i < x.size(); i++) {
         for (int symm = 0; symm < nirrep; ++symm) {
-            SharedMatrix t(new Matrix("X",Caocc_->nirrep(), Caocc_->colspi(), Cavir_->colspi(), symm));
+            auto t = std::make_shared<Matrix>("X",Caocc_->nirrep(), Caocc_->colspi(), Cavir_->colspi(), symm);
             long int offset = 0L;
             for (int h = 0; h < nirrep; ++h) {
                 int nocc = Caocc_->colspi()[h];
@@ -905,17 +906,17 @@ TDARHamiltonian::TDARHamiltonian(std::shared_ptr<JK> jk,
                     std::shared_ptr<Vector> eps_avir) :
     CISRHamiltonian(jk,Caocc,Cavir,eps_aocc,eps_avir,v), Cocc_(Cocc)
 {
-    std::vector<SharedMatrix>& C = v->C();
-    C.clear();
-    C.push_back(Cocc);
+    // std::vector<SharedMatrix>& C = v->C();
+    // C.clear();
+    // C.push_back(Cocc);
 
-    std::vector<SharedMatrix>& Cao = v->Caocc();
-    Cao.clear();
-    Cao.push_back(Caocc);
+    //std::vector<SharedMatrix>& Cao = v->Caocc();
+    //Cao.clear();
+    //Cao.push_back(Caocc);
 
-    std::vector<SharedMatrix>& Cav = v->Cavir();
-    Cav.clear();
-    Cav.push_back(Cavir);
+    //std::vector<SharedMatrix>& Cav = v->Cavir();
+    //Cav.clear();
+    //Cav.push_back(Cavir);
 }
 TDARHamiltonian::~TDARHamiltonian()
 {
@@ -931,11 +932,11 @@ void TDARHamiltonian::product(const std::vector<std::shared_ptr<Vector> >& x,
 {
     std::vector<SharedMatrix >& C_left = jk_->C_left();
     std::vector<SharedMatrix >& C_right = jk_->C_right();
-    std::vector<SharedMatrix >& P = v_->P();
+    // std::vector<SharedMatrix >& P = v_->P();
 
     C_left.clear();
     C_right.clear();
-    P.clear();
+    // P.clear();
 
     int nirrep = (x.size() ? x[0]->nirrep() : 0);
 
@@ -946,7 +947,7 @@ void TDARHamiltonian::product(const std::vector<std::shared_ptr<Vector> >& x,
 
             std::stringstream ss;
             ss << "C_right, h = " << symm << ", N = " << N;
-            SharedMatrix Cr(new Matrix(ss.str(), Caocc_->nirrep(), Caocc_->rowspi(), Caocc_->colspi(), symm));
+            auto Cr = std::make_shared<Matrix>(ss.str(), Caocc_->nirrep(), Caocc_->rowspi(), Caocc_->colspi(), symm);
 
             long int offset = 0L;
             for (int h = 0; h < Caocc_->nirrep(); ++h) {
@@ -969,7 +970,7 @@ void TDARHamiltonian::product(const std::vector<std::shared_ptr<Vector> >& x,
 
             std::stringstream ss2;
             ss2 << "P, h = " << symm << ", N = " << N;
-            SharedMatrix P2(new Matrix(ss2.str(), Caocc_->colspi(), Cavir_->colspi(), symm));
+            auto P2 = std::make_shared<Matrix>(ss2.str(), Caocc_->colspi(), Cavir_->colspi(), symm);
 
             offset = 0L;
             for (int h = 0; h < Caocc_->nirrep(); ++h) {
@@ -982,16 +983,16 @@ void TDARHamiltonian::product(const std::vector<std::shared_ptr<Vector> >& x,
                 offset += nocc * nvir;
             }
 
-            P.push_back(P2);
+            // P.push_back(P2);
         }
     }
 
     jk_->compute();
-    v_->compute();
+    // v_->compute();
 
     const std::vector<SharedMatrix >& J = jk_->J();
 //    const std::vector<SharedMatrix >& K = jk_->K();
-    const std::vector<SharedMatrix >& V = v_->V();
+//    const std::vector<SharedMatrix >& V = v_->V();
 
     double* Tp = new double[Caocc_->max_nrow() * Caocc_->max_ncol()];
 
@@ -1018,7 +1019,7 @@ void TDARHamiltonian::product(const std::vector<std::shared_ptr<Vector> >& x,
 
                 double** Jp  = J[symm * x.size() + N]->pointer(h);
 //                double** Kp  = K[symm * x.size() + N]->pointer(h);
-                double** Vp  = V[symm * x.size() + N]->pointer(h);
+//                double** Vp  = V[symm * x.size() + N]->pointer(h);
 
                 // TODO: hybrid/RC terms
                 // -(ij|ab)P_jb = C_im K_mn C_na
@@ -1032,8 +1033,8 @@ void TDARHamiltonian::product(const std::vector<std::shared_ptr<Vector> >& x,
                 }
 
                 // V matrix
-                C_DGEMM('T','N',nocc,nsovir,nsoocc,1.0,Cop[0],nocc,Vp[0],nsovir,0.0,Tp,nsovir);
-                C_DGEMM('N','N',nocc,nvir,nsovir,1.0,Tp,nsovir,Cvp[0],nvir,1.0,&bp[offset],nvir);
+                // C_DGEMM('T','N',nocc,nsovir,nsoocc,1.0,Cop[0],nocc,Vp[0],nsovir,0.0,Tp,nsovir);
+                // C_DGEMM('N','N',nocc,nvir,nsovir,1.0,Tp,nsovir,Cvp[0],nvir,1.0,&bp[offset],nvir);
 
                 for (int i = 0; i < nocc; ++i) {
                     for (int a = 0; a < nvir; ++a) {
@@ -1065,17 +1066,17 @@ TDDFTRHamiltonian::TDDFTRHamiltonian(std::shared_ptr<JK> jk,
                     std::shared_ptr<Vector> eps_avir) :
     TDHFRHamiltonian(jk,Caocc,Cavir,eps_aocc,eps_avir,v), Cocc_(Cocc)
 {
-    std::vector<SharedMatrix>& C = v->C();
-    C.clear();
-    C.push_back(Cocc);
+    // std::vector<SharedMatrix>& C = v->C();
+    // C.clear();
+    // C.push_back(Cocc);
 
-    std::vector<SharedMatrix>& Cao = v->Caocc();
-    Cao.clear();
-    Cao.push_back(Caocc);
+    // std::vector<SharedMatrix>& Cao = v->Caocc();
+    // Cao.clear();
+    // Cao.push_back(Caocc);
 
-    std::vector<SharedMatrix>& Cav = v->Cavir();
-    Cav.clear();
-    Cav.push_back(Cavir);
+    // std::vector<SharedMatrix>& Cav = v->Cavir();
+    // Cav.clear();
+    // Cav.push_back(Cavir);
 }
 TDDFTRHamiltonian::~TDDFTRHamiltonian()
 {
@@ -1111,7 +1112,7 @@ void TDDFTRHamiltonian::product(const std::vector<std::shared_ptr<Vector> >& x,
 
             std::stringstream ss;
             ss << "C_right_X, h = " << symm << ", N = " << N;
-            SharedMatrix CXr(new Matrix(ss.str(), Caocc_->nirrep(), Caocc_->rowspi(), Caocc_->colspi(), symm));
+            auto CXr = std::make_shared<Matrix>(ss.str(), Caocc_->nirrep(), Caocc_->rowspi(), Caocc_->colspi(), symm);
 
             long int offset = 0L;
             for (int h = 0; h < Caocc_->nirrep(); ++h) {
@@ -1134,7 +1135,7 @@ void TDDFTRHamiltonian::product(const std::vector<std::shared_ptr<Vector> >& x,
 
             std::stringstream ss2;
             ss2 << "C_right_Y, h = " << symm << ", N = " << N;
-            SharedMatrix CYr(new Matrix(ss.str(), Caocc_->nirrep(), Caocc_->rowspi(), Caocc_->colspi(), symm));
+            auto CYr = std::make_shared<Matrix>(ss.str(), Caocc_->nirrep(), Caocc_->rowspi(), Caocc_->colspi(), symm);
 
             offset = 0L;
             for (int h = 0; h < Caocc_->nirrep(); ++h) {
@@ -1267,17 +1268,17 @@ CPKSRHamiltonian::CPKSRHamiltonian(std::shared_ptr<JK> jk,
                     std::shared_ptr<Vector> eps_avir) :
     CPHFRHamiltonian(jk,Caocc,Cavir,eps_aocc,eps_avir,v), Cocc_(Cocc)
 {
-    std::vector<SharedMatrix>& C = v->C();
-    C.clear();
-    C.push_back(Cocc);
+    // std::vector<SharedMatrix>& C = v->C();
+    // C.clear();
+    // C.push_back(Cocc);
 
-    std::vector<SharedMatrix>& Cao = v->Caocc();
-    Cao.clear();
-    Cao.push_back(Caocc);
+    // std::vector<SharedMatrix>& Cao = v->Caocc();
+    // Cao.clear();
+    // Cao.push_back(Caocc);
 
-    std::vector<SharedMatrix>& Cav = v->Cavir();
-    Cav.clear();
-    Cav.push_back(Cavir);
+    // std::vector<SharedMatrix>& Cav = v->Cavir();
+    // Cav.clear();
+    // Cav.push_back(Cavir);
 }
 CPKSRHamiltonian::~CPKSRHamiltonian()
 {
@@ -1308,7 +1309,7 @@ void CPKSRHamiltonian::product(const std::vector<std::shared_ptr<Vector> >& x,
 
             std::stringstream ss;
             ss << "C_right, h = " << symm << ", N = " << N;
-            SharedMatrix Cr(new Matrix(ss.str(), Caocc_->nirrep(), Caocc_->rowspi(), Caocc_->colspi(), symm));
+            auto Cr = std::make_shared<Matrix>(ss.str(), Caocc_->nirrep(), Caocc_->rowspi(), Caocc_->colspi(), symm);
 
             long int offset = 0L;
             for (int h = 0; h < Caocc_->nirrep(); ++h) {
@@ -1438,8 +1439,8 @@ std::pair<std::shared_ptr<Vector>, std::shared_ptr<Vector> > USTABHamiltonian::d
         }
     }
 
-    std::shared_ptr<Vector> diaga(new Vector("UStab Alpha Diagonal", nova));
-    std::shared_ptr<Vector> diagb(new Vector("UStab Beta Diagonal", novb));
+    auto diaga = std::make_shared<Vector>("UStab Alpha Diagonal", nova);
+    auto diagb = std::make_shared<Vector>("UStab Beta Diagonal", novb);
 
     for (int symm = 0; symm < nirrepa; ++symm) {
         long int offset = 0L;
@@ -1547,7 +1548,7 @@ void USTABHamiltonian::product(const std::vector<std::pair <std::shared_ptr<Vect
 
                 std::stringstream ss;
                 ss << "C_left alpha, h = " << symm << ", N = " << N;
-                SharedMatrix Cl(new Matrix(ss.str(), Cocca_->nirrep(), Cocca_->rowspi(), rank));
+                auto Cl = std::make_shared<Matrix>(ss.str(), Cocca_->nirrep(), Cocca_->rowspi(), rank);
 
                 double** Clp = Cl->pointer(delta_h);
                 double** Cop = Cocca_->pointer(delta_h);
@@ -1555,7 +1556,7 @@ void USTABHamiltonian::product(const std::vector<std::pair <std::shared_ptr<Vect
 
                 std::stringstream ss2;
                 ss2 << "C_right alpha, h = " << symm << ", N = " << N;
-                SharedMatrix Cr(new Matrix(ss2.str(), Cocca_->nirrep(), Cocca_->rowspi(), rank, symm));
+                auto Cr = std::make_shared<Matrix>(ss2.str(), Cocca_->nirrep(), Cocca_->rowspi(), rank, symm);
 
                 double** Crp = Cr->pointer(delta_h^symm);
                 double** Cvp = Cvira_->pointer(delta_h^symm);
@@ -1567,7 +1568,7 @@ void USTABHamiltonian::product(const std::vector<std::pair <std::shared_ptr<Vect
             } else {
                 std::stringstream ss;
                 ss << "C_right alpha, h = " << symm << ", N = " << N;
-                SharedMatrix Cr(new Matrix(ss.str(), Cocca_->nirrep(), Cocca_->rowspi(), Cocca_->colspi(), symm));
+                auto Cr = std::make_shared<Matrix>(ss.str(), Cocca_->nirrep(), Cocca_->rowspi(), Cocca_->colspi(), symm);
 
                 offset = 0L;
                 for (int h = 0; h < Cocca_->nirrep(); ++h) {
@@ -1636,7 +1637,7 @@ void USTABHamiltonian::product(const std::vector<std::pair <std::shared_ptr<Vect
 
                 std::stringstream ss;
                 ss << "C_left beta, h = " << symm << ", N = " << N;
-                SharedMatrix Cl(new Matrix(ss.str(), Coccb_->nirrep(), Coccb_->rowspi(), rank));
+                auto Cl = std::make_shared<Matrix>(ss.str(), Coccb_->nirrep(), Coccb_->rowspi(), rank);
 
                 double** Clp = Cl->pointer(delta_h);
                 double** Cop = Coccb_->pointer(delta_h);
@@ -1644,7 +1645,7 @@ void USTABHamiltonian::product(const std::vector<std::pair <std::shared_ptr<Vect
 
                 std::stringstream ss2;
                 ss2 << "C_right beta, h = " << symm << ", N = " << N;
-                SharedMatrix Cr(new Matrix(ss2.str(), Coccb_->nirrep(), Coccb_->rowspi(), rank, symm));
+                auto Cr = std::make_shared<Matrix>(ss2.str(), Coccb_->nirrep(), Coccb_->rowspi(), rank, symm);
 
                 double** Crp = Cr->pointer(delta_h^symm);
                 double** Cvp = Cvirb_->pointer(delta_h^symm);
@@ -1656,7 +1657,7 @@ void USTABHamiltonian::product(const std::vector<std::pair <std::shared_ptr<Vect
             } else {
                 std::stringstream ss;
                 ss << "C_right beta, h = " << symm << ", N = " << N;
-                SharedMatrix Cr(new Matrix(ss.str(), Coccb_->nirrep(), Coccb_->rowspi(), Coccb_->colspi(), symm));
+                auto Cr = std::make_shared<Matrix>(ss.str(), Coccb_->nirrep(), Coccb_->rowspi(), Coccb_->colspi(), symm);
 
                 offset = 0L;
                 for (int h = 0; h < Coccb_->nirrep(); ++h) {
@@ -1832,8 +1833,8 @@ std::vector<std::pair<SharedMatrix, SharedMatrix> > USTABHamiltonian::unpack_pai
     int nirrep = eig->nirrep();
     std::vector<std::pair<SharedMatrix, SharedMatrix> > t1;
     for (int symm = 0; symm < nirrep; ++symm) {
-        SharedMatrix talpha(new Matrix("T",Cocca_->nirrep(), Cocca_->colspi(), Cvira_->colspi(), symm));
-        SharedMatrix tbeta(new Matrix("T",Coccb_->nirrep(), Coccb_->colspi(), Cvirb_->colspi(), symm));
+        auto talpha = std::make_shared<Matrix>("T",Cocca_->nirrep(), Cocca_->colspi(), Cvira_->colspi(), symm);
+        auto tbeta = std::make_shared<Matrix>("T",Coccb_->nirrep(), Coccb_->colspi(), Cvirb_->colspi(), symm);
         long int offseta = 0L;
         long int offsetb = 0L;
         for (int h = 0; h < nirrep; ++h) {
