@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -26,15 +26,15 @@
  * @END LICENSE
  */
 
-#include <memory>
-#include <stdexcept>
 #include "psi4/libciomr/libciomr.h"
 #include "psi4/libmints/angularmomentum.h"
 #include "psi4/libmints/basisset.h"
+#include "psi4/libmints/molecule.h"
 #include "psi4/libmints/integral.h"
 #include "psi4/physconst.h"
 
-#define MAX(a, b) ((a) > (b) ? (a) : (b))
+#include <memory>
+#include <stdexcept>
 
 using namespace psi;
 
