@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -33,7 +33,6 @@
 */
 
 #include "psi4/libciomr/libciomr.h"
-#include "psi4/libparallel/parallel.h"
 #include "psi4/psifiles.h"
 
 #include "vector3.h"
@@ -44,13 +43,10 @@
 #include "integral.h"
 #include "gshell.h"
 #include "factory.h"
-#include "basisset_parser.h"
 #include "pointgrp.h"
 #include "wavefunction.h"
 #include "coordentry.h"
-#include "psi4/libparallel/ParallelPrinter.h"
-
-#include "psi4/pybind11.h"
+#include "psi4/libpsi4util/process.h"
 
 #include <memory>
 #include <regex>
@@ -65,11 +61,10 @@ using namespace psi;
 
 bool BasisSet::initialized_shared_ = false;
 
-std::vector <Vector3> BasisSet::exp_ao[LIBINT_MAX_AM];
+std::vector<Vector3> BasisSet::exp_ao[LIBINT_MAX_AM];
 
 namespace {
-bool has_ending(std::string const &fullString, std::string const &ending)
-{
+bool has_ending(std::string const &fullString, std::string const &ending) {
     if (fullString.length() >= ending.length()) {
         return (0 == fullString.compare(fullString.length() - ending.length(), ending.length(), ending));
     } else {
@@ -77,21 +72,19 @@ bool has_ending(std::string const &fullString, std::string const &ending)
     }
 }
 
-std::string to_upper_copy(const std::string &original)
-{
+std::string to_upper_copy(const std::string &original) {
     std::string upper = original;
     std::transform(upper.begin(), upper.end(), upper.begin(), ::toupper);
     return upper;
 }
-} // namespace anonmyous
+}  // namespace anonmyous
 
 // Constructs a zero AO basis set
-BasisSet::BasisSet()
-{
+BasisSet::BasisSet() {
     initialize_singletons();
 
     // Add a dummy atom at the origin, to hold this basis function
-    molecule_ = std::shared_ptr<Molecule>(new Molecule);
+    molecule_ = std::make_shared<Molecule>();
     molecule_->add_atom(0, 0.0, 0.0, 0.0);
     // Fill with data representing a single S function, at the origin, with 0 exponent
     n_uprimitive_ = 1;
@@ -136,27 +129,24 @@ BasisSet::BasisSet()
     name_ = "(Empty Basis Set)";
     key_ = "(Empty Basis Set)";
     target_ = "(Empty Basis Set)";
-    shells_[0] = GaussianShell(0, nprimitive_, uoriginal_coefficients_, ucoefficients_, uerd_coefficients_,
+    shells_[0] = GaussianShell(Gaussian, 0, nprimitive_, uoriginal_coefficients_, ucoefficients_, uerd_coefficients_,
                                uexponents_, GaussianType(0), 0, xyz_, 0);
 }
 
-std::shared_ptr <BasisSet> BasisSet::build(std::shared_ptr <Molecule> /*molecule*/,
-                                           const std::vector <ShellInfo> & /*shells*/)
-{
-//TRIAL//    //TODO fixme!!!
-//TRIAL//    std::shared_ptr <BasisSet> basis(new BasisSet());
-//TRIAL//    //    basis->molecule_ = molecule;
-//TRIAL//    //    basis->shells_ = shells;
-//TRIAL//    //    basis->refresh();
-//TRIAL//
+std::shared_ptr<BasisSet> BasisSet::build(std::shared_ptr<Molecule> /*molecule*/,
+                                          const std::vector<ShellInfo> & /*shells*/) {
+    // TRIAL//    //TODO fixme!!!
+    // TRIAL//    auto basis = std::make_shared<BasisSet>();
+    // TRIAL//    //    basis->molecule_ = molecule;
+    // TRIAL//    //    basis->shells_ = shells;
+    // TRIAL//    //    basis->refresh();
+    // TRIAL//
     throw NOT_IMPLEMENTED_EXCEPTION();
-//TRIAL//    return basis;
+    // TRIAL//    return basis;
 }
 
-void BasisSet::initialize_singletons()
-{
-    if (initialized_shared_ == true)
-        return;
+void BasisSet::initialize_singletons() {
+    if (initialized_shared_ == true) return;
 
     // Populate the exp_ao arrays
     for (int l = 0; l < LIBINT_MAX_AM; ++l) {
@@ -175,15 +165,52 @@ void BasisSet::initialize_singletons()
     initialized_shared_ = true;
 }
 
-std::shared_ptr <Molecule> BasisSet::molecule() const
-{
-    return molecule_;
+std::shared_ptr<Molecule> BasisSet::molecule() const { return molecule_; }
+
+int BasisSet::n_ecp_core() const {
+    int ncoreelectrons = 0;
+    for (int A = 0; A < molecule_->natom(); A++) ncoreelectrons += n_ecp_core(molecule_->label(A));
+    return ncoreelectrons;
 }
 
-void BasisSet::print(std::string out) const
-{
-    std::shared_ptr <psi::PsiOutStream> printer = (out == "outfile" ? outfile :
-                                                   std::shared_ptr<OutFile>(new OutFile(out)));
+int BasisSet::n_frozen_core(const std::string &depth, SharedMolecule mol) {
+    std::string local = depth;
+    if (depth.empty()) local = Process::environment.options.get_str("FREEZE_CORE");
+
+    SharedMolecule mymol = mol ? mol : molecule_;
+
+    if (local == "FALSE") {
+        return 0;
+    } else if (local == "TRUE") {
+        int nfzc = 0;
+        // Freeze the number of core electrons corresponding to the
+        // nearest previous noble gas atom.  This means that the 4p block
+        // will still have 3d electrons active.  Alkali earth atoms will
+        // have one valence electron in this scheme.
+        for (int A = 0; A < mymol->natom(); A++) {
+            double Z   = mymol->Z(A);
+            // Add ECPs to Z, the number of electrons less ECP-treated electrons
+            double ECP = n_ecp_core(mymol->label(A));
+            if (Z + ECP > 2) nfzc += 1;
+            if (Z + ECP > 10) nfzc += 4;
+            if (Z + ECP > 18) nfzc += 4;
+            if (Z + ECP > 36) nfzc += 9;
+            if (Z + ECP > 54) nfzc += 9;
+            if (Z + ECP > 86) nfzc += 16;
+            if (Z + ECP > 108) {
+                throw PSIEXCEPTION("Invalid atomic number");
+            }
+            // If this center has an ECP, some pairs are already frozen
+            if (ECP > 0) nfzc -= ECP/2;
+        }
+        return nfzc;
+    } else {
+        throw std::invalid_argument("Frozen core spec is not supported, options are {true, false}.");
+    }
+}
+
+void BasisSet::print(std::string out) const {
+    std::shared_ptr<psi::PsiOutStream> printer = (out == "outfile" ? outfile : std::make_shared<PsiOutStream>(out));
     printer->Printf("  Basis Set: %s\n", name_.c_str());
     printer->Printf("    Blend: %s\n", target_.c_str());
     printer->Printf("    Number of shells: %d\n", nshell());
@@ -191,10 +218,16 @@ void BasisSet::print(std::string out) const
     printer->Printf("    Number of Cartesian functions: %d\n", nao());
     printer->Printf("    Spherical Harmonics?: %s\n", has_puream() ? "true" : "false");
     printer->Printf("    Max angular momentum: %d\n\n", max_am());
+    if (has_ECP()) {
+        printer->Printf("  Core potential: %s\n", name_.c_str());
+        printer->Printf("    Number of shells: %d\n", n_ecp_shell());
+        printer->Printf("    Number of ECP primitives: %d\n", n_ecp_primitive());
+        printer->Printf("    Number of ECP core electrons: %d\n", n_ecp_core());
+        printer->Printf("    Max angular momentum: %d\n\n", max_ecp_am());
+    }
 }
 
-void BasisSet::print_by_level(std::string out, int level) const
-{
+void BasisSet::print_by_level(std::string out, int level) const {
     if (level < 1)
         return;
     else if (level == 1)
@@ -205,11 +238,9 @@ void BasisSet::print_by_level(std::string out, int level) const
         print_detail(out);
 }
 
-void BasisSet::print_summary(std::string out) const
-{
+void BasisSet::print_summary(std::string out) const {
+    std::shared_ptr<psi::PsiOutStream> printer = (out == "outfile" ? outfile : std::make_shared<PsiOutStream>(out));
 
-    std::shared_ptr <psi::PsiOutStream> printer = (out == "outfile" ? outfile :
-                                                   std::shared_ptr<OutFile>(new OutFile(out)));
     printer->Printf("  -AO BASIS SET INFORMATION:\n");
     printer->Printf("    Name                   = %s\n", name_.c_str());
     printer->Printf("    Blend                  = %s\n", target_.c_str());
@@ -225,23 +256,19 @@ void BasisSet::print_summary(std::string out) const
     printer->Printf("    Atom   Type   All Primitives // Shells:\n");
     printer->Printf("   ------ ------ --------------------------\n");
 
-
     int *nprims = new int[max_am_ + 1];
     int *nunique = new int[max_am_ + 1];
     int *nshells = new int[max_am_ + 1];
     char *amtypes = new char[max_am_ + 1];
 
     for (int A = 0; A < molecule_->natom(); A++) {
-
-        memset((void *) nprims, '\0', (max_am_ + 1) * sizeof(int));
-        memset((void *) nunique, '\0', (max_am_ + 1) * sizeof(int));
-        memset((void *) nshells, '\0', (max_am_ + 1) * sizeof(int));
-
+        memset((void *)nprims, '\0', (max_am_ + 1) * sizeof(int));
+        memset((void *)nunique, '\0', (max_am_ + 1) * sizeof(int));
+        memset((void *)nshells, '\0', (max_am_ + 1) * sizeof(int));
 
         printer->Printf("    %4d    ", A + 1);
         printer->Printf("%2s     ", molecule_->symbol(A).c_str());
 
-
         int first_shell = center_to_shell_[A];
         int n_shell = center_to_nshell_[A];
 
@@ -255,15 +282,13 @@ void BasisSet::print_summary(std::string out) const
 
         // All Primitives
         for (int l = 0; l < max_am_ + 1; l++) {
-            if (nprims[l] == 0)
-                continue;
+            if (nprims[l] == 0) continue;
             printer->Printf("%d%c ", nprims[l], amtypes[l]);
         }
         // Shells
         printer->Printf("// ");
         for (int l = 0; l < max_am_ + 1; l++) {
-            if (nshells[l] == 0)
-                continue;
+            if (nshells[l] == 0) continue;
             printer->Printf("%d%c ", nshells[l], amtypes[l]);
         }
         printer->Printf("\n");
@@ -274,13 +299,71 @@ void BasisSet::print_summary(std::string out) const
     delete[] nunique;
     delete[] nshells;
     delete[] amtypes;
+    if (has_ECP()) {
+        printer->Printf("  -CORE POTENTIAL INFORMATION:\n");
+        printer->Printf("    Total number of shells   = %d\n", n_ecp_shell());
+        printer->Printf("    Number of terms          = %d\n", n_ecp_primitive_);
+        printer->Printf("    Number of core electrons = %d\n", n_ecp_core());
+        printer->Printf("    Maximum AM               = %d\n", max_ecp_am_);
+        printer->Printf("\n");
+
+        printer->Printf("  -Contraction Scheme:\n");
+        printer->Printf("    Atom   Type  #elec    All terms // Shells:   \n");
+        printer->Printf("   ------ ------ ----- --------------------------\n");
+
+        int *nprims = new int[max_ecp_am_ + 1];
+        int *nunique = new int[max_ecp_am_ + 1];
+        int *nshells = new int[max_ecp_am_ + 1];
+        char *amtypes = new char[max_ecp_am_ + 1];
+
+        for (int A = 0; A < molecule_->natom(); A++) {
+            memset((void *)nprims, '\0', (max_ecp_am_ + 1) * sizeof(int));
+            memset((void *)nunique, '\0', (max_ecp_am_ + 1) * sizeof(int));
+            memset((void *)nshells, '\0', (max_ecp_am_ + 1) * sizeof(int));
+
+            printer->Printf("    %4d    ", A + 1);
+            printer->Printf("%2s     ", molecule_->symbol(A).c_str());
+
+            int first_shell = center_to_ecp_shell_[A];
+            int n_shell = center_to_ecp_nshell_[A];
+            int ncoreelectrons = n_ecp_core(molecule_->label(A));
+            printer->Printf("%2d   ", ncoreelectrons);
+
+            if (ncoreelectrons) {
+                for (int Q = 0; Q < n_shell; Q++) {
+                    const GaussianShell &shell = ecp_shells_[Q + first_shell];
+                    nshells[shell.am()]++;
+                    nunique[shell.am()] += shell.nprimitive();
+                    nprims[shell.am()] += shell.nprimitive();
+                    amtypes[shell.am()] = shell.amchar();
+                }
+
+                // All Primitives
+                for (int l = 0; l < max_ecp_am_ + 1; l++) {
+                    if (nprims[l] == 0) continue;
+                    printer->Printf("%d%c ", nprims[l], amtypes[l]);
+                }
+                // Shells
+                if (n_shell) printer->Printf("// ");
+                for (int l = 0; l < max_ecp_am_ + 1; l++) {
+                    if (nshells[l] == 0) continue;
+                    printer->Printf("%d%c ", nshells[l], amtypes[l]);
+                }
+            }
+            printer->Printf("\n");
+        }
+        printer->Printf("\n");
+
+        delete[] nprims;
+        delete[] nunique;
+        delete[] nshells;
+        delete[] amtypes;
+    }
 }
 
-void BasisSet::print_detail(std::string out) const
-{
+void BasisSet::print_detail(std::string out) const {
     print_summary(out);
-    std::shared_ptr <psi::PsiOutStream> printer = (out == "outfile" ? outfile :
-                                                   std::shared_ptr<OutFile>(new OutFile(out)));
+    std::shared_ptr<psi::PsiOutStream> printer = (out == "outfile" ? outfile : std::make_shared<PsiOutStream>(out));
 
     printer->Printf("  ==> AO Basis Functions <==\n");
     printer->Printf("\n");
@@ -291,30 +374,50 @@ void BasisSet::print_detail(std::string out) const
         printer->Printf("    cartesian\n");
     printer->Printf("    ****\n");
 
-
     for (int uA = 0; uA < molecule_->nunique(); uA++) {
         const int A = molecule_->unique(uA);
 
         printer->Printf("   %2s %3d\n", molecule_->symbol(A).c_str(), A + 1);
 
-
         int first_shell = center_to_shell_[A];
         int n_shell = center_to_nshell_[A];
 
-        for (int Q = 0; Q < n_shell; Q++)
-            shells_[Q + first_shell].print(out);
-
+        for (int Q = 0; Q < n_shell; Q++) shells_[Q + first_shell].print(out);
 
         printer->Printf("    ****\n");
-
     }
 
     printer->Printf("\n");
+    if (has_ECP()) {
+        printer->Printf("  ==> Core Potential Functions <==\n");
+        printer->Printf("\n");
+        printer->Printf("    [ %s ]\n", name_.c_str());
+        printer->Printf("    ****\n");
 
+        for (int uA = 0; uA < molecule_->nunique(); uA++) {
+            const int A = molecule_->unique(uA);
+            if (n_ecp_core(molecule_->label(A))) {
+                int first_shell = center_to_ecp_shell_[A];
+                int n_shell = center_to_ecp_nshell_[A];
+                int shellam = 0;
+                for (int shell = 0; shell < n_shell; ++shell)
+                    shellam = ecp_shells_[shell + first_shell].am() > shellam ? ecp_shells_[shell + first_shell].am()
+                                                                              : shellam;
+                printer->Printf("   %2s %3d\n", molecule_->symbol(A).c_str(), A + 1);
+                printer->Printf("   %2s-ECP  %d %3d\n", molecule_->symbol(A).c_str(), shellam,
+                                n_ecp_core(molecule_->label(A)));
+
+                for (int Q = 0; Q < n_shell; Q++) ecp_shells_[Q + first_shell].print(out);
+
+                printer->Printf("    ****\n");
+            }
+        }
+
+        printer->Printf("\n");
+    }
 }
 
-std::string BasisSet::print_detail_cfour() const
-{
+std::string BasisSet::print_detail_cfour() const {
     char buffer[120];
     std::stringstream ss;
     std::string nameUpperCase = name_;
@@ -325,22 +428,20 @@ std::string BasisSet::print_detail_cfour() const
 
         sprintf(buffer, "%s:P4_%d\n", molecule_->symbol(A).c_str(), A + 1);
         ss << buffer;
-        sprintf(buffer, "Psi4 basis %s for element %s atom %d\n\n",
-                nameUpperCase.c_str(), molecule_->symbol(A).c_str(), A + 1);
+        sprintf(buffer, "Psi4 basis %s for element %s atom %d\n\n", nameUpperCase.c_str(), molecule_->symbol(A).c_str(),
+                A + 1);
         ss << buffer;
 
-
         int first_shell = center_to_shell_[A];
         int n_shell = center_to_nshell_[A];
 
         int max_am_center = 0;
         for (int Q = 0; Q < n_shell; Q++)
-            max_am_center = (shells_[Q + first_shell].am() > max_am_center) ? shells_[Q + first_shell].am() : max_am_center;
-
-        std::vector <std::vector<int>> shell_per_am(max_am_center + 1);
-        for (int Q = 0; Q < n_shell; Q++)
-            shell_per_am[shells_[Q + first_shell].am()].push_back(Q);
+            max_am_center =
+                (shells_[Q + first_shell].am() > max_am_center) ? shells_[Q + first_shell].am() : max_am_center;
 
+        std::vector<std::vector<int>> shell_per_am(max_am_center + 1);
+        for (int Q = 0; Q < n_shell; Q++) shell_per_am[shells_[Q + first_shell].am()].push_back(Q);
 
         // Write number of shells in the basis set
         sprintf(buffer, "%3d\n", max_am_center + 1);
@@ -362,9 +463,8 @@ std::string BasisSet::print_detail_cfour() const
         sprintf(buffer, "\n");
         ss << buffer;
 
-
-        std::vector <std::vector<double>> exp_per_am(max_am_center + 1);
-        std::vector <std::vector<double>> coef_per_am(max_am_center + 1);
+        std::vector<std::vector<double>> exp_per_am(max_am_center + 1);
+        std::vector<std::vector<double>> coef_per_am(max_am_center + 1);
         for (int am = 0; am <= max_am_center; am++) {
             // TODO: std::find safe on floats? seems to work
             // Collect unique exponents among all functions
@@ -392,7 +492,6 @@ std::string BasisSet::print_detail_cfour() const
             }
         }
 
-
         // Write number of exponents for each shell
         for (int am = 0; am <= max_am_center; am++) {
             sprintf(buffer, "%5lu", exp_per_am[am].size());
@@ -404,7 +503,14 @@ std::string BasisSet::print_detail_cfour() const
         for (int am = 0; am <= max_am_center; am++) {
             // Write exponents for each shell
             for (size_t ep = 0; ep < exp_per_am[am].size(); ep++) {
-                sprintf(buffer, "%14.7f", exp_per_am[am][ep]);
+                if (exp_per_am[am][ep] >= 10000000.0)
+                    sprintf(buffer, "%13.4f ", exp_per_am[am][ep]);
+                else if (exp_per_am[am][ep] >= 1000000.0)
+                    sprintf(buffer, "%13.5f ", exp_per_am[am][ep]);
+                else if (exp_per_am[am][ep] >= 100000.0)
+                    sprintf(buffer, "%13.6f ", exp_per_am[am][ep]);
+                else
+                    sprintf(buffer, "%14.7f", exp_per_am[am][ep]);
                 ss << buffer;
                 if (((ep + 1) % 5 == 0) || ((ep + 1) == exp_per_am[am].size())) {
                     sprintf(buffer, "\n");
@@ -426,13 +532,11 @@ std::string BasisSet::print_detail_cfour() const
             sprintf(buffer, "\n");
             ss << buffer;
         }
-
     }
     return ss.str();
 }
 
-const GaussianShell &BasisSet::shell(int si) const
-{
+const GaussianShell &BasisSet::shell(int si) const {
     if (si < 0 || si > nshell()) {
         outfile->Printf("BasisSet::shell(si = %d), requested a shell out-of-bound.\n", si);
         outfile->Printf("     Max shell size: %d\n", nshell());
@@ -442,86 +546,38 @@ const GaussianShell &BasisSet::shell(int si) const
     return shells_[si];
 }
 
-const GaussianShell &BasisSet::shell(int center, int si) const
-{
-    return shell(center_to_shell_[center] + si);
+const GaussianShell &BasisSet::ecp_shell(int si) const {
+    if (si < 0 || si > n_ecp_shell()) {
+        outfile->Printf("BasisSet::ecp_shell(si = %d), requested a shell out-of-bound.\n", si);
+        outfile->Printf("     Max shell size: %d\n", n_ecp_shell());
+        outfile->Printf("     Name: %s\n", name().c_str());
+        throw PSIEXCEPTION("BasisSet::ecp_shell: requested shell is out-of-bounds.");
+    }
+    return ecp_shells_[si];
 }
 
-std::shared_ptr <BasisSet> BasisSet::zero_ao_basis_set()
-{
+const GaussianShell &BasisSet::shell(int center, int si) const { return shell(center_to_shell_[center] + si); }
+
+std::shared_ptr<BasisSet> BasisSet::zero_ao_basis_set() {
     // In the new implementation, we simply call the default constructor
-    std::shared_ptr <BasisSet> new_basis(new BasisSet());
+    auto new_basis = std::make_shared<BasisSet>();
     return new_basis;
 }
 
-//std::shared_ptr<SOBasisSet> BasisSet::zero_so_basis_set(const std::shared_ptr<IntegralFactory>& factory)
-//{
-//    std::shared_ptr<BasisSet> zero = BasisSet::zero_ao_basis_set();
-//    std::shared_ptr<SOBasisSet> sozero(new SOBasisSet(zero, factory));
-//    return sozero;
-//}
-
-std::shared_ptr<BasisSet> BasisSet::construct_from_pydict(const std::shared_ptr <Molecule> &mol, py::dict pybs, const int forced_puream){
-
-    std::string key = pybs["key"].cast<std::string>();
-    std::string name = pybs["name"].cast<std::string>();
-    std::string label = pybs["blend"].cast<std::string>();
-    std::string message = pybs["message"].cast<std::string>();
-    //if (Process::environment.options.get_int("PRINT") > 1)
-    //    outfile->Printf("%s\n", message.c_str());
-
-    // Handle mixed puream signals and seed parser with the resolution
-    int native_puream = pybs["puream"].cast<int>();
-    int user_puream = (Process::environment.options.get_global("PUREAM").has_changed()) ?
-                      ((Process::environment.options.get_global("PUREAM").to_integer()) ? Pure : Cartesian) : -1;
-    int resolved_puream;
-    if (user_puream == -1)
-        resolved_puream = (forced_puream == -1) ? native_puream : forced_puream;
-    else
-        resolved_puream = user_puream;
-
-    // Not like we're ever using a non-G94 format
-    const std::shared_ptr <BasisSetParser> parser(new Gaussian94BasisSetParser(resolved_puream));
-
-    mol->set_basis_all_atoms(name, key);
-
-    // Map of GaussianShells: basis_atom_shell[basisname][atomlabel] = gaussian_shells
-    typedef std::map <std::string, std::map<std::string, std::vector < ShellInfo>>> map_ssv;
-    map_ssv basis_atom_shell;
-    // basisname is uniform; fill map with key/value (gbs entry) pairs of elements from pybs['shell_map']
-    py::list shmp = pybs["shell_map"].cast<py::list>();
-    for (int ent = 0; ent < (len(shmp)); ent += 3) {
-        std::string label = shmp[ent].cast<std::string>();
-        std::string hash = shmp[ent + 1].cast<std::string>();
-        std::vector <std::string> basbit = parser->string_to_vector(shmp[ent + 2].cast<std::string>());
-        mol->set_shell_by_label(label, hash, key);
-        basis_atom_shell[name][label] = parser->parse(label, basbit);
-    }
-    mol->update_geometry();  // update symmetry with basisset info
-
-    std::shared_ptr <BasisSet> basisset(new BasisSet(key, mol, basis_atom_shell));
-    basisset->name_.clear();
-    basisset->name_ = name;
-    basisset->key_ = key;
-    basisset->target_ = label;
-
-    //outfile->Printf("puream: basis %d, arg %d, user %d, resolved %d, final %d\n",
-    //    native_puream, forced_puream, user_puream, resolved_puream, basisset->has_puream());
-    return basisset;
-}
-
 BasisSet::BasisSet(const std::string &basistype, SharedMolecule mol,
-                   std::map <std::string, std::map<std::string, std::vector < ShellInfo>>> &shell_map)
-: name_ (basistype), molecule_(mol)
-{
+                   std::map<std::string, std::map<std::string, std::vector<ShellInfo>>> &shell_map,
+                   std::map<std::string, std::map<std::string, std::vector<ShellInfo>>> &ecp_shell_map)
+    : name_(basistype), molecule_(mol) {
     // Singletons
     initialize_singletons();
 
     int natom = molecule_->natom();
 
     /// These will tell us where the primitives for [basis][symbol] start and end, in the compact array
-    std::map <std::string, std::map<std::string, int>> primitive_start;
-    std::map <std::string, std::map<std::string, int>> primitive_end;
+    std::map<std::string, std::map<std::string, int>> primitive_start;
+    std::map<std::string, std::map<std::string, int>> primitive_end;
+    std::map<std::string, std::map<std::string, int>> ecp_primitive_start;
+    std::map<std::string, std::map<std::string, int>> ecp_primitive_end;
 
     /*
      * First, loop over the unique primitives, and store them
@@ -531,17 +587,15 @@ BasisSet::BasisSet(const std::string &basistype, SharedMolecule mol,
     std::vector<double> uoriginal_coefs;
     std::vector<double> uerd_coefs;
     n_uprimitive_ = 0;
-    std::map < std::string, std::map < std::string, std::vector < ShellInfo > > > ::iterator
-    basis_iter;
+    std::map<std::string, std::map<std::string, std::vector<ShellInfo>>>::iterator basis_iter;
     for (basis_iter = shell_map.begin(); basis_iter != shell_map.end(); ++basis_iter) {
         const std::string &basis = basis_iter->first;
-        std::map <std::string, std::vector<ShellInfo>> &symbol_map = shell_map[basis];
-        std::map < std::string, std::vector < ShellInfo > > ::iterator
-        symbol_iter;
+        std::map<std::string, std::vector<ShellInfo>> &symbol_map = shell_map[basis];
+        std::map<std::string, std::vector<ShellInfo>>::iterator symbol_iter;
         for (symbol_iter = symbol_map.begin(); symbol_iter != symbol_map.end(); ++symbol_iter) {
-            const std::string &label = symbol_iter->first;  // symbol --> label
-            std::vector <ShellInfo> &shells = symbol_map[label];  // symbol --> label
-            primitive_start[basis][label] = n_uprimitive_;  // symbol --> label
+            const std::string &label = symbol_iter->first;       // symbol --> label
+            std::vector<ShellInfo> &shells = symbol_map[label];  // symbol --> label
+            primitive_start[basis][label] = n_uprimitive_;       // symbol --> label
             for (size_t i = 0; i < shells.size(); ++i) {
                 const ShellInfo &shell = shells[i];
                 for (int prim = 0; prim < shell.nprimitive(); ++prim) {
@@ -556,6 +610,34 @@ BasisSet::BasisSet(const std::string &basistype, SharedMolecule mol,
         }
     }
 
+    /*
+     * Now, loop over the ECP primitives, and store them
+     */
+    std::vector<double> uecpexps;
+    std::vector<double> uecpcoefs;
+    std::vector<int> uns;
+    n_ecp_uprimitive_ = 0;
+    for (basis_iter = ecp_shell_map.begin(); basis_iter != ecp_shell_map.end(); ++basis_iter) {
+        const std::string &basis = basis_iter->first;
+        std::map<std::string, std::vector<ShellInfo>> &symbol_map = ecp_shell_map[basis];
+        std::map<std::string, std::vector<ShellInfo>>::iterator symbol_iter;
+        for (symbol_iter = symbol_map.begin(); symbol_iter != symbol_map.end(); ++symbol_iter) {
+            const std::string &label = symbol_iter->first;          // symbol --> label
+            std::vector<ShellInfo> &shells = symbol_map[label];     // symbol --> label
+            ecp_primitive_start[basis][label] = n_ecp_uprimitive_;  // symbol --> label
+            for (size_t i = 0; i < shells.size(); ++i) {
+                const ShellInfo &shell = shells[i];
+                for (int prim = 0; prim < shell.nprimitive(); ++prim) {
+                    uecpexps.push_back(shell.exp(prim));
+                    uns.push_back(shell.nval(prim));
+                    uecpcoefs.push_back(shell.coef(prim));
+                    n_ecp_uprimitive_++;
+                }
+            }
+            ecp_primitive_end[basis][label] = n_ecp_uprimitive_;  // symbol --> label
+        }
+    }
+
     /*
      * Count basis functions, shells and primitives
      */
@@ -563,11 +645,13 @@ BasisSet::BasisSet(const std::string &basistype, SharedMolecule mol,
     nprimitive_ = 0;
     nao_ = 0;
     nbf_ = 0;
+    n_ecp_shells_ = 0;
+    n_ecp_primitive_ = 0;
     for (int n = 0; n < natom; ++n) {
-        const std::shared_ptr <CoordEntry> &atom = molecule_->atom_entry(n);
+        const std::shared_ptr<CoordEntry> &atom = molecule_->atom_entry(n);
         std::string basis = atom->basisset(basistype);
-        std::string label = atom->label();  // symbol --> label
-        std::vector <ShellInfo> &shells = shell_map[basis][label];  // symbol --> label
+        std::string label = atom->label();                         // symbol --> label
+        std::vector<ShellInfo> &shells = shell_map[basis][label];  // symbol --> label
         for (size_t i = 0; i < shells.size(); ++i) {
             const ShellInfo &shell = shells[i];
             int nprim = shell.nprimitive();
@@ -576,6 +660,16 @@ BasisSet::BasisSet(const std::string &basistype, SharedMolecule mol,
             nao_ += shell.ncartesian();
             nbf_ += shell.nfunction();
         }
+        // ECP information
+        if (!ecp_shell_map.empty()) {
+            std::vector<ShellInfo> &ecpshells = ecp_shell_map[basis][label];
+            for (size_t i = 0; i < ecpshells.size(); ++i) {
+                const ShellInfo &ecpshell = ecpshells[i];
+                int nprim = ecpshell.nprimitive();
+                n_ecp_primitive_ += nprim;
+                n_ecp_shells_++;
+            }
+        }
     }
 
     /*
@@ -587,22 +681,35 @@ BasisSet::BasisSet(const std::string &basistype, SharedMolecule mol,
     ucoefficients_ = new double[n_uprimitive_];
     uoriginal_coefficients_ = new double[n_uprimitive_];
     uerd_coefficients_ = new double[n_uprimitive_];
+    uecpexponents_ = new double[n_ecp_uprimitive_];
+    uecpcoefficients_ = new double[n_ecp_uprimitive_];
+    uecpns_ = new int[n_ecp_uprimitive_];
+
     for (int i = 0; i < n_uprimitive_; ++i) {
         uexponents_[i] = uexps[i];
         ucoefficients_[i] = ucoefs[i];
         uoriginal_coefficients_[i] = uoriginal_coefs[i];
         uerd_coefficients_[i] = uerd_coefs[i];
     }
+    for (int i = 0; i < n_ecp_uprimitive_; ++i) {
+        uecpexponents_[i] = uecpexps[i];
+        uecpcoefficients_[i] = uecpcoefs[i];
+        uecpns_[i] = uns[i];
+    }
 
     shell_first_ao_ = new int[n_shells_];
     shell_first_basis_function_ = new int[n_shells_];
     shells_ = new GaussianShell[n_shells_];
+    ecp_shells_ = new GaussianShell[n_ecp_shells_];
     ao_to_shell_ = new int[nao_];
     function_to_shell_ = new int[nbf_];
     function_center_ = new int[nbf_];
     shell_center_ = new int[n_shells_];
     center_to_nshell_ = new int[natom];
     center_to_shell_ = new int[natom];
+    center_to_ecp_nshell_ = new int[natom];
+    center_to_ecp_shell_ = new int[natom];
+    ecp_shell_center_ = new int[n_ecp_shells_];
     xyz_ = new double[3 * natom];
 
     /*
@@ -616,31 +723,37 @@ BasisSet::BasisSet(const std::string &basistype, SharedMolecule mol,
     max_am_ = 0;
     max_nprimitive_ = 0;
     for (int n = 0; n < natom; ++n) {
-        const std::shared_ptr <CoordEntry> &atom = molecule_->atom_entry(n);
+        const std::shared_ptr<CoordEntry> &atom = molecule_->atom_entry(n);
         std::string basis = atom->basisset(basistype);
-        std::string label = atom->label();  // symbol --> label
-        std::vector <ShellInfo> &shells = shell_map[basis][label];  // symbol --> label
-        int ustart = primitive_start[basis][label];  // symbol --> label
-        int uend = primitive_end[basis][label];  // symbol --> label
+        std::string label = atom->label();                         // symbol --> label
+        std::vector<ShellInfo> &shells = shell_map[basis][label];  // symbol --> label
+        int ustart = primitive_start[basis][label];                // symbol --> label
+        int uend = primitive_end[basis][label];                    // symbol --> label
         int nshells = shells.size();
         center_to_nshell_[n] = nshells;
         center_to_shell_[n] = shell_count;
         int atom_nprim = 0;
         for (int i = 0; i < nshells; ++i) {
             const ShellInfo &thisshell = shells[i];
+            ShellType shelltype = thisshell.shell_type();
             shell_first_ao_[shell_count] = ao_count;
             shell_first_basis_function_[shell_count] = bf_count;
             int shell_nprim = thisshell.nprimitive();
             int am = thisshell.am();
             max_nprimitive_ = shell_nprim > max_nprimitive_ ? shell_nprim : max_nprimitive_;
-            max_am_ = max_am_ > am ? max_am_ : am;
+            max_am_ = max_am_ > std::abs(am) ? max_am_ : std::abs(am);
             shell_center_[shell_count] = n;
             GaussianType puream = thisshell.is_pure() ? Pure : Cartesian;
-            if (puream)
-                puream_ = true;
-            //            outfile->Printf( "atom %d basis %s shell %d nprim %d atom_nprim %d\n", n, basis.c_str(), i, shell_nprim, atom_nprim);
-            shells_[shell_count] = GaussianShell(am, shell_nprim, &uoriginal_coefficients_[ustart + atom_nprim],
-                                                 &ucoefficients_[ustart + atom_nprim], &uerd_coefficients_[ustart + atom_nprim], &uexponents_[ustart + atom_nprim], puream, n, xyz_ptr, bf_count);
+            if (puream) puream_ = true;
+            if (shelltype == Gaussian) {
+                // This is a regular Gaussian basis set
+                shells_[shell_count] =
+                    GaussianShell(shelltype, am, shell_nprim, &uoriginal_coefficients_[ustart + atom_nprim],
+                                  &ucoefficients_[ustart + atom_nprim], &uerd_coefficients_[ustart + atom_nprim],
+                                  &uexponents_[ustart + atom_nprim], puream, n, xyz_ptr, bf_count);
+            } else {
+                throw PSIEXCEPTION("Unexpected shell type in BasisSet constructor!");
+            }
             for (int thisbf = 0; thisbf < thisshell.nfunction(); ++thisbf) {
                 function_to_shell_[bf_count] = shell_count;
                 function_center_[bf_count++] = n;
@@ -660,10 +773,51 @@ BasisSet::BasisSet(const std::string &basistype, SharedMolecule mol,
             throw PSIEXCEPTION("Problem with nprimitive in basis set construction!");
         }
     }
+
+    /*
+     * Now loop over ECPs and finalize metadata
+     */
+    max_ecp_am_ = -1;
+    if (!ecp_shell_map.empty()) {
+        xyz_ptr = xyz_;
+        int ecp_shell_count = 0;
+        for (int n = 0; n < natom; ++n) {
+            const std::shared_ptr<CoordEntry> &atom = molecule_->atom_entry(n);
+            std::string basis = atom->basisset(basistype);
+            std::string label = atom->label();                                 // symbol --> label
+            std::vector<ShellInfo> &ecp_shells = ecp_shell_map[basis][label];  // symbol --> label
+            int ustart = ecp_primitive_start[basis][label];                    // symbol --> label
+            int uend = ecp_primitive_end[basis][label];                        // symbol --> label
+            int n_ecp_shells = ecp_shells.size();
+            center_to_ecp_nshell_[n] = n_ecp_shells;
+            center_to_ecp_shell_[n] = ecp_shell_count;
+            int atom_nprim = 0;
+            for (int i = 0; i < n_ecp_shells; ++i) {
+                const ShellInfo &thisshell = ecp_shells[i];
+                ShellType shelltype = thisshell.shell_type();
+                int ecp_shell_nprim = thisshell.nprimitive();
+                int am = thisshell.am();
+                max_ecp_am_ = max_ecp_am_ > std::abs(am) ? max_ecp_am_ : std::abs(am);
+                ecp_shell_center_[ecp_shell_count] = n;
+                if (shelltype == ECPType1 || shelltype == ECPType2) {
+                    ecp_shells_[ecp_shell_count] =
+                        GaussianShell(shelltype, am, ecp_shell_nprim, &uecpcoefficients_[ustart + atom_nprim],
+                                      &uecpexponents_[ustart + atom_nprim], &uecpns_[ustart + atom_nprim], n, xyz_ptr);
+                } else {
+                    throw PSIEXCEPTION("Unknown ECP shell type in BasisSet constructor!");
+                }
+                atom_nprim += ecp_shell_nprim;
+                ecp_shell_count++;
+            }
+            if (atom_nprim != uend - ustart) {
+                throw PSIEXCEPTION("Problem with nprimitive in ECP basis set construction!");
+            }
+            xyz_ptr += 3;
+        }
+    }
 }
 
-std::string BasisSet::make_filename(const std::string &name)
-{
+std::string BasisSet::make_filename(const std::string &name) {
     // Modify the name of the basis set to generate a filename: STO-3G -> sto-3g
     std::string basisname = name;
 
@@ -705,9 +859,8 @@ std::string BasisSet::make_filename(const std::string &name)
     return basisname;
 }
 
-void BasisSet::refresh()
-{
-    //TODO FIXME!!!
+void BasisSet::refresh() {
+    // TODO FIXME!!!
     //    // Reset data to initial values
     //    nprimitive_ = 0;
     //    nao_ = 0;
@@ -794,8 +947,7 @@ void BasisSet::refresh()
     //    }
 }
 
-std::pair <std::vector<std::string>, std::shared_ptr<BasisSet>> BasisSet::test_basis_set(int /*max_am*/)
-{
+std::pair<std::vector<std::string>, std::shared_ptr<BasisSet>> BasisSet::test_basis_set(int /*max_am*/) {
     throw NOT_IMPLEMENTED_EXCEPTION();
 #if 0
     int max_centers = 4;
@@ -935,10 +1087,10 @@ std::pair <std::vector<std::string>, std::shared_ptr<BasisSet>> BasisSet::test_b
         max_shells = 10;
     }
 
-    std::shared_ptr<BasisSet> new_basis(new BasisSet());
+    auto new_basis = std::make_shared<BasisSet>();
 
     // Add 4 atoms to the molecule for this basis (max integal centers is 4 at the moment)
-    new_basis->molecule_ = std::shared_ptr<Molecule>(new Molecule);
+    new_basis->molecule_ = std::make_shared<Molecule>();
     // Ghost atoms are now handled differently, they are not added to the normal xyz information array,
     // but to the fxyz array.
     double x = 0.0;
@@ -972,8 +1124,14 @@ std::pair <std::vector<std::string>, std::shared_ptr<BasisSet>> BasisSet::test_b
 #endif
 }
 
-void BasisSet::compute_phi(double *phi_ao, double x, double y, double z)
-{
+void BasisSet::move_atom(int atom, const Vector3 &trans) {
+    int offset = 3 * atom;
+    xyz_[offset + 0] += trans[0];
+    xyz_[offset + 1] += trans[1];
+    xyz_[offset + 2] += trans[2];
+}
+
+void BasisSet::compute_phi(double *phi_ao, double x, double y, double z) {
     zero_arr(phi_ao, nao());
 
     int ao = 0;
@@ -991,17 +1149,14 @@ void BasisSet::compute_phi(double *phi_ao, double x, double y, double z)
         double rr = dx * dx + dy * dy + dz * dz;
 
         double cexpr = 0;
-        for (int np = 0; np < nprim; np++)
-            cexpr += c[np] * exp(-a[np] * rr);
+        for (int np = 0; np < nprim; np++) cexpr += c[np] * exp(-a[np] * rr);
 
         for (int l = 0; l < INT_NCART(am); l++) {
             Vector3 &components = exp_ao[am][l];
-            phi_ao[ao + l] += pow(dx, (double) components[0]) *
-                              pow(dy, (double) components[1]) *
-                              pow(dz, (double) components[2]) *
-                              cexpr;
+            phi_ao[ao + l] += pow(dx, (double)components[0]) * pow(dy, (double)components[1]) *
+                              pow(dz, (double)components[2]) * cexpr;
         }
 
         ao += INT_NCART(am);
-    } // nshell
+    }  // nshell
 }
