@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -69,7 +69,7 @@ DipoleInt::~DipoleInt()
 
 SharedVector DipoleInt::nuclear_contribution(std::shared_ptr<Molecule> mol, const Vector3& origin)
 {
-    std::shared_ptr<Vector> sret(new Vector(3));
+    auto sret = std::make_shared<Vector>(3);
     double *ret = sret->pointer();
 
     for(int i=0; i<mol->natom(); ++i) {
