@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -35,8 +35,6 @@
 #include <map>
 #include <memory>
 
-#include "psi4/pybind11.h"
-
 #define LINEAR_A_TOL 1.0E-2 //When sin(a) is below this, we consider the angle to be linear
 #define DEFAULT_SYM_TOL 1.0E-8
 #define FULL_PG_TOL 1.0e-8 // default
@@ -46,7 +44,7 @@
 
 namespace psi {
 class PointGroup;
-
+class BasisSet;
 enum RotorType {RT_ASYMMETRIC_TOP, RT_SYMMETRIC_TOP, RT_SPHERICAL_TOP, RT_LINEAR, RT_ATOM};
 enum FullPointGroup {PG_ATOM, PG_Cinfv, PG_Dinfh, PG_C1, PG_Cs, PG_Ci, PG_Cn, PG_Cnv,
  PG_Cnh, PG_Sn, PG_Dn, PG_Dnd, PG_Dnh, PG_Td, PG_Oh, PG_Ih};
@@ -61,7 +59,7 @@ const std::string FullPointGroupList[] = {"ATOM", "C_inf_v", "D_inf_h", "C1", "C
  *  \class Molecule
  *  \brief Molecule information class.
  */
-class Molecule
+class PSI_API Molecule
 {
 public:
     /**
@@ -164,10 +162,8 @@ protected:
     std::map<std::string, double> geometry_variables_;
     /// A list describing how to handle each fragment
     std::vector<FragmentType> fragment_types_;
-//****AVC****//
-// moved fragments_ to public
-// moved fragment_levels_ to public
-//****AVC****//
+    /// The list of atom ranges defining each fragment from parent molecule
+    std::vector<std::pair<int, int> > fragments_;
     /// Symmetry string from geometry specification
     std::string symmetry_from_input_;
     /// Reinterpret the coord entries or not
@@ -177,12 +173,10 @@ protected:
     bool lock_frame_;
     /// Whether this molecule has at least one zmatrix entry
     bool zmat_;
+    /// Whether this molecule has at least one cartesian entry
+    bool cart_;
 
 public:
-//****AVC****//
-    /// The list of atom ranges defining each fragment from parent molecule
-    std::vector<std::pair<int, int> > fragments_;
-//****AVC****//
 
     Molecule();
     /// Copy constructor.
@@ -198,12 +192,6 @@ public:
     /// Operators
     /// Assignment operator.
     Molecule& operator=(const Molecule& other);
-    /// Addition
-    Molecule operator+(const Molecule& other);
-    /// Subtraction
-    Molecule operator-(const Molecule& other);
-    /// Plus equals
-    void operator+=(const Molecule& other);
     /// @}
 
 
@@ -219,29 +207,35 @@ public:
      * \param x cartesian coordinate
      * \param y cartesian coordinate
      * \param z cartesian coordinate
-     * \param symb atomic symbol to use
+     * \param sym atomic symbol to use
      * \param mass mass to use if non standard
      * \param charge charge to use if non standard
-     * \param lineno line number when taken from a string
+     * \param lbl extended atomic symbol
+     * \param A mass number
      */
-    void add_atom(int Z, double x, double y, double z,
-                  const char *symb = "", double mass = 0.0,
-                  double charge = 0.0, int lineno = -1);
+    void add_atom(double Z, double x, double y, double z, std::string sym = "", double mass = 0.0,
+                  double charge = 0.0, std::string lbl = "", int A = -1);
+    void add_unsettled_atom(double Z, std::vector<std::string> anchor, std::string sym = "", double mass = 0.0,
+                            double charge = 0.0, std::string lbl = "", int A = -1);
 
     /// Whether the multiplicity was given by the user
-    bool multiplicity_specified() const { return multiplicity_specified_; }
+    bool multiplicity_specified() const { return multiplicity_specified_; }  // TODO remove
     /// Whether the charge was given by the user
-    bool charge_specified() const { return charge_specified_; }
+    bool charge_specified() const { return charge_specified_; }  // TODO remove
     /// The number of fragments in the molecule
     int nfragments() const { return fragments_.size();}
     /// The number of active fragments in the molecule
     int nactive_fragments();
     /// Returns the list of atoms belonging to a fragment.
     // Needed for EFP interface
-    std::pair<int, int> fragment_atom_pair(int f) { return fragments_[f]; }
+    std::pair<int, int> fragment_atom_pair(int f) { return fragments_[f]; }  // TODO remove?
+    /// Set whether to leave the geometry alone upon update_geometry()
+    void set_lock_frame(bool tf) { lock_frame_ = tf; }
 
     /// Get molecule name
     const std::string name() const {return name_; }
+    /// Returns the name of the basis set on the specified atom
+    const std::string& basis_on_atom(int atom) const;
     /// Set molecule name
     void set_name(const std::string &_name) { name_ = _name; }
     /// Number of atoms
@@ -273,7 +267,9 @@ public:
     double mass(int atom) const;
 
     /// Set the mass of a particular atom (good for isotopic substitutions)
-    void set_mass(int atom, double mass) { full_atoms_[atom]->set_mass(mass); }
+    void set_mass(int atom, double mass);
+    /// Set the nuclear charge of an atom (primarily used in ECP calculations).
+    void set_nuclear_charge(int atom, double newZ);
 
     /// Returns the cleaned up label of the atom (C2 => C, H4 = H)
     std::string symbol(int atom) const;
@@ -283,6 +279,8 @@ public:
     std::string label(int atom) const;
     /// Returns charge of atom
     double charge(int atom) const;
+    /// Returns mass number of atom
+    int mass_number(int atom) const;
     /// Returns the true atomic number of an atom
     int true_atomic_number(int atom) const;
     int ftrue_atomic_number(int atom) const;
@@ -292,6 +290,8 @@ public:
     std::string flabel(int atom) const;
     /// Returns charge of atom
     double fcharge(int atom) const;
+    /// Returns mass number of atom
+    int fmass_number(int atom) const;
     /// Returns the CoordEntry for an atom
     const std::shared_ptr<CoordEntry>& atom_entry(int atom) const;
 
@@ -301,9 +301,6 @@ public:
     void set_basis_by_label(const std::string& label, const std::string& name, const std::string& type="BASIS");
     void set_shell_by_label(const std::string& label, const std::string& name, const std::string& type="BASIS");
 
-    /// Number of frozen core for molecule given freezing state
-    int nfrozen_core(const std::string& depth = "");
-
     /// @{
     /// Tests to see of an atom is at the passed position with a given tolerance
     int atom_at_position1(double *, double tol = 0.05) const;
@@ -364,13 +361,15 @@ public:
     /// Computes center of mass of molecule (does not translate molecule)
     Vector3 center_of_mass() const;
     /// Computes nuclear repulsion energy
-    double nuclear_repulsion_energy() const;
+    /// The dipole field is a vector of length 3, containing the dipole field strength in the {x,y,z} directions.
+    double nuclear_repulsion_energy(const std::array<double,3> &dipole_field) const;
     /// The dipole generated by the nuclear charges evaluated at the origin.
     Vector3 nuclear_dipole() const;
     /// The dipole generated by the nuclear charges evaluated using a given origin.
     Vector3 nuclear_dipole(const Vector3 &origin) const;
     /// Computes nuclear repulsion energy derivatives.
-    Matrix nuclear_repulsion_energy_deriv1() const;
+    /// The dipole field is a vector of length 3, containing the dipole field strength in the {x,y,z} directions.
+    Matrix nuclear_repulsion_energy_deriv1(const std::array<double, 3> &dipole_field) const;
     /// Computes nuclear repulsion energy second derivatives.
     Matrix nuclear_repulsion_energy_deriv2() const;
 
@@ -459,37 +458,37 @@ public:
     ///
     /// Symmetry
     /// @{
-    bool has_symmetry_element(Vector3& op, double tol=DEFAULT_SYM_TOL) const;
+    bool has_symmetry_element(Vector3& op, double tol = DEFAULT_SYM_TOL) const;
     std::shared_ptr<PointGroup> point_group() const;
     void set_point_group(std::shared_ptr<PointGroup> pg);
     /// Determine and set FULL point group
-    void set_full_point_group(double tol=FULL_PG_TOL);
+    void set_full_point_group(double tol = FULL_PG_TOL);
     /// Does the molecule have an inversion center at origin
-    bool has_inversion(Vector3& origin, double tol=DEFAULT_SYM_TOL) const;
+    bool has_inversion(Vector3& origin, double tol = DEFAULT_SYM_TOL) const;
     /// Is a plane?
-    bool is_plane(Vector3& origin, Vector3& uperp, double tol=DEFAULT_SYM_TOL) const;
+    bool is_plane(Vector3& origin, Vector3& uperp, double tol = DEFAULT_SYM_TOL) const;
     /// Is an axis?
-    bool is_axis(Vector3& origin, Vector3& axis, int order, double tol=DEFAULT_SYM_TOL) const;
+    bool is_axis(Vector3& origin, Vector3& axis, int order, double tol = DEFAULT_SYM_TOL) const;
     /// Is the molecule linear, or planar?
-    void is_linear_planar(bool& linear, bool& planar, double tol=DEFAULT_SYM_TOL) const;
+    void is_linear_planar(bool& linear, bool& planar, double tol = DEFAULT_SYM_TOL) const;
     /// Find computational molecular point group, user can override this with the "symmetry" keyword
-    std::shared_ptr<PointGroup> find_point_group(double tol=DEFAULT_SYM_TOL) const;
+    std::shared_ptr<PointGroup> find_point_group(double tol = DEFAULT_SYM_TOL) const;
     /// Override symmetry from outside the molecule string
     void reset_point_group(const std::string& pgname);
     /// Find highest molecular point group
-    std::shared_ptr<PointGroup> find_highest_point_group(double tol=DEFAULT_SYM_TOL) const;
+    std::shared_ptr<PointGroup> find_highest_point_group(double tol = DEFAULT_SYM_TOL) const;
     /// Determine symmetry reference frame. If noreorient is set, this is the rotation matrix
     /// applied to the geometry in update_geometry.
-    std::shared_ptr<Matrix> symmetry_frame(double tol=DEFAULT_SYM_TOL);
+    std::shared_ptr<Matrix> symmetry_frame(double tol = DEFAULT_SYM_TOL);
     /// Release symmetry information
     void release_symmetry_information();
     /// Initialize molecular specific symemtry information
     /// Uses the point group object obtain by calling point_group()
-    void form_symmetry_information(double tol=DEFAULT_SYM_TOL);
+    void form_symmetry_information(double tol = DEFAULT_SYM_TOL);
     /// Returns the symmetry label
     std::string sym_label();
     /// Returns the irrep labels
-    char **irrep_labels();
+    std::vector<std::string> irrep_labels();
     const std::string& symmetry_from_input() const { return symmetry_from_input_; }
 
     /**
@@ -529,7 +528,7 @@ public:
      * Sets the specified list of fragments to be real.
      * @param reals The list of real fragments.
      */
-    void set_active_fragments(py::list reals);
+    void set_active_fragments(std::vector<int> reals);
 
     /**
      * Sets the specified fragment to be real.
@@ -541,7 +540,7 @@ public:
      * Sets the specified list of fragments to be ghosts.
      * @param ghosts The list of ghosts fragments.
      */
-    void set_ghost_fragments(py::list ghosts);
+    void set_ghost_fragments(std::vector<int> ghosts);
 
     /**
      * Sets the specified fragment to be a ghost.
@@ -556,8 +555,8 @@ public:
      * @param ghost_list The list of fragments that should be present in the molecule as ghosts.
      * @return The ref counted cloned molecule
      */
-    std::shared_ptr<Molecule> extract_subsets(const std::vector<int> &real_list,
-                                                const std::vector<int> &ghost_list) const;
+    std::shared_ptr<Molecule> extract_subsets(const std::vector<int>& real_list,
+                                              const std::vector<int>& ghost_list) const;
 
     /**
      * A wrapper to extract_subsets, callable from Boost
@@ -565,8 +564,7 @@ public:
      * @param ghost A list containing the ghost atoms.
      * @return The ref counted cloned molecule.
      */
-    std::shared_ptr<Molecule> py_extract_subsets_1(py::list reals,
-                                                   py::list ghost);
+    std::shared_ptr<Molecule> py_extract_subsets_1(std::vector<int> reals, std::vector<int> ghost);
 
     /**
      * A wrapper to extract_subsets, callable from Boost
@@ -574,8 +572,7 @@ public:
      * @param ghost An int containing the ghost atoms.
      * @return The ref counted cloned molecule.
      */
-    std::shared_ptr<Molecule> py_extract_subsets_2(py::list reals,
-                                                   int ghost = -1);
+    std::shared_ptr<Molecule> py_extract_subsets_2(std::vector<int> reals, int ghost = -1);
 
     /**
      * A wrapper to extract_subsets, callable from Boost
@@ -583,8 +580,7 @@ public:
      * @param ghost A list containing the ghost atoms.
      * @return The ref counted cloned molecule.
      */
-    std::shared_ptr<Molecule> py_extract_subsets_3(int reals,
-                                                   py::list ghost);
+    std::shared_ptr<Molecule> py_extract_subsets_3(int reals, std::vector<int> ghost);
 
     /**
      * A wrapper to extract_subsets, callable from Boost
@@ -592,15 +588,14 @@ public:
      * @param ghost An int containing the ghost atoms.
      * @return The ref counted cloned molecule.
      */
-    std::shared_ptr<Molecule> py_extract_subsets_4(int reals,
-                                                   int ghost = -1);
+    std::shared_ptr<Molecule> py_extract_subsets_4(int reals, int ghost = -1);
 
     /**
      * A wrapper to extract_subsets, callable from Boost
      * @param reals A list containing the real atoms.
      * @return The ref counted cloned molecule.
      */
-    std::shared_ptr<Molecule> py_extract_subsets_5(py::list reals);
+    std::shared_ptr<Molecule> py_extract_subsets_5(std::vector<int> reals);
 
     /**
      * A wrapper to extract_subsets, callable from Boost
@@ -611,48 +606,71 @@ public:
 
     // => Fragment Composition <= //
 
-    /// The list of atom ranges defining each fragment from parent molecule (fragments[frag_ind] = <Afirst,Alast+1>)
-    const std::vector<std::pair<int, int> >& fragments() const { return fragments_; }
+    /// The list of atom ranges defining each fragment from parent molecule (fragments[frag_ind] =
+    /// <Afirst,Alast+1>)
+    const std::vector<std::pair<int, int> >& get_fragments() const { return fragments_; }
     /// A list describing how to handle each fragment
-    const std::vector<FragmentType>& fragment_types() const { return fragment_types_; }
+    const std::vector<FragmentType>& get_fragment_types() const { return fragment_types_; }
     /// The charge of each fragment
-    const std::vector<int>& fragment_charges() const { return fragment_charges_; }
+    const std::vector<int>& get_fragment_charges() const { return fragment_charges_; }
     /// The multiplicity of each fragment
-    const std::vector<int>& fragment_multiplicities() const { return fragment_multiplicities_; }
+    const std::vector<int>& get_fragment_multiplicities() const { return fragment_multiplicities_; }
+    /// Sets the fragmentation information directly
+    void set_fragment_pattern(const std::vector<std::pair<int, int>>,
+                              const std::vector<FragmentType>,
+                              const std::vector<int>,
+                              const std::vector<int>);
 
+    /// Sets whether this molecule contains at least one cartesian entry
+    void set_has_cartesian(bool tf) { cart_ = tf; }
     /// Sets whether this molecule contains at least one zmatrix entry
-    void set_has_zmatrix(bool tf) {zmat_ = tf;}
+    void set_has_zmatrix(bool tf) { zmat_ = tf; }
     /// Whether this molecule has at least one zmatrix entry
-    bool has_zmatrix() const {return zmat_;}
+    bool has_zmatrix() const { return zmat_; }
     /// Assigns the value val to the variable labelled string in the list of geometry variables.
     /// Also calls update_geometry()
-    void set_variable(const std::string &str, double val);
+    void set_variable(const std::string& str, double val);
+    /// Plain assigns the vlue val to the variable labeled string in the list of geometry variables.
+    void set_geometry_variable(const std::string &str, double val) { geometry_variables_[str] = val; }
     /// Checks to see if the variable str is in the list, sets it to val and returns
     /// true if it is, and returns false if not.
-    double get_variable(const std::string &str);
+    double get_variable(const std::string& str);
     /// Checks to see if the variable str is in the list, returns
     /// true if it is, and returns false if not.
-    bool is_variable(const std::string &str) const;
+    bool is_variable(const std::string& str) const;
 
     /// Sets the molecular charge
-    void set_molecular_charge(int charge) {charge_specified_ = true; molecular_charge_ = charge;}
+    void set_molecular_charge(int charge) {
+        charge_specified_ = true;
+        molecular_charge_ = charge;
+    }
     /// Gets the molecular charge
-    int molecular_charge() const;
+    int molecular_charge() const { return molecular_charge_; }
     /// Sets the multiplicity (defined as 2Ms + 1)
-    void set_multiplicity(int mult) { multiplicity_specified_ = true; multiplicity_ = mult; }
+    void set_multiplicity(int mult) {
+        multiplicity_specified_ = true;
+        multiplicity_ = mult;
+    }
     /// Get the multiplicity (defined as 2Ms + 1)
-    int multiplicity() const;
+    int multiplicity() const { return multiplicity_; }
+
     /// Sets the geometry units
-    void set_units(GeometryUnits units) { units_ = units; }
+    void set_units(GeometryUnits units);
     /// Gets the geometry units
     GeometryUnits units() const { return units_; }
-
+    /// Sets the geometry unit conversion.
+    /// May be used to override internal a2b physconst. Call _after_ units set.
+    void set_input_units_to_au(double conv);
+    /// Gets the geometry unit conversion
+    double input_units_to_au() const { return input_units_to_au_; }
     /// Get whether or not orientation is fixed
     bool orientation_fixed() const { return fix_orientation_; }
     /// Fix the orientation at its current frame
-    void set_orientation_fixed(bool fix = true) { fix_orientation_ = fix;}
+    void set_orientation_fixed(bool fix = true) { fix_orientation_ = fix; }
+    /// Get whether or not COM is fixed
+    bool com_fixed() const { return !move_to_com_; }
     /// Fix the center of mass at its current frame
-    void set_com_fixed(bool fix = true) {move_to_com_ = !fix;}
+    void set_com_fixed(bool fix = true) { move_to_com_ = !fix; }
     /// Returns the Schoenflies symbol
     std::string schoenflies_symbol() const;
     /// Check if current geometry fits current point group
@@ -660,9 +678,12 @@ public:
     /// Return point group name such as C3v or S8.
     std::string full_point_group() const;
     /// Return point group name such as Cnv or Sn.
-    std::string full_point_group_with_n() const { return FullPointGroupList[full_pg_];}
+    std::string full_point_group_with_n() const { return FullPointGroupList[full_pg_]; }
     /// Return n in Cnv, etc.; If there is no n (e.g. Td) it's the highest-order rotation axis.
     int full_pg_n() { return full_pg_n_; }
+    /// Number of unique orientations of the rigid molecule that only interchange identical atoms.
+    ///    Source: http://cccbdb.nist.gov/thermo.asp (search "symmetry number")
+    int rotational_symmetry_number() const;
 
     /**
      * Updates the geometry, by (re)interpreting the string used to create the molecule, and the current values
@@ -671,8 +692,6 @@ public:
     void update_geometry();
 };
 
-typedef std::shared_ptr<Molecule> SharedMolecule;
-
 }
 
 #endif
