@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -39,7 +39,6 @@
 
 namespace psi {
 
-class Matrix;
 class Wavefunction;
 class IntegralFactory;
 class MatrixFactory;
@@ -369,9 +368,9 @@ public:
 //    // Deprecated
 //   // // Compute routines (these all work on a block of points)
 //   // /// Compute mo values
-//   // void compute_mos(std::shared_ptr<GridBlock> g, unsigned long int offset);
+//   // void compute_mos(std::shared_ptr<GridBlock> g, size_t offset);
 //   // /// Compute basis function values
-//   // void compute_basis_funs(std::shared_ptr<GridBlock> g, unsigned long int offset);
+//   // void compute_basis_funs(std::shared_ptr<GridBlock> g, size_t offset);
 //   // /// Compute total density
 //   // void compute_rho(std::shared_ptr<GridBlock> g, double* results);
 //   // /// Compute spin density (rho_a - rho_b)
