@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -32,8 +32,10 @@
 #include "psi4/libmints/integral.h"
 #include "psi4/libmints/basisset.h"
 #include "psi4/libmints/matrix.h"
+#include "psi4/libmints/molecule.h"
 #include "psi4/libmints/sobasis.h"
 #include "psi4/physconst.h"
+#include "typedefs.h"
 
 #define MAX(a, b) ((a) > (b) ? (a) : (b))
 
@@ -78,7 +80,7 @@ PotentialInt::PotentialInt(std::vector<SphericalTransform>& st, std::shared_ptr<
     buffer_ = new double[maxnao1*maxnao2];
 
     // Setup the initial field of partial charges
-    Zxyz_ = SharedMatrix (new Matrix("Partial Charge Field (Z,x,y,z)", bs1_->molecule()->natom(), 4));
+    Zxyz_ = std::make_shared<Matrix>("Partial Charge Field (Z,x,y,z)", bs1_->molecule()->natom(), 4);
     double** Zxyzp = Zxyz_->pointer();
 
     for (int A = 0; A < bs1_->molecule()->natom(); A++) {
@@ -1008,7 +1010,7 @@ void PotentialSOInt::compute_deriv1(std::vector<SharedMatrix > result,
                                 for (int nx=0; nx<cdsalc1.nx(); ++nx) {
                                     const CdSalcWRTAtom::Component element = cdsalc1.x(nx);
                                     double temp = jcoef_aobuf * element.coef;
-                                    if ((iirrep ^ jirrep) == element.irrep && fabs(temp) > 1.0e-10) {
+                                    if ((iirrep ^ jirrep) == element.irrep && std::fabs(temp) > 1.0e-10) {
                                         result[element.salc]->add(iirrep, irel, jrel, temp);
                                     }
                                 }
@@ -1017,7 +1019,7 @@ void PotentialSOInt::compute_deriv1(std::vector<SharedMatrix > result,
                                 for (int ny=0; ny<cdsalc1.ny(); ++ny) {
                                     const CdSalcWRTAtom::Component element = cdsalc1.y(ny);
                                     double temp = jcoef_aobuf * element.coef;
-                                    if ((iirrep ^ jirrep) == element.irrep && fabs(temp) > 1.0e-10) {
+                                    if ((iirrep ^ jirrep) == element.irrep && std::fabs(temp) > 1.0e-10) {
                                         result[element.salc]->add(iirrep, irel, jrel, temp);
                                     }
                                 }
@@ -1026,7 +1028,7 @@ void PotentialSOInt::compute_deriv1(std::vector<SharedMatrix > result,
                                 for (int nz=0; nz<cdsalc1.nz(); ++nz) {
                                     const CdSalcWRTAtom::Component element = cdsalc1.z(nz);
                                     double temp = jcoef_aobuf * element.coef;
-                                    if ((iirrep ^ jirrep) == element.irrep && fabs(temp) > 1.0e-10) {
+                                    if ((iirrep ^ jirrep) == element.irrep && std::fabs(temp) > 1.0e-10) {
                                         result[element.salc]->add(iirrep, irel, jrel, temp);
                                     }
                                 }
