@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -39,7 +39,6 @@
 
 namespace psi {
 
-class Matrix;
 class Vector;
 class IntVector;
 
@@ -78,23 +77,23 @@ void PSI_DTRSM(int irrep, char side, char uplo, char transa, char diag, int m, i
 /// PSI_DTRSV, a wrapper to C_DTRSV using objects
 void PSI_DTRSV(int irrep, char uplo, char trans, char diag, int n, SharedMatrix a, int lda, std::shared_ptr<Vector> x, int incx);
 /// PSI_DROT, a wrapper to C_DROT using objects
-void PSI_DROT(int irrep, unsigned long int n, std::shared_ptr<Vector> x, int incx, std::shared_ptr<Vector> y, int incy, double c, double s);
+void PSI_DROT(int irrep, size_t n, std::shared_ptr<Vector> x, int incx, std::shared_ptr<Vector> y, int incy, double c, double s);
 /// PSI_DSWAP, a wrapper to C_DSWAP using objects
-void PSI_DSWAP(int irrep, unsigned long int n, std::shared_ptr<Vector> x, int incx, std::shared_ptr<Vector> y, int incy);
+void PSI_DSWAP(int irrep, size_t n, std::shared_ptr<Vector> x, int incx, std::shared_ptr<Vector> y, int incy);
 /// PSI_DCOPY, a wrapper to C_DCOPY using objects
-void PSI_DCOPY(int irrep, unsigned long int n, std::shared_ptr<Vector> x, int incx, std::shared_ptr<Vector> y, int incy);
+void PSI_DCOPY(int irrep, size_t n, std::shared_ptr<Vector> x, int incx, std::shared_ptr<Vector> y, int incy);
 /// PSI_DSCAL, a wrapper to C_DSCAL using objects
-void PSI_DSCAL(int irrep, unsigned long int n, double alpha, std::shared_ptr<Vector> x, int incx);
+void PSI_DSCAL(int irrep, size_t n, double alpha, std::shared_ptr<Vector> x, int incx);
 /// PSI_DAXPY, a wrapper to C_DAXPY using objects
-void PSI_DAXPY(int irrep, unsigned long int n, double alpha, std::shared_ptr<Vector> x, int incx, std::shared_ptr<Vector> y, int incy);
+void PSI_DAXPY(int irrep, size_t n, double alpha, std::shared_ptr<Vector> x, int incx, std::shared_ptr<Vector> y, int incy);
 /// PSI_DDOT, a wrapper to C_DDOT using objects
-double PSI_DDOT(int irrep, unsigned long int n, std::shared_ptr<Vector> x, int incx, std::shared_ptr<Vector> y, int incy);
+double PSI_DDOT(int irrep, size_t n, std::shared_ptr<Vector> x, int incx, std::shared_ptr<Vector> y, int incy);
 /// PSI_DNRM2, a wrapper to C_DNRM2 using objects
-double PSI_DNRM2(int irrep, unsigned long int n, std::shared_ptr<Vector> x, int incx);
+double PSI_DNRM2(int irrep, size_t n, std::shared_ptr<Vector> x, int incx);
 /// PSI_DASUM, a wrapper to C_DASUM using objects
-double PSI_DASUM(int irrep, unsigned long int n, std::shared_ptr<Vector> x, int incx);
+double PSI_DASUM(int irrep, size_t n, std::shared_ptr<Vector> x, int incx);
 /// PSI_IDAMAX, a wrapper to C_IDAMAX using objects
-unsigned long int PSI_IDAMAX(int irrep, unsigned long int n, std::shared_ptr<Vector> x, int incx);
+size_t PSI_IDAMAX(int irrep, size_t n, std::shared_ptr<Vector> x, int incx);
 /// LAPACK
 /// PSI_DBDSDC, a wrapper to return C_DBDSDC using objects
 int PSI_DBDSDC(int irrep, char uplo, char compq, int n, std::shared_ptr<Vector> d, std::shared_ptr<Vector> e, SharedMatrix u, int ldu, SharedMatrix vt, int ldvt, std::shared_ptr<Vector> q, std::shared_ptr<IntVector> iq, std::shared_ptr<Vector> work, std::shared_ptr<IntVector> iwork);
