@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -29,11 +29,10 @@
 #include <utility>
 #include <algorithm>
 #include "psi4/libmints/writer.h"
-#include "psi4/libmints/view.h"
 #include "psi4/psi4-dec.h"
 #include "psi4/physconst.h"
 #include "psi4/masses.h"
-#include "psi4/libparallel/ParallelPrinter.h"
+#include "psi4/libpsi4util/PsiOutStream.h"
 #include "psi4/libmints/wavefunction.h"
 #include "psi4/libmints/pointgrp.h"
 #include "psi4/libmints/molecule.h"
@@ -43,7 +42,6 @@
 #include "psi4/libmints/mintshelper.h"
 
 
-using namespace std;
 using namespace psi;
 ;
 
@@ -54,7 +52,7 @@ GradientWriter::GradientWriter(std::shared_ptr<Molecule> mol, const Matrix& grad
 
 void GradientWriter::write(const std::string &filename)
 {
-   std::shared_ptr<OutFile> printer(new OutFile(filename,APPEND));
+   auto printer = std::make_shared<PsiOutStream>(filename,std::ostream::app);
    int i;
 
 
@@ -79,11 +77,10 @@ void GradientWriter::write(const std::string &filename)
 MoldenWriter::MoldenWriter(std::shared_ptr<Wavefunction> wavefunction)
     : wavefunction_(wavefunction)
 {
-
 }
 void MoldenWriter::write(const std::string &filename, std::shared_ptr<Matrix> Ca, std::shared_ptr<Matrix> Cb, std::shared_ptr<Vector> Ea, std::shared_ptr<Vector> Eb, std::shared_ptr<Vector> OccA, std::shared_ptr<Vector> OccB, bool dovirtual)
 {
-    std::shared_ptr<OutFile> printer(new OutFile(filename,APPEND));
+    auto printer = std::make_shared<PsiOutStream>(filename,std::ostream::app);
 
     int atom;
 
@@ -128,7 +125,7 @@ void MoldenWriter::write(const std::string &filename, std::shared_ptr<Matrix> Ca
     }
 
     // Convert Ca & Cb
-    std::shared_ptr<PetiteList> pl(new PetiteList(wavefunction_->basisset(), wavefunction_->integral()));
+    auto pl = std::make_shared<PetiteList>(wavefunction_->basisset(), wavefunction_->integral());
     // get the "aotoso" transformation matrix, ao by so
     SharedMatrix aotoso = pl->aotoso();
     // need dimensions
@@ -136,8 +133,8 @@ void MoldenWriter::write(const std::string &filename, std::shared_ptr<Matrix> Ca
     const Dimension sos = pl->SO_basisdim();
     const Dimension nmo = Ca->colspi();
 
-    SharedMatrix Ca_ao_mo(new Matrix("Ca AO x MO", aos, nmo));
-    SharedMatrix Cb_ao_mo(new Matrix("Cb AO x MO", aos, nmo));
+    auto Ca_ao_mo = std::make_shared<Matrix>("Ca AO x MO", aos, nmo);
+    auto Cb_ao_mo = std::make_shared<Matrix>("Cb AO x MO", aos, nmo);
 
     // do the half transform
     Ca_ao_mo->gemm(false, false, 1.0, aotoso, Ca, 0.0);
@@ -179,11 +176,11 @@ void MoldenWriter::write(const std::string &filename, std::shared_ptr<Matrix> Ca
             for (int h=0; h<nirrep; ++h)
                 ncartpi[h] = ncart;
 
-            View block_a(Ca_ao_mo, ncartpi, Ca_ao_mo->colspi(), countpi, zeropi);
-            View block_b(Cb_ao_mo, ncartpi, Cb_ao_mo->colspi(), countpi, zeropi);
-
-            SharedMatrix temp_a = block_a();
-            SharedMatrix temp_b = block_b();
+            Slice row_slice(countpi,countpi + ncartpi);
+            Slice acol_slice(zeropi,zeropi + Ca_ao_mo->colspi());
+            Slice bcol_slice(zeropi,zeropi + Cb_ao_mo->colspi());
+            SharedMatrix temp_a = Ca_ao_mo->get_block(row_slice,acol_slice);
+            SharedMatrix temp_b = Cb_ao_mo->get_block(row_slice,bcol_slice);
 
             for( int j =0; j < ncart; j++) {
                 for (int h=0; h < Ca_ao_mo->nirrep(); ++h) {
@@ -224,8 +221,8 @@ void MoldenWriter::write(const std::string &filename, std::shared_ptr<Matrix> Ca
     bool SameOcc = true;
     for (int h=0; h<wavefunction_->nirrep(); ++h) {
         for (int n=0; n<nmoh[h]; ++n) {
-            mos.push_back(make_pair(Ea->get(h, n), make_pair(h, n)));
-            if(fabs(OccA->get(h,n) - OccB->get(h,n)) > 1e-10)
+            mos.push_back(std::make_pair(Ea->get(h, n), std::make_pair(h, n)));
+            if(std::fabs(OccA->get(h,n) - OccB->get(h,n)) > 1e-10)
                 SameOcc = false;
         }
     }
@@ -251,7 +248,7 @@ void MoldenWriter::write(const std::string &filename, std::shared_ptr<Matrix> Ca
     if (Ca != Cb || Ea != Eb || !SameOcc) {
         for (int h=0; h<wavefunction_->nirrep(); ++h) {
             for (int n=0; n<nmoh[h]; ++n) {
-                mos.push_back(make_pair(Eb->get(h, n), make_pair(h, n)));
+                mos.push_back(std::make_pair(Eb->get(h, n), std::make_pair(h, n)));
             }
         }
         std::sort(mos.begin(), mos.end());
@@ -275,6 +272,8 @@ void MoldenWriter::write(const std::string &filename, std::shared_ptr<Matrix> Ca
 FCHKWriter::FCHKWriter(std::shared_ptr<Wavefunction> wavefunction)
     : wavefunction_(wavefunction)
 {
+    SharedMatrix Ca = wavefunction_->Ca();
+    Ca->print();
 }
 
 
@@ -519,7 +518,7 @@ void FCHKWriter::write(const std::string &filename)
          ///*  0 */  { pf1, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0 },
     };
 
-    SharedMatrix transmat(new Matrix("Reorder", nbf, nbf));
+    auto transmat = std::make_shared<Matrix>("Reorder", nbf, nbf);
     transmat->identity();
     int offset = 0;
     for(int nshell = 0; nshell < basis->nshell(); ++nshell){
@@ -558,21 +557,21 @@ void FCHKWriter::write(const std::string &filename)
     SharedMatrix reorderedDs(Dtot_ao->clone());
     reorderedDt->back_transform(Dtot_ao, transmat);
     reorderedDs->back_transform(Dspin_ao, transmat);
-    SharedMatrix reorderedCa(new Matrix("Reordered Ca", Ca_ao->ncol(), Ca_ao->nrow()));
-    SharedMatrix reorderedCb(new Matrix("Reordered Cb", Cb_ao->ncol(), Cb_ao->nrow()));
+    auto reorderedCa = std::make_shared<Matrix>("Reordered Ca", Ca_ao->ncol(), Ca_ao->nrow());
+    auto reorderedCb = std::make_shared<Matrix>("Reordered Cb", Cb_ao->ncol(), Cb_ao->nrow());
     reorderedCa->gemm(true, true, 1.0, Ca_ao, transmat, 0.0);
     reorderedCb->gemm(true, true, 1.0, Cb_ao, transmat, 0.0);
     for(int i = 0; i < reorderedDt->nrow(); ++i)
         for(int j = 0; j < reorderedDt->ncol(); ++j)
-            if(fabs(reorderedDt->get(i,j)) < 1E-12)
+            if(std::fabs(reorderedDt->get(i,j)) < 1E-12)
                 reorderedDt->set(i,j,0.0);
     for(int i = 0; i < reorderedCa->nrow(); ++i)
         for(int j = 0; j < reorderedCa->ncol(); ++j)
-            if(fabs(reorderedCa->get(i,j)) < 1E-12)
+            if(std::fabs(reorderedCa->get(i,j)) < 1E-12)
                 reorderedCa->set(i,j,0.0);
     for(int i = 0; i < reorderedCb->nrow(); ++i)
         for(int j = 0; j < reorderedCb->ncol(); ++j)
-            if(fabs(reorderedCb->get(i,j)) < 1E-12)
+            if(std::fabs(reorderedCb->get(i,j)) < 1E-12)
                 reorderedCb->set(i,j,0.0);
     std::vector<double> shell_coords;
     std::vector<double> coefficients;
@@ -635,10 +634,14 @@ void FCHKWriter::write(const std::string &filename)
     write_matrix("Contraction coefficients", coefficients);
     write_matrix("Coordinates of each shell", shell_coords);
     write_number("Total Energy", wavefunction_->reference_energy());
-    write_matrix("Alpha Orbital Energies", wavefunction_->epsilon_a_subset("AO"));
-    write_matrix("Alpha MO coefficients", reorderedCa);
-    write_matrix("Beta Orbital Energies", wavefunction_->epsilon_b_subset("AO"));
-    write_matrix("Beta MO coefficients", reorderedCb);
+    //write_matrix("Alpha Orbital Energies", wavefunction_->epsilon_a_subset("AO"));
+    write_matrix(wavefunction_->epsilon_a()->name().c_str(), wavefunction_->epsilon_a_subset("AO"));
+    //write_matrix("Alpha MO coefficients", reorderedCa);
+    write_matrix(wavefunction_->Ca()->name().c_str(), reorderedCa);
+    //write_matrix("Beta Orbital Energies", wavefunction_->epsilon_b_subset("AO"));
+    write_matrix(wavefunction_->epsilon_b()->name().c_str(), wavefunction_->epsilon_b_subset("AO"));
+    //write_matrix("Beta MO coefficients", reorderedCb);
+    write_matrix(wavefunction_->Cb()->name().c_str(), reorderedCb);
     char* label = new char[256];
     std::string type = name == "DFT" ? "SCF" : name;
     sprintf(label, "Total %s Density", type.c_str());
@@ -675,7 +678,7 @@ void NBOWriter::write(const std::string &filename)
 
     MintsHelper helper(wavefunction_->basisset(), wavefunction_->options(), 0);
     SharedMatrix sotoao = helper.petite_list()->sotoao();
-    std::shared_ptr<OutFile> printer(new OutFile(filename,APPEND));
+    auto printer = std::make_shared<PsiOutStream>(filename,std::ostream::app);
 
 
     //Get the basis set and molecule from the wavefuntion
@@ -904,17 +907,17 @@ void NBOWriter::write(const std::string &filename)
 
     //Alpha Density Matrix
     SharedMatrix soalphadens = wavefunction_->Da();
-    SharedMatrix alphadens(new Matrix(nbf, nbf));
+    auto alphadens = std::make_shared<Matrix>(nbf, nbf);
     alphadens->remove_symmetry (soalphadens, sotoao);
     //Beta density
-    SharedMatrix betadens(new Matrix(nbf, nbf));
+    auto betadens = std::make_shared<Matrix>(nbf, nbf);
     SharedMatrix sobetadens = wavefunction_->Db();
     betadens->remove_symmetry (sobetadens, sotoao);
     //Now print the density matrix
     printer->Printf( "\n $DENSITY");
     if(wavefunction_->same_a_b_dens ())
     {
-        SharedMatrix density(new Matrix(nbf, nbf));
+        auto density = std::make_shared<Matrix>(nbf, nbf);
         density->copy (alphadens);
         density->add (betadens);
         for( int i=0; i<nbf; i++)
@@ -956,7 +959,7 @@ void NBOWriter::write(const std::string &filename)
 
     // alpha Fock matrix
     SharedMatrix alphasofock = wavefunction_->Fa();
-    SharedMatrix alphafock(new Matrix(nbf, nbf));
+    auto alphafock = std::make_shared<Matrix>(nbf, nbf);
     alphafock->remove_symmetry (alphasofock, sotoao);
     // print the Fock matrix
     printer->Printf( "\n $FOCK");
@@ -976,7 +979,7 @@ void NBOWriter::write(const std::string &filename)
     else
     {
         // beta Fock
-        SharedMatrix betafock(new Matrix(nbf, nbf));
+        auto betafock = std::make_shared<Matrix>(nbf, nbf);
         SharedMatrix betasofock = wavefunction_->Fb();
         betafock->remove_symmetry(betasofock, sotoao);
         int count=0;
@@ -1007,7 +1010,7 @@ void NBOWriter::write(const std::string &filename)
     SharedMatrix soalphac = wavefunction_->Ca();
     const Dimension aos = helper.petite_list()->AO_basisdim();
     const Dimension nmo = wavefunction_->Ca()->colspi();
-    SharedMatrix alphac(new Matrix("Ca AO x MO", aos, nmo));
+    auto alphac = std::make_shared<Matrix>("Ca AO x MO", aos, nmo);
     alphac->gemm(true, false, 1.00, sotoao, soalphac, 0.00);
 
     printer->Printf( "\n $LCAOMO");
@@ -1027,7 +1030,7 @@ void NBOWriter::write(const std::string &filename)
     else
     {
         //Beta AO->MO transformation
-        SharedMatrix betac(new Matrix(nbf, nbf));
+        auto betac = std::make_shared<Matrix>(nbf, nbf);
         SharedMatrix sobetac = wavefunction_->Cb();
         betac->gemm(true, false, 1.00, sotoao, sobetac, 0.00);
 
@@ -1078,7 +1081,7 @@ void MOWriter::write()
     Vector& Ea = *wavefunction_->epsilon_a().get();
     Vector& Eb = *wavefunction_->epsilon_b().get();
 
-    std::shared_ptr<PetiteList> pl(new PetiteList(wavefunction_->basisset(), wavefunction_->integral()));
+    auto pl = std::make_shared<PetiteList>(wavefunction_->basisset(), wavefunction_->integral());
 
     // get the "aotoso" transformation matrix, ao by so
     SharedMatrix aotoso = pl->aotoso();
@@ -1087,8 +1090,8 @@ void MOWriter::write()
     const Dimension sos = pl->SO_basisdim();
     const Dimension mos = wavefunction_->nmopi();
 
-    SharedMatrix Ca_ao_mo(new Matrix("Ca AO x MO", aos, mos));
-    SharedMatrix Cb_ao_mo(new Matrix("Cb AO x MO", aos, mos));
+    auto Ca_ao_mo = std::make_shared<Matrix>("Ca AO x MO", aos, mos);
+    auto Cb_ao_mo = std::make_shared<Matrix>("Cb AO x MO", aos, mos);
 
     // do the half transform
     Ca_ao_mo->gemm(false, false, 1.0, aotoso, Ca, 0.0);
