@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -36,10 +36,10 @@
 
 namespace psi {
 
-psio_tocentry*PSIO::toclast(unsigned int unit) {
+psio_tocentry*PSIO::toclast(size_t unit) {
   psio_tocentry *this_entry = psio_unit[unit].toc;
 
-  while (this_entry->next != NULL)
+  while (this_entry->next != nullptr)
     this_entry = this_entry->next;
 
   return (this_entry);
