@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -30,6 +30,7 @@
 #include "psipcm.h"
 #include "psi4/libmints/matrix.h"
 #include "psi4/libmints/vector.h"
+#include "psi4/libmints/molecule.h"
 #include "psi4/libmints/basisset.h"
 #include "psi4/liboptions/liboptions.h"
 #include "psi4/libmints/integral.h"
@@ -106,7 +107,7 @@ PCM::PCM(Options &options, std::shared_ptr<PSIO> /* psio */, int nirrep, std::sh
   basisset_ = basisset;
 
   std::shared_ptr<IntegralFactory>
-    integrals(new IntegralFactory(basisset, basisset, basisset, basisset));
+    integrals = std::make_shared<IntegralFactory>(basisset, basisset, basisset, basisset);
 
   PetiteList petite(basisset, integrals, true);
   my_aotoso_ = petite.aotoso();
@@ -133,8 +134,8 @@ PCM::PCM(Options &options, std::shared_ptr<PSIO> /* psio */, int nirrep, std::sh
     context_ = pcmsolver_new(PCMSOLVER_READER_HOST, molecule->natom(), charges, coordinates,
                              symmetry_info, &host_input, host_writer);
   } else {
-    context_ = pcmsolver_new(PCMSOLVER_READER_OWN, molecule->natom(), charges, coordinates,
-                             symmetry_info, &host_input, host_writer);
+    context_ = pcmsolver_new_v1112(PCMSOLVER_READER_OWN, molecule->natom(), charges, coordinates,
+                             symmetry_info, options.get_str("PCMSOLVER_PARSED_FNAME").c_str(), &host_input, host_writer);
   }
   pcmsolver_print(context_);
   ntess_ = pcmsolver_get_cavity_size(context_);
@@ -148,7 +149,7 @@ PCM::PCM(Options &options, std::shared_ptr<PSIO> /* psio */, int nirrep, std::sh
   tess_charges_ = new double[ntess_];
 
   int natom = molecule->natom();
-  SharedMatrix atom_Zxyz_ = SharedMatrix(new Matrix("Atom Zxyz", natom, 4));
+  auto atom_Zxyz_ = std::make_shared<Matrix>("Atom Zxyz", natom, 4);
   for(int atom = 0; atom < natom; ++atom){
     Vector3 xyz = molecule->xyz(atom);
     atom_Zxyz_->set(atom, 0, molecule->charge(atom));
@@ -158,7 +159,7 @@ PCM::PCM(Options &options, std::shared_ptr<PSIO> /* psio */, int nirrep, std::sh
   }
 
   // The charge and {x,y,z} coordinates (in bohr) for each tessera
-  tess_Zxyz_ = SharedMatrix(new Matrix("Tess Zxyz", ntess_, 4));
+  tess_Zxyz_ = std::make_shared<Matrix>("Tess Zxyz", ntess_, 4);
   double **ptess_Zxyz = tess_Zxyz_->pointer();
   // Set the tesserae's coordinates (note the loop bounds; this function is 1-based)
   for(int tess = 1; tess <= ntess_; ++tess)
@@ -244,8 +245,7 @@ double PCM::compute_E_total(SharedMatrix &D)
 
   SharedMatrix D_carts;
   if(basisset_->has_puream()){
-    D_carts = SharedMatrix(new Matrix("D carts", basisset_->nao(), basisset_->nao()));
-    outfile->Flush();
+    D_carts = std::make_shared<Matrix>("D carts", basisset_->nao(), basisset_->nao());
     D_carts->back_transform(D,my_aotoso_);
   }
   else D_carts = D;
@@ -300,8 +300,7 @@ double PCM::compute_E_separate(SharedMatrix &D)
 
   SharedMatrix D_carts;
   if(basisset_->has_puream()){
-    D_carts = SharedMatrix(new Matrix("D carts", basisset_->nao(), basisset_->nao()));
-    outfile->Flush();
+    D_carts = std::make_shared<Matrix>("D carts", basisset_->nao(), basisset_->nao());
     D_carts->back_transform(D,my_aotoso_);
   }
   else D_carts = D;
@@ -371,8 +370,7 @@ double PCM::compute_E_electronic(SharedMatrix &D)
 
   SharedMatrix D_carts;
   if(basisset_->has_puream()){
-    D_carts = SharedMatrix(new Matrix("D carts", basisset_->nao(), basisset_->nao()));
-    outfile->Flush();
+    D_carts = std::make_shared<Matrix>("D carts", basisset_->nao(), basisset_->nao());
     D_carts->back_transform(D,my_aotoso_);
   }
   else D_carts = D;
@@ -413,13 +411,13 @@ double PCM::compute_E_electronic(SharedMatrix &D)
 
 SharedMatrix PCM::compute_V()
 {
-  SharedMatrix V_pcm_cart = SharedMatrix(new Matrix("PCM potential cart", basisset_->nao(), basisset_->nao()));
+  auto V_pcm_cart = std::make_shared<Matrix>("PCM potential cart", basisset_->nao(), basisset_->nao());
   ContractOverChargesFunctor contract_charges_functor(tess_charges_, V_pcm_cart);
   potential_int_->compute(contract_charges_functor);
   // The potential might need to be transformed to the spherical harmonic basis
   SharedMatrix V_pcm_pure;
   if(basisset_->has_puream()){
-      V_pcm_pure = SharedMatrix(new Matrix("PCM potential pure", basisset_->nbf(), basisset_->nbf()));
+      V_pcm_pure = std::make_shared<Matrix>("PCM potential pure", basisset_->nbf(), basisset_->nbf());
       V_pcm_pure->transform(V_pcm_cart, my_aotoso_);
   }
   if(basisset_->has_puream()) return V_pcm_pure;
@@ -428,13 +426,13 @@ SharedMatrix PCM::compute_V()
 
 SharedMatrix PCM::compute_V_electronic()
 {
-  SharedMatrix V_pcm_cart = SharedMatrix(new Matrix("PCM potential cart", basisset_->nao(), basisset_->nao()));
+  auto V_pcm_cart = std::make_shared<Matrix>("PCM potential cart", basisset_->nao(), basisset_->nao());
   ContractOverChargesFunctor contract_charges_functor(tess_charges_e_, V_pcm_cart);
   potential_int_->compute(contract_charges_functor);
   // The potential might need to be transformed to the spherical harmonic basis
   SharedMatrix V_pcm_pure;
   if(basisset_->has_puream()){
-      V_pcm_pure = SharedMatrix(new Matrix("PCM potential pure", basisset_->nbf(), basisset_->nbf()));
+      V_pcm_pure = std::make_shared<Matrix>("PCM potential pure", basisset_->nbf(), basisset_->nbf());
       V_pcm_pure->transform(V_pcm_cart, my_aotoso_);
   }
   if(basisset_->has_puream()) return V_pcm_pure;
