@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -36,12 +36,17 @@
 #include "psi4/psifiles.h"
 #include "psi4/libciomr/libciomr.h"
 #include "psi4/libpsio/psio.h"
-#include "psi4/libparallel/parallel.h"
 #include "psi4/libiwl/iwl.hpp"
 #include "psi4/libqt/qt.h"
 #include "psi4/psifiles.h"
+#include "psi4/libmints/vector.h"
 #include "psi4/libmints/matrix.h"
+#include "psi4/libmints/molecule.h"
 #include "psi4/libmints/pointgrp.h"
+#include "psi4/libpsi4util/PsiOutStream.h"
+#include "psi4/liboptions/liboptions.h"
+#include "psi4/libdiis/diismanager.h"
+#include "psi4/libdiis/diisentry.h"
 
 #include "hf.h"
 
@@ -50,7 +55,6 @@
 #endif
 
 
-using namespace std;
 using namespace psi;
 
 namespace psi { namespace scf {
@@ -65,9 +69,9 @@ void HF::MOM_start()
     MOM_performed_ = true; // Gets printed next iteration
     //
     // Build Ca_old_ matrices
-    Ca_old_ = SharedMatrix(new Matrix("C Alpha Old (SO Basis)", nirrep_, nsopi_, nmopi_));
+    Ca_old_ = std::make_shared<Matrix>("C Alpha Old (SO Basis)", nirrep_, nsopi_, nmopi_);
     if (!same_a_b_orbs()) {
-        Cb_old_ = SharedMatrix(new Matrix("C Beta Old (SO Basis)", nirrep_, nsopi_, nmopi_));
+        Cb_old_ = std::make_shared<Matrix>("C Beta Old (SO Basis)", nirrep_, nsopi_, nmopi_);
     } else {
         Cb_old_ = Ca_old_;
     }
@@ -98,7 +102,7 @@ void HF::MOM_start()
         if (nmo == 0) continue;
         double* eps = epsilon_a_->pointer(h);
         for (int a = 0; a < nmo; a++)
-            orbs_a.push_back(make_pair(eps[a], make_pair(h, a)));
+            orbs_a.push_back(std::make_pair(eps[a], std::make_pair(h, a)));
     }
     std::vector<std::pair<double, std::pair<int, int> > > orbs_b;
     for (int h = 0; h < nirrep_; h++) {
@@ -106,7 +110,7 @@ void HF::MOM_start()
         if (nmo == 0) continue;
         double* eps = epsilon_b_->pointer(h);
         for (int a = 0; a < nmo; a++)
-            orbs_b.push_back(make_pair(eps[a], make_pair(h, a)));
+            orbs_b.push_back(std::make_pair(eps[a], std::make_pair(h, a)));
     }
     sort(orbs_a.begin(),orbs_a.end());
     sort(orbs_b.begin(),orbs_b.end());
@@ -135,8 +139,8 @@ void HF::MOM_start()
         bool si = (i > 0);
         bool sa = (a > 0);
 
-        i = abs(i) - 1;
-        a = abs(a) - 1;
+        i = std::abs(i) - 1;
+        a = std::abs(a) - 1;
 
         if (options_.get_str("REFERENCE") == "RHF" || options_.get_str("REFERENCE") == "RKS") {
 
@@ -546,16 +550,16 @@ void HF::MOM_start()
                 std::vector<std::pair<double,std::pair<int, bool> > > betas;
 
                 for (int i = 0; i < nalphapi_[h]; i++) {
-                    alphas.push_back(make_pair(epsilon_a_->get(h,i), make_pair(i, true)));
+                    alphas.push_back(std::make_pair(epsilon_a_->get(h,i), std::make_pair(i, true)));
                 }
                 for (int i = 0; i < nbetapi_[h]; i++) {
-                    betas.push_back(make_pair(epsilon_b_->get(h,i), make_pair(i, true)));
+                    betas.push_back(std::make_pair(epsilon_b_->get(h,i), std::make_pair(i, true)));
                 }
                 for (int i = nalphapi_[h]; i < nmopi_[h]; i++) {
-                    alphas.push_back(make_pair(epsilon_a_->get(h,i), make_pair(i, false)));
+                    alphas.push_back(std::make_pair(epsilon_a_->get(h,i), std::make_pair(i, false)));
                 }
                 for (int i = nbetapi_[h]; i < nmopi_[h]; i++) {
-                    betas.push_back(make_pair(epsilon_b_->get(h,i), make_pair(i, false)));
+                    betas.push_back(std::make_pair(epsilon_b_->get(h,i), std::make_pair(i, false)));
                 }
                 sort(alphas.begin(),alphas.end());
                 sort(betas.begin(),betas.end());
@@ -620,8 +624,8 @@ void HF::MOM()
         std::vector<std::pair<double, int> > pvec;
         pvec.resize(nmo);
         for (int a = 0; a < nmo; a++)
-            pvec[a] = make_pair(fabs(p[a]), a);
-        sort(pvec.begin(),pvec.end(), greater<std::pair<double, int> >());
+            pvec[a] = std::make_pair(std::fabs(p[a]), a);
+        sort(pvec.begin(),pvec.end(), std::greater<std::pair<double, int> >());
 
         //outfile->Printf("  P_a sorted:\n");
         //for (int a = 0; a < nmo; a++)
@@ -631,7 +635,7 @@ void HF::MOM()
         std::vector<std::pair<double, int> > occvec;
         occvec.resize(nalpha);
         for (int a = 0; a < nalpha; a++)
-            occvec[a] = make_pair(eps[pvec[a].second], pvec[a].second);
+            occvec[a] = std::make_pair(eps[pvec[a].second], pvec[a].second);
         sort(occvec.begin(),occvec.end());
 
         //outfile->Printf("  P_a_occ sorted:\n");
@@ -641,7 +645,7 @@ void HF::MOM()
         std::vector<std::pair<double, int> > virvec;
         virvec.resize(nmo - nalpha);
         for (int a = 0; a < nmo - nalpha; a++)
-            virvec[a] = make_pair(eps[pvec[a + nalpha].second], pvec[a + nalpha].second);
+            virvec[a] = std::make_pair(eps[pvec[a + nalpha].second], pvec[a + nalpha].second);
         sort(virvec.begin(),virvec.end());
 
         //outfile->Printf("  P_a_vir sorted:\n");
@@ -708,8 +712,8 @@ void HF::MOM()
         std::vector<std::pair<double, int> > pvec;
         pvec.resize(nmo);
         for (int a = 0; a < nmo; a++)
-            pvec[a] = make_pair(fabs(p[a]), a);
-        sort(pvec.begin(),pvec.end(), greater<std::pair<double, int> >());
+            pvec[a] = std::make_pair(std::fabs(p[a]), a);
+        sort(pvec.begin(),pvec.end(), std::greater<std::pair<double, int> >());
 
         //outfile->Printf("  P_a sorted:\n");
         //for (int a = 0; a < nmo; a++)
@@ -719,7 +723,7 @@ void HF::MOM()
         std::vector<std::pair<double, int> > occvec;
         occvec.resize(nbeta);
         for (int a = 0; a < nbeta; a++)
-            occvec[a] = make_pair(eps[pvec[a].second], pvec[a].second);
+            occvec[a] = std::make_pair(eps[pvec[a].second], pvec[a].second);
         sort(occvec.begin(),occvec.end());
 
         //outfile->Printf("  P_a_occ sorted:\n");
@@ -729,7 +733,7 @@ void HF::MOM()
         std::vector<std::pair<double, int> > virvec;
         virvec.resize(nmo - nbeta);
         for (int a = 0; a < nmo - nbeta; a++)
-            virvec[a] = make_pair(eps[pvec[a + nbeta].second], pvec[a + nbeta].second);
+            virvec[a] = std::make_pair(eps[pvec[a + nbeta].second], pvec[a + nbeta].second);
         sort(virvec.begin(),virvec.end());
 
         //outfile->Printf("  P_a_vir sorted:\n");
