@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -44,63 +44,65 @@
 #include "psi4/psifiles.h"
 #include "psi4/libciomr/libciomr.h"
 #include "psi4/libpsio/psio.h"
-#include "psi4/libparallel/parallel.h"
 #include "psi4/libiwl/iwl.hpp"
 #include "psi4/libqt/qt.h"
 #include "psi4/psifiles.h"
 #include "psi4/libmints/matrix.h"
 #include "psi4/libmints/petitelist.h"
+#include "psi4/libmints/molecule.h"
+#include "psi4/libmints/basisset.h"
 #include "psi4/libmints/integral.h"
 #include "psi4/libmints/sointegral_onebody.h"
 #include "psi4/libmints/factory.h"
+#include "psi4/libdiis/diismanager.h"
+#include "psi4/libdiis/diisentry.h"
 #include "psi4/libfock/jk.h"
+#include "psi4/lib3index/dfhelper.h"
+#include "psi4/libpsi4util/PsiOutStream.h"
+#include "psi4/libpsi4util/process.h"
+#include "psi4/liboptions/liboptions.h"
 #include "hf.h"
 #include "sad.h"
 
-
-using namespace std;
 using namespace psi;
 
-namespace psi { namespace scf {
+namespace psi {
+namespace scf {
 
-SADGuess::SADGuess(std::shared_ptr<BasisSet> basis,
-                   std::vector<std::shared_ptr<BasisSet>> atomic_bases,
-                   int nalpha, int nbeta, Options& options) :
-    basis_(basis), atomic_bases_(atomic_bases), nalpha_(nalpha), nbeta_(nbeta),
-    options_(options) {
+SADGuess::SADGuess(std::shared_ptr<BasisSet> basis, std::vector<std::shared_ptr<BasisSet>> atomic_bases, int nalpha,
+                   int nbeta, Options& options)
+    : basis_(basis), atomic_bases_(atomic_bases), nalpha_(nalpha), nbeta_(nbeta), options_(options) {
     common_init();
 }
 SADGuess::~SADGuess() {}
-void SADGuess::common_init()
-{
+void SADGuess::common_init() {
     molecule_ = basis_->molecule();
 
-    std::shared_ptr<IntegralFactory> ints(new IntegralFactory(basis_));
-    std::shared_ptr<PetiteList> petite(new PetiteList(basis_,ints));
-    AO2SO_ =  petite->aotoso();
+    auto ints = std::make_shared<IntegralFactory>(basis_);
+    auto petite = std::make_shared<PetiteList>(basis_, ints);
+    AO2SO_ = petite->aotoso();
 
     print_ = options_.get_int("SAD_PRINT");
     debug_ = options_.get_int("DEBUG");
-    if(options_["SOCC"].size()>0||options_["DOCC"].size()>0)
-       PSIEXCEPTION("SAD guess not implemented for user-specified SOCCs and/or DOCCs yet");
+    if (options_["SOCC"].size() > 0 || options_["DOCC"].size() > 0)
+        PSIEXCEPTION("SAD guess not implemented for user-specified SOCCs and/or DOCCs yet");
 }
-void SADGuess::compute_guess()
-{
-
+void SADGuess::compute_guess() {
     timer_on("SAD Guess");
+    start_skip_timers();
     form_D();
     form_C();
+    stop_skip_timers();
     timer_off("SAD Guess");
 }
-void SADGuess::form_D()
-{
+void SADGuess::form_D() {
     // Build Neutral D in AO basis (block diagonal)
     SharedMatrix DAO = form_D_AO();
 
     // Transform Neutral D from AO to SO basis
-    Da_ = SharedMatrix(new Matrix("Da SAD",AO2SO_->colspi(),AO2SO_->colspi()));
+    Da_ = std::make_shared<Matrix>("Da SAD", AO2SO_->colspi(), AO2SO_->colspi());
 
-    double* temp = new double[AO2SO_->rowspi()[0] * (ULI) AO2SO_->max_ncol()];
+    double* temp = new double[AO2SO_->rowspi()[0] * (size_t)AO2SO_->max_ncol()];
     for (int h = 0; h < Da_->nirrep(); h++) {
         int nao = AO2SO_->rowspi()[h];
         int nso = AO2SO_->colspi()[h];
@@ -110,8 +112,8 @@ void SADGuess::form_D()
         double** DSOp = Da_->pointer(h);
         double** Up = AO2SO_->pointer(h);
 
-        C_DGEMM('N','N',nao,nso,nao,1.0,DAOp[0],nao,Up[0],nso,0.0,temp,nso);
-        C_DGEMM('T','N',nso,nso,nao,1.0,Up[0],nso,temp,nso,0.0,DSOp[0],nso);
+        C_DGEMM('N', 'N', nao, nso, nao, 1.0, DAOp[0], nao, Up[0], nso, 0.0, temp, nso);
+        C_DGEMM('T', 'N', nso, nso, nao, 1.0, Up[0], nso, temp, nso, 0.0, DSOp[0], nso);
     }
     delete[] temp;
 
@@ -120,7 +122,7 @@ void SADGuess::form_D()
     for (int A = 0; A < molecule_->natom(); A++) {
         npair += 0.5 * molecule_->Z(A);
     }
-    Da_->scale(((double) nalpha_) / npair);
+    Da_->scale(((double)nalpha_) / npair);
 
     // Build/Scale Db if needed
     if (nalpha_ == nbeta_) {
@@ -128,7 +130,7 @@ void SADGuess::form_D()
     } else {
         Db_ = SharedMatrix(Da_->clone());
         Db_->set_name("Db SAD");
-        Db_->scale(((double) nbeta_) / ((double) nalpha_));
+        Db_->scale(((double)nbeta_) / ((double)nalpha_));
     }
 
     if (debug_) {
@@ -136,17 +138,15 @@ void SADGuess::form_D()
         Db_->print();
     }
 }
-void SADGuess::form_C()
-{
+void SADGuess::form_C() {
     Ca_ = Da_->partial_cholesky_factorize(options_.get_double("SAD_CHOL_TOLERANCE"));
     Ca_->set_name("Ca SAD");
     if (nalpha_ == nbeta_) {
-
         Cb_ = Ca_;
     } else {
         Cb_ = SharedMatrix(Ca_->clone());
         Cb_->set_name("Cb SAD");
-        Cb_->scale(sqrt(((double)nbeta_)/((double)nalpha_)));
+        Cb_->scale(sqrt(((double)nbeta_) / ((double)nalpha_)));
     }
 
     if (debug_) {
@@ -154,11 +154,9 @@ void SADGuess::form_C()
         Cb_->print();
     }
 }
-SharedMatrix SADGuess::form_D_AO()
-{
-
+SharedMatrix SADGuess::form_D_AO() {
     if (print_ > 6) {
-        for (int A = 0; A<molecule_->natom(); A++) {
+        for (int A = 0; A < molecule_->natom(); A++) {
             outfile->Printf("  SAD: Atomic Basis Set %d\n", A);
             atomic_bases_[A]->molecule()->print();
             outfile->Printf("\n");
@@ -167,41 +165,43 @@ SharedMatrix SADGuess::form_D_AO()
         }
     }
 
-    //Spin occupations per atom, to be determined by Hund's Rules
-    //or user input
+    // Spin occupations per atom, to be determined by Hund's Rules
+    // or user input
     std::vector<int> nalpha(molecule_->natom(), 0);
     std::vector<int> nbeta(molecule_->natom(), 0);
     std::vector<int> nelec(molecule_->natom(), 0);
     std::vector<int> nhigh(molecule_->natom(), 0);
     int tot_elec = 0;
 
-    //Ground state high spin occupency array, atoms 0 to 36 (see Giffith's Quantum Mechanics, pp. 217)
-    //For 37 to 86, save for f-block: Atomic, Molecular, & Optical Physics Handbook, Ed. Gordon W. F. Drake, American Institute of Physics, Woodbury, New York, USA, 1996.
-    const int reference_S[] = {0,1,0,1,0,1,2,3,2,1,0,1,0,1,2,3,2,1,0,1,0,1,2,3,6,5,4,3,2,1,0,1,2,3,2,1,0,1,0,1,2,5,6,5,4,3,0,1,0,1,2,3,2,1,0,1,0,1,0,3,4,5,6,7,8,5,4,3,2,1,0,1,2,3,4,5,4,3,2,1,0,1,2,3,2,1,0};
+    // Ground state high spin occupency array, atoms 0 to 36 (see Giffith's Quantum Mechanics, pp. 217)
+    // For 37 to 86, save for f-block: Atomic, Molecular, & Optical Physics Handbook, Ed. Gordon W. F. Drake, American
+    // Institute of Physics, Woodbury, New York, USA, 1996.
+    const int reference_S[] = {0, 1, 0, 1, 0, 1, 2, 3, 2, 1, 0, 1, 0, 1, 2, 3, 2, 1, 0, 1, 0, 1, 2, 3, 6, 5, 4, 3, 2,
+                               1, 0, 1, 2, 3, 2, 1, 0, 1, 0, 1, 2, 5, 6, 5, 4, 3, 0, 1, 0, 1, 2, 3, 2, 1, 0, 1, 0, 1,
+                               0, 3, 4, 5, 6, 7, 8, 5, 4, 3, 2, 1, 0, 1, 2, 3, 4, 5, 4, 3, 2, 1, 0, 1, 2, 3, 2, 1, 0};
     const int MAX_Z = 86;
 
-    if (print_ > 1)
-        outfile->Printf("  Determining Atomic Occupations\n");
+    if (print_ > 1) outfile->Printf("  Determining Atomic Occupations\n");
 
-    for (int A = 0; A<molecule_->natom(); A++) {
+    for (int A = 0; A < molecule_->natom(); A++) {
         int Z = molecule_->Z(A);
-        if (Z>MAX_Z) {
+        if (Z > MAX_Z) {
             throw std::domain_error(" Only Atoms up to 86 (Rn) are currently supported with SAD Guess");
         }
         nhigh[A] = reference_S[Z];
         nelec[A] = Z;
-        tot_elec+= nelec[A];
-        nbeta[A] = (nelec[A]-nhigh[A])/2;
-        nalpha[A] = nelec[A]-nbeta[A];
+        tot_elec += nelec[A];
+        nbeta[A] = (nelec[A] - nhigh[A]) / 2;
+        nalpha[A] = nelec[A] - nbeta[A];
         if (print_ > 1)
-            outfile->Printf("  Atom %d, Z = %d, nelec = %d, nhigh = %d, nalpha = %d, nbeta = %d\n",A,Z,nelec[A],nhigh[A],nalpha[A],nbeta[A]);
+            outfile->Printf("  Atom %d, Z = %d, nelec = %d, nhigh = %d, nalpha = %d, nbeta = %d\n", A, Z, nelec[A],
+                            nhigh[A], nalpha[A], nbeta[A]);
     }
 
-
     // Determine redundant atoms
-    std::vector<int> unique_indices(molecule_->natom(), 0); // All atoms to representative unique atom
-    std::vector<int> atomic_indices(molecule_->natom(), 0); // unique atom to first representative atom
-    std::vector<int> offset_indices(molecule_->natom(), 0); // unique atom index to rank
+    std::vector<int> unique_indices(molecule_->natom(), 0);  // All atoms to representative unique atom
+    std::vector<int> atomic_indices(molecule_->natom(), 0);  // unique atom to first representative atom
+    std::vector<int> offset_indices(molecule_->natom(), 0);  // unique atom index to rank
     int nunique = 0;
     for (int l = 0; l < molecule_->natom(); l++) {
         unique_indices[l] = l;
@@ -211,30 +211,18 @@ SharedMatrix SADGuess::form_D_AO()
     // This is all overkill for now, but lets leave it incase we do something oddball in the future
     for (int l = 0; l < molecule_->natom() - 1; l++) {
         for (int m = l + 1; m < molecule_->natom(); m++) {
-            if (unique_indices[m] != m)
-                continue; //Already assigned
-            if (molecule_->Z(l) != molecule_->Z(m))
-                continue;
-            if (nalpha[l] != nalpha[m])
-                continue;
-            if (nbeta[l] != nbeta[m])
-                continue;
-            if (nhigh[l] != nhigh[m])
-                continue;
-            if (nelec[l] != nelec[m])
-                continue;
-            if (atomic_bases_[l]->nbf() != atomic_bases_[m]->nbf())
-                continue;
-            if (atomic_bases_[l]->nshell() != atomic_bases_[m]->nshell())
-                continue;
-            if (atomic_bases_[l]->nprimitive() != atomic_bases_[m]->nprimitive())
-                continue;
-            if (atomic_bases_[l]->max_am() != atomic_bases_[m]->max_am())
-                continue;
-            if (atomic_bases_[l]->max_nprimitive() != atomic_bases_[m]->max_nprimitive())
-                continue;
-            if (atomic_bases_[l]->has_puream() !=  atomic_bases_[m]->has_puream())
-                continue;
+            if (unique_indices[m] != m) continue;  // Already assigned
+            if (molecule_->Z(l) != molecule_->Z(m)) continue;
+            if (nalpha[l] != nalpha[m]) continue;
+            if (nbeta[l] != nbeta[m]) continue;
+            if (nhigh[l] != nhigh[m]) continue;
+            if (nelec[l] != nelec[m]) continue;
+            if (atomic_bases_[l]->nbf() != atomic_bases_[m]->nbf()) continue;
+            if (atomic_bases_[l]->nshell() != atomic_bases_[m]->nshell()) continue;
+            if (atomic_bases_[l]->nprimitive() != atomic_bases_[m]->nprimitive()) continue;
+            if (atomic_bases_[l]->max_am() != atomic_bases_[m]->max_am()) continue;
+            if (atomic_bases_[l]->max_nprimitive() != atomic_bases_[m]->max_nprimitive()) continue;
+            if (atomic_bases_[l]->has_puream() != atomic_bases_[m]->has_puream()) continue;
 
             // Semi-Rigorous match obtained
             unique_indices[m] = l;
@@ -248,43 +236,38 @@ SharedMatrix SADGuess::form_D_AO()
         }
     }
 
-    //Atomic D matrices within the atom specific AO basis
+    // Atomic D matrices within the atom specific AO basis
     std::vector<SharedMatrix> atomic_D;
-    for (int A = 0; A<nunique; A++) {
+    for (int A = 0; A < nunique; A++) {
         int nbf = atomic_bases_[atomic_indices[A]]->nbf();
-        SharedMatrix dtmp(new Matrix("Atomic D", nbf, nbf));
+        auto dtmp = std::make_shared<Matrix>("Atomic D", nbf, nbf);
         atomic_D.push_back(dtmp);
     }
 
-    if (print_ > 1)
-        outfile->Printf("\n  Performing Atomic UHF Computations:\n");
-    for (int A = 0; A<nunique; A++) {
+    if (print_ > 1) outfile->Printf("\n  Performing Atomic UHF Computations:\n");
+    for (int A = 0; A < nunique; A++) {
         int index = atomic_indices[A];
-        if (print_ > 1)
-            outfile->Printf("\n  UHF Computation for Unique Atom %d which is Atom %d:",A, index);
-        if (options_.get_str("SAD_SCF_TYPE") == "DF"){
-            get_uhf_atomic_density(atomic_bases_[index], atomic_fit_bases_[index], nelec[index], nhigh[index], atomic_D[A]);
+        if (print_ > 1) outfile->Printf("\n  UHF Computation for Unique Atom %d which is Atom %d:", A, index);
+
+        if (options_.get_str("SAD_SCF_TYPE") == "DF") {
+            get_uhf_atomic_density(atomic_bases_[index], atomic_fit_bases_[index], nelec[index], nhigh[index],
+                                   atomic_D[A]);
         } else {
             std::shared_ptr<BasisSet> zbas = BasisSet::zero_ao_basis_set();
             get_uhf_atomic_density(atomic_bases_[index], zbas, nelec[index], nhigh[index], atomic_D[A]);
         }
-        if (print_ > 1)
-            outfile->Printf("Finished UHF Computation!\n");
+        if (print_ > 1) outfile->Printf("Finished UHF Computation!\n");
     }
-    if (print_)
-        outfile->Printf("\n");
+    if (print_) outfile->Printf("\n");
 
-
-
-    //Add atomic_D into D (scale by 1/2, we like effective pairs)
-    SharedMatrix DAO = SharedMatrix(new Matrix("D_SAD (AO)", basis_->nbf(), basis_->nbf()));
+    // Add atomic_D into D (scale by 1/2, we like effective pairs)
+    auto DAO = std::make_shared<Matrix>("D_SAD (AO)", basis_->nbf(), basis_->nbf());
     for (int A = 0, offset = 0; A < molecule_->natom(); A++) {
         int norbs = atomic_bases_[A]->nbf();
         int back_index = unique_indices[A];
-        for (int m = 0; m<norbs; m++)
-            for (int n = 0; n<norbs; n++)
-                DAO->set(0, m+offset, n+offset,
-                         0.5 * atomic_D[offset_indices[back_index]]->get(m,  n));
+        for (int m = 0; m < norbs; m++)
+            for (int n = 0; n < norbs; n++)
+                DAO->set(0, m + offset, n + offset, 0.5 * atomic_D[offset_indices[back_index]]->get(m, n));
         offset += norbs;
     }
 
@@ -294,11 +277,11 @@ SharedMatrix SADGuess::form_D_AO()
 
     return DAO;
 }
-void SADGuess::get_uhf_atomic_density(std::shared_ptr<BasisSet> bas, std::shared_ptr<BasisSet> fit, int nelec, int nhigh, SharedMatrix D)
-{
+void SADGuess::get_uhf_atomic_density(std::shared_ptr<BasisSet> bas, std::shared_ptr<BasisSet> fit, int nelec,
+                                      int nhigh, SharedMatrix D) {
     std::shared_ptr<Molecule> mol = bas->molecule();
     mol->update_geometry();
-    if (print_ > 1){
+    if (print_ > 1) {
         mol->print();
     }
 
@@ -313,7 +296,7 @@ void SADGuess::get_uhf_atomic_density(std::shared_ptr<BasisSet> bas, std::shared
     if (print_ > 1) {
         outfile->Printf("\n");
         bas->print("outfile");
-        outfile->Printf("  Occupation: nalpha = %d, nbeta = %d, norbs = %d\n",nalpha,nbeta,norbs);
+        outfile->Printf("  Occupation: nalpha = %d, nbeta = %d, norbs = %d\n", nalpha, nbeta, norbs);
         outfile->Printf("\n  Atom:\n");
         mol->print();
     }
@@ -324,10 +307,10 @@ void SADGuess::get_uhf_atomic_density(std::shared_ptr<BasisSet> bas, std::shared
 
     IntegralFactory integral(bas, bas, bas, bas);
     MatrixFactory mat;
-    mat.init_with(1,&norbs,&norbs);
-    OneBodyAOInt *S_ints = integral.ao_overlap();
-    OneBodyAOInt *T_ints = integral.ao_kinetic();
-    OneBodyAOInt *V_ints = integral.ao_potential();
+    mat.init_with(1, &norbs, &norbs);
+    OneBodyAOInt* S_ints = integral.ao_overlap();
+    OneBodyAOInt* T_ints = integral.ao_kinetic();
+    OneBodyAOInt* V_ints = integral.ao_potential();
 
     // Compute overlap S and orthogonalizer X;
     SharedMatrix S(mat.create_matrix("Overlap Matrix"));
@@ -342,7 +325,7 @@ void SADGuess::get_uhf_atomic_density(std::shared_ptr<BasisSet> bas, std::shared
         X->print();
     }
 
-    //Compute H
+    // Compute H
     SharedMatrix T(mat.create_matrix("T"));
     T_ints->compute(T);
     SharedMatrix V(mat.create_matrix("V"));
@@ -377,41 +360,33 @@ void SADGuess::get_uhf_atomic_density(std::shared_ptr<BasisSet> bas, std::shared
 
     // Factional occupation
     SharedVector occ_a, occ_b;
-    if (options_.get_double("SAD_FRAC_OCC")){
+    if (options_.get_bool("SAD_FRAC_OCC")) {
         int nfzc = 0, nact = 0;
-        if (Z <= 2){
+        if (Z <= 2) {
             nfzc = 0;
             nact = 1;
-        }
-        else if (Z <= 4){
+        } else if (Z <= 4) {
             nfzc = 1;
             nact = 1;
-        }
-        else if (Z <= 10){
+        } else if (Z <= 10) {
             nfzc = 2;
             nact = 3;
-        }
-        else if (Z <= 18){
+        } else if (Z <= 18) {
             nfzc = 5;
             nact = 4;
-        }
-        else if (Z <= 36){
+        } else if (Z <= 36) {
             nfzc = 9;
             nact = 9;
-        }
-        else if (Z <= 54){
+        } else if (Z <= 54) {
             nfzc = 18;
             nact = 9;
-        }
-        else if (Z <= 54){
+        } else if (Z <= 54) {
             nfzc = 18;
             nact = 9;
-        }
-        else if (Z <= 86){
+        } else if (Z <= 86) {
             nfzc = 27;
             nact = 16;
-        }
-        else{
+        } else {
             throw PSIEXCEPTION("SAD: Fractional occupations are not supported beyond Radon");
         }
 
@@ -419,25 +394,23 @@ void SADGuess::get_uhf_atomic_density(std::shared_ptr<BasisSet> bas, std::shared
         nbeta = nalpha;
         double frac_act = std::pow(((double)(Z - nfzc * 2)) / ((double)nact * 2), 0.5);
 
-        occ_a = std::shared_ptr<Vector>(new Vector("Alpha fractional occupation", nalpha));
-        for (size_t x = 0; x<nfzc; x++) occ_a->set(x, 1.0);
-        for (size_t x = nfzc; x<nalpha; x++) occ_a->set(x, frac_act);
+        occ_a = std::make_shared<Vector>("Alpha fractional occupation", nalpha);
+        for (size_t x = 0; x < nfzc; x++) occ_a->set(x, 1.0);
+        for (size_t x = nfzc; x < nalpha; x++) occ_a->set(x, frac_act);
         occ_b = std::shared_ptr<Vector>(occ_a->clone());
 
-    }
-    else{
-
+    } else {
         // Conventional occupations
-        occ_a = std::shared_ptr<Vector>(new Vector("Alpha occupation", nalpha));
-        for (size_t x = 0; x<nalpha; x++) occ_a->set(x, 1.0);
-        occ_b = std::shared_ptr<Vector>(new Vector("Beta occupation", nbeta));
-        for (size_t x = 0; x<nbeta; x++) occ_b->set(x, 1.0);
+        occ_a = std::make_shared<Vector>("Alpha occupation", nalpha);
+        for (size_t x = 0; x < nalpha; x++) occ_a->set(x, 1.0);
+        occ_b = std::make_shared<Vector>("Beta occupation", nbeta);
+        for (size_t x = 0; x < nbeta; x++) occ_b->set(x, 1.0);
     }
 
-    SharedMatrix Ca_occ(new Matrix("Ca occupied", norbs, nalpha));
-    SharedMatrix Cb_occ(new Matrix("Cb occupied", norbs, nbeta));
+    auto Ca_occ = std::make_shared<Matrix>("Ca occupied", norbs, nalpha);
+    auto Cb_occ = std::make_shared<Matrix>("Cb occupied", norbs, nbeta);
 
-    //Compute initial Cx, Dx, and D from core guess
+    // Compute initial Cx, Dx, and D from core guess
     form_C_and_D(nalpha, norbs, X, H, Ca, Ca_occ, occ_a, Da);
     form_C_and_D(nbeta, norbs, X, H, Cb, Cb_occ, occ_b, Db);
 
@@ -455,7 +428,7 @@ void SADGuess::get_uhf_atomic_density(std::shared_ptr<BasisSet> bas, std::shared
         D->print();
     }
 
-    //Compute inital E for reference
+    // Compute inital E for reference
     double E = D->vector_dot(H);
     E *= 0.5;
 
@@ -475,49 +448,44 @@ void SADGuess::get_uhf_atomic_density(std::shared_ptr<BasisSet> bas, std::shared
     std::unique_ptr<JK> jk;
 
     // Need a very special auxiliary basis here
-    if (options_.get_str("SAD_SCF_TYPE") == "DF"){
-
-        DFJK* dfjk = new DFJK(bas, fit);
-        dfjk->set_unit(PSIF_SAD);
+    if (options_.get_str("SAD_SCF_TYPE") == "DF") {
+        MemDFJK* dfjk = new MemDFJK(bas, fit);
         if (options_["DF_INTS_NUM_THREADS"].has_changed())
             dfjk->set_df_ints_num_threads(options_.get_int("DF_INTS_NUM_THREADS"));
+        dfjk->dfh()->set_print_lvl(0);
         jk = std::unique_ptr<JK>(dfjk);
-    }
-    else if (options_.get_str("SAD_SCF_TYPE") == "DIRECT"){
+    } else if (options_.get_str("SAD_SCF_TYPE") == "DIRECT") {
         DirectJK* directjk(new DirectJK(bas));
         if (options_["DF_INTS_NUM_THREADS"].has_changed())
             directjk->set_df_ints_num_threads(options_.get_int("DF_INTS_NUM_THREADS"));
         jk = std::unique_ptr<JK>(directjk);
-    }
-    else {
+    } else {
         std::stringstream msg;
         msg << "SAD: JK type of " << options_.get_str("SAD_SCF_TYPE") << " not understood.\n";
         throw PSIEXCEPTION(msg.str());
     }
 
-    jk->set_memory((ULI)(0.5 * (Process::environment.get_memory() / 8L)));
+    jk->set_memory((size_t)(0.5 * (Process::environment.get_memory() / 8L)));
     jk->initialize();
-    if (print_ > 1)
-        jk->print_header();
+    if (print_ > 1) jk->print_header();
 
     // These are static so lets just grab them now
-    std::vector<SharedMatrix> & jkC = jk->C_left();
+    std::vector<SharedMatrix>& jkC = jk->C_left();
     jkC.push_back(Ca_occ);
     jkC.push_back(Cb_occ);
-    const std::vector<SharedMatrix> & Jvec = jk->J();
-    const std::vector<SharedMatrix> & Kvec = jk->K();
+    const std::vector<SharedMatrix>& Jvec = jk->J();
+    const std::vector<SharedMatrix>& Kvec = jk->K();
 
     // Print a header
     bool converged = false;
     if (print_ > 1) {
-        outfile->Printf( "\n  Initial Atomic UHF Energy:    %14.10f\n\n",E);
-        outfile->Printf( "                                         Total Energy            Delta E              Density RMS\n\n");
-
+        outfile->Printf("\n  Initial Atomic UHF Energy:    %14.10f\n\n", E);
+        outfile->Printf(
+            "                                         Total Energy            Delta E              Density RMS\n\n");
     }
 
     // Run the iterations
     do {
-
         iteration++;
 
         // Copy the old values over for error analysis
@@ -537,12 +505,12 @@ void SADGuess::get_uhf_atomic_density(std::shared_ptr<BasisSet> bas, std::shared
         Fb->subtract(Kvec[1]);
 
         // Compute E
-        E  = H->vector_dot(D);
+        E = H->vector_dot(D);
         E += Da->vector_dot(Fa);
         E += Db->vector_dot(Fb);
         E *= 0.5;
 
-        double deltaE = fabs(E-E_old);
+        double deltaE = std::fabs(E - E_old);
 
         // Build Gradient
         form_gradient(norbs, gradient_a, Fa, Da, S, X);
@@ -553,11 +521,11 @@ void SADGuess::get_uhf_atomic_density(std::shared_ptr<BasisSet> bas, std::shared
         diis_manager.add_entry(4, gradient_a.get(), gradient_b.get(), Fa.get(), Fb.get());
         diis_manager.extrapolate(2, Fa.get(), Fb.get());
 
-        //Diagonalize Fa and Fb to from Ca and Cb and Da and Db
+        // Diagonalize Fa and Fb to from Ca and Cb and Da and Db
         form_C_and_D(nalpha, norbs, X, Fa, Ca, Ca_occ, occ_a, Da);
         form_C_and_D(nbeta, norbs, X, Fb, Cb, Cb_occ, occ_b, Db);
 
-        //Form D
+        // Form D
         D->copy(Da);
         D->add(Db);
 
@@ -572,28 +540,27 @@ void SADGuess::get_uhf_atomic_density(std::shared_ptr<BasisSet> bas, std::shared
             D->print();
         }
         if (print_ > 1)
-            outfile->Printf( "  @Atomic UHF iteration %3d energy: %20.14f    %20.14f %20.14f\n", iteration, E, E-E_old, Drms);
+            outfile->Printf("  @Atomic UHF iteration %3d energy: %20.14f    %20.14f %20.14f\n", iteration, E, E - E_old,
+                            Drms);
 
-        //Check convergence
-        if (iteration > 1 && deltaE < E_tol && Drms < D_tol)
-            converged = true;
+        // Check convergence
+        if (iteration > 1 && deltaE < E_tol && Drms < D_tol) converged = true;
 
         if (iteration > maxiter) {
-            outfile->Printf( "\n WARNING: Atomic UHF is not converging! Try casting from a smaller basis or call Rob at CCMST.\n");
+            outfile->Printf(
+                "\n WARNING: Atomic UHF is not converging! Try casting from a smaller basis or call Rob at CCMST.\n");
             break;
         }
 
     } while (!converged);
 
     if (converged && print_ > 1)
-        outfile->Printf( "  @Atomic UHF Final Energy for atom %s: %20.14f\n", mol->symbol(0).c_str(),E);
-
+        outfile->Printf("  @Atomic UHF Final Energy for atom %s: %20.14f\n", mol->symbol(0).c_str(), E);
 }
-void SADGuess::form_gradient(int norbs, SharedMatrix grad, SharedMatrix F, SharedMatrix D,
-                             SharedMatrix S, SharedMatrix X)
-{
-    SharedMatrix Scratch1(new Matrix("Scratch1", norbs, norbs));
-    SharedMatrix Scratch2(new Matrix("Scratch2", norbs, norbs));
+void SADGuess::form_gradient(int norbs, SharedMatrix grad, SharedMatrix F, SharedMatrix D, SharedMatrix S,
+                             SharedMatrix X) {
+    auto Scratch1 = std::make_shared<Matrix>("Scratch1", norbs, norbs);
+    auto Scratch2 = std::make_shared<Matrix>("Scratch2", norbs, norbs);
 
     // FDS
     Scratch1->gemm(false, false, 1.0, F, D, 0.0);
@@ -615,56 +582,51 @@ void SADGuess::form_gradient(int norbs, SharedMatrix grad, SharedMatrix F, Share
     Scratch2.reset();
 }
 
-
-void SADGuess::form_C_and_D(int nocc, int norbs, SharedMatrix X, SharedMatrix F,
-                                        SharedMatrix C, SharedMatrix Cocc, SharedVector occ,
-                                        SharedMatrix D)
-{
+void SADGuess::form_C_and_D(int nocc, int norbs, SharedMatrix X, SharedMatrix F, SharedMatrix C, SharedMatrix Cocc,
+                            SharedVector occ, SharedMatrix D) {
     if (nocc == 0) return;
 
-    //Forms C in the AO basis for SAD Guesses
-    SharedMatrix Scratch1(new Matrix("Scratch1", norbs, norbs));
-    SharedMatrix Scratch2(new Matrix("Scratch2", norbs, norbs));
+    // Forms C in the AO basis for SAD Guesses
+    auto Scratch1 = std::make_shared<Matrix>("Scratch1", norbs, norbs);
+    auto Scratch2 = std::make_shared<Matrix>("Scratch2", norbs, norbs);
 
     // Form Fp = XFX
     Scratch1->gemm(true, false, 1.0, X, F, 0.0);
     Scratch2->gemm(false, false, 1.0, Scratch1, X, 0.0);
 
-    SharedVector eigvals(new Vector("Eigenvalue scratch", norbs));
+    auto eigvals = std::make_shared<Vector>("Eigenvalue scratch", norbs);
     Scratch2->diagonalize(Scratch1, eigvals);
 
-    //Form C = XC'
+    // Form C = XC'
     C->gemm(false, false, 1.0, X, Scratch1, 0.0);
 
     // Copy over Cocc
     double** Coccp = Cocc->pointer();
     double** Cp = C->pointer();
-    for (int i = 0; i < norbs; i++){
+    for (int i = 0; i < norbs; i++) {
         C_DCOPY(nocc, Cp[i], 1, Coccp[i], 1);
     }
     // Scale by occ
-    for (int i = 0; i < nocc; i++){
+    for (int i = 0; i < nocc; i++) {
         C_DSCAL(norbs, occ->get(i), &Cp[0][i], nocc);
     }
-    //Form D = Cocc*Cocc'
+    // Form D = Cocc*Cocc'
     D->gemm(false, true, 1.0, Cocc, Cocc, 0.0);
 
     Scratch1.reset();
     Scratch2.reset();
 }
 
-void HF::compute_SAD_guess()
-{
-
-    if (sad_basissets_.empty()){
+void HF::compute_SAD_guess() {
+    if (sad_basissets_.empty()) {
         throw PSIEXCEPTION("  SCF guess was set to SAD, but sad_basissets_ was empty!\n\n");
     }
-    if ((options_.get_str("SAD_SCF_TYPE") == "DF") && sad_fitting_basissets_.empty()){
-        throw PSIEXCEPTION("  SCF guess was set to SAD with DFJK, but sad_fitting_basissets_ was empty!\n\n");
+    if ((options_.get_str("SAD_SCF_TYPE") == "DF") && sad_fitting_basissets_.empty()) {
+        throw PSIEXCEPTION("  SCF guess was set to SAD with DiskDFJK, but sad_fitting_basissets_ was empty!\n\n");
     }
 
-    std::shared_ptr<SADGuess> guess(new SADGuess(basisset_, sad_basissets_, nalpha_, nbeta_, options_));
-    if (options_.get_str("SAD_SCF_TYPE") == "DF"){
+    auto guess = std::make_shared<SADGuess>(basisset_, sad_basissets_, nalpha_, nbeta_, options_);
+    if (options_.get_str("SAD_SCF_TYPE") == "DF") {
         guess->set_atomic_fit_bases(sad_fitting_basissets_);
     }
 
@@ -677,11 +639,9 @@ void HF::compute_SAD_guess()
     Dimension sad_dim(Da_->nirrep(), "SAD Dimensions");
 
     for (int h = 0; h < Da_->nirrep(); h++) {
-
         int nso = Ca_sad->rowspi()[h];
         int nmo = Ca_sad->colspi()[h];
-        if (nmo > X_->colspi()[h])
-            nmo = X_->colspi()[h];
+        if (nmo > X_->colspi()[h]) nmo = X_->colspi()[h];
 
         sad_dim[h] = nmo;
 
@@ -693,8 +653,8 @@ void HF::compute_SAD_guess()
         double** Cb2p = Cb_sad->pointer(h);
 
         for (int i = 0; i < nso; i++) {
-            ::memcpy((void*) Cap[i], (void*) Ca2p[i], nmo*sizeof(double));
-            ::memcpy((void*) Cbp[i], (void*) Cb2p[i], nmo*sizeof(double));
+            ::memcpy((void*)Cap[i], (void*)Ca2p[i], nmo * sizeof(double));
+            ::memcpy((void*)Cbp[i], (void*)Cb2p[i], nmo * sizeof(double));
         }
     }
 
@@ -705,7 +665,7 @@ void HF::compute_SAD_guess()
     doccpi_ = sad_dim;
     soccpi_ = Dimension(Da_->nirrep(), "SAD SOCC dim (0's)");
 
-    E_ = 0.0; // This is the -1th iteration
+    E_ = 0.0;  // This is the -1th iteration
+}
+}
 }
-
-}}
