@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -39,6 +39,11 @@
 #include "psi4/libpsio/psio.hpp"
 #include "psi4/libiwl/iwl.hpp"
 #include "psi4/libqt/qt.h"
+#include "psi4/libpsi4util/PsiOutStream.h"
+#include "psi4/libpsi4util/process.h"
+#include "psi4/liboptions/liboptions.h"
+#include "psi4/libdiis/diismanager.h"
+#include "psi4/libdiis/diisentry.h"
 
 #include "psi4/libpsi4util/libpsi4util.h"
 #include "psi4/libfock/v.h"
@@ -50,6 +55,9 @@
 #include "stability.h"
 #include "psi4/libmints/matrix.h"
 #include "psi4/libmints/factory.h"
+#include "psi4/libmints/molecule.h"
+#include "psi4/libmints/basisset.h"
+#include "psi4/libmints/vector.h"
 
 namespace psi { namespace scf {
 
@@ -87,10 +95,12 @@ void UHF::common_init()
     Db_old_ = SharedMatrix(factory_->create_matrix("Old beta SCF density"));
     Dt_old_ = SharedMatrix(factory_->create_matrix("D total old"));
     Lagrangian_ = SharedMatrix(factory_->create_matrix("Lagrangian"));
-    Ca_     = SharedMatrix(factory_->create_matrix("C alpha"));
-    Cb_     = SharedMatrix(factory_->create_matrix("C beta"));
+    Ca_     = SharedMatrix(factory_->create_matrix("alpha MO coefficients (C)"));
+    Cb_     = SharedMatrix(factory_->create_matrix("beta MO coefficients (C)"));
     Ga_     = SharedMatrix(factory_->create_matrix("G alpha"));
     Gb_     = SharedMatrix(factory_->create_matrix("G beta"));
+    Va_     = SharedMatrix(factory_->create_matrix("V alpha"));
+    Vb_     = SharedMatrix(factory_->create_matrix("V beta"));
     J_      = SharedMatrix(factory_->create_matrix("J total"));
     Ka_     = SharedMatrix(factory_->create_matrix("K alpha"));
     Kb_     = SharedMatrix(factory_->create_matrix("K beta"));
@@ -98,7 +108,9 @@ void UHF::common_init()
     wKb_    = SharedMatrix(factory_->create_matrix("wK beta"));
 
     epsilon_a_ = SharedVector(factory_->create_vector());
+    epsilon_a_->set_name("alpha orbital energies");
     epsilon_b_ = SharedVector(factory_->create_vector());
+    epsilon_b_->set_name("beta orbital energies");
 
     same_a_b_dens_ = false;
     same_a_b_orbs_ = false;
@@ -144,19 +156,23 @@ void UHF::save_density_and_energy()
 }
 void UHF::form_V()
 {
-    // Push the C matrix on
-    std::vector<SharedMatrix> & C = potential_->C();
-    C.clear();
-    C.push_back(Ca_subset("SO", "OCC"));
-    C.push_back(Cb_subset("SO", "OCC"));
+    // // Push the C matrix on
+    // std::vector<SharedMatrix> & C = potential_->C();
+    // C.clear();
+    // C.push_back(Ca_subset("SO", "OCC"));
+    // C.push_back(Cb_subset("SO", "OCC"));
 
-    // Run the potential object
-    potential_->compute();
+    // // Run the potential object
+    // potential_->compute();
+
+    // // Pull the V matrices off
+    // const std::vector<SharedMatrix> & V = potential_->V();
+    // Va_ = V[0];
+    // Vb_ = V[1];
+    potential_->set_D({Da_, Db_});
+    potential_->compute_V({Va_, Vb_});
+    // Vb_ = Va_;
 
-    // Pull the V matrices off
-    const std::vector<SharedMatrix> & V = potential_->V();
-    Va_ = V[0];
-    Vb_ = V[1];
 }
 void UHF::form_G()
 {
@@ -198,7 +214,7 @@ void UHF::form_G()
     Gb_->add(J_);
 
     double alpha = functional_->x_alpha();
-    double beta = 1.0 - alpha;
+    double beta = functional_->x_beta();
 
     if (alpha != 0.0) {
         Ga_->axpy(-alpha, Ka_);
@@ -228,7 +244,7 @@ bool UHF::test_convergency()
     double ediff = E_ - Eold_;
 
     // Drms was computed earlier
-    if (fabs(ediff) < energy_threshold_ && Drms_ < density_threshold_)
+    if (std::fabs(ediff) < energy_threshold_ && Drms_ < density_threshold_)
         return true;
     else
         return false;
@@ -315,6 +331,15 @@ void UHF::form_D()
         Db_->print();
     }
 }
+void UHF::damp_update()
+{
+    Da_->scale(1.0 - damping_percentage_);
+    Da_->axpy(damping_percentage_, Da_old_);
+    Db_->scale(1.0 - damping_percentage_);
+    Db_->axpy(damping_percentage_, Db_old_);
+    Dt_->copy(Da_);
+    Dt_->add(Db_);
+}
 
 // TODO: Once Dt_ is refactored to D_ the only difference between this and RHF::compute_initial_E is a factor of 0.5
 double UHF::compute_initial_E()
@@ -333,13 +358,17 @@ double UHF::compute_E()
     coulomb_E += Db_->vector_dot(J_);
 
     double XC_E = 0.0;
+    double VV10_E = 0.0;
     if (functional_->needs_xc()) {
         XC_E = potential_->quadrature_values()["FUNCTIONAL"];
     }
+    if (functional_->needs_vv10()){
+        VV10_E = potential_->quadrature_values()["VV10"];
+    }
 
     double exchange_E = 0.0;
     double alpha = functional_->x_alpha();
-    double beta = 1.0 - alpha;
+    double beta = functional_->x_beta();
     if (functional_->is_x_hybrid()) {
         exchange_E -= alpha * Da_->vector_dot(Ka_);
         exchange_E -= alpha * Db_->vector_dot(Kb_);
@@ -353,6 +382,7 @@ double UHF::compute_E()
     energies_["One-Electron"] = one_electron_E;
     energies_["Two-Electron"] = 0.5 * (coulomb_E + exchange_E);
     energies_["XC"] = XC_E;
+    energies_["VV10"] = VV10_E;
     energies_["-D"] = variables_["-D Energy"];
     double dashD_E = energies_["-D"];
 
@@ -362,303 +392,484 @@ double UHF::compute_E()
     Etotal += 0.5 * coulomb_E;
     Etotal += 0.5 * exchange_E;
     Etotal += XC_E;
+    Etotal += VV10_E;
     Etotal += dashD_E;
 
     return Etotal;
 }
-void UHF::Hx(SharedMatrix x_a, SharedMatrix IFock_a, SharedMatrix Cocc_a,
-             SharedMatrix Cvir_a, SharedMatrix ret_a,
-             SharedMatrix x_b, SharedMatrix IFock_b, SharedMatrix Cocc_b,
-             SharedMatrix Cvir_b, SharedMatrix ret_b)
-{
-    if (functional_->needs_xc()){
-        throw PSIEXCEPTION("SCF: Cannot yet compute DFT Hessian-vector products.\n");
+std::vector<SharedMatrix> UHF::onel_Hx(std::vector<SharedMatrix> x_vec) {
+    if ((x_vec.size() % 2) != 0){
+        throw PSIEXCEPTION("UHF::onel_Hx expect incoming vector to alternate A/B");
     }
 
-    // => Effective one electron part <= //
-    Dimension virpi_a = Cvir_a->colspi();
-    Dimension virpi_b = Cvir_b->colspi();
-    for (size_t h=0; h<nirrep_; h++){
+    // Compute Fij x_ia - Fab x_ia
+
+    SharedMatrix Ca_occ = Ca_subset("SO", "OCC");
+    SharedMatrix Ca_vir = Ca_subset("SO", "VIR");
+    SharedMatrix Cb_occ = Cb_subset("SO", "OCC");
+    SharedMatrix Cb_vir = Cb_subset("SO", "VIR");
+
+    std::vector<SharedMatrix> ret;
+    for (size_t i = 0; i < x_vec.size() / 2; i++) {
+        if ((x_vec[2 * i]->rowspi() != Ca_occ->colspi()) || (x_vec[2 * i]->colspi() != Ca_vir->colspi())){
+            throw PSIEXCEPTION(
+                "SCF::onel_Hx incoming rotation matrices must have shape (occ x vir).");
+        }
+
+        if ((x_vec[2 * i + 1]->rowspi() != Cb_occ->colspi()) || (x_vec[2 * i + 1]->colspi() != Cb_vir->colspi())){
+            throw PSIEXCEPTION(
+                "SCF::onel_Hx incoming rotation matrices must have shape (occ x vir).");
+        }
+
         // Alpha
-        if (nalphapi_[h] && virpi_a[h]){
-            double** IFp = IFock_a->pointer(h);
-            double** retp = ret_a->pointer(h);
-            double** xp = x_a->pointer(h);
+        SharedMatrix tmp1 = Matrix::triplet(Ca_occ, Fa_, Ca_occ, true, false, false);
+        SharedMatrix result = Matrix::doublet(tmp1, x_vec[2 * i], false, false);
 
-            // ret_ia = F_ij X_ja
-            C_DGEMM('N','N',nalphapi_[h],virpi_a[h],nalphapi_[h],1.0,
-                    IFp[0],nmopi_[h],
-                    xp[0],virpi_a[h],0.0,retp[0],virpi_a[h]);
+        SharedMatrix tmp2 = Matrix::triplet(x_vec[2 * i], Ca_vir, Fa_, false, true, false);
+        result->gemm(false, false, -1.0, tmp2, Ca_vir, 1.0);
 
-            // ret_ia -= X_ib F_ba
-            C_DGEMM('N','N',nalphapi_[h],virpi_a[h],virpi_a[h],-1.0,
-                    xp[0],virpi_a[h],
-                    (IFp[nalphapi_[h]]+nalphapi_[h]),nmopi_[h],1.0,retp[0],virpi_a[h]);
+        ret.push_back(result);
 
-        }
         // Beta
-        if (nbetapi_[h] && virpi_b[h]){
-            double** IFp = IFock_b->pointer(h);
-            double** retp = ret_b->pointer(h);
-            double** xp = x_b->pointer(h);
+        tmp1 = Matrix::triplet(Cb_occ, Fb_, Cb_occ, true, false, false);
+        result = Matrix::doublet(tmp1, x_vec[2 * i + 1], false, false);
 
-            // ret_ia = F_ij X_ja
-            C_DGEMM('N','N',nbetapi_[h],virpi_b[h],nbetapi_[h],1.0,
-                    IFp[0],nmopi_[h],
-                    xp[0],virpi_b[h],0.0,retp[0],virpi_b[h]);
+        tmp2 = Matrix::triplet(x_vec[2 * i + 1], Cb_vir, Fb_, false, true, false);
+        result->gemm(false, false, -1.0, tmp2, Cb_vir, 1.0);
 
-            // ret_ia -= X_ib F_ba
-            C_DGEMM('N','N',nbetapi_[h],virpi_b[h],virpi_b[h],-1.0,
-                    xp[0],virpi_b[h],
-                    (IFp[nbetapi_[h]]+nbetapi_[h]),nmopi_[h],1.0,retp[0],virpi_b[h]);
+        ret.push_back(result);
 
-        }
     }
 
-    // => Two electron part <= //
+    return ret;
+}
+std::vector<SharedMatrix> UHF::twoel_Hx(std::vector<SharedMatrix> x_vec, bool combine, std::string return_basis) {
+    if ((x_vec.size() % 2) != 0){
+        throw PSIEXCEPTION("UHF::onel_Hx expect incoming vector to alternate A/B");
+    }
+
+    // Compute Fij x_ia - Fab x_ia
+
+    SharedMatrix Ca_occ = Ca_subset("SO", "OCC");
+    SharedMatrix Ca_vir = Ca_subset("SO", "VIR");
+    SharedMatrix Cb_occ = Cb_subset("SO", "OCC");
+    SharedMatrix Cb_vir = Cb_subset("SO", "VIR");
+
+    // Setup jk
     std::vector<SharedMatrix>& Cl = jk_->C_left();
     std::vector<SharedMatrix>& Cr = jk_->C_right();
     Cl.clear();
     Cr.clear();
 
-    Cl.push_back(Cocc_a);
-    Cl.push_back(Cocc_b);
+    int nvecs = x_vec.size() / 2;
 
-    SharedMatrix R_a = Matrix::doublet(Cvir_a, x_a, false, true);
-    SharedMatrix R_b = Matrix::doublet(Cvir_b, x_b, false, true);
-    R_a->scale(-1.0);
-    R_b->scale(-1.0);
-    Cr.push_back(R_a);
-    Cr.push_back(R_b);
+    // We actually want to compute all alpha then all beta, its smart enough to figure out the half transform
+    for (size_t i = 0; i < nvecs; i++) {
+        if ((x_vec[2 * i]->rowspi() != Ca_occ->colspi()) || (x_vec[2 * i]->colspi() != Ca_vir->colspi())){
+            throw PSIEXCEPTION(
+                "SCF::onel_Hx incoming rotation matrices must have shape (occ x vir).");
+        }
 
+        Cl.push_back(Ca_occ);
+
+        SharedMatrix R = Matrix::doublet(Ca_vir, x_vec[2 * i], false, true);
+        R->scale(-1.0);
+        Cr.push_back(R);
+
+    }
+    for (size_t i = 0; i < nvecs; i++) {
+
+        if ((x_vec[2 * i + 1]->rowspi() != Cb_occ->colspi()) || (x_vec[2 * i + 1]->colspi() != Cb_vir->colspi())){
+            throw PSIEXCEPTION(
+                "SCF::onel_Hx incoming rotation matrices must have shape (occ x vir).");
+        }
+        Cl.push_back(Cb_occ);
+
+        SharedMatrix R = Matrix::doublet(Cb_vir, x_vec[2 * i + 1], false, true);
+        R->scale(-1.0);
+        Cr.push_back(R);
+    }
+
+    // Compute JK
     jk_->compute();
 
-    // Just in case someone only clears out Cleft and gets very strange errors
-    Cl.clear();
-    Cr.clear();
-
     const std::vector<SharedMatrix>& J = jk_->J();
     const std::vector<SharedMatrix>& K = jk_->K();
+    const std::vector<SharedMatrix>& wK = jk_->wK();
 
-    // D_nm = Cocc_ni x_ia Cvir_ma
-    // Cocc_ni (4 * J[D]_nm - K[D]_nm - K[D]_mn) C_vir_ma
-    J[0]->add(J[1]);
-    J[0]->scale(2.0);
-    J[1]->copy(J[0]);
+    std::vector<SharedMatrix> Vx;
+    if (functional_->needs_xc()){
+        std::vector<SharedMatrix> Dx;
+        // Gotta reorder the wizardry
+        for (size_t i = 0; i < nvecs; i++) {
+            Dx.push_back(Matrix::doublet(Cl[i], Cr[i], false, true));
+            Vx.push_back(std::make_shared<Matrix>("Vax Temp", Dx[i]->rowspi(), Dx[i]->colspi()));
 
-    J[0]->subtract(K[0]);
-    J[0]->subtract(K[0]->transpose());
-    R_a->gemm(false, false, 1.0, J[0], Cocc_a, 0.0);
-    ret_a->gemm(true, false, 1.0, R_a, Cvir_a, 1.0);
-    ret_a->scale(-4.0);
+            Dx.push_back(Matrix::doublet(Cl[nvecs + i], Cr[nvecs + i], false, true));
+            Vx.push_back(std::make_shared<Matrix>("Vbx Temp", Dx[nvecs + i]->rowspi(), Dx[nvecs +i]->colspi()));
+        }
+        potential_->compute_Vx(Dx, Vx);
+    }
 
-    J[1]->subtract(K[1]);
-    J[1]->subtract(K[1]->transpose());
-    R_b->gemm(false, false, 1.0, J[1], Cocc_b, 0.0);
-    ret_b->gemm(true, false, 1.0, R_b, Cvir_b, 1.0);
-    ret_b->scale(-4.0);
+    Cl.clear();
+    Cr.clear();
 
-    // Cleaup
-    R_a.reset();
-    R_b.reset();
+    // Build return vector
+    double alpha = functional_->x_alpha();
+    double beta = functional_->x_beta();
+    std::vector<SharedMatrix> ret;
+    if (combine){
+        for (size_t i = 0; i < nvecs; i++){
+            J[i]->scale(2.0);
+            J[i]->axpy(2.0, J[nvecs + i]);
+            J[nvecs + i]->copy(J[i]);
+            if (functional_->needs_xc()){
+                J[i]->axpy(2.0, Vx[2 * i]);
+                J[nvecs + i]->axpy(2.0, Vx[2 * i + 1]);
+            }
+            if (functional_->is_x_hybrid()) {
+                J[i]->axpy(-alpha, K[i]);
+                J[i]->axpy(-alpha, K[i]->transpose());
 
+                J[nvecs + i]->axpy(-alpha, K[nvecs + i]);
+                J[nvecs + i]->axpy(-alpha, K[nvecs + i]->transpose());
+            }
+            if (functional_->is_x_lrc()) {
+                J[i]->axpy(-beta, wK[i]);
+                J[i]->axpy(-beta, wK[i]->transpose());
+
+                J[nvecs + i]->axpy(-beta, wK[nvecs + i]);
+                J[nvecs + i]->axpy(-beta, wK[nvecs + i]->transpose());
+            }
+            ret.push_back(J[i]);
+            ret.push_back(J[nvecs + i]);
+        }
+    } else{
+        for (size_t i = 0; i < nvecs; i++){
+            ret.push_back(J[i]);
+            ret.push_back(J[nvecs + i]);
+            if (functional_->is_x_hybrid()) {
+                K[i]->scale(alpha);
+                ret.push_back(K[i]);
+
+                K[nvecs + i]->scale(alpha);
+                ret.push_back(K[nvecs + i]);
+                if (functional_->is_x_lrc()) {
+                    K[i]->axpy(beta, wK[i]);
+                    K[nvecs + i]->axpy(beta, wK[nvecs + i]);
+                }
+            }
+            if (functional_->needs_xc()){
+                ret.push_back(Vx[i]);
+            }
+       }
+    }
+
+    // Transform if needed
+    if (return_basis == "SO"){
+        /* pass */
+    } else if (return_basis == "MO"){
+        for (size_t i = 0; i < nvecs; i++){
+            ret[2 * i] = Matrix::triplet(Ca_occ, ret[2 * i], Ca_vir, true, false, false);
+            ret[2 * i + 1] = Matrix::triplet(Cb_occ, ret[2 * i + 1], Cb_vir, true, false, false);
+       }
+    } else{
+        throw PSIEXCEPTION("SCF::twoel_Hx: return_basis option not understood.");
+    }
+
+    return ret;
 }
-void UHF::damp_update()
-{
-  Da_->scale(1.0 - damping_percentage_);
-  Da_->axpy(damping_percentage_, Da_old_);
-  Db_->scale(1.0 - damping_percentage_);
-  Db_->axpy(damping_percentage_, Db_old_);
-  Dt_->copy(Da_);
-  Dt_->add(Db_);
+std::vector<SharedMatrix> UHF::cphf_Hx(std::vector<SharedMatrix> x_vec) {
+
+    // Compute quantities
+    std::vector<SharedMatrix> onel = onel_Hx(x_vec);
+    std::vector<SharedMatrix> twoel = twoel_Hx(x_vec, true, "MO");
+
+    for (size_t i = 0; i < onel.size(); i++){
+        onel[i]->add(twoel[i]);
+    }
+
+    return onel;
+}
+std::vector<SharedMatrix> UHF::cphf_solve(std::vector<SharedMatrix> x_vec, double conv_tol,
+                                          int max_iter, int print_lvl) {
+    if ((x_vec.size() % 2) != 0){
+        throw PSIEXCEPTION("UHF::onel_Hx expect incoming vector to alternate A/B");
+    }
+
+    time_t start, stop;
+    start = time(nullptr);
+    cphf_converged_ = false;
+    cphf_nfock_builds_ = 0;
+
+    // => Build preconditioner <= //
+
+    // Grab occ and vir orbitals
+    Dimension virpi_a = nmopi_ - nalphapi_;
+    Dimension virpi_b = nmopi_ - nbetapi_;
+
+    // MO Fock Matrix (Inactive Fock in Helgaker's language)
+    SharedMatrix IFock_a = Matrix::triplet(Ca_, Fa_, Ca_, true, false, false);
+    SharedMatrix IFock_b = Matrix::triplet(Cb_, Fb_, Cb_, true, false, false);
+
+    auto Precon_a = std::make_shared<Matrix>("Alpha Precon", nirrep_, nalphapi_, virpi_a);
+    auto Precon_b = std::make_shared<Matrix>("Beta Precon", nirrep_, nbetapi_, virpi_b);
+
+    for (size_t h = 0; h < nirrep_; h++) {
+        if (virpi_a[h] && nalphapi_[h]){
+            double* denom_ap = Precon_a->pointer(h)[0];
+            double** f_ap = IFock_a->pointer(h);
+            for (size_t i = 0, target = 0; i < nalphapi_[h]; i++) {
+                for (size_t a = nalphapi_[h]; a < nmopi_[h]; a++) {
+                    denom_ap[target++] = -f_ap[i][i] + f_ap[a][a];
+                }
+            }
+        }
+
+        if (virpi_b[h] && nbetapi_[h]){
+            double* denom_bp = Precon_b->pointer(h)[0];
+            double** f_bp = IFock_b->pointer(h);
+            for (size_t i = 0, target = 0; i < nbetapi_[h]; i++) {
+                for (size_t a = nbetapi_[h]; a < nmopi_[h]; a++) {
+                    denom_bp[target++] = -f_bp[i][i] + f_bp[a][a];
+                }
+            }
+        }
+    }
+
+    // => Header <= //
+    if (print_lvl) {
+        outfile->Printf("\n");
+        outfile->Printf("   ==> Coupled-Perturbed %s Solver <==\n\n",
+                        options_.get_str("REFERENCE").c_str());
+        outfile->Printf("    Maxiter             = %11d\n", max_iter);
+        outfile->Printf("    Convergence         = %11.3E\n", conv_tol);
+        outfile->Printf("    Number of equations = %11ld\n", x_vec.size());
+        outfile->Printf("   -----------------------------------------------------\n");
+        outfile->Printf("     %4s %14s %12s  %6s  %6s\n", "Iter", "Residual RMS", "Max RMS",
+                        "Remain", "Time [s]");
+        outfile->Printf("   -----------------------------------------------------\n");
+    }
+
+    // => Initial state <= //
+
+    // What vectors do we need?
+    int nvecs = x_vec.size() / 2;
+    int nvecs_ab = x_vec.size();
+    std::vector<SharedMatrix> ret_vec, r_vec, z_vec, p_vec;
+    std::vector<double> resid(nvecs), resid_denom(nvecs), rms(nvecs), rzpre(nvecs);
+    std::vector<bool> active(nvecs);
+    std::vector<int> active_map(nvecs);
+
+    // => Initial CG guess <= //
+    for (size_t i = 0; i < nvecs; i++) {
+        ret_vec.push_back(x_vec[2 * i]->clone());
+        ret_vec.push_back(x_vec[2 * i + 1]->clone());
+
+        ret_vec[2 * i]->apply_denominator(Precon_a);
+        ret_vec[2 * i + 1]->apply_denominator(Precon_b);
+
+        r_vec.push_back(x_vec[2 * i]->clone());
+        r_vec.push_back(x_vec[2 * i + 1]->clone());
+    }
+
+    // Calc hessian vector product, find residual and conditioned residual
+    std::vector<SharedMatrix> Ax_vec = cphf_Hx(ret_vec);
+
+    double max_rms = 0.0;
+    double mean_rms = 0.0;
+    int nremain = 0;
+    for (size_t i = 0; i < nvecs; i++) {
+        r_vec[2 * i]->subtract(Ax_vec[2 * i]);
+        r_vec[2 * i + 1]->subtract(Ax_vec[2 * i + 1]);
+
+        resid[i] = r_vec[2 * i]->sum_of_squares();
+        resid[i] += r_vec[2 * i + 1]->sum_of_squares();
+
+        resid_denom[i] = x_vec[2 * i]->sum_of_squares();
+        resid_denom[i] += x_vec[2 * i + 1]->sum_of_squares();
+
+        // Compute residuals
+        if (resid_denom[i] < 1.e-14) {
+            resid_denom[i] = 1.e-14;  // Prevent rel denom from being too small
+        }
+        rms[i] = sqrt(resid[i] / resid_denom[i]);
+        mean_rms += rms[i];
+        if (rms[i] > max_rms) {
+            max_rms = rms[i];
+        }
+        active[i] = true;
+        active_map[i] = nremain;
+
+        // p and z vectors
+        z_vec.push_back(r_vec[2 * i]->clone());
+        z_vec.push_back(r_vec[2 * i + 1]->clone());
+
+        z_vec[2 * i]->apply_denominator(Precon_a);
+        z_vec[2 * i + 1]->apply_denominator(Precon_b);
+        p_vec.push_back(z_vec[2 * i]->clone());
+        p_vec.push_back(z_vec[2 * i + 1]->clone());
+        nremain++;
+    }
+    mean_rms /= (double)nvecs;
+    cphf_nfock_builds_ += nremain;
+
+    stop = time(nullptr);
+    if (print_lvl > 1) {
+        outfile->Printf("    %5s %14.3e %12.3e %7d %9ld\n", "Guess", mean_rms, max_rms, nremain,
+                        stop - start);
+    }
+
+    // => CG iterations <= //
+    for (int cg_iter = 1; cg_iter < max_iter; cg_iter++) {
+        // Build an active vector
+        std::vector<SharedMatrix> active_p_vec;
+        for (size_t i = 0; i < nremain; i++) {
+            // outfile->Printf("Giving vec %d", active_map[i]);
+            active_p_vec.push_back(p_vec[2 * active_map[i]]);
+            active_p_vec.push_back(p_vec[2 * active_map[i] + 1]);
+        }
+
+        // Calc hessian vector product
+        std::vector<SharedMatrix> Ap_vec = cphf_Hx(active_p_vec);
+
+        max_rms = 0.0;
+        mean_rms = 0.0;
+        nremain = 0;
+        int new_remain = 0;
+        // Find factors and scale
+        for (size_t i = 0; i < nvecs; i++) {
+            if (!active[i]) {
+                mean_rms += rms[i];
+                continue;
+            }
+
+            // Compute update
+            rzpre[i] = r_vec[2 * i]->vector_dot(z_vec[2 * i]);
+            rzpre[i] += r_vec[2 * i + 1]->vector_dot(z_vec[2 * i + 1]);
+
+            double tmp_denom = p_vec[2 * i]->vector_dot(Ap_vec[2 * nremain]);
+            tmp_denom += p_vec[2 * i + 1]->vector_dot(Ap_vec[2 * nremain + 1]);
+            double alpha = rzpre[i] / tmp_denom;
+
+            if (std::isnan(alpha)) {
+                outfile->Printf(
+                    "RHF::CPHF Warning CG alpha is zero/nan for vec %d. Stopping vec.\n", i);
+                active[i] = false;
+                alpha = 0.0;
+            }
+
+            // Update vectors
+            ret_vec[2 * i]->axpy(alpha, p_vec[2 * i]);
+            r_vec[2 * i]->axpy(-alpha, Ap_vec[2 * nremain]);
+
+            ret_vec[2 * i + 1]->axpy(alpha, p_vec[2 * i + 1]);
+            r_vec[2 * i + 1]->axpy(-alpha, Ap_vec[2 * nremain + 1]);
+
+            // Get residual
+            resid[i] = r_vec[2 * i]->sum_of_squares();
+            resid[i] += r_vec[2 * i + 1]->sum_of_squares();
+
+            rms[i] = sqrt(resid[i] / resid_denom[i]);
+            if (rms[i] > max_rms) {
+                max_rms = rms[i];
+            }
+            mean_rms += rms[i];
+
+            // Figure out what we need to do.
+            if (rms[i] < conv_tol) {
+                active[i] = false;
+            } else {
+                active_map[new_remain] = i;
+                new_remain++;
+            }
+            nremain++;
+        }
+        cphf_nfock_builds_ += nremain;
+        nremain = new_remain;
+        mean_rms /= (double)nvecs;
+
+        stop = time(nullptr);
+        if (print_lvl) {
+            outfile->Printf("    %5d %14.3e %12.3e %7d %9ld\n", cg_iter, mean_rms, max_rms, nremain,
+                            stop - start);
+        }
+
+        // Check convergence
+        if ((max_rms < conv_tol) && (!nremain)) {
+            break;
+        }
+
+        // Update p and z
+        for (size_t i = 0; i < nvecs; i++) {
+            if (!active[i]) continue;
+            z_vec[2 * i]->copy(r_vec[2 * i]);
+            z_vec[2 * i]->apply_denominator(Precon_a);
+
+            z_vec[2 * i + 1]->copy(r_vec[2 * i + 1]);
+            z_vec[2 * i + 1]->apply_denominator(Precon_b);
+
+            double tmp_numer = r_vec[2 * i]->vector_dot(z_vec[2 * i]);
+            tmp_numer += r_vec[2 * i + 1]->vector_dot(z_vec[2 * i + 1]);
+            double beta = tmp_numer / rzpre[i];
+
+            p_vec[2 * i]->scale(beta);
+            p_vec[2 * i]->add(z_vec[2 * i]);
+
+            p_vec[2 * i + 1]->scale(beta);
+            p_vec[2 * i + 1]->add(z_vec[2 * i + 1]);
+        }
+    }
+
+    // Convergence
+    if (!nremain) {
+        cphf_converged_ = true;
+    }
+
+    // Print out tail
+    if (print_lvl > 1) {
+        outfile->Printf("   -----------------------------------------------------\n");
+        outfile->Printf("\n");
+        if (nremain) {
+            outfile->Printf("    Warning! %d equations did not converge!\n\n", nremain);
+        } else {
+            outfile->Printf("    Solver has converged.\n\n");
+        }
+    }
+
+    return ret_vec;
 }
 int UHF::soscf_update(void)
 {
     time_t start, stop;
-    start = time(NULL);
+    start = time(nullptr);
 
     // => Build gradient and preconditioner <= //
 
     // Grab occ and vir orbitals
     SharedMatrix Cocc_a = Ca_subset("SO", "OCC");
     SharedMatrix Cvir_a = Ca_subset("SO", "VIR");
-    Dimension virpi_a = Cvir_a->colspi();
+    SharedMatrix Gradient_a = Matrix::triplet(Cocc_a, Fa_, Cvir_a, true, false, false);
 
     SharedMatrix Cocc_b = Cb_subset("SO", "OCC");
     SharedMatrix Cvir_b = Cb_subset("SO", "VIR");
-    Dimension virpi_b = Cvir_b->colspi();
-
-    // MO Fock Matrix (Inactive Fock in Helgaker's language)
-    SharedMatrix IFock_a = Matrix::triplet(Ca_, Fa_, Ca_, true, false, false);
-    SharedMatrix Gradient_a = SharedMatrix(new Matrix("Alpha Gradient",
-                                           nirrep_, nalphapi_, virpi_a));
-    SharedMatrix Precon_a = SharedMatrix(new Matrix("Alpha Precon",
-                                         nirrep_, nalphapi_, virpi_a));
-
-    SharedMatrix IFock_b = Matrix::triplet(Cb_, Fb_, Cb_, true, false, false);
-    SharedMatrix Gradient_b = SharedMatrix(new Matrix("Beta Gradient",
-                                           nirrep_, nbetapi_, virpi_b));
-    SharedMatrix Precon_b = SharedMatrix(new Matrix("Beta Precon",
-                                         nirrep_, nbetapi_, virpi_b));
-
-    for (size_t h=0; h<nirrep_; h++){
-
-        if (nalphapi_[h] && virpi_a[h]){
-            double* gp = Gradient_a->pointer(h)[0];
-            double* denomp = Precon_a->pointer(h)[0];
-            double** fp = IFock_a->pointer(h);
-
-            for (size_t i=0, target=0; i<nalphapi_[h]; i++){
-                for (size_t a=nalphapi_[h]; a < nmopi_[h]; a++){
-                    gp[target] = -4.0 * fp[i][a];
-                    denomp[target++] = -4.0 * (fp[i][i] - fp[a][a]);
-                }
-            }
-        }
-        if (nbetapi_[h] && virpi_b[h]){
-            double* gp = Gradient_b->pointer(h)[0];
-            double* denomp = Precon_b->pointer(h)[0];
-            double** fp = IFock_b->pointer(h);
-
-            for (size_t i=0, target=0; i<nbetapi_[h]; i++){
-                for (size_t a=nbetapi_[h]; a < nmopi_[h]; a++){
-                    gp[target] = -4.0 * fp[i][a];
-                    denomp[target++] = -4.0 * (fp[i][i] - fp[a][a]);
-                }
-            }
-        }
-    }
+    SharedMatrix Gradient_b = Matrix::triplet(Cocc_b, Fb_, Cvir_b, true, false, false);
 
     // Make sure the MO gradient is reasonably small
-    if ((Gradient_a->absmax() > 0.3) || (Gradient_b->absmax() > 0.3)){
+    if ((Gradient_a->absmax() > 0.3) || (Gradient_b->absmax() > 0.3 )){
         if (print_ > 1){
             outfile->Printf("    Gradient element too large for SOSCF, using DIIS.\n");
         }
         return 0;
     }
-
-    if (soscf_print_){
-        outfile->Printf("\n");
-        outfile->Printf("    ==> SOUHF Iterations <==\n");
-        outfile->Printf("    Maxiter     = %11d\n", soscf_max_iter_);
-        outfile->Printf("    Miniter     = %11d\n", soscf_min_iter_);
-        outfile->Printf("    Convergence = %11.3E\n", soscf_conv_);
-        outfile->Printf("    ---------------------------------------\n");
-        outfile->Printf("    %-4s   %11s     %10s\n", "Iter", "Residual RMS", "Time [s]");
-        outfile->Printf("    ---------------------------------------\n");
-    }
-
-    // => Initial CG guess <= //
-    SharedMatrix x_a = Gradient_a->clone();
-    x_a->apply_denominator(Precon_a);
-    SharedMatrix x_b = Gradient_b->clone();
-    x_b->apply_denominator(Precon_b);
-
-    // Calc hessian vector product, find residual and conditioned residual
-    SharedMatrix r_a = Gradient_a->clone();
-    SharedMatrix Ap_a = SharedMatrix(new Matrix("Ap_a", nirrep_, nalphapi_, virpi_a));
-    SharedMatrix r_b = Gradient_b->clone();
-    SharedMatrix Ap_b = SharedMatrix(new Matrix("Ap_b", nirrep_, nbetapi_, virpi_b));
-
-    Hx(x_a, IFock_a, Cocc_a, Cvir_a, Ap_a,
-       x_b, IFock_b, Cocc_b, Cvir_b, Ap_b);
-    r_a->subtract(Ap_a);
-    r_b->subtract(Ap_b);
-
-    // Print iteration 0 timings and rms
-    double rconv = r_a->sum_of_squares() + r_b->sum_of_squares();
-    double grad_rms = Gradient_a->sum_of_squares() + Gradient_b->sum_of_squares();
-    if (grad_rms < 1.e-14){
-        grad_rms = 1.e-14; // Prevent rel denom from being too small
-    }
-    double rms = 0.5 * sqrt(rconv / grad_rms);
-    stop = time(NULL);
-    if (soscf_print_){
-        outfile->Printf("    %-5s %11.3E %10ld\n", "Guess", rms, stop-start);
-    }
-
-    // Build new p and z vectors
-    SharedMatrix z_a = r_a->clone();
-    z_a->apply_denominator(Precon_a);
-    SharedMatrix p_a = z_a->clone();
-
-    SharedMatrix z_b = r_b->clone();
-    z_b->apply_denominator(Precon_b);
-    SharedMatrix p_b = z_b->clone();
-
-    // => CG iterations <= //
-    int fock_builds = 1;
-    for (int cg_iter=1; cg_iter<soscf_max_iter_; cg_iter++) {
-
-        // Calc hessian vector product
-        Hx(p_a, IFock_a, Cocc_a, Cvir_a, Ap_a,
-           p_b, IFock_b, Cocc_b, Cvir_b, Ap_b);
-        fock_builds += 1;
-
-        // Find factors and scale
-        double rzpre = r_a->vector_dot(z_a) + r_b->vector_dot(z_b);
-        double alpha = rzpre / (p_a->vector_dot(Ap_a) + p_b->vector_dot(Ap_b));
-        if (std::isnan(alpha)){
-            outfile->Printf("UHF::SOSCF Warning CG alpha is zero/nan. Stopping CG.\n");
-            alpha = 0.0;
-        }
-
-        x_a->axpy(alpha, p_a);
-        r_a->axpy(-alpha, Ap_a);
-
-        x_b->axpy(alpha, p_b);
-        r_b->axpy(-alpha, Ap_b);
-
-        // Get residual
-        double rconv = r_a->sum_of_squares() + r_b->sum_of_squares();
-        double rms = 0.5 * sqrt(rconv / grad_rms);
-        stop = time(NULL);
-        if (soscf_print_){
-            outfile->Printf("    %-5d %11.3E %10ld\n", cg_iter, rms, stop-start);
-        }
-
-        // Check convergence
-        if (((rms < soscf_conv_) && (cg_iter >= soscf_min_iter_)) || (alpha==0.0)) {
-            break;
-        }
-
-        // Update p and z
-        z_a->copy(r_a);
-        z_a->apply_denominator(Precon_a);
-
-        z_b->copy(r_b);
-        z_b->apply_denominator(Precon_b);
-
-        double beta = (r_a->vector_dot(z_a) + r_b->vector_dot(z_b)) / rzpre;
-
-        p_a->scale(beta);
-        p_a->add(z_a);
-
-        p_b->scale(beta);
-        p_b->add(z_b);
-
-    }
-    if (soscf_print_){
-        outfile->Printf("    ---------------------------------------\n");
-        outfile->Printf("\n");
-    }
+    std::vector<SharedMatrix> ret_x = cphf_solve({Gradient_a, Gradient_b}, soscf_conv_, soscf_max_iter_,
+                                             soscf_print_ ? 2 : 0);
 
     // => Rotate orbitals <= //
-    rotate_orbitals(Ca_, x_a);
-    rotate_orbitals(Cb_, x_b);
+    rotate_orbitals(Ca_, ret_x[0]);
+    rotate_orbitals(Cb_, ret_x[1]);
 
-    // => Cleanup <= //
-    Cocc_a.reset();     Cocc_b.reset();
-    Cvir_a.reset();     Cvir_b.reset();
-    IFock_a.reset();    IFock_b.reset();
-    Precon_a.reset();   Precon_b.reset();
-    Gradient_a.reset(); Gradient_b.reset();
-    Ap_a.reset();       Ap_b.reset();
-    z_a.reset();        z_b.reset();
-    r_a.reset();        r_b.reset();
-    p_a.reset();        p_b.reset();
-
-    return fock_builds;
+    return cphf_nfock_builds_;
 }
 
 void UHF::compute_orbital_gradient(bool save_fock)
@@ -669,7 +880,7 @@ void UHF::compute_orbital_gradient(bool save_fock)
 
     if(save_fock){
         if (initialized_diis_manager_ == false) {
-            diis_manager_ = std::shared_ptr<DIISManager>(new DIISManager(max_diis_vectors_, "HF DIIS vector", DIISManager::LargestError, DIISManager::OnDisk));
+            diis_manager_ = std::make_shared<DIISManager>(max_diis_vectors_, "HF DIIS vector", DIISManager::LargestError, DIISManager::OnDisk);
             diis_manager_->set_error_vector_size(2,
                                                  DIISEntry::Matrix, gradient_a.get(),
                                                  DIISEntry::Matrix, gradient_b.get());
@@ -690,7 +901,10 @@ bool UHF::diis()
 
 bool UHF::stability_analysis()
 {
-    std::shared_ptr<UStab> stab = std::shared_ptr<UStab>(new UStab(shared_from_this(), options_));
+    if (functional_->needs_xc()) {
+        throw PSIEXCEPTION("Stability analysis not yet supported for XC functionals.");
+    }
+    auto stab = std::make_shared<UStab>(shared_from_this(), options_);
     stab->compute_energy();
     SharedMatrix eval_sym = stab->analyze();
     outfile->Printf( "    Lowest UHF->UHF stability eigenvalues: \n");
@@ -767,17 +981,17 @@ void UHF::compute_nos()
     start_occ = (start_occ < 0 ? 0 : start_occ);
     int stop_vir = offset + max_num + 1;
     stop_vir = (int)((size_t)stop_vir >= metric.size() ? metric.size() : stop_vir);
-    char** labels = basisset_->molecule()->irrep_labels();
+    std::vector<std::string> labels = basisset_->molecule()->irrep_labels();
     outfile->Printf( "\n  UHF NO Occupations:\n");
     for (int index = start_occ; index < stop_vir; index++) {
       if (index < offset) {
         outfile->Printf( "  HONO-%-2d: %4d%3s %9.7f\n", offset- index - 1,
-        std::get<2>(metric[index])+1,labels[std::get<1>(metric[index])],
+        std::get<2>(metric[index])+1,labels[std::get<1>(metric[index])].c_str(),
         std::get<0>(metric[index]));
       }
       else {
         outfile->Printf( "  LUNO+%-2d: %4d%3s %9.7f\n", index - offset,
-        std::get<2>(metric[index])+1,labels[std::get<1>(metric[index])],
+        std::get<2>(metric[index])+1,labels[std::get<1>(metric[index])].c_str(),
         std::get<0>(metric[index]));
       }
     }
@@ -859,4 +1073,32 @@ void UHF::compute_nos()
     }
 }
 
+
+std::shared_ptr<UHF> UHF::c1_deep_copy(std::shared_ptr<BasisSet> basis)
+{
+    std::shared_ptr<Wavefunction> wfn = Wavefunction::c1_deep_copy(basis);
+    auto hf_wfn = std::make_shared<UHF>(wfn, functional_, wfn->options(), wfn->psio());
+
+    // now just have to copy the matrices that UHF initializes
+    // include only those that are not temporary (some deleted in finalize())
+    if (Ca_) hf_wfn->Ca_ = Ca_subset("AO", "ALL");
+    if (Cb_) hf_wfn->Cb_ = Cb_subset("AO", "ALL");
+    if (Da_) hf_wfn->Da_ = Da_subset("AO");
+    if (Db_) hf_wfn->Db_ = Db_subset("AO");
+    if (Fa_) hf_wfn->Fa_ = Fa_subset("AO");
+    if (Fb_) hf_wfn->Fb_ = Fb_subset("AO");
+    if (epsilon_a_) hf_wfn->epsilon_a_ =
+        epsilon_subset_helper(epsilon_a_, nsopi_, "AO", "ALL");
+    if (epsilon_b_) hf_wfn->epsilon_b_ =
+        epsilon_subset_helper(epsilon_b_, nsopi_, "AO", "ALL");
+    // H_ ans X_ reset in the HF constructor, copy them over here
+    SharedMatrix SO2AO = aotoso()->transpose();
+    if (H_) hf_wfn->H_->remove_symmetry(H_, SO2AO);
+    if (X_) hf_wfn->X_->remove_symmetry(X_, SO2AO);
+
+
+    return hf_wfn;
+}
+
+
 }}
