@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -27,12 +27,11 @@
  */
 
 #include "psi4/psi4-dec.h"
-#include "psi4/libparallel/parallel.h"
+#include "psi4/pybind11.h"
 #include "psi4/liboptions/liboptions.h"
 
 #include "psi4/libscf_solver/rohf.h"
 
-#include "psi4/libmints/view.h"
 #include "psi4/libpsio/psio.hpp"
 #include "psi4/libiwl/iwl.hpp"
 #include "psi4/libtrans/integraltransform.h"
@@ -42,7 +41,7 @@
 #include "psi4/libfock/apps.h"
 #include "psi4/libqt/qt.h"
 #include <vector>
-#include "psi4/libparallel/ParallelPrinter.h"
+#include "psi4/libpsi4util/PsiOutStream.h"
 #include "psi4/fnocc/frozen_natural_orbitals.h"
 #include "psi4/libmints/matrix.h"
 #include "psi4/libmints/molecule.h"
@@ -57,14 +56,14 @@ namespace mrcc {
 
 namespace {
 
-void write_oei_to_disk(std::shared_ptr <OutFile> &printer, SharedMatrix moH)
+void write_oei_to_disk(std::shared_ptr<PsiOutStream> &printer, SharedMatrix moH)
 {
     // Walk through moH and save the non-zero values
     int offset = 0;
     for (int h = 0; h < moH->nirrep(); ++h) {
         for (int m = 0; m < moH->rowdim(h); ++m) {
             for (int n = 0; n <= m; ++n) {
-                if (fabs(moH->get(h, m, n)) > 1.0e-12) {
+                if (std::fabs(moH->get(h, m, n)) > 1.0e-12) {
                     printer->Printf("%28.20E%4d%4d%4d%4d\n", moH->get(h, m, n), m + offset + 1, n + offset + 1, 0, 0);
                 }
             }
@@ -73,7 +72,7 @@ void write_oei_to_disk(std::shared_ptr <OutFile> &printer, SharedMatrix moH)
     }
 }
 
-void write_tei_to_disk(std::shared_ptr <OutFile> &printer, int nirrep, dpdbuf4 &K, double ints_tolerance)
+void write_tei_to_disk(std::shared_ptr<PsiOutStream> &printer, int nirrep, dpdbuf4 &K, double ints_tolerance)
 {
     for (int h = 0; h < nirrep; ++h) {
         global_dpd_->buf4_mat_irrep_init(&K, h);
@@ -85,7 +84,7 @@ void write_tei_to_disk(std::shared_ptr <OutFile> &printer, int nirrep, dpdbuf4 &
                 int r = K.params->colorb[h][rs][0];
                 int s = K.params->colorb[h][rs][1];
 
-                if (fabs(K.matrix[h][pq][rs]) > ints_tolerance)
+                if (std::fabs(K.matrix[h][pq][rs]) > ints_tolerance)
                     printer->Printf("%28.20E%4d%4d%4d%4d\n",
                                     K.matrix[h][pq][rs], p + 1, q + 1, r + 1, s + 1);
             }
@@ -260,7 +259,7 @@ public:
                 // It's also normalized differently to Psi's, by a factor of 2.
                 if (r != 0 && s != 0) {
                     if (p >= r && q >= s)
-                        if (fabs(value) > tolerance_)
+                        if (std::fabs(value) > tolerance_)
                             filler(bucket, p - 1, r - 1, q - 1, s - 1, value * 0.5);
                 } else
                     one_particle_->set(abs_mo_to_irrep_[p - 1], abs_mo_to_rel_[p - 1], abs_mo_to_rel_[q - 1], value);
@@ -321,7 +320,7 @@ public:
 
 		    p = static_cast<int **>(realloc(static_cast<void *>(bucket_offset_),
 						    nbucket_ * sizeof(int *)));
-		    if(p == NULL) {
+		    if(p == nullptr) {
 		      throw PsiException("file_build: allocation error", __FILE__, __LINE__);
 		    } else {
 		      bucket_offset_ = p;
@@ -331,7 +330,7 @@ public:
 
 		    p = static_cast<int **>(realloc(static_cast<void *>(bucket_row_dim_),
 						    nbucket_ * sizeof(int *)));
-		    if(p == NULL) {
+		    if(p == nullptr) {
 		      throw PsiException("file_build: allocation error", __FILE__, __LINE__);
 		    } else {
 		      bucket_row_dim_ = p;
@@ -341,7 +340,7 @@ public:
 
 		    p = static_cast<int **>(realloc(static_cast<void *>(bucket_size_),
 						    nbucket_ * sizeof(int *)));
-		    if(p == NULL) {
+		    if(p == nullptr) {
 		      throw PsiException("file_build: allocation error", __FILE__, __LINE__);
 		    } else {
 		      bucket_size_ = p;
@@ -434,7 +433,7 @@ void load_restricted(SharedWavefunction ref, FILE *ccdensities, double tolerance
     global_dpd_->file4_init(&I, PSIF_TPDM_PRESORT, 0,
                             ints.DPD_ID("[A>=A]+"), ints.DPD_ID("[A>=A]+"), "MO TPDM (AA|AA)");
 
-    SharedMatrix one_particle(new Matrix("MO-basis OPDM", active_mopi, active_mopi));
+    auto one_particle = std::make_shared<Matrix>("MO-basis OPDM", active_mopi, active_mopi);
 
     DPDBucketFiller bucket(&I, Process::environment.get_memory());
     // While MRCCRestricedReader is processing the two particle values it will
@@ -463,10 +462,10 @@ void load_restricted(SharedWavefunction ref, FILE *ccdensities, double tolerance
      */
 
     // One-electron contribution: Xpq <- h_pr D_rq
-    SharedMatrix H(new Matrix(PSIF_MO_FZC, nmopi, nmopi));
+    auto H = std::make_shared<Matrix>(PSIF_MO_FZC, nmopi, nmopi);
     // TODO make sure the density is frozen appropriately with frozen core
     H->load(_default_psio_lib_, PSIF_OEI);
-    SharedMatrix X(new Matrix("X (1e contribution)", nmopi, nmopi));
+    auto X = std::make_shared<Matrix>("X (1e contribution)", nmopi, nmopi);
     X->gemm(false, false, 1.0, one_particle, H, 0.0);
 
     // Two-electron contribution: Xpq <- 2 (pr|st) G_qrst
@@ -485,7 +484,7 @@ void load_restricted(SharedWavefunction ref, FILE *ccdensities, double tolerance
                             "X (2e contribution)");
 
     // Check energy
-    double enuc = ref->molecule()->nuclear_repulsion_energy();
+    double enuc = ref->molecule()->nuclear_repulsion_energy(ref->get_dipole_field_strength());
     double E1e = one_particle->vector_dot(H);
     double E2e = global_dpd_->buf4_dot(&G, &D);
     outfile->Printf("\tEnergies recomputed from MRCC's density matrices:\n");
@@ -494,7 +493,7 @@ void load_restricted(SharedWavefunction ref, FILE *ccdensities, double tolerance
     outfile->Printf("\t\tTotal energy        = %16.10f\n", enuc + E1e + E2e);
 
     global_dpd_->contract442(&G, &D, &X2, 0, 0, 2.0, 0.0);
-    SharedMatrix X2mat(new Matrix(&X2));
+    auto X2mat = std::make_shared<Matrix>(&X2);
     X->print();
     X2mat->print();
     X->add(X2mat);
@@ -526,7 +525,7 @@ void load_restricted(SharedWavefunction ref, FILE *ccdensities, double tolerance
     // Form the energy-weighted OPDM
 
     // Form the Lagrangian
-    //SharedMatrix Lia(new Matrix("Lia", naocc, navir));
+    //auto Lia = std::make_shared<Matrix>("Lia", naocc, navir);
     //for (int h = 0; h < Lia->nirrep(); h++) {
     //    int ni = naocc[h];
     //    int na = navir[h];
@@ -542,8 +541,7 @@ void load_restricted(SharedWavefunction ref, FILE *ccdensities, double tolerance
     //}
 
     // Form the orbital response contributions to the relaxed OPDM
-    View ia_view(one_particle, aocc, avir, focc, docc);
-    SharedMatrix Pia = ia_view();
+    SharedMatrix Pia = one_particle->get_block({focc, focc + aocc},{docc,docc + avir});
     Pia->set_name("Pia (MRCC OPDM ov Block)");
 
     if (debug) {
@@ -553,11 +551,11 @@ void load_restricted(SharedWavefunction ref, FILE *ccdensities, double tolerance
     // Construct a RCPHF Object
     Options &options = Process::environment.options;
 
-    std::shared_ptr <RCPHF> cphf(new RCPHF(ref, options));
+    auto cphf = std::make_shared<RCPHF>(ref, options);
     cphf->preiterations();
 
     // TODO: Add pre-CPHF A-matrix correction
-    std::shared_ptr <JK> jk = cphf->jk();
+    std::shared_ptr<JK> jk = cphf->jk();
 
     // Task and solve orbital Z-Vector Equations
     std::map <std::string, SharedMatrix> &b = cphf->b();
@@ -629,7 +627,7 @@ PsiReturnType mrcc_load_ccdensities(SharedWavefunction wave, Options &options, c
     int exlevel = level["order"].cast<int>();
     std::string fullname = level["fullname"].cast<std::string>();
     bool pertcc = exlevel > 0 ? false : true;
-    exlevel = abs(exlevel);
+    exlevel = std::abs(exlevel);
 
     outfile->Printf("    Loading gradient data for %s.\n\n", fullname.c_str());
 
@@ -652,14 +650,14 @@ PsiReturnType mrcc_load_ccdensities(SharedWavefunction wave, Options &options, c
     // Use libtrans to initialize DPD
     std::vector <std::shared_ptr<MOSpace>> spaces;
     spaces.push_back(MOSpace::all);
-    IntegralTransform ints(wave, spaces, restricted ? IntegralTransform::Restricted : IntegralTransform::Unrestricted);
+    IntegralTransform ints(wave, spaces, restricted ? IntegralTransform::TransformationType::Restricted : IntegralTransform::TransformationType::Unrestricted);
 
     // Use the IntegralTransform object's DPD instance, for convenience
     dpd_set_default(ints.get_dpd_id());
 
     // Obtain a single handle to the CCDENSITIES file
     FILE *ccdensities = fopen("CCDENSITIES", "r");
-    if (ccdensities == NULL)
+    if (ccdensities == nullptr)
         throw PSIEXCEPTION("MRCC interface: Unable to open CCDENSITIES. Did MRCC finish successfully?");
 
     const Dimension active_mopi = wave->nmopi() - wave->frzcpi() - wave->frzvpi();
@@ -692,7 +690,7 @@ PsiReturnType mrcc_generate_input(SharedWavefunction ref_wfn, Options &options,
     int exlevel = level["order"].cast<int>();
     std::string fullname = level["fullname"].cast<std::string>();
     bool pertcc = exlevel > 0 ? false : true;
-    exlevel = abs(exlevel);
+    exlevel = std::abs(exlevel);
 
     outfile->Printf("    Generating inputs for %s.\n\n", fullname.c_str());
 
@@ -700,16 +698,16 @@ PsiReturnType mrcc_generate_input(SharedWavefunction ref_wfn, Options &options,
     outfile->Printf("        method %d\n        exlevel %d\n        fullname %s\n\n",
                     method, exlevel, fullname.c_str());
 
-    std::shared_ptr <Wavefunction> wave;
+    std::shared_ptr<Wavefunction> wave;
     //   freeze MP2 natural virtual orbitals?
     if (options.get_bool("NAT_ORBS")) {
-        std::shared_ptr <psi::fnocc::FrozenNO> fno(new psi::fnocc::FrozenNO(ref_wfn, options));
+        auto fno = std::make_shared<psi::fnocc::FrozenNO>(ref_wfn, options);
         fno->ComputeNaturalOrbitals();
-        wave = (std::shared_ptr <Wavefunction>) fno;
+        wave = (std::shared_ptr<Wavefunction>) fno;
     } else {
         wave = ref_wfn;
     }
-    std::shared_ptr <Molecule> molecule = wave->molecule();
+    std::shared_ptr<Molecule> molecule = wave->molecule();
 
     // Orbitals spaces
     Dimension docc = wave->doccpi();
@@ -734,7 +732,7 @@ PsiReturnType mrcc_generate_input(SharedWavefunction ref_wfn, Options &options,
 
     outfile->Printf("\n");
     //FILE* fort55 = fopen("fort.55", "w");
-    std::shared_ptr <OutFile> printer(new OutFile("fort.55", TRUNCATE));
+    auto printer = std::make_shared<PsiOutStream>("fort.55", std::ostream::trunc);
     printer->Printf("%22d%22d\n", nbf, nelectron);
 
     // Print out orbital symmetries
@@ -789,7 +787,7 @@ PsiReturnType mrcc_generate_input(SharedWavefunction ref_wfn, Options &options,
     }
 
     // Create integral transformation object
-    IntegralTransform ints(wave, spaces, closedshell ? IntegralTransform::Restricted : IntegralTransform::Unrestricted);
+    IntegralTransform ints(wave, spaces, closedshell ? IntegralTransform::TransformationType::Restricted : IntegralTransform::TransformationType::Unrestricted);
 
     // This transforms everything (OEI and TEI)
     ints.transform_tei(MOSpace::all, MOSpace::all, MOSpace::all, MOSpace::all);
@@ -820,15 +818,15 @@ PsiReturnType mrcc_generate_input(SharedWavefunction ref_wfn, Options &options,
         global_dpd_->buf4_close(&K);
 
         // Load in frozen core operator, in the event of FREEZE_CORE = FALSE this is the MO OEI
-        SharedMatrix moH(new Matrix(PSIF_MO_FZC, wave->nmopi(), wave->nmopi()));
+        auto moH = std::make_shared<Matrix>(PSIF_MO_FZC, wave->nmopi(), wave->nmopi());
         moH->load(_default_psio_lib_, PSIF_OEI);
-        View vmoH(moH, active_mopi, active_mopi, wave->frzcpi(), wave->frzcpi());
-        moH = vmoH();
-        write_oei_to_disk(printer, moH);
+        Slice slice_fc(wave->frzcpi(),wave->frzcpi() + active_mopi);
+        SharedMatrix moHblock = moH->get_block(slice_fc,slice_fc);
+        write_oei_to_disk(printer, moHblock);
 
         // Print nuclear repulsion energy.
         // Eventually needs to be changed to frozen core energy + nuclear repulsion energy
-        printer->Printf("%28.20E%4d%4d%4d%4d\n", ints.get_frozen_core_energy() + molecule->nuclear_repulsion_energy(), 0, 0, 0, 0);
+        printer->Printf("%28.20E%4d%4d%4d%4d\n", ints.get_frozen_core_energy() + molecule->nuclear_repulsion_energy(wave->get_dipole_field_strength()), 0, 0, 0, 0);
     } else {
 
         // We want only the permutationally unique integrals, hence [A>=A]+, see libtrans documenation for details
@@ -870,35 +868,34 @@ PsiReturnType mrcc_generate_input(SharedWavefunction ref_wfn, Options &options,
         printer->Printf("%28.20E%4d%4d%4d%4d\n", 0.0, 0, 0, 0, 0);
 
         // Load in alpha frozen core operator, in the event of FREEZE_CORE = FALSE this is the MO OEI
-        SharedMatrix moH(new Matrix(PSIF_MO_A_FZC, wave->nmopi(), wave->nmopi()));
+        auto moH = std::make_shared<Matrix>(PSIF_MO_A_FZC, wave->nmopi(), wave->nmopi());
         moH->load(_default_psio_lib_, PSIF_OEI);
-        View vmoH(moH, active_mopi, active_mopi, wave->frzcpi(), wave->frzcpi());
-        moH = vmoH();
-        write_oei_to_disk(printer, moH);
+        Slice slice_fc(wave->frzcpi(),wave->frzcpi() + active_mopi);
+        SharedMatrix moHblock = moH->get_block(slice_fc,slice_fc);
+        write_oei_to_disk(printer, moHblock);
 
         // Write out separator
         printer->Printf("%28.20E%4d%4d%4d%4d\n", 0.0, 0, 0, 0, 0);
 
         // Load in beta frozen core operator, in the event of FREEZE_CORE = FALSE this is the MO OEI
-        SharedMatrix moHb(new Matrix(PSIF_MO_B_FZC, wave->nmopi(), wave->nmopi()));
+        auto moHb = std::make_shared<Matrix>(PSIF_MO_B_FZC, wave->nmopi(), wave->nmopi());
         moHb->load(_default_psio_lib_, PSIF_OEI);
-        View vmoHb(moHb, active_mopi, active_mopi, wave->frzcpi(), wave->frzcpi());
-        moHb = vmoHb();
-        write_oei_to_disk(printer, moHb);
+        SharedMatrix moHblockb = moHb->get_block(slice_fc,slice_fc);
+        write_oei_to_disk(printer, moHblockb);
 
         // Write out separator
         printer->Printf("%28.20E%4d%4d%4d%4d\n", 0.0, 0, 0, 0, 0);
 
         // Print nuclear repulsion energy.
         // Eventually needs to be changed to frozen core energy + nuclear repulsion energy
-        printer->Printf("%28.20E%4d%4d%4d%4d\n", ints.get_frozen_core_energy() + molecule->nuclear_repulsion_energy(), 0, 0, 0, 0);
+        printer->Printf("%28.20E%4d%4d%4d%4d\n", ints.get_frozen_core_energy() + molecule->nuclear_repulsion_energy(wave->get_dipole_field_strength()), 0, 0, 0, 0);
     }
     _default_psio_lib_->close(PSIF_LIBTRANS_DPD, 1);
 
     outfile->Printf("done.\n  Generating fort.56 input file...");
 
     // Determine energy convergence to pass to MRCC
-    double user_e = fabs(Process::environment.options.get_double("E_CONVERGENCE"));
+    double user_e = std::fabs(Process::environment.options.get_double("E_CONVERGENCE"));
     int e_conv = 0;
 
     if (user_e >= 1.0)
@@ -963,7 +960,7 @@ PsiReturnType mrcc_generate_input(SharedWavefunction ref_wfn, Options &options,
         for (int n = 0; n < active_socc[h]; ++n)
             symm ^= h;
     symm += 1; // stupid 1 based fortran
-    printer = std::shared_ptr<OutFile>(new OutFile("fort.56", TRUNCATE));
+    printer = std::make_shared<PsiOutStream>("fort.56", std::ostream::trunc);
     //FILE* fort56 = fopen("fort.56", "w");
     printer->Printf("%6d%6d%6d%6d%6d      0     0%6d     0%6d%6d%6d%6d      0      0%6d     0     0    0.00    0%6lu\n",
                     exlevel,                                         // # 1
