@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -34,8 +34,6 @@
 #include "defines.h"
 
 
-using namespace std;
-
 namespace psi{ namespace occwave{
 
 void OCCWave::coord_grad()
@@ -286,7 +284,7 @@ if (reference_ == "RESTRICTED") {
                    double value = 2.0 * G.matrix[h][ij][kl];
                    if (I > K) value *= 2.0;
                    if (J > L) value *= 2.0;
-                   iwl_buf_wrt_val(&AA, I, K, J, L, value, 0, "NULL", 0);
+                   iwl_buf_wrt_val(&AA, I, K, J, L, value, 0, "outfile", 0);
                 }
             }
         }
@@ -317,7 +315,7 @@ if (wfn_type_ != "OMP2") {
                    double value = 2.0 * G.matrix[h][ab][cd];
                    if (A > C) value *= 2.0;
                    if (B > D) value *= 2.0;
-                   iwl_buf_wrt_val(&AA, A, C, B, D, value, 0, "NULL", 0);
+                   iwl_buf_wrt_val(&AA, A, C, B, D, value, 0, "outfile", 0);
                 }
             }
         }
@@ -346,7 +344,7 @@ if (wfn_type_ != "OMP2") {
                 int JB = ((B - nooA) * nooA)  + J;
                 if (IA >= JB) {
                    double value = 8.0 * G.matrix[h][ij][ab];
-                   iwl_buf_wrt_val(&AA, A, I, B, J, value, 0, "NULL", 0);
+                   iwl_buf_wrt_val(&AA, A, I, B, J, value, 0, "outfile", 0);
                 }
             }
         }
@@ -550,7 +548,7 @@ else if (reference_ == "UNRESTRICTED") {
                 int K = aocc_qt[k];
                 int L = bocc_qt[l];
                 double value = 4.0 * G.matrix[h][ij][kl];
-                iwl_buf_wrt_val(&AB, I, K, J, L, value, 0, "NULL", 0);
+                iwl_buf_wrt_val(&AB, I, K, J, L, value, 0, "outfile", 0);
             }
         }
         global_dpd_->buf4_mat_irrep_close(&G, h);
@@ -614,7 +612,7 @@ if (wfn_type_ != "OMP2") {
                 int A = avir_qt[a];
                 int B = bvir_qt[b];
                 double value = 8.0 * G.matrix[h][ij][ab];
-                iwl_buf_wrt_val(&AB, I, A, J, B, value, 0, "NULL", 0);
+                iwl_buf_wrt_val(&AB, I, A, J, B, value, 0, "outfile", 0);
             }
         }
         global_dpd_->buf4_mat_irrep_close(&G, h);
@@ -639,7 +637,7 @@ if (wfn_type_ != "OMP2") {
                 int J = aocc_qt[j];
                 int B = avir_qt[b];
                 double value = 2.0 * G.matrix[h][ia][jb];
-                iwl_buf_wrt_val(&AA, I, J, A, B, value, 0, "NULL", 0);
+                iwl_buf_wrt_val(&AA, I, J, A, B, value, 0, "outfile", 0);
             }
         }
         global_dpd_->buf4_mat_irrep_close(&G, h);
@@ -663,7 +661,7 @@ if (wfn_type_ != "OMP2") {
                 int J = bocc_qt[j];
                 int B = bvir_qt[b];
                 double value = 2.0 * G.matrix[h][ia][jb];
-                iwl_buf_wrt_val(&BB, I, J, A, B, value, 0, "NULL", 0);
+                iwl_buf_wrt_val(&BB, I, J, A, B, value, 0, "outfile", 0);
             }
         }
         global_dpd_->buf4_mat_irrep_close(&G, h);
@@ -687,7 +685,7 @@ if (wfn_type_ != "OMP2") {
                 int J = aocc_qt[j];
                 int B = bvir_qt[b];
                 double value = 4.0 * G.matrix[h][ia][jb];
-                iwl_buf_wrt_val(&AB, I, J, A, B, value, 0, "NULL", 0);
+                iwl_buf_wrt_val(&AB, I, J, A, B, value, 0, "outfile", 0);
             }
         }
         global_dpd_->buf4_mat_irrep_close(&G, h);
@@ -713,7 +711,7 @@ if (wfn_type_ != "OMP2") {
                 int J = aocc_qt[j];
                 int B = avir_qt[b];
                 double value = -2.0 * G.matrix[h][ia][jb];
-                iwl_buf_wrt_val(&AA, I, B, A, J, value, 0, "NULL", 0);
+                iwl_buf_wrt_val(&AA, I, B, A, J, value, 0, "outfile", 0);
             }
         }
         global_dpd_->buf4_mat_irrep_close(&G, h);
@@ -738,7 +736,7 @@ if (wfn_type_ != "OMP2") {
                 int J = bocc_qt[j];
                 int B = bvir_qt[b];
                 double value = -2.0 * G.matrix[h][ia][jb];
-                iwl_buf_wrt_val(&BB, I, B, A, J, value, 0, "NULL", 0);
+                iwl_buf_wrt_val(&BB, I, B, A, J, value, 0, "outfile", 0);
             }
         }
         global_dpd_->buf4_mat_irrep_close(&G, h);
@@ -764,7 +762,7 @@ if (wfn_type_ != "OMP2") {
                 int B = avir_qt[b];
                 int J = bocc_qt[j];
                 double value = 8.0 * G.matrix[h][ia][bj];
-                iwl_buf_wrt_val(&AB, I, B, A, J, value, 0, "NULL", 0);
+                iwl_buf_wrt_val(&AB, I, B, A, J, value, 0, "outfile", 0);
             }
         }
         global_dpd_->buf4_mat_irrep_close(&G, h);
@@ -790,7 +788,7 @@ if (wfn_type_ != "OMP2") {
                 int B = avir_qt[b];
                 int J = bocc_qt[j];
                 double value = 4.0 * G.matrix[h][ai][bj];
-                iwl_buf_wrt_val(&AB, A, B, I, J, value, 0, "NULL", 0);
+                iwl_buf_wrt_val(&AB, A, B, I, J, value, 0, "outfile", 0);
             }
         }
         global_dpd_->buf4_mat_irrep_close(&G, h);
@@ -830,7 +828,7 @@ if (wfn_type_ != "OMP2") {
                 int I = aocc_qt[i];
                 int N = bocc_qt[n];
                 double value = G.matrix[h][am][in];
-                iwl_buf_wrt_val(&AB, A, I, M, N, value, 0, "NULL", 0);
+                iwl_buf_wrt_val(&AB, A, I, M, N, value, 0, "outfile", 0);
             }
         }
         global_dpd_->buf4_mat_irrep_wrt(&G, h);
@@ -855,7 +853,7 @@ if (wfn_type_ != "OMP2") {
                 int N = aocc_qt[n];
                 int I = bocc_qt[i];
                 double value = G.matrix[h][ma][ni];
-                iwl_buf_wrt_val(&AB, M, N, A, I, value, 0, "NULL", 0);
+                iwl_buf_wrt_val(&AB, M, N, A, I, value, 0, "outfile", 0);
             }
         }
         global_dpd_->buf4_mat_irrep_wrt(&G, h);
@@ -1907,10 +1905,10 @@ void OCCWave::oeprop()
     outfile->Printf("\tComputing one-electron properties...\n");
 
 
-    //SharedMatrix Da_ = SharedMatrix(new Matrix("MO-basis alpha OPDM", nmo_, nmo_));
-    //SharedMatrix Db_ = SharedMatrix(new Matrix("MO-basis beta OPDM", nmo_, nmo_));
-    SharedMatrix Da_ = SharedMatrix(new Matrix("MO-basis alpha OPDM", nirrep_, nmopi_, nmopi_));
-    SharedMatrix Db_ = SharedMatrix(new Matrix("MO-basis beta OPDM", nirrep_, nmopi_, nmopi_));
+    //auto Da_ = std::make_shared<Matrix>("MO-basis alpha OPDM", nmo_, nmo_);
+    //auto Db_ = std::make_shared<Matrix>("MO-basis beta OPDM", nmo_, nmo_);
+    auto Da_ = std::make_shared<Matrix>("MO-basis alpha OPDM", nirrep_, nmopi_, nmopi_);
+    auto Db_ = std::make_shared<Matrix>("MO-basis beta OPDM", nirrep_, nmopi_, nmopi_);
     if (reference_ == "RESTRICTED") {
         Da_->copy(g1symm);
         Da_->scale(0.5);
@@ -1923,7 +1921,7 @@ void OCCWave::oeprop()
     }
 
     // Compute oeprop
-    std::shared_ptr<OEProp> oe(new OEProp(shared_from_this()));
+    auto oe = std::make_shared<OEProp>(shared_from_this());
     oe->set_Da_mo(Da_);
     if (reference_ == "UNRESTRICTED") oe->set_Db_mo(Db_);
     oe->add("DIPOLE");
