@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -40,8 +40,6 @@
 #include "defines.h"
 
 
-using namespace std;
-
 
 namespace psi{ namespace occwave{
 
@@ -54,7 +52,7 @@ void OCCWave::ep2_ip()
 //===========================================================================================
 if (reference_ == "RESTRICTED") {
      // Memory allocation for diagonal self-energy
-     SharedVector eOccOrbA = std::shared_ptr<Vector>(new Vector("eOccOrbA", nirrep_, occpiA));
+     auto eOccOrbA = std::make_shared<Vector>("eOccOrbA", nirrep_, occpiA);
 
      dpdbuf4 K, T, D;
 
@@ -272,7 +270,7 @@ if (reference_ == "RESTRICTED") {
 
     Molecule& mol = *reference_wavefunction_->molecule().get();
     CharacterTable ct = mol.point_group()->char_table();
-    string pgroup = mol.point_group()->symbol();
+    std::string pgroup = mol.point_group()->symbol();
 
     // print alpha occ orb energy
     outfile->Printf( "\tAlpha occupied orbitals\n");
@@ -299,8 +297,8 @@ if (reference_ == "RESTRICTED") {
 else if (reference_ == "UNRESTRICTED") {
 
      // Memory allocation
-     SharedVector eOccOrbA = std::shared_ptr<Vector>(new Vector("eOccOrbA", nirrep_, occpiA));
-     SharedVector eOccOrbB = std::shared_ptr<Vector>(new Vector("eOccOrbB", nirrep_, occpiB));
+     auto eOccOrbA = std::make_shared<Vector>("eOccOrbA", nirrep_, occpiA);
+     auto eOccOrbB = std::make_shared<Vector>("eOccOrbB", nirrep_, occpiB);
      eOccOrbA->zero();
      eOccOrbB->zero();
 
@@ -751,7 +749,7 @@ else if (reference_ == "UNRESTRICTED") {
 
     Molecule& mol = *reference_wavefunction_->molecule().get();
     CharacterTable ct = mol.point_group()->char_table();
-    string pgroup = mol.point_group()->symbol();
+    std::string pgroup = mol.point_group()->symbol();
 
     // print alpha occ orb energy
     outfile->Printf( "\tAlpha occupied orbitals\n");
