@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -32,8 +32,7 @@
 #include "occwave.h"
 #include "defines.h"
 
-
-using namespace std;
+#include <cmath>
 
 
 namespace psi{ namespace occwave{
@@ -216,7 +215,7 @@ if (reference_ == "RESTRICTED") {
         // find biggest_kappa
 	biggest_kappaA=0;
 	for (int i=0; i<nidpA;i++) {
-	    if (fabs(kappaA->get(i)) > biggest_kappaA) biggest_kappaA=fabs(kappaA->get(i));
+	    if (std::fabs(kappaA->get(i)) > biggest_kappaA) biggest_kappaA=std::fabs(kappaA->get(i));
 	}
 
         // Scale
@@ -230,9 +229,9 @@ if (reference_ == "RESTRICTED") {
 	  biggest_kappaA=0;
 	  for (int i=0; i<nidpA;i++)
 	  {
-	      if (fabs(kappaA->get(i)) > biggest_kappaA)
+	      if (std::fabs(kappaA->get(i)) > biggest_kappaA)
 	      {
-		  biggest_kappaA = fabs(kappaA->get(i));
+		  biggest_kappaA = std::fabs(kappaA->get(i));
 	      }
 	  }
 	}
@@ -595,12 +594,12 @@ else if (reference_ == "UNRESTRICTED") {
         // find biggest_kappa
 	biggest_kappaA=0;
 	for (int i=0; i<nidpA;i++) {
-	    if (fabs(kappaA->get(i)) > biggest_kappaA) biggest_kappaA=fabs(kappaA->get(i));
+	    if (std::fabs(kappaA->get(i)) > biggest_kappaA) biggest_kappaA=std::fabs(kappaA->get(i));
 	}
 
 	biggest_kappaB=0;
 	for (int i=0; i<nidpB;i++){
-	    if (fabs(kappaB->get(i)) > biggest_kappaB) biggest_kappaB=fabs(kappaB->get(i));
+	    if (std::fabs(kappaB->get(i)) > biggest_kappaB) biggest_kappaB=std::fabs(kappaB->get(i));
 	}
 
         // Scale
@@ -618,9 +617,9 @@ else if (reference_ == "UNRESTRICTED") {
 	  biggest_kappaA=0;
 	  for (int i=0; i<nidpA;i++)
 	  {
-	      if (fabs(kappaA->get(i)) > biggest_kappaA)
+	      if (std::fabs(kappaA->get(i)) > biggest_kappaA)
 	      {
-		  biggest_kappaA = fabs(kappaA->get(i));
+		  biggest_kappaA = std::fabs(kappaA->get(i));
 	      }
 	  }
 	}
@@ -630,9 +629,9 @@ else if (reference_ == "UNRESTRICTED") {
 	  biggest_kappaB=0;
 	  for (int i=0; i<nidpB;i++)
 	  {
-	      if (fabs(kappaB->get(i)) > biggest_kappaB)
+	      if (std::fabs(kappaB->get(i)) > biggest_kappaB)
 	      {
-		  biggest_kappaB=fabs(kappaB->get(i));
+		  biggest_kappaB=std::fabs(kappaB->get(i));
 	      }
 	  }
 	}
@@ -832,7 +831,7 @@ void OCCWave::orb_resp_pcg_rhf()
    if (rms_r_pcgA < tol_pcg || rms_kappaA < tol_pcg) break;
 
  }
- while(fabs(rms_pcg) >= tol_pcg);
+ while(std::fabs(rms_pcg) >= tol_pcg);
 
 }// end orb_resp_pcg_rhf
 
@@ -1161,7 +1160,7 @@ void OCCWave::orb_resp_pcg_uhf()
    if (rms_r_pcg < tol_pcg || rms_kappa < tol_pcg) break;
 
  }
- while(fabs(rms_pcg) >= tol_pcg);
+ while(std::fabs(rms_pcg) >= tol_pcg);
 
 }// end orb_resp_pcg_uhf
 }} // End Namespaces
