@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -37,7 +37,7 @@ SharedWavefunction occwave(SharedWavefunction ref_wfn, Options &options)
     // Start the timers
     tstart();
 
-    SharedWavefunction occ = SharedWavefunction(new OCCWave(ref_wfn, options));
+    auto occ = std::make_shared<OCCWave>(ref_wfn, options);
     occ->compute_energy();
 
     // Shut down the timers
