@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -26,12 +26,14 @@
  * @END LICENSE
  */
 
-#include "psi4/libqt/qt.h"
 #include "occwave.h"
 
+#include "psi4/libqt/qt.h"
+#include "psi4/libpsi4util/process.h"
+
+#include <cmath>
 
 using namespace psi;
-using namespace std;
 
 
 namespace psi{ namespace occwave{
@@ -106,7 +108,7 @@ void OCCWave::omp2_manager()
 	mograd();
         occ_iterations();
 
-        if (rms_wog <= tol_grad && fabs(DE) >= tol_Eod) {
+        if (rms_wog <= tol_grad && std::fabs(DE) >= tol_Eod) {
            orbs_already_opt = 1;
 	   if (conver == 1) outfile->Printf("\n\tOrbitals are optimized now.\n");
 	   else if (conver == 0) {
@@ -382,6 +384,11 @@ void OCCWave::mp2_manager()
              }
 	}
 
+         /* updates the wavefunction for checkpointing */
+        energy_ = Process::environment.globals["MP2 TOTAL ENERGY"];
+        name_ = "MP2";
+
+
         // S2
         //if (comput_s2_ == "TRUE" && reference_ == "UNRESTRICTED") s2_response();
 
@@ -543,7 +550,7 @@ void OCCWave::omp3_manager()
 	mograd();
         occ_iterations();
 
-        if (rms_wog <= tol_grad && fabs(DE) >= tol_Eod) {
+        if (rms_wog <= tol_grad && std::fabs(DE) >= tol_Eod) {
            orbs_already_opt = 1;
 	   if (conver == 1) outfile->Printf("\n\tOrbitals are optimized now.\n");
 	   else if (conver == 0) {
@@ -979,7 +986,7 @@ void OCCWave::ocepa_manager()
            cepa_iterations();
         }
 
-        if (rms_wog <= tol_grad && fabs(DE) >= tol_Eod) {
+        if (rms_wog <= tol_grad && std::fabs(DE) >= tol_Eod) {
            orbs_already_opt = 1;
 	   if (conver == 1) outfile->Printf("\n\tOrbitals are optimized now.\n");
 	   else if (conver == 0) {
@@ -1288,7 +1295,7 @@ void OCCWave::omp2_5_manager()
 	mograd();
         occ_iterations();
 
-        if (rms_wog <= tol_grad && fabs(DE) >= tol_Eod) {
+        if (rms_wog <= tol_grad && std::fabs(DE) >= tol_Eod) {
            orbs_already_opt = 1;
 	   if (conver == 1) outfile->Printf("\n\tOrbitals are optimized now.\n");
 	   else if (conver == 0) {
