@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -32,8 +32,7 @@
 #include "defines.h"
 #include "occwave.h"
 
-
-using namespace std;
+#include <cmath>
 
 
 namespace psi{ namespace occwave{
@@ -197,7 +196,7 @@ if (reference_ == "RESTRICTED") {
     rms_t2 = 0.0;
     rms_t2 = global_dpd_->buf4_dot_self(&R);
     global_dpd_->buf4_close(&R);
-    rms_t2 = sqrt(rms_t2) / nElements;
+    rms_t2 = std::sqrt(rms_t2) / nElements;
 
     // Reset
     global_dpd_->buf4_copy(&Tnew, PSIF_OCC_DPD, "T2_2 <OO|VV>");
@@ -812,7 +811,7 @@ else if (reference_ == "UNRESTRICTED") {
     rms_t2AA = 0.0;
     rms_t2AA = global_dpd_->buf4_dot_self(&R);
     global_dpd_->buf4_close(&R);
-    rms_t2AA = sqrt(rms_t2AA) / nElements;
+    rms_t2AA = std::sqrt(rms_t2AA) / nElements;
 
     // Reset
     global_dpd_->buf4_copy(&Tnew, PSIF_OCC_DPD, "T2_2 <OO|VV>");
@@ -843,7 +842,7 @@ else if (reference_ == "UNRESTRICTED") {
     rms_t2BB = 0.0;
     rms_t2BB = global_dpd_->buf4_dot_self(&R);
     global_dpd_->buf4_close(&R);
-    rms_t2BB = sqrt(rms_t2BB) / nElements;
+    rms_t2BB = std::sqrt(rms_t2BB) / nElements;
 
 
     // Reset
@@ -875,7 +874,7 @@ else if (reference_ == "UNRESTRICTED") {
     rms_t2AB = 0.0;
     rms_t2AB = global_dpd_->buf4_dot_self(&R);
     global_dpd_->buf4_close(&R);
-    rms_t2AB = sqrt(rms_t2AA) / nElements;
+    rms_t2AB = std::sqrt(rms_t2AA) / nElements;
 
     // Reset
     global_dpd_->buf4_copy(&Tnew, PSIF_OCC_DPD, "T2_2 <Oo|Vv>");
