@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -36,8 +36,6 @@
 #include "defines.h"
 
 
-using namespace std;
-
 namespace psi{ namespace occwave{
 
 void OCCWave::trans_ints_uhf()
@@ -52,52 +50,52 @@ void OCCWave::trans_ints_uhf()
 
     // Trans (OO|OO)
     timer_on("Trans (OO|OO)");
-    ints->transform_tei(MOSpace::occ, MOSpace::occ, MOSpace::occ, MOSpace::occ, IntegralTransform::MakeAndKeep);
+    ints->transform_tei(MOSpace::occ, MOSpace::occ, MOSpace::occ, MOSpace::occ, IntegralTransform::HalfTrans::MakeAndKeep);
     timer_off("Trans (OO|OO)");
 
     // Trans (OO|OV)
     timer_on("Trans (OO|OV)");
-    ints->transform_tei(MOSpace::occ, MOSpace::occ, MOSpace::occ, MOSpace::vir, IntegralTransform::ReadAndKeep);
+    ints->transform_tei(MOSpace::occ, MOSpace::occ, MOSpace::occ, MOSpace::vir, IntegralTransform::HalfTrans::ReadAndKeep);
     timer_off("Trans (OO|OV)");
 
     // Trans (OO|VV)
     timer_on("Trans (OO|VV)");
-    ints->transform_tei(MOSpace::occ, MOSpace::occ, MOSpace::vir, MOSpace::vir, IntegralTransform::ReadAndNuke);
+    ints->transform_tei(MOSpace::occ, MOSpace::occ, MOSpace::vir, MOSpace::vir, IntegralTransform::HalfTrans::ReadAndNuke);
     timer_off("Trans (OO|VV)");
 
     // Trans (OV|OO)
     timer_on("Trans (OV|OO)");
-    ints->transform_tei(MOSpace::occ, MOSpace::vir, MOSpace::occ, MOSpace::occ, IntegralTransform::MakeAndKeep);
+    ints->transform_tei(MOSpace::occ, MOSpace::vir, MOSpace::occ, MOSpace::occ, IntegralTransform::HalfTrans::MakeAndKeep);
     timer_off("Trans (OV|OO)");
 
     // Trans (OV|OV)
     timer_on("Trans (OV|OV)");
-    ints->transform_tei(MOSpace::occ, MOSpace::vir, MOSpace::occ, MOSpace::vir, IntegralTransform::ReadAndKeep);
+    ints->transform_tei(MOSpace::occ, MOSpace::vir, MOSpace::occ, MOSpace::vir, IntegralTransform::HalfTrans::ReadAndKeep);
     timer_off("Trans (OV|OV)");
 
     // Trans (OV|VV)
     timer_on("Trans (OV|VV)");
-    ints->transform_tei(MOSpace::occ, MOSpace::vir, MOSpace::vir, MOSpace::vir, IntegralTransform::ReadAndNuke);
+    ints->transform_tei(MOSpace::occ, MOSpace::vir, MOSpace::vir, MOSpace::vir, IntegralTransform::HalfTrans::ReadAndNuke);
     timer_off("Trans (OV|VV)");
 
     // Trans (VV|OO)
     timer_on("Trans (VV|OO)");
-    ints->transform_tei(MOSpace::vir, MOSpace::vir, MOSpace::occ, MOSpace::occ, IntegralTransform::MakeAndKeep);
+    ints->transform_tei(MOSpace::vir, MOSpace::vir, MOSpace::occ, MOSpace::occ, IntegralTransform::HalfTrans::MakeAndKeep);
     timer_off("Trans (VV|OO)");
 
 
     // Trans (VV|OV)
     timer_on("Trans (VV|OV)");
     if (wfn_type_ == "OMP2" && ekt_ea_ == "FALSE") {
-        ints->transform_tei(MOSpace::vir, MOSpace::vir, MOSpace::occ, MOSpace::vir, IntegralTransform::ReadAndNuke);
+        ints->transform_tei(MOSpace::vir, MOSpace::vir, MOSpace::occ, MOSpace::vir, IntegralTransform::HalfTrans::ReadAndNuke);
     }
-    else ints->transform_tei(MOSpace::vir, MOSpace::vir, MOSpace::occ, MOSpace::vir, IntegralTransform::ReadAndKeep);
+    else ints->transform_tei(MOSpace::vir, MOSpace::vir, MOSpace::occ, MOSpace::vir, IntegralTransform::HalfTrans::ReadAndKeep);
     timer_off("Trans (VV|OV)");
 
 if (wfn_type_ != "OMP2" || ekt_ea_ == "TRUE") {
     // Trans (VV|VV)
     timer_on("Trans (VV|VV)");
-    ints->transform_tei(MOSpace::vir, MOSpace::vir, MOSpace::vir, MOSpace::vir, IntegralTransform::ReadAndNuke);
+    ints->transform_tei(MOSpace::vir, MOSpace::vir, MOSpace::vir, MOSpace::vir, IntegralTransform::HalfTrans::ReadAndNuke);
     timer_off("Trans (VV|VV)");
 }
 
