@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -39,7 +39,8 @@
 #include "linear_algebra.h"
 #include "atom_data.h"
 #include "psi4/optking/physconst.h"
-#include "psi4/libparallel/ParallelPrinter.h"
+#include "psi4/libpsi4util/PsiOutStream.h"
+#include "psi4/libpsi4util/process.h"
 #include "print.h"
 #define EXTERN
 #include "globals.h"
@@ -55,8 +56,6 @@
 
 namespace opt {
 
-using namespace std;
-
 // if allocate_fragment, then read the number of atoms and allocate memory for
 //   a fragment of that size.  Otherwise, this is an empty constructor.
 
