@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -40,6 +40,7 @@
 #include "v3d.h"
 #include "atom_data.h"
 #include "psi4/optking/physconst.h"
+#include "psi4/libpsi4util/process.h"
 #include "cov_radii.h"
 
 #include "print.h"
@@ -194,7 +195,7 @@ void MOLECULE::fragmentize(void) {
           for (std::size_t f1_atom=0; f1_atom<fatoms[f1].size(); ++f1_atom) {
             for (std::size_t f2_atom=0; f2_atom<fatoms[f2].size(); ++f2_atom) {
               tval = v3d_dist(geom[fatoms[f1][f1_atom]], geom[fatoms[f2][f2_atom]]);
-              if (fabs(tval - min) < 1.0e-14) {
+              if (std::fabs(tval - min) < 1.0e-14) {
                 i = fatoms[f1][f1_atom];
                 j = fatoms[f2][f2_atom];
                 fragments[0]->connect(i,j);
@@ -298,7 +299,7 @@ void MOLECULE::add_interfragment(void) {
   double tval, min;
   int ndA, ndB; // num of reference atoms on each fragment
   char error_msg[100];
-  double **weight_A=NULL, **weight_B=NULL;
+  double **weight_A=nullptr, **weight_B=nullptr;
   FRAG *Afrag, *Bfrag;
   if (fragments.size() == 1) return;
   std::vector<std::vector<std::vector<int> > > frag_ref_atoms = Opt_params.frag_ref_atoms;
@@ -519,7 +520,7 @@ void MOLECULE::add_interfragment(void) {
       else
         ndB = 3;
 
-      INTERFRAG * one_IF = new INTERFRAG(Afrag, Bfrag, frag_i, frag_i+1, NULL, NULL, ndA, ndB, true);
+      INTERFRAG * one_IF = new INTERFRAG(Afrag, Bfrag, frag_i, frag_i+1, nullptr, nullptr, ndA, ndB, true);
       interfragments.push_back(one_IF);
     }
 
