@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -58,8 +58,6 @@ namespace psi{
     extern MemoryManager* memory_manager;
 
 
-using namespace std;
-
 /**
  * Allocate the effective Hamiltonian matrices and eigenvectors
  * @todo wrap the current operations in an init() function
@@ -80,7 +78,7 @@ CCManyBody::CCManyBody(SharedWavefunction ref_wfn, Options &options):
   norm_amps = 0.0;
   delta_t1_amps = 0.0;
   delta_t2_amps = 0.0;
-  d3_ooo = d3_ooO = d3_oOO = d3_OOO =  d3_vvv = d3_vvV = d3_vVV = d3_VVV = NULL;
+  d3_ooo = d3_ooO = d3_oOO = d3_OOO =  d3_vvv = d3_vvV = d3_vVV = d3_VVV = nullptr;
 }
 
 /**
@@ -387,9 +385,9 @@ void CCManyBody::print_eigensystem(int ndets, double** Heff,double*& eigenvector
 
   std::vector<std::pair<double,int> > eigenvector_index_pair;
   for(int i = 0; i < ndets; ++i){
-    eigenvector_index_pair.push_back(make_pair(eigenvector[i]*eigenvector[i],i));
+    eigenvector_index_pair.push_back(std::make_pair(eigenvector[i]*eigenvector[i],i));
   }
-  sort(eigenvector_index_pair.begin(),eigenvector_index_pair.end(),greater<pair<double,int> >());
+  sort(eigenvector_index_pair.begin(),eigenvector_index_pair.end(),std::greater<std::pair<double,int> >());
   int max_size_list = std::min(10,static_cast<int>(eigenvector_index_pair.size()));
   outfile->Printf("\n\n  Most important determinants in the wave function");
   outfile->Printf("\n\n  determinant  eigenvector   eigenvector^2\n");
@@ -498,7 +496,7 @@ double CCManyBody::diagonalize_Heff(int root,int ndets, double** Heff,double*& r
     energy = real[root];
     // Eliminate the triplet solution if required
     if((options_.get_bool("LOCK_SINGLET")==1)&&(ndets==4)){
-      if((fabs(right_eigenvector[0])<5.0e-2)&& (fabs(right_eigenvector[3])<5.0e-2) && ((right_eigenvector[1]/right_eigenvector[2])<-0.5)){
+      if((std::fabs(right_eigenvector[0])<5.0e-2)&& (std::fabs(right_eigenvector[3])<5.0e-2) && ((right_eigenvector[1]/right_eigenvector[2])<-0.5)){
         outfile->Printf("\n\tSelecting root %d since original root is a triplet\n",root+1);
         root++;
         for(int k=0;k<ndets;k++){
@@ -555,7 +553,7 @@ void CCManyBody::sort_eigensystem(int ndets,double*& real,double*& imaginary,dou
 {
   std::vector<std::pair<double, int> > pairs;
   for(int i=0;i<ndets;i++)
-    pairs.push_back(make_pair(real[i],i));
+    pairs.push_back(std::make_pair(real[i],i));
   sort(pairs.begin(),pairs.end());
 
   double*  tempv;
