@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -31,6 +31,7 @@
 
 #include "psi4/libmoinfo/libmoinfo.h"
 #include "psi4/libciomr/libciomr.h"
+#include "psi4/libpsi4util/PsiOutStream.h"
 
 #include "index.h"
 #include "matrix.h"
@@ -39,8 +40,6 @@ namespace psi{
 
     namespace psimrcc{
 
-using namespace std;
-
 
 //////////////////////////////////////////////////////////////////////////////
 //
