@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -207,7 +207,7 @@ void MRCCSD_T::compute_ooo_triples_restricted()
       double oldE  = 1.0;
       double newE  = 0.0;
       tot_triplets++;
-      while(fabs(oldE-newE) > threshold){
+      while(std::fabs(oldE-newE) > threshold){
         tot_cycles++;
         cycle++;
         oldE = newE;
@@ -357,7 +357,7 @@ void MRCCSD_T::compute_OOO_triples_restricted()
       int    cycle = 0;
       double oldE  = 1.0;
       double newE  = 0.0;
-      while(fabs(oldE-newE) > threshold){
+      while(std::fabs(oldE-newE) > threshold){
         cycle++;
         oldE = newE;
         newE = 0.0;
@@ -516,7 +516,7 @@ void MRCCSD_T::compute_ooO_triples_restricted()
       int    cycle = 0;
       double oldE  = 1.0;
       double newE  = 0.0;
-      while(fabs(oldE-newE) > threshold){
+      while(std::fabs(oldE-newE) > threshold){
         cycle++;
         oldE = newE;
         newE = 0.0;
@@ -681,7 +681,7 @@ void MRCCSD_T::compute_oOO_triples_restricted()
       int    cycle = 0;
       double oldE  = 1.0;
       double newE  = 0.0;
-      while(fabs(oldE-newE) > threshold){
+      while(std::fabs(oldE-newE) > threshold){
         cycle++;
         oldE = newE;
         newE = 0.0;
