@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2017 The Psi4 Developers.
+ * Copyright (c) 2007-2018 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -30,8 +30,12 @@
 #define SAPTENERGY_H
 
 #include "psi4/psi4-dec.h"
+#include "psi4/libmints/typedefs.h"
 
-namespace psi { namespace sapt {
+namespace psi {
+class Options;
+
+namespace sapt {
 
 PsiReturnType sapt(SharedWavefunction Dimer, SharedWavefunction MonomerA,
                    SharedWavefunction MonomerB, Options & options);
