@@ -5,7 +5,7 @@
 #
 # Psi4: an open-source quantum chemistry software package
 #
-# Copyright (c) 2007-2017 The Psi4 Developers.
+# Copyright (c) 2007-2018 The Psi4 Developers.
 #
 # The copyrights for code used from other parties are included in
 # the corresponding files.
@@ -139,7 +139,7 @@ sub do_tests
     if ($jobtype eq "energy" || 
         $jobtype eq "gradient" || 
         $jobtype eq "hessian" || 
-        $jobtype eq "property") {
+        $jobtype eq "properties") {
       
       $fail |= compare_nuc();
       $fail |= compare_scf_energy();  # We always have SCF energies?
@@ -177,7 +177,7 @@ sub do_tests
           if ($wfn eq "SCF+D")  { $fail |= compare_scf_d_energy(); last SWITCH2; }
       }
 
-     if ($jobtype eq "property") {
+     if ($jobtype eq "properties") {
        if ($wfn eq "CCSD" || $wfn eq "ccsd" || 
            $wfn eq "CC2" || $wfn eq "cc2") {
           $fail |= compare_cclambda_overlap($wfn);
@@ -3199,8 +3199,8 @@ sub get_calctype_string
       @data = split(/\'/, $line);
       $wfn = $data[1];
     }
-    elsif ($line =~ m/property\s*\(/) {
-      $jobtype = "property";
+    elsif ($line =~ m/properties\s*\(/) {
+      $jobtype = "properties";
       @data = split(/\'/, $line);
       $wfn = $data[1];
     }
