@@ -1,6 +1,8 @@
 import psi4
 import pytest
 
+from addons import *
+
 
 using_ambit = pytest.mark.skipif(psi4.addons("ambit") is False,
                                 reason="Psi4 not compiled with ambit. Rebuild with -DENABLE_ambit")
@@ -28,6 +30,14 @@ using_simint = pytest.mark.skipif(psi4.addons("simint") is False,
                                 reason="Psi4 not compiled with simint. Rebuild with -DENABLE_simint")
 using_v2rdm_casscf = pytest.mark.skipif(psi4.addons("v2rdm_casscf") is False,
                                 reason="Psi4 not detecting plugin v2rdm_casscf. Build plugin if necessary and add to envvar PYTHONPATH")
+using_gpu_dfcc = pytest.mark.skipif(psi4.addons("gpu_dfcc") is False,
+                                reason="Psi4 not detecting plugin gpu_dfcc. Build plugin if necessary and add to envvar PYTHONPATH")
+using_forte = pytest.mark.skipif(psi4.addons("forte") is False,
+                                reason="Psi4 not detecting plugin forte. Build plugin if necessary and add to envvar PYTHONPATH")
+using_snsmp2 = pytest.mark.skipif(psi4.addons("snsmp2") is False,
+                                reason="Psi4 not detecting plugin snsmp2. Build plugin if necessary and add to envvar PYTHONPATH (or rebuild Psi with -DENABLE_snsmp2)")
+using_resp = pytest.mark.skipif(psi4.addons("resp") is False,
+                                reason="Psi4 not detecting plugin resp. Build plugin if necessary and add to envvar PYTHONPATH (or rebuild Psi with -DENABLE_resp)")
 
 
 @using_gdma
@@ -633,7 +643,7 @@ def test_json():
     json_data = {}
     json_data["molecule"] = """He 0 0 0\n--\nHe 0 0 1"""
     json_data["driver"] = "gradient"
-    json_data["args"] = 'SCF'
+    json_data["method"] = 'SCF'
     json_data["kwargs"] = {}
     json_data["options"] = {"BASIS": "STO-3G"}
     json_data["return_output"] = True
@@ -655,7 +665,7 @@ def test_json():
     assert psi4.compare_integers(True, return_wfn, "Immutable input")
 
     with open("pytest_output.dat", "w") as f:
-        f.write(json_data["output"])
+        f.write(json_data["raw_output"])
 
 
 @using_cfour
@@ -722,14 +732,13 @@ def test_v2rdm_casscf():
       'restricted_docc': [ 2, 0, 0, 0, 0, 2, 0, 0 ],
       'active': [ 1, 0, 1, 1, 0, 1, 1, 1 ],
     })
-    ##psi4.set_module_options('v2rdm_casscf', {
-    psi4.set_options({
-    #  'positivity': 'dqg',
+    psi4.set_module_options('v2rdm_casscf', {
+      'positivity': 'dqg',
       'r_convergence': 1e-5,
       'e_convergence': 1e-6,
       'maxiter': 20000,
-    #  #'orbopt_frequency': 1000,
-    #  #'mu_update_frequency': 1000,
+      #'orbopt_frequency': 1000,
+      #'mu_update_frequency': 1000,
     })
 
     psi4.activate(n2)
@@ -743,8 +752,45 @@ def test_v2rdm_casscf():
     assert psi4.compare_values(refscf, psi4.get_variable("SCF TOTAL ENERGY"), 8, "SCF total energy")
     assert psi4.compare_values(refv2rdm, psi4.get_variable("CURRENT ENERGY"), 5, "v2RDM-CASSCF total energy")
 
-@using_gcp
+
+@hardware_nvidia_gpu
+@using_gpu_dfcc
+def test_gpu_dfcc():
+    """gpu_dfcc/tests/gpu_dfcc1"""
+    #! cc-pvdz (H2O)2 Test DF-CCSD vs GPU-DF-CCSD
+    
+    import gpu_dfcc 
+ 
+    H20 = psi4.geometry("""
+               O          0.000000000000     0.000000000000    -0.068516219310   
+               H          0.000000000000    -0.790689573744     0.543701060724   
+               H          0.000000000000     0.790689573744     0.543701060724   
+    """)
+    
+    psi4.set_memory(32000000000)
+    psi4.set_options({
+      'cc_timings': False,
+      'num_gpus': 1,
+      'cc_type': 'df',
+      'df_basis_cc':  'aug-cc-pvdz-ri',
+      'df_basis_scf': 'aug-cc-pvdz-jkfit',
+      'basis':        'aug-cc-pvdz',
+      'freeze_core': 'true',
+      'e_convergence': 1e-8,
+      'd_convergence': 1e-8,
+      'r_convergence': 1e-8,
+      'scf_type': 'df',
+      'maxiter': 30})
+    psi4.set_num_threads(2)
+    en_dfcc     = psi4.energy('ccsd', molecule=H20)
+    en_gpu_dfcc = psi4.energy('gpu-df-ccsd', molecule=H20)
+    
+    assert psi4.compare_values(en_gpu_dfcc, en_dfcc, 8, "CCSD total energy")
+    
+    
+    
 @using_dftd3
+@using_gcp
 def test_grimme_3c():
 
     s16di = psi4.geometry("""
@@ -791,3 +837,133 @@ def test_dkh():
 
     assert psi4.compare_values(-128.66891610, e, 6, '2nd order vs Molpro')
 
+@using_ambit
+@using_forte
+def disabled_test_forte():
+    """aci-10: Perform aci on benzyne"""
+
+    import forte
+
+    refscf    = -229.20378006852584
+    refaci    = -229.359450812283
+    refacipt2 = -229.360444943286
+
+    mbenzyne = psi4.geometry("""
+      0 1
+       C   0.0000000000  -2.5451795941   0.0000000000
+       C   0.0000000000   2.5451795941   0.0000000000
+       C  -2.2828001669  -1.3508352528   0.0000000000
+       C   2.2828001669  -1.3508352528   0.0000000000
+       C   2.2828001669   1.3508352528   0.0000000000
+       C  -2.2828001669   1.3508352528   0.0000000000
+       H  -4.0782187459  -2.3208602146   0.0000000000
+       H   4.0782187459  -2.3208602146   0.0000000000
+       H   4.0782187459   2.3208602146   0.0000000000
+       H  -4.0782187459   2.3208602146   0.0000000000
+
+      units bohr
+    """)
+
+    psi4.set_options({
+       'basis': 'DZ',
+       'df_basis_mp2': 'cc-pvdz-ri',
+       'reference': 'uhf',
+       'scf_type': 'pk',
+       'd_convergence': 10,
+       'e_convergence': 12,
+       'guess': 'gwh',
+    })
+
+    psi4.set_module_options("FORTE", {
+      'root_sym': 0,
+      'frozen_docc':     [2,1,0,0,0,0,2,1],
+      'restricted_docc': [3,2,0,0,0,0,2,3],
+      'active':          [1,0,1,2,1,2,1,0],
+      'multiplicity': 1,
+      'aci_nroot': 1,
+      'job_type': 'aci',
+      'sigma': 0.001,
+      'aci_select_type': 'aimed_energy',
+      'aci_spin_projection': 1,
+      'aci_enforce_spin_complete': True,
+      'aci_add_aimed_degenerate': False,
+      'aci_project_out_spin_contaminants': False,
+      'diag_algorithm': 'full',
+      'aci_quiet_mode': True,
+    })
+
+    scf = psi4.energy('scf')
+    assert psi4.compare_values(refscf, scf,10,"SCF Energy")
+
+    psi4.energy('forte')
+    assert psi4.compare_values(refaci, psi4.get_variable("ACI ENERGY"),10,"ACI energy")
+    assert psi4.compare_values(refacipt2, psi4.get_variable("ACI+PT2 ENERGY"),8,"ACI+PT2 energy")
+
+
+@using_snsmp2
+def test_snsmp2():
+    """snsmp2/he-he"""
+
+    HeHe = psi4.geometry("""
+    0 1
+    He 0 0 0
+    --
+    He 2 0 0
+    """)
+
+    e = psi4.energy('sns-mp2')
+
+    assert psi4.compare_values(0.00176708227, psi4.get_variable('SNS-MP2 TOTAL ENERGY'), 5, "SNS-MP2 IE [Eh]")
+
+
+@using_resp
+def test_resp():
+    """resp/tests/test_resp_1"""
+    import resp
+    import numpy as np
+
+    mol = psi4.geometry(""" C   1.45051389  -0.06628932   0.00000000
+     H   1.75521613  -0.62865986  -0.87500146
+     H   1.75521613  -0.62865986   0.87500146
+     H   1.92173244   0.90485897   0.00000000
+     C  -0.04233122   0.09849378   0.00000000
+     O  -0.67064817  -1.07620915   0.00000000
+     H  -1.60837259  -0.91016601   0.00000000
+     O  -0.62675864   1.13160510   0.00000000""")
+    mol.update_geometry()
+
+    options = {'N_VDW_LAYERS'       : 4,
+               'VDW_SCALE_FACTOR'   : 1.4,
+               'VDW_INCREMENT'      : 0.2,
+               'VDW_POINT_DENSITY'  : 1.0,
+               'resp_a'             : 0.0005,
+               'RESP_B'             : 0.1,
+               }
+
+    # Call for first stage fit
+    charges1 = resp.resp([mol], [options])
+
+    # Reference charges are generated by the R.E.D.-III.5 tools
+    # with GAMESS as the quantum chemistry package
+    reference_charges1 = np.array([-0.294974,  0.107114,  0.107114,  0.084795,
+                                    0.803999, -0.661279,  0.453270, -0.600039])
+    assert np.allclose(charges1[0][1], reference_charges1, atol=5e-4)
+
+    options['resp_a'] = 0.001
+
+    # Add constraint for atoms fixed in second stage fit
+    constraint_charge = []
+    for i in range(4, 8):
+        constraint_charge.append([charges1[0][1][i], [i+1]])
+    options['constraint_charge'] = constraint_charge
+    options['constraint_group'] = [[2, 3, 4]]
+    options['grid'] = '1_%s_grid.dat' %mol.name()
+    options['esp'] = '1_%s_grid_esp.dat' %mol.name()
+    mol.set_name('stage2')
+
+    # Call for second stage fit
+    charges2 = resp.resp([mol], [options])
+
+    reference_charges2 = np.array([-0.290893,  0.098314,  0.098314,  0.098314,
+                                   0.803999, -0.661279,  0.453270, -0.600039])
+    assert np.allclose(charges2[0][1], reference_charges2, atol=5e-4)
